*===================================================================;
*  Title:  PROGRAM 1 ASSIGN AHRQ PEDIATRIC QUALITY INDICATORS
*          TO INPATIENT RECORDS
*
*  Description:
*         ASSIGNS THE OUTCOME OF INTEREST AND POPULATION AT RISK
*         INDICATORS TO INPATIENT RECORDS. 
*
*          >>>  VERSION 3.2, March 2008 <<<
*
*  USER NOTE:  Make sure you have created the format library
*              using PDFMTS.SAS BEFORE running this program.
* 
*===================================================================;
FILENAME CONTROL "C:\PATHNAME\CONTROL_PDI.SAS"; *<==USER MUST modify;

%INCLUDE CONTROL;

 TITLE2 'PROGRAM 1';
 TITLE3 'AHRQ PEDIATRIC QUALITY INDICATORS: ASSIGN PDIS TO INPATIENT DATA';

 * -------------------------------------------------------------- ;
 * --- PEDIATRIC QUALITY INDICATOR (PDI) NAMING CONVENTION:           --- ;
 * --- THE FIRST LETTER IDENTIFIES THE PEDIATRIC INDICATOR    --- ;
 * --- AS ONE OF THE FOLLOWING:
                (O) OBSERVED RATES
                (E) EXPECTED RATES
                (R) RISK-ADJUSTED RATES
                (S) SMOOTHED RATES
                (T) NUMERATOR ("TOP")
                (P) POPULATION ("POP")
 * --- THE SECOND LETTER IDENTIFIES THE PDI AS A PROVIDER (P) --- ;
 * --- OR AN AREA (A) LEVEL INDICATOR.  THE NEXT TWO          --- ;
 * --- CHARACTERS ARE ALWAYS 'PD'. THE LAST TWO DIGITS ARE    --- ;
 * --- THE INDICATOR NUMBER (WITHIN THAT SUBTYPE).            --- ;
 * -------------------------------------------------------------- ;

 %MACRO ADDPRDAY; 
    %IF &PRDAY EQ 1 %THEN PRDAY1-PRDAY&NPR. ;
 %MEND;

 %MACRO ADDPOA; 
    %IF &POAFG EQ 1 %THEN DXATADMIT1-DXATADMIT&NDX.;
 %MEND;

 DATA   OUT1.&OUTFILE1. 
    (KEEP=KEY HOSPID DRG MDC AGE AGEDAY DISP LOS ATYPE ASOURCE MAREA YEAR DQTR
          PAGECAT AGEDCAT POPCAT BWHTCAT SEXCAT RACECAT PAYCAT
          TPPD01-TPPD13 TAPD14-TAPD18 TAPD90-TAPD92
          GPPD01 GPPD02 GPPD08 GPPD10 GPPD11 GPPD12
          HPPD01 HPPD06 HPPD10 MULTIPLE MDX4D STRCABN
          CCS4   CCS6   CCS21  CCS33  CCS35  CCS38  CCS39  CCS41  CCS42  CCS48
          CCS51  CCS52  CCS56  CCS57  CCS58  CCS62  CCS63  CCS65  CCS67  CCS81
          CCS82  CCS83  CCS85  CCS95  CCS96  CCS98  CCS103 CCS105 CCS106 CCS108
          CCS133 CCS138 CCS151 CCS158 CCS161 CCS210 CCS211 CCS213 CCS214 CCS215
          CCS216 CCS217 CCS219 CCS221 CCS224 CCS227 DISCWT);
 SET   IN1.&INFILE1. 
      (KEEP=KEY DRG MDC SEX AGE AGEDAY RACE PSTCO PAY1 HOSPID DISP LOS ASOURCE ATYPE
            DX1-DX&NDX. PR1-PR&NPR. %ADDPRDAY YEAR DQTR %ADDPOA DISCWT);
 
 * -------------------------------------------------------------- ;
 * --- AREA, DIAGNOSIS AND PROCEDURE MACROS --------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO CTY2MA;
    %IF &MALEVL EQ 0 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='FIPS STATE COUNTY CODE';
        MAREA = FIPSTCO;
    %END;
    %ELSE %IF &MALEVL EQ 1 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='MODIFIED FIPS';
        MAREA = INPUT(PUT(FIPSTCO,$M1AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 2 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='OMB 1999 METRO AREA';
        MAREA = INPUT(PUT(FIPSTCO,$M2AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 3 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='OMB 2003 METRO AREA';
        MAREA = INPUT(PUT(FIPSTCO,$M3AREA.),$5.);
    %END;
 %MEND;

 %MACRO MDX(FMT);

 (%DO I = 1 %TO &NDX.-1;
  (PUT(DX&I.,&FMT.) = '1') OR
  %END;
  (PUT(DX&NDX.,&FMT.) = '1'))

 %MEND;

 %MACRO MDX1(FMT);

 ((PUT(DX1,&FMT.) = '1') %EXCPOA)

 %MEND;

 %MACRO MDX1P(FMT);

 (PUT(DX1,&FMT.) = '1')

 %MEND;

 %MACRO MDX2(FMT);

 (%DO I = 2 %TO &NDX.-1;
  (PUT(DX&I.,&FMT.) = '1') OR
  %END;
  (PUT(DX&NDX.,&FMT.) = '1'))

 %MEND;

 %MACRO EXCPOA;
    %IF &POAFG. EQ 1 %THEN %DO;
       OR
       (%DO I = 2 %TO &NDX.-1;
        (PUT(DX&I.,&FMT.) = '1' AND DXATADMIT&I. = 1) OR
        %END;
        (PUT(DX&NDX.,&FMT.) = '1' AND DXATADMIT&NDX. = 1))
    %END;
 %MEND;

 %MACRO MDR(FMT);

 (PUT(PUT(DRG,Z3.),&FMT.) = '1')

 %MEND;

 %MACRO MPR(FMT);

 (%DO I = 1 %TO &NPR.-1;
  (PUT(PR&I.,&FMT.) = '1') OR
  %END;
  (PUT(PR&NPR.,&FMT.) = '1'))

 %MEND;

 %MACRO MPR1(FMT);

 (PUT(PR1,&FMT.) = '1')

 %MEND;

 %MACRO MPR2(FMT);

 (%DO I = 2 %TO &NPR.-1;
  (PUT(PR&I.,&FMT.) = '1') OR
  %END;
  (PUT(PR&NPR.,&FMT.) = '1'))

 %MEND;

 %MACRO MPRCNT(FMT);

    MPRCNT = 0; 
    %DO I = 1 %TO &NPR.;
       IF PUT(PR&I.,&FMT.) = '1'    AND
          PUT(PR&I.,$ORPROC.) = '1' THEN MPRCNT + 1;
    %END;

 %MEND;

 %MACRO MPRDAY(FMT);

    MPRDAY = .;
    %DO I = 1 %TO &NPR.;
       IF PUT(PR&I.,&FMT.) = '1' AND PRDAY&I. NE . THEN DO;
          IF MPRDAY = . THEN MPRDAY = PRDAY&I;
          ELSE IF MPRDAY > PRDAY&I. THEN MPRDAY = PRDAY&I;
       END;
    %END;

 %MEND;

%MACRO ORCNT;

    ORCNT = 0;
    %DO I = 1 %TO &NPR.;
       IF(PUT(PR&I.,$ORPROC.) = '1') OR (PR&I. IN ('640') AND AGEDAY>28) THEN ORCNT + 1;
    %END;

%MEND;

%MACRO ORDAY(FMT);

    ORDAY = .;
    %DO I = 1 %TO &NPR.;
       IF ((PUT(PR&I.,$ORPROC.) = '1') OR
	   (PR&I. IN ('640') AND AGEDAY>28)) AND
          PUT(PR&I.,&FMT.)    = '0' THEN DO;
          IF PRDAY&I. NE . THEN DO;
             IF ORDAY = . THEN ORDAY = PRDAY&I;
             ELSE IF ORDAY > PRDAY&I. THEN ORDAY = PRDAY&I;
          END;
       END;
    %END;

%MEND;

%MACRO PRCLASS;

    PRCLS1 = 0; PRCLS2 = 0; PRCLS3 = 0; PRCLS4 = 0; 
    PRCIDX = 0;

    %DO I = 1 %TO &NPR.;
       PRCIDX = PUT(PR&I.,$PRCLASS.);
	 IF PR&I. IN ('640') AND 0 <= AGEDAY <= 28 THEN PRCLS2 + 1;
       ELSE IF PRCIDX = 1 THEN PRCLS1 + 1;
       ELSE IF PRCIDX = 2 THEN PRCLS2 + 1;
       ELSE IF PRCIDX = 3 THEN PRCLS3 + 1;
       ELSE IF PRCIDX = 4 THEN PRCLS4 + 1;
    %END;

%MEND;

%MACRO DOLPOA;

   %IF &POAFG EQ 1 %THEN 
   IF DXATADMIT&I. ~= 0 THEN;

%MEND;

%MACRO CCS;

   %DO I = 2 %TO &NDX.;
      CCSIDX = 0;
      %DOLPOA CCSIDX = PUT(DX&I.,$CCS.);
      IF CCSIDX > 0 THEN DO;
         DO J = 1 TO 46;
            IF CCSARRY1(J) = CCSIDX THEN CCSARRY2(J) = 1;
         END;
      END;
   %END;

%MEND;

%MACRO PRPDCNT1;

    MPR1P = 0; MDX2D = 0; MDX3D = 0; MDX4D = 0; 

    %DO I = 1 %TO &NPR.;
       IF PUT(PR&I.,$PRPED1P.) = '1' THEN MPR1P + 1;
    %END;

    %DO I = 1 %TO &NDX.;
       IF PUT(DX&I.,$PRPED2D.) = '1' THEN MDX2D + 1;
       IF PUT(DX&I.,$PRPED3D.) = '1' THEN MDX3D + 1;
       IF PUT(DX&I.,$PRPED4D.) = '1' THEN MDX4D + 1;
    %END;

 %MEND;

 %MACRO PRPDCNT2;

    MPR3AP = 0; MPR3BP = 0; MPR3CP = 0; MPR3DP = 0; 
    MPR3EP = 0; MPR3FP = 0; MPR4P = 0;  MPR5P = 0;  
    MPR6P = 0;  MPR7P = 0;

    %DO I = 1 %TO &NPR.;
       IF (MPR1P > 0 OR MDX2D > 0) AND PUT(PR&I.,$PRPED2P.) = '1' 
       THEN MPR1P + 1;
       IF PUT(PR&I.,$PRPD3AP.) = '1' 
       THEN MPR3AP + 1;
       IF PUT(PR&I.,$PRPD3BP.) = '1' 
       THEN MPR3BP + 1;
       IF PUT(PR&I.,$PRPD3CP.) = '1' 
       THEN MPR3CP + 1;
       IF PUT(PR&I.,$PRPD3DP.) = '1' 
       THEN MPR3DP + 1;
       IF PUT(PR&I.,$PRPD3EP.) = '1' 
       THEN MPR3EP + 1;
       IF PUT(PR&I.,$PRPD3FP.) = '1' 
       THEN MPR3FP + 1;
       IF PUT(PR&I.,$PRPED4P.) = '1' 
       THEN MPR4P + 1;      
       IF PUT(PR&I.,$PRPED5P.) = '1' 
       THEN MPR5P + 1;      
       IF PUT(PR&I.,$PRPED6P.) = '1' 
       THEN MPR6P + 1;
       IF PUT(PR&I.,$PRPED7P.) = '1' 
       THEN MPR7P + 1;
   %END;

%MEND;

 * -------------------------------------------------------------- ;
 * --- DELETE NON-PEDIATRIC RECORDS AND RECORDS W MISSING VALUES  ;
 * -------------------------------------------------------------- ;
 IF SEX LE 0 THEN DELETE;
 IF AGE LT 0 THEN DELETE;
 IF AGE GE 18 OR MDC IN (14) THEN DELETE;
 IF PUT(PUT(DRG,Z3.),$ADULTDR.) = '1' THEN DELETE;

 * -------------------------------------------------------------- ;
 * --- SET MISSING DISCHARGE WEIGHT TO ONE              --------- ;
 * -------------------------------------------------------------- ;
 IF DISCWT LT 0 THEN DISCWT = 1;

 * -------------------------------------------------------------- ;
 * --- DEFINE FIPS STATE AND COUNTY CODES             ----------- ;
 * -------------------------------------------------------------- ;
 ATTRIB FIPSTCO LENGTH=$5
   LABEL='FIPS STATE COUNTY CODE';
 FIPSTCO = PUT(PSTCO,Z5.);

 ATTRIB FIPST LENGTH=$2
   LABEL='STATE FIPS CODE';
 FIPST = SUBSTR(FIPSTCO,1,2);

 * -------------------------------------------------------------- ;
 * --- CONDITIONALLY DEFINE METRO AREAS (MA) FROM COUNTY CODES -- ;
 * -------------------------------------------------------------- ;
 %CTY2MA

 * -------------------------------------------------------------- ;
 * --- MS-DRG                                                  -- ;
 * -------------------------------------------------------------- ;
 IF YEAR IN (2008) OR (YEAR IN (2007) AND DQTR IN (4)) THEN
    DRG = PUT(PUT(DRG,Z3.),$MSDRG.);

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: PAYER CATEGORY ------------------------ ;
 * -------------------------------------------------------------- ;
 ATTRIB PAYCAT LENGTH=3
   LABEL='PATIENT PRIMARY PAYER';

 SELECT (PAY1);
   WHEN (1)  PAYCAT = 1;
   WHEN (2)  PAYCAT = 2;
   WHEN (3)  PAYCAT = 3;
   WHEN (4)  PAYCAT = 4;
   WHEN (5)  PAYCAT = 5;
   OTHERWISE PAYCAT = 6;
 END; * SELECT PAY1 ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: RACE CATEGORY ------------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB RACECAT LENGTH=3
   LABEL='PATIENT RACE/ETHNICITY';

 SELECT (RACE);
   WHEN (1)  RACECAT = 1;
   WHEN (2)  RACECAT = 2;
   WHEN (3)  RACECAT = 3;
   WHEN (4)  RACECAT = 4;
   WHEN (5)  RACECAT = 5;
   OTHERWISE RACECAT = 6;
 END; * SELECT RACE ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: AGE CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB PAGECAT LENGTH=3
   LABEL='PATIENT AGE';

 SELECT;
   WHEN (0  <= AGE <  1)  PAGECAT = 1;
   WHEN (1  <= AGE <  3)  PAGECAT = 2;
   WHEN (3  <= AGE <  6)  PAGECAT = 3;
   WHEN (6  <= AGE < 13)  PAGECAT = 4;
   WHEN (13 <= AGE < 18)  PAGECAT = 5;
 END; * SELECT AGE ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: AGEDAY CATEGORY  ---------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB AGEDCAT LENGTH=3
   LABEL='PATIENT AGE IN DAYS';

 SELECT;
   WHEN (      AGEDAY <   0)  AGEDCAT = 0;
   WHEN (0  <= AGEDAY <= 28)  AGEDCAT = 1;
   WHEN (29 <= AGEDAY <= 60)  AGEDCAT = 2;
   WHEN (61 <= AGEDAY <= 90)  AGEDCAT = 3;
   WHEN (91 <= AGEDAY      )  AGEDCAT = 4;
 END; * SELECT AGEDAY ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: SEX CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB SEXCAT LENGTH=3
   LABEL='PATIENT GENDER';

 SELECT (SEX);
   WHEN (1)  SEXCAT = 1;
   WHEN (2)  SEXCAT = 2;
 END; * SELECT SEX ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: POPULATION CATEGORY ------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB POPCAT LENGTH=3
   LABEL='PATIENT AGE';

 POPCAT=PUT(AGE,AGEFMT.);

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: BIRTH WEIGHT CATEGORY  ---------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB BWHTCAT LENGTH=3
   LABEL='PATIENT BIRTHWEIGHT';

 %MACRO BWHT;

 BWHTCAT = 0;
 %DO I = 1 %TO &NDX.;
    IF PUT(DX&I.,$LW500G.)  = '1'      THEN BWHTCAT = 1;
    ELSE IF PUT(DX&I.,$LW1000G.) = '1' THEN BWHTCAT = 2;
    ELSE IF PUT(DX&I.,$LW1500G.) = '1' THEN BWHTCAT = 3;
    ELSE IF PUT(DX&I.,$LW2000G.) = '1' THEN BWHTCAT = 4;
    ELSE IF PUT(DX&I.,$LW2500G.) = '1' THEN BWHTCAT = 5;
 %END;
 
 %MEND;

 %BWHT;

 * -------------------------------------------------------------- ;
 * --- COUNT OR PROCEDURES AND IDENTIFY FIRST OR PROCEDURE ------ ;
 * -------------------------------------------------------------- ;
 ATTRIB ORCNT LENGTH=8
   LABEL='OR PROCEDURE COUNT';

 ATTRIB ORDAY LENGTH=8
   LABEL='OR PROCEDURE DAY';

 %ORCNT;

 * -------------------------------------------------------------- ;
 * --- DEFINE PROCEDURE TYPE ------------------------------------ ;
 * -------------------------------------------------------------- ;

 %PRCLASS;

 * -------------------------------------------------------------- ;
 * --- DEFINE CCS ----------------------------------------------- ;
 * -------------------------------------------------------------- ;

 ARRAY CCSARRY1{46} _temporary_ (
   4   6  21  33  35  38  39  41  42  48
  51  52  56  57  58  62  63  65  67  81
  82  83  85  95  96  98 103 105 106 108
 133 138 151 158 161 210 211 213 214 215
 216 217 219 221 224 227
 );

 ARRAY CCSARRY2{46} 
    CCS4   CCS6   CCS21  CCS33  CCS35  CCS38  CCS39  CCS41  CCS42  CCS48
    CCS51  CCS52  CCS56  CCS57  CCS58  CCS62  CCS63  CCS65  CCS67  CCS81
    CCS82  CCS83  CCS85  CCS95  CCS96  CCS98  CCS103 CCS105 CCS106 CCS108
    CCS133 CCS138 CCS151 CCS158 CCS161 CCS210 CCS211 CCS213 CCS214 CCS215
    CCS216 CCS217 CCS219 CCS221 CCS224 CCS227
 ;

 DO J = 1 TO 46;
    CCSARRY2(J) = 0;
 END;

 %CCS;

 LABEL
    CCS4 = "Mycoses"   
    CCS6 = "Hepatitis"   
    CCS21 = "Cancer of bone and connective tissue"  
    CCS33 = "Cancer of kidney and renal pelvis"  
    CCS35 = "Cancer of brain and nervous system"  
    CCS38 = "Non-Hodgkins lymphoma"  
    CCS39 = "Leukemias"  
    CCS41 = "Cancer, other and unspecified primary"  
    CCS42 = "Secondary malignancies"  
    CCS48 = "Thyroid disorders"
    CCS51 = "Other endocrine disorders"  
    CCS52 = "Nutritional deficiencies"  
    CCS56 = "Cystic fibrosis"  
    CCS57 = "Immunity disorders"  
    CCS58 = "Other nutritional, endocrine, and metabolic disorders"  
    CCS62 = "Coagulation and hemorrhagic disorders"  
    CCS63 = "Diseases of white blood cells"  
    CCS65 = "Mental retardation"  
    CCS67 = "Substance-related mental disorders"  
    CCS81 = "Other hereditary and degenerative nervous system conditions"
    CCS82 = "Paralysis"  
    CCS83 = "Epilepsy, convulsions"  
    CCS85 = "Coma, stupor, and brain damage"  
    CCS95 = "Other nervous system disorders"  
    CCS96 = "Heart valve disorders"  
    CCS98 = "Essential hypertension"  
    CCS103 = "Pulmonary heart disease" 
    CCS105 = "Conduction disorders" 
    CCS106 = "Cardiac dysrhythmias" 
    CCS108 = "Congestive heart failure, nonhypertensive"
    CCS133 = "Other lower respiratory disease" 
    CCS138 = "Esophageal disorders" 
    CCS151 = "Other liver diseases" 
    CCS158 = "Chronic renal failure" 
    CCS161 = "Other diseases of kidney and ureters" 
    CCS210 = "Systemic lupus erythematosus and connective tissue disorders" 
    CCS211 = "Other connective tissue disease" 
    CCS213 = "Cardiac and circulatory congenital anomalies" 
    CCS214 = "Digestive congenital anomalies" 
    CCS215 = "Genitourinary congenital anomalies"
    CCS216 = "Nervous system congenital anomalies" 
    CCS217 = "Other congenital anomalies" 
    CCS219 = "Short gestation, low birth weight, and fetal growth retardation" 
    CCS221 = "Respiratory distress syndrome" 
    CCS224 = "Other perinatal conditions" 
    CCS227 = "Spinal cord injury"
 ;

 * -------------------------------------------------------------- ;
 * --- DEFINE PROVIDER LEVEL INDICATORS ------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO LBL;

 ATTRIB
 TPPD01 LENGTH=3
   LABEL='ACCIDENTAL PUNCTURE AND LACERATION (Num)'
 TPPD02 LENGTH=3
   LABEL='DECUBITUS ULCER (Numerator)'
 TPPD03 LENGTH=3
   LABEL='FOREIGN BODY LEFT IN DURING PROC (Num)'
 TPPD04 LENGTH=3
   LABEL='IATROGENIC PNEUMOTHORAX NEONATE (Num)'
 TPPD05 LENGTH=3
   LABEL='IATROGENIC PNEUMOTHORAX (Numerator)'
 TPPD06 LENGTH=3
   LABEL='IN-HOSP MORT PEDIATRIC HEART SURG (Num)'
 TPPD07 LENGTH=3
   LABEL='VOLUME PEDIATRIC HEART SURGERY (Num)'
 TPPD08 LENGTH=3
   LABEL='POSTOP HEMORRHAGE OR HEMATOMA (Num)'
 TPPD09 LENGTH=3
   LABEL='POSTOP RESPIRATORY FAILURE (Numerator)'
 TPPD10 LENGTH=3
   LABEL='POSTOPERATIVE SEPSIS (Numerator)' 
 TPPD11 LENGTH=3
   LABEL='POSTOPERATIVE WOUND DEHISCENCE (Num)'
 TPPD12 LENGTH=3
   LABEL='INFECTION DUE TO MEDICAL CARE (Num)'
 TPPD13 LENGTH=3
   LABEL='TRANSFUSION REACTION (Numerator)'
;

 * -------------------------------------------------------------- ;
 * --- DEFINE AREA LEVEL INDICATORS ----------------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB
 TAPD14 LENGTH=3
   LABEL='ASTHMA (Numerator)'
 TAPD15 LENGTH=3
   LABEL='DIABETES SHORT TRM COMPLICATN (Num)'
 TAPD16 LENGTH=3
   LABEL='GASTROENTERITIS (Numerator)'
 TAPD17 LENGTH=3
   LABEL='PERFORATED APPENDIX (Numerator)'
 TAPD18 LENGTH=3
   LABEL='URINARY INFECTION (Numerator)'
 TAPD90 LENGTH=3
   LABEL='OVERALL PDI (Numeratr)'
 TAPD91 LENGTH=3
   LABEL='ACUTE PDI (Numeratr)'
 TAPD92 LENGTH=3
   LABEL='CHRONIC PDI (Numeratr)'
;

 * -------------------------------------------------------------- ;
 * --- RE-LABEL DAY DEPENDENT INDICATORS ------------------------ ;
 * -------------------------------------------------------------- ;
 %IF &PRDAY. = 0 %THEN %DO;

 LABEL
   TPPD02 = 'DECUBITUS ULCER-NO PRDAY (Numerator)'
   TPPD08 = 'POSTOP HEMOR OR HEMAT-NO PRDAY (Num)'
   TPPD09 = 'POSTOP RESP FAILURE-NO PRDAY (Numerator)'
   TPPD11 = 'POSTOP WOUND DEHISCENCE-NO PRDAY (Num)'
 ;
 %END;

 %MEND;

 %LBL;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIERS AND RISK CLASSES ---------------------- ;
 * -------------------------------------------------------------- ;
  ATTRIB
  GPPD01 LENGTH=3
   LABEL='STRATA FOR PDI #01'
  GPPD02 LENGTH=3
   LABEL='STRATA FOR PDI #02'
  GPPD08 LENGTH=3
   LABEL='STRATA FOR PDI #08'
  GPPD10 LENGTH=3
   LABEL='STRATA FOR PDI #10'
  GPPD11 LENGTH=3
   LABEL='STRATA FOR PDI #11'
  GPPD12 LENGTH=3
   LABEL='STRATA FOR PDI #12'
  HPPD01 LENGTH=3
   LABEL='RISK CLASS FOR PDI #01'
  HPPD10 LENGTH=3
   LABEL='RISK CLASS FOR PDI #10'
 ;

 * -------------------------------------------------------------- ;
 * --- IDENTIFY NEONATES AND NEWBORNS --------------------------- ;
 * -------------------------------------------------------------- ;

   NEONATE = 0;
   IF 0 <= AGEDAY <= 28 THEN NEONATE = 1;
   ELSE IF AGEDAY = . AND AGE = 0 THEN DO;
      IF ATYPE IN (4) OR %MDX($V29D.) OR %MDX($LIVEBND.)
      THEN NEONATE = 1;
   END;

   NEWBORN = 0;
   IF NEONATE THEN DO;
      IF %MDX($LIVEBND.) AND NOT AGEDAY > 0 THEN NEWBORN = 1;
      ELSE IF ATYPE IN (4) AND AGEDAY = 0 AND NOT %MDX($LIVEB2D.)
      THEN NEWBORN = 1;
   END;
 
   NORMAL = 0;
   IF NEWBORN AND DRG IN (391) THEN NORMAL = 1;

 * -------------------------------------------------------------- ;
 * --- CONSTRUCT PROVIDER LEVEL INDICATORS ---------------------- ;
 * -------------------------------------------------------------- ;


 * --- ACCIDENTAL PUNCTURE OR LACERATION                    --- ;

   IF %MDR($MEDICDR.) OR %MDR($SURGIDR.) THEN DO;

      TPPD01 = 0;

      IF %MDX2($TECHNID.) THEN TPPD01 = 1;

      *** Exclude principal diagnosis; 

      IF %MDX1($TECHNID.) THEN TPPD01 = .;

      *** Exclude spine surgery; 

      IF %MPR($SPINEP.) THEN TPPD01 = .;

      *** Exclude Normal Newborn;

      IF NORMAL THEN TPPD01 = .;

      *** Exclude Neonate < 500g;

      IF NEONATE AND BWHTCAT IN (1) THEN TPPD01 = .;

      *** Stratify by risk category (MDC)
           1 - Eye, ear, nose, mouth, throat, skin, breast and other low-risk procedures
           2 - Thoracic, cardiovascular, and specified neoplastic procedures
           3 - Kidney, and male/female reproductive procedures
           4 - Infectious, immunological, hematological, and ungroupable procedures
           5 - Trauma, orthopedic, and neurologic procedures
           6 - Gastrointestinal, hepatobiliary, and endocrine procedures;

      IF TPPD01 NE . THEN DO;
         IF MDC IN (2,3,9,19,22,23)     THEN GPPD01 = 1;
         ELSE IF MDC IN (4,5,17)        THEN GPPD01 = 2; 
         ELSE IF MDC IN (11,12,13)      THEN GPPD01 = 3; 
         ELSE IF MDC IN (0,16,18,25,99) THEN GPPD01 = 4; 
         ELSE IF MDC IN (1,8,21,24)     THEN GPPD01 = 5; 
         ELSE IF MDC IN (6,7,10)        THEN GPPD01 = 6; 
         ELSE GPPD01 = 9; 
      END;

      *** Risk adjust by risk category (Procedure Type)
           1. No therapeutic procedure with any or no diagnostic procedures
           2. Only minor therapeutic procedure with any or no diagnostic procedures 
           3. One major therapeutic without diagnostic procedure
           4. One major therapeutic with only minor diagnostic procedure(s)
           5. One major therapeutic with major diagnostic procedure(s) 
           6. Two major therapeutic procedures with any or no diagnostic procedures 
           7. Three or more major therapeutic procedures with any or no diagnostic procedures;

      IF TPPD01 NE . THEN DO;
         IF PRCLS2 = 0 AND PRCLS4 = 0                     THEN HPPD01 = 1;
         ELSE IF PRCLS4 = 0                               THEN HPPD01 = 2;
         ELSE IF PRCLS1 = 0 AND PRCLS3 = 0 AND PRCLS4 = 1 THEN HPPD01 = 3;
         ELSE IF PRCLS3 = 0 AND PRCLS4 = 1                THEN HPPD01 = 4;
         ELSE IF PRCLS4 = 1                               THEN HPPD01 = 5;
         ELSE IF PRCLS4 = 2                               THEN HPPD01 = 6;
         ELSE IF PRCLS4 >= 3                              THEN HPPD01 = 7;
         ELSE                                                  HPPD01 = 9;
      END;

   END;


   * --- DECUBITUS ULCER --- ;

 %MACRO PD2;

 IF (&PRDAY. = 1  AND ORDAY NE . AND MPRDAY NE .) THEN DO;

      IF MPRDAY <= ORDAY THEN TPPD02 = .;

 END;
 ELSE DO;

      IF %MPR1($DEBRIDP.) THEN TPPD02 = .;

 END;

 %MEND;

   IF %MDR($MEDICDR.) OR %MDR($SURGIDR.) THEN DO;

      TPPD02 = 0;
     
      IF %MDX2($DECUBID.) THEN TPPD02 = 1;
 
      *** Exclude principal diagnosis; 

      IF %MDX1($DECUBID.) THEN TPPD02 = .;

      IF %MDR($SURGIDR.) AND ORCNT > 0 THEN DO;
 
         *** Exclude if debridement or pedicle graft is the only OR procedure;
         %MPRCNT($DEBRIDP.);
         IF ORCNT = MPRCNT THEN TPPD02 = .;

         *** Exclude if debridement or pedicle graft occurs before or 
             on the same day as the first OR procedure;
         %ORDAY($DEBRIDP.);
         %MPRDAY($DEBRIDP.);
         %PD2;

      END;

      *** Exclude MDC 9;

      IF MDC IN (9) THEN TPPD02 = .;

      *** Exclude LOS < 5, Admitted from LTC, Transfer from Acute Care Facility;

      IF LOS < 5 OR ASOURCE IN (2,3) THEN TPPD02 = .;

      *** Exclude Neonate;

      IF NEONATE THEN TPPD02 = .;

      *** Stratify by risk category (1 - Low risk, 2 - High risk);

      IF TPPD02 NE . THEN DO;
         IF %MDX($HEMIPID.) OR %MDX($SPIBIFD.) OR %MDX($ANOXBD.) OR %MPR($CMVENP.) THEN GPPD02 = 2;
         ELSE GPPD02 = 1; 
      END;

   END;


   * --- FOREIGN BODY LEFT IN DURING PROCEDURE                --- ;

   IF %MDR($MEDICDR.) OR %MDR($SURGIDR.) THEN DO;

      TPPD03 = .;

      IF %MDX2($FOREIID.) THEN TPPD03 = 1;

      *** Exclude principal diagnosis; 

      IF %MDX1($FOREIID.) THEN TPPD03 = .;

      *** Require POA; 

      IF &POAFG. EQ 0 THEN TPPD03 = .;

      *** Exclude normal newborn; 

      IF NORMAL THEN TPPD03 = .;

      *** Exclude Neonate < 500g;
      
      IF NEONATE AND BWHTCAT IN (1) THEN TPPD03 = .;

   END;


   * --- IATROGENIC PNEUMOTHORAX  --- ;

   IF %MDR($MEDICDR.) OR %MDR($SURGIDR.) THEN DO;

      TPPD05 = 0;  
  
      IF %MDX2($IATROID.) THEN TPPD05 = 1;
           
      *** Exclude principal diagnosis; 

      IF %MDX1($IATROID.) THEN TPPD05 = .;

      *** Exclude Chest Trauma, Pleural effusion;

      IF %MDX($CTRAUMD.) OR %MDX($PLEURAD.) 
      THEN TPPD05 = .;

      *** Exclude Thoracic surgery, Lung or pleural biopsy,
          Cardiac surgery or Diaphragmatic surgery repair;

      IF %MPR($THORAIP.) OR %MPR($LUNGBIP.) OR %MDR($CARDSDR.) OR 
         %MPR($DIAPHRP.)
      THEN TPPD05 = .;

      *** Exclude normal newborn; 

      IF NORMAL THEN TPPD05 = .;

      *** Exclude Neonate < 500g;
     
      IF NEONATE AND BWHTCAT IN (1) THEN TPPD05 = .;

      IF NEONATE = 1 AND BWHTCAT IN (2,3,4,5) THEN DO;
         TPPD04 = TPPD05;
         TPPD05 = .;
      END;

 END;


   * --- PEDIATRIC HEART SURGERY MORTALITY  --- ;

   * --- COUNTS THE NUMBER OF CARDIAC SURGERY CODES -------------- ;

   %PRPDCNT1;
   %PRPDCNT2;

   IF MPR1P > 0  THEN DO;

      TPPD06 = 0;

      IF DISP = 20 THEN

         TPPD06 = 1;

   * --- EXCLUDE TRANSCATHETER INTERVENTIONS ------------------------ ;

      PDA = 0;
      IF ((MDX3D > 0 AND MDX3D = MDX2D) AND (MPR3EP > 0 AND MPR3EP = MPR1P))
      THEN PDA = 1;

      IF MPR5P = 0 AND MPR6P > 0 AND (
         MPR3AP = MPR1P OR 
         MPR3BP = MPR1P OR 
         MPR3CP = MPR1P OR 
         MPR3DP = MPR1P OR 
         PDA OR 
         MPR3FP = MPR1P) 
      THEN TPPD06 = .;

      IF MPR5P = 0 AND (MPR4P = MPR1P) 
      THEN TPPD06 = .;

      * --- EXCLUDE HEART TRANSPLANT, UNKNOWN DISPOSITION, PREMATURE INFANTS
            WITH PDA AS ONLY CARDIAC PROCEDURE AND AGE LESS THAN 30 DAYS WITH
            PDA AS ONLY CARDIAC PROCEDURE                          ----- ;

      IF MPR7P > 0 OR DISP = . OR
         (MDX4D AND PDA) OR
         ((AGE = 0 AND AGEDAY <=30) AND PDA)           
      THEN TPPD06 = .;

      *** Exclude Neonate < 500g;
     
      IF NEONATE AND BWHTCAT IN (1) THEN TPPD06 = .;

   END;

   * --- Risk Categories for Congenital Heart Surgery-1 (RACHS-1) --- ;

%INCLUDE PHSRACHS;

   * --- VOLUME PEDIATRIC HEART SURGERY    --- ;

   * --- COUNTS THE NUMBER OF CARDIAC SURGERY CODES -------------- ;

   %PRPDCNT1;
   %PRPDCNT2;

   IF MPR1P > 0  THEN DO;

      TPPD07 = 1;

      * --- EXCLUDE TRANSCATHETER INTERVENTIONS ------------------------ ;

      PDA = 0;
      IF ((MDX3D > 0 AND MDX3D = MDX2D) AND (MPR3EP > 0 AND MPR3EP = MPR1P))
      THEN PDA = 1;

      IF MPR5P = 0 AND MPR6P > 0 AND (
         MPR3AP = MPR1P OR 
         MPR3BP = MPR1P OR 
         MPR3CP = MPR1P OR 
         MPR3DP = MPR1P OR 
         PDA OR 
         MPR3FP = MPR1P) 
      THEN TPPD07 = .;

      IF MPR5P = 0 AND (MPR4P = MPR1P) 
      THEN TPPD07 = .;

   END;


   * --- POSTOPERATIVE HEMORRHAGE OR HEMATOMA                --- ;

   %MACRO PD8;

   IF (&PRDAY. = 1 AND ORDAY NE . AND MPRDAY NE .) THEN DO;

      IF (%MDX2($POHMAID.) OR %MDX2($POHMRID.)) AND MPRDAY < ORDAY
      THEN TPPD08 = .;

   END;
   ELSE DO;

      IF (%MDX2($POHMAID.) OR %MDX2($POHMRID.)) AND %MPR1($HEMIP.)
      THEN TPPD08 = .;

   END;

   %MEND;

   IF %MDR($SURGIDR.) AND ORCNT > 0 AND ATYPE IN (3) THEN DO;

      TPPD08 = 0;

      IF (%MDX2($POHMAID.) OR %MDX2($POHMRID.)) AND 
         (%MPR($HEMATIP.)  OR %MPR($HEMORIP.)) 
      THEN TPPD08 = 1;

      *** Exclude principal diagnosis; 

      IF %MDX1($POHMAID.) OR %MDX1($POHMRID.) THEN TPPD08 = .;

      *** Exclude if control of post-operative hemorrhage or
          hematoma are the only OR procedures;

      %MPRCNT($HEMIP.);
      IF ORCNT = MPRCNT THEN TPPD08 = .;

      *** Exclude if control of post-operative hemorrhage or
          hematoma occurs before the first OR procedure;

      %ORDAY($HEMIP.);
      %MPRDAY($HEMIP.);
      %PD8;

      *** Exclude Neonate < 500g;
     
      IF NEONATE AND BWHTCAT IN (1) THEN TPPD08 = .;

      *** Stratify by risk category (1-Low risk, 2-High risk);

      IF TPPD08 NE . THEN DO;
         IF %MDX($ACGOFD.) OR %MPR($ECMOP.) THEN GPPD08 = 2;
         ELSE GPPD08 = 1;
      END;

   END;

      
   * --- POSTOPERATIVE RESPIRATORY FAILURE                    --- ;

   %MACRO PD9N(FMT,DAYS);

      %MPRDAY(&FMT.);

      IF (&PRDAY. = 1  AND ORDAY NE . AND MPRDAY NE .) THEN DO;

         IF MPRDAY >= ORDAY + &DAYS. THEN TPPD09 = 1;

      END;
      ELSE DO;

         IF %MPR2(&FMT.) THEN TPPD09 = 1;

      END;

   %MEND;

   %MACRO PD9;

      IF (&PRDAY. = 1  AND ORDAY NE . AND MPRDAY NE .) THEN DO;

         IF MPRDAY < ORDAY THEN TPPD09 = .;

      END;
      ELSE DO;

         IF %MPR1($TRACHIP.) THEN TPPD09 = .;

      END;

   %MEND;

   IF %MDR($SURGIDR.) AND ORCNT > 0 AND ATYPE IN (3) THEN DO;

      TPPD09 = 0;

      IF %MDX2($ACURFID.) THEN TPPD09 = 1;

      *** Exclude principal diagnosis; 

      IF %MDX1($ACURFID.) THEN TPPD09 = .;

      *** Include in numerator if reintubation procedure occurs on the same day or
          # days after the first OR procedure;
 
      %ORDAY($BLANK.);
      %PD9N($PR9604P.,1);
      %PD9N($PR9670P.,2);
      %PD9N($PR9671P.,2);
      %PD9N($PR9672P.,0);

      *** Exclude if tracheostomy procedure is the only OR procedure;
      %MPRCNT($TRACHIP.);
      IF ORCNT = MPRCNT THEN TPPD09 = .;

      *** Exclude if tracheostomy procedure occurs before the 
          first OR procedure;
      %ORDAY($TRACHIP.);
      %MPRDAY($TRACHIP.);
      %PD9;

      *** Exclude Neuromuscular disorders;
 
      IF %MDX($NEUROMD.) THEN TPPD09 = .;

      *** Exclude MDC 4, 5;
 
      IF MDC IN (4,5) THEN TPPD09 = .;

      *** Exclude Neonate < 500g;
     
      IF NEONATE AND BWHTCAT IN (1) THEN TPPD09 = .;

   END;


   * --- POSTOPERATIVE SEPSIS --- ;

      IF %MDR($SURGIDR.) AND ORCNT > 0 THEN DO;

      TPPD10 = 0;

      IF %MDX2($SEPTIID.) THEN TPPD10 = 1;

      *** Exclude principal diagnosis; 

      IF %MDX1($SEPTIID.) THEN TPPD10 = .;

      *** Exclude Infection;

      IF %MDX1($INFECID.) THEN TPPD10 = .;

      *** Exclude DRG in surgical class 4;

      IF %MDR($DRG4C.) THEN TPPD10 = .;

      *** Exclude Length of stay less then 4 days;

      IF LOS < 4 THEN TPPD10 = .;
     
      *** Exclude Neonate;

      IF NEONATE THEN TPPD10 = .;
 
      *** Stratify by procedure type (1-Low risk to 4-High risk);

      IF TPPD10 NE . THEN DO;
         IF %MDR($DRG1C.) THEN DO;
            IF ATYPE IN (3) THEN GPPD10 = 1; ELSE GPPD10 = 2;
         END;
         ELSE IF %MDR($DRG2C.) OR %MDR($DRG3C.) OR %MDR($DRG9C.) THEN DO;
            IF ATYPE IN (3) THEN GPPD10 = 3; ELSE GPPD10 = 4;
         END;
         ELSE IF %MDR($DRG4C.) THEN GPPD10 = 5;
         ELSE GPPD10 = 9;
      END;

      *** Risk adjust by risk category (1-Low risk, 2-Intermediate risk, 3-High risk);

      IF TPPD10 NE . THEN DO;
         IF %MDX($IMMUNHD.) OR %MPR($TRANSPP.) THEN HPPD10 = 3;
         ELSE IF %MDX($IMMUITD.) OR (%MDX($HEPFA2D.) AND %MDX($HEPFA3D.)) THEN HPPD10 = 2; 
         ELSE HPPD10 = 1;
      END;

 END;
 

   * --- POSTOPERATIVE WOUND DEHISCENCE --- ;

   %MACRO PD11A;

      IF (&PRDAY. = 1 AND MPRDAYA NE . AND MPRDAYB NE .) THEN DO;

         IF MPRDAYB <= MPRDAYA THEN TPPD11 = .;

      END ;
      ELSE DO;

         IF %MPR1($RECLOIP.) THEN TPPD11 = .;

      END;

   %MEND;

   %MACRO PD11B;

      IF (&PRDAY. = 1 AND MPRDAYA NE . AND MPRDAYB NE .) THEN DO;

         IF MPRDAYB < MPRDAYA THEN TPPD11 = .;

      END;
      ELSE DO;

         IF %MPR1($REPGAST.) THEN TPPD11 = .;

      END;

   %MEND;

   IF ((YEAR < 2004 OR (YEAR = 2004 AND DQTR IN (1,2,3))) AND (%MPR($ABDOMIP.)                   )) OR
      ((YEAR > 2004 OR (YEAR = 2004 AND DQTR IN (4)    )) AND (%MPR($ABDOMIP.) OR %MPR($ABDOM2P.))) 
   THEN DO;

      TPPD11 = 0;

      IF %MPR($RECLOIP.) THEN TPPD11 = 1;

      *** Exclude if wound reclosure occurs before or on the same
          day as the first abdominopelvic procedure;

      %MPRDAY($ABDOMIP.); MPRDAYA = MPRDAY;
      %MPRDAY($RECLOIP.); MPRDAYB = MPRDAY;
      %PD11A;

      *** Exclude if gastrochiesis OR umbilical hernia repair performed
          before reclosure;
      %MPRDAY($RECLOIP.); MPRDAYA = MPRDAY;
      %MPRDAY($REPGAST.); MPRDAYB = MPRDAY;
      %PD11B;

      *** Exclude High and Intermediate Risk Immunocompromised state;

      IF %MDX($IMMUNHD.) OR %MPR($TRANSPP.) THEN TPPD11 = .;     

      IF %MDX($IMMUITD.) OR (%MDX($HEPFA2D.) AND %MDX($HEPFA3D.)) THEN TPPD11 = .; 

      *** Exclude LOS < 2; 
      IF LOS < 2 THEN TPPD11 = .;

      *** Exclude Neonate < 500g;
     
      IF NEONATE AND BWHTCAT IN (1) THEN TPPD11 = .;

      *** Stratify by procedure type (1-Low risk to 4-High risk);

      IF TPPD11 NE . THEN DO;
         IF %MDR($DRG1C.) THEN DO;
            IF ATYPE IN (3) THEN GPPD11 = 1; ELSE GPPD11 = 2;
         END;
         ELSE IF %MDR($DRG2C.) OR %MDR($DRG3C.) OR %MDR($DRG9C.) THEN DO;
            IF ATYPE IN (3) THEN GPPD11 = 3; ELSE GPPD11 = 4;
         END;
         ELSE IF %MDR($DRG4C.) THEN GPPD11 = 5;
         ELSE GPPD11 = 9;
      END;

   END;


 * --- SELECTED INFECTION DUE TO MEDICAL CARE --- ;

   IF %MDR($MEDICDR.) OR %MDR($SURGIDR.) THEN DO;

      TPPD12 = 0;

      IF %MDX2($IDTMCID.) THEN TPPD12 = 1;
 
      *** Exclude principal diagnosis; 

      IF %MDX1($IDTMCID.) THEN TPPD12 = .;

      *** Exclude LOS < 2;
 
      IF LOS < 2 THEN TPPD12 = .;

      *** Exclude Newborn;

      IF NORMAL THEN TPPD12 = .;

      *** Exclude Neonate < 500g;
     
      IF NEONATE AND BWHTCAT IN (1) THEN TPPD12 = .;

      *** Stratify by risk category (1-Low risk, 2-Intermediate risk, 3-High risk);

      IF TPPD12 NE . THEN DO;
         IF %MDX($IMMUNHD.) OR %MPR($TRANSPP.) OR %MDX($CANITD.) THEN GPPD12 = 3;
         ELSE IF %MDX($IMMUITD.) OR (%MDX($HEPFA2D.) AND %MDX($HEPFA3D.)) OR
                 %MDX($ACSCYFD.) OR %MDX($HEMOPHD.) THEN GPPD12 = 2; 
         ELSE GPPD12 = 1;
      END;

  END;


   * --- TRANSFUSION REACTION                                 --- ;

   IF %MDR($MEDICDR.) OR %MDR($SURGIDR.) THEN DO;

      TPPD13 = .;
 
      IF %MDX2($TRANFID.) THEN TPPD13 = 1;

      *** Exclude principal diagnosis; 

      IF %MDX1($TRANFID.) THEN TPPD13 = .;
  
      *** Exclude Neonate;

      IF NEONATE THEN TPPD13 = .;

   END;

  
 * -------------------------------------------------------------- ;
 * --- CONSTRUCT AREA LEVEL INDICATORS -------------------------- ;
 * -------------------------------------------------------------- ;


   * --- PEDIATRIC ASTHMA                  --- ;
   
   IF %MDX1P($ACSASTD.) THEN DO;

      TAPD14 = 1;

      *** Exclude Cystic Fibrosis and Anomalies of the Respiratory System;

      IF %MDX($RESPAN.) THEN TAPD14 = .;

      *** Exclude age < 2 years;

      IF AGE < 2 THEN TAPD14 = .;

   END;


   * --- DIABETES SHORT TERM COMPLICATION  --- ;

   IF %MDX1P($ACDIASD.) THEN DO;

      TAPD15 = 1;

      *** Exclude age < 6 years;

      IF AGE < 6 THEN TAPD15 = .;

   END;


   * --- PEDIATRIC GASTROENTERITIS         --- ;

   IF %MDX1P($ACPGASD.) OR (%MDX2($ACPGASD.) AND %MDX1P($ACSDEHD.)) THEN DO;

      TAPD16 = 1;
  
      *** Exclude age <= 90 days;

      IF 0 <= AGEDAY <= 90 OR (AGEDAY < 0 AND NEONATE) THEN TAPD16 = .;

     *** Exclude Gastrointestinal Abnormalities and Bacterial Gastroenteritis ;

     IF %MDX($ACGDISD.) THEN TAPD16 = .; 
     IF %MDX($ACBACGD.) THEN TAPD16 = .;
   
   END;


   * --- PERFORATED APPENDIX               --- ;

   IF %MDX($ACSAP2D.) THEN DO;

      TAPD17 = 0;

      IF %MDX($ACSAPPD.) THEN TAPD17 = 1;

      *** Exclude age < 1 year;

      IF AGE < 1 THEN TAPD17 = .;

   END;


   * --- URINARY INFECTION                 --- ;

   IF %MDX1P($ACSUTID.) THEN DO;

      TAPD18 = 1;

      *** Exclude Kidney/Urinary Tract Disorder;

      IF %MDX($KIDNEY.) THEN TAPD18 = .;

      *** Exclude High and Intermediate Risk Immunocompromised state;

      IF %MDX($IMMUNHD.) OR %MPR($TRANSPP.) THEN TAPD18 = .;     

      IF %MDX($IMMUITD.) OR (%MDX($HEPFA2D.) AND %MDX($HEPFA3D.)) THEN TAPD18 = .; 

      *** Exclude age <= 90 days;

      IF 0 <= AGEDAY <= 90 OR (AGEDAY < 0 AND NEONATE) THEN TAPD18 = .;
 
   END;

 * -------------------------------------------------------------- ;
 * --- CONSTRUCT AREA LEVEL COMPOSITE INDICATORS ---------------- ;
 * -------------------------------------------------------------- ;

   * --- OVERALL                          --- ;

   IF TAPD14 = 1 OR TAPD15 = 1 OR TAPD16 = 1 OR TAPD18 = 1 THEN DO;
      TAPD90 = MAX(OF TAPD14 TAPD15 TAPD16 TAPD18);
      IF AGE < 6 THEN TAPD90 = .;
   END;

   * --- ACUTE                            --- ;

   IF TAPD14 = 1 OR TAPD15 = 1 THEN DO;
      TAPD91 = MAX(OF TAPD14 TAPD15);
      IF AGE < 6 THEN TAPD91 = .;
   END;

   * --- CHRONIC                          --- ;

   IF TAPD16 = 1 OR TAPD18 = 1 THEN DO;
      TAPD92 = MAX(OF TAPD16 TAPD18);
      IF AGE < 6 THEN TAPD92 = . ;
   END;

 * -------------------------------------------------------------- ;
 * --- EXCLUDE CASES WITH MISSING VALUES FOR DISP             --- ;
 * -------------------------------------------------------------- ;

 IF (DISP LT 0) THEN DO;
   TPPD06 = .;
 END;

 * -------------------------------------------------------------- ;
 * --- EXCLUDE TRANSFERS ---------------------------------------- ;
 * -------------------------------------------------------------- ;

 * --- TRANSFER FROM ANOTHER ---------------- ;
 IF (2 <= ASOURCE <= 3) THEN DO;
   TAPD14 = .;
   TAPD15 = .;
   TAPD16 = .;
   TAPD17 = .;
   TAPD18 = .;
   TAPD90 = .;
   TAPD91 = .;
   TAPD92 = .;
 END;

 * --- TRANSFER TO ANOTHER ACUTE ------------------ ;
 IF (DISP = 2) THEN DO;
   TPPD06 = .;
 END;

RUN;

PROC MEANS DATA=OUT1.&OUTFILE1. N NMISS MIN MAX MEAN SUM;
RUN;

PROC CONTENTS DATA=OUT1.&OUTFILE1. POSITION;
RUN;

PROC PRINT DATA=OUT1.&OUTFILE1. (OBS=24);
TITLE4 "FIRST 24 RECORDS IN OUTPUT DATA SET &OUTFILE1.";
RUN;













