*==================================================================
*  Title:  PROGRAM A2 CALCULATES OBSERVED AREA RATES FOR AHRQ
*          PEDIATRIC QUALITY INDICATORS
*
*  Description:
*         USES PROC SUMMARY TO CALCULATE OBSERVED RATES FOR
*         PEDIATRIC QUALITY INDICATORS ACROSS STRATIFIERS:
*         PROGRAM USES AREA, POPCAT, SEXCAT AND RACECAT
*
*          >>>  VERSION 3.2, March 2008 <<<
*
*===================================================================;
FILENAME CONTROL "C:\PATHNAME\CONTROL_PDI.SAS"; *<==USER MUST modify;

%INCLUDE CONTROL;

 %MACRO CTY2MA;
    %IF &MALEVL EQ 0 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='FIPS STATE COUNTY CODE';
        MAREA = FIPSTCO;
    %END;
    %ELSE %IF &MALEVL EQ 1 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='MODIFIED FIPS';
        MAREA = INPUT(PUT(FIPSTCO,$M1AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 2 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='OMB 1999 METRO AREA';
        MAREA = INPUT(PUT(FIPSTCO,$M2AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 3 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='OMB 2003 METRO AREA';
        MAREA = INPUT(PUT(FIPSTCO,$M3AREA.),$5.);
    %END;
 %MEND;

 TITLE2 'PROGRAM A2';
 TITLE3 'AHRQ PEDIATRIC QUALITY INDICATORS: CALCULATE OBSERVED AREA RATES';
 run;

 * -------------------------------------------------------------- ;
 * --- Calculate the Numerators (T prefix) for the observed rates ;
 * --- and the Denominators (P prefix) for those Pediatric        ;
 * --- Quality Indicators that are based on the hospitalized      ;
 * --- population.                                                ;
 * -------------------------------------------------------------- ;

 PROC   SUMMARY DATA=INA2.&INFILEA2. NWAY;
 CLASS  MAREA POPCAT SEXCAT RACECAT;
 VAR    TAPD14-TAPD18 TAPD90-TAPD92;
 OUTPUT OUT=TEMP1
        SUM(TAPD14-TAPD18 TAPD90-TAPD92)=
            TAPD14-TAPD18 TAPD90-TAPD92
          N(TAPD17)=PAPD17;
 RUN;

 PROC   SORT DATA=TEMP1
                  (KEEP=MAREA POPCAT SEXCAT RACECAT
                        TAPD14-TAPD18 TAPD90-TAPD92
                        PAPD17 _TYPE_);
 BY     MAREA POPCAT SEXCAT RACECAT;
 RUN;

 * -------------------------------------------------------------- ;
 * --- ADD THE AREA POPULATION DENOMINATORS --------------------- ;
 * -------------------------------------------------------------- ;

 PROC   SORT DATA=TEMP1 OUT=MAREA(KEEP=MAREA) NODUPKEY;
 BY     MAREA;
 RUN;

 * -------------------------------------------------------------- ;
 * --- READ CTY LEVEL POPS AND IF MALEVL SET TO 1,2,3 SUMMARIZE - ;
 * --- TO METRO AREA, ELSE SUMMARIZE TO CTY --------------------- ;
 * -------------------------------------------------------------- ;

 DATA QIPOP0;
    LENGTH FIPSTCO $5 SEXCAT POPCAT POPCAT RACECAT 3 
           POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
           POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
           POP_2005 POP_2006 POP_2007 POP_2008 POP 8;

    INFILE POPFILE MISSOVER FIRSTOBS=2;

    INPUT FIPSTCO SEXCAT POPCAT RACECAT 
          POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
          POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
          POP_2005 POP_2006 POP_2007 POP_2008;

    %CTY2MA

    POP = POP_&POPYEAR.;

    IF POPCAT IN (1,2,3,4);

 RUN;
 
 PROC   SUMMARY DATA=QIPOP0 NWAY;
 CLASS  MAREA POPCAT SEXCAT RACECAT;
 VAR    POP;
 OUTPUT OUT=QIPOP SUM(POP)=;
 RUN;

 PROC   SORT DATA=QIPOP;
 BY     MAREA POPCAT SEXCAT RACECAT;
 RUN;

 DATA   QIPOP(KEEP=MAREA POPCAT SEXCAT RACECAT POP);
 MERGE  MAREA(IN=X) QIPOP;
 BY     MAREA;
 IF X;
 RUN;

 * -------------------------------------------------------------- ;
 * --- CALCULATE OBSERVED RATES                               --- ;
 * --- NOTE THAT OBSERVED RATES OF THE TOTAL AREA MAY OR MAY  --- ;
 * --- NOT BE DIFFERENT DEPENDING ON WHETHER COUNTY-LEVEL OR  --- ;
 * --- MA-LEVEL AREA STRATIFICATION WAS SPECIFIED.  THIS IS   --- ;
 * --- DUE TO THE INCLUSION OF COUNTY POPULATIONS UNDER MA-   --- ;
 * --- LEVEL STRATIFICATION THAT WOULD OTHERWISE BE EXCLUDED  --- ;
 * --- UNDER COUNTY-LEVEL STRATIFICATION.  UNDER COUNTY-LEVEL --- ;
 * --- STRATIFICATION, A COUNTY WOULD BE INCLUDED ONLY IF THERE - ;
 * --- WAS AT LEAST ONE DISCHARGE FROM THAT COUNTY.  UNDER MA  -- ;
 * --- LEVEL STRATIFICATION, A COUNTY WOULD BE INCLUDED IF ANY- - ;
 * --- COUNTY WITHIN THE SAME MA HAD AT LEAST ONE DISCHARGE.      ;
 *                                                                ;
 * --- DISCHARGES WITH MISSING PSTCO DATA HAVE BEEN           --- ;
 * --- EXCLUDED FROM THESE ANALYSIS.                          --- ;
 * -------------------------------------------------------------- ;

 DATA  TEMP1;
 MERGE TEMP1 QIPOP;
 BY    MAREA POPCAT SEXCAT RACECAT;

 IF POP = . THEN
    PUT 'MISSING POPULATION ' MAREA POPCAT SEXCAT RACECAT POP;

 ARRAY PPD1{7} PAPD14-PAPD16 PAPD18 PAPD90-PAPD92;

 DO J = 1 to 7;
    PPD1{J} = POP;
 END;

 IF POPCAT IN (1) THEN DO;
   PAPD14 = PAPD14 * 0.60;
   PAPD15 = .;
   PAPD16 = PAPD16 * 0.95;
   PAPD18 = PAPD18 * 0.95;
   PAPD90 = .;
   PAPD91 = .;
   PAPD92 = .;
 END;
 ELSE IF POPCAT IN (2) THEN DO;
   PAPD90 = PAPD90 * 0.80;
   PAPD91 = PAPD91 * 0.80;
   PAPD92 = PAPD92 * 0.80;
 END;

 RUN;

 * -------------------------------------------------------------- ;
 * --- AGGREGATE POPULATION COUNTS, BY STRATIFIERS            --- ;
 * -------------------------------------------------------------- ;

 PROC   SUMMARY DATA=TEMP1;
 CLASS  MAREA POPCAT SEXCAT RACECAT;
 VAR    TAPD14-TAPD18 TAPD90-TAPD92
        PAPD14-PAPD18 PAPD90-PAPD92;
 OUTPUT OUT=TEMP2 SUM=;
 RUN;

 DATA &OUTFILA2.;
 SET TEMP2;

 IF _TYPE_ &TYPELVLA;

 ARRAY PPD2{8} PAPD14-PAPD18 PAPD90-PAPD92;
 ARRAY TPD{8} TAPD14-TAPD18 TAPD90-TAPD92;
 ARRAY OPD{8} OAPD14-OAPD18 OAPD90-OAPD92;

 DO J = 1 to 8;
    IF TPD{J} GT 0 AND PPD2{J} GT 0 THEN OPD{J} = TPD{J} / PPD2{J};
    ELSE IF PPD2{J} GT 0 THEN OPD{J} = 0;
 END;

 LABEL
 TAPD14 = 'ASTHMA                  (Numerator)'
 TAPD15 = 'DIABETES SHORT TRM COMPLICATN (Num)'
 TAPD16 = 'GASTROENTERITIS         (Numerator)'
 TAPD17 = 'PERFORATED APPENDIX     (Numerator)'
 TAPD18 = 'URINARY INFECTION       (Numerator)'
 TAPD90 = 'OVERALL PDI             (Numerator)'
 TAPD91 = 'ACUTE PDI               (Numerator)'
 TAPD92 = 'CHRONIC PDI             (Numerator)'
 ;
 LABEL
 PAPD14 = 'ASTHMA                 (Population)'
 PAPD15 = 'DIABETES SHORT TRM COMPLICATN (Pop)'
 PAPD16 = 'GASTROENTERITIS        (Population)'
 PAPD17 = 'PERFORATED APPENDIX    (Population)'
 PAPD18 = 'URINARY INFECTION      (Population)'
 PAPD90 = 'OVERALL PDI            (Population)'
 PAPD91 = 'ACUTE PDI              (Population)'
 PAPD92 = 'CHRONIC PDI            (Population)'
 ;
 LABEL
 OAPD14 = 'ASTHMA                   (Observed)'
 OAPD15 = 'DIABETES SHORT TRM COMPLICATN (Obs)'
 OAPD16 = 'GASTROENTERITIS          (Observed)'
 OAPD17 = 'PERFORATED APPENDIX      (Observed)'
 OAPD18 = 'URINARY INFECTION        (Observed)'
 OAPD90 = 'OVERALL PDI              (Observed)'
 OAPD91 = 'ACUTE PDI                (Observed)'
 OAPD92 = 'CHRONIC PDI              (Observed)'
 _TYPE_ = 'STRATIFICATION LEVEL'
 ;

 DROP J;

 RUN;

 PROC SORT DATA=&OUTFILA2. OUT=OUTA2.&OUTFILA2.;
 BY MAREA POPCAT SEXCAT RACECAT;
 RUN;

 * -------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF AREA OBSERVED MEANS FILE ----------- ;
 * -------------------------------------------------------------- ;

 PROC CONTENTS DATA=OUTA2.&OUTFILA2. POSITION;
 RUN;

 PROC MEANS DATA=OUTA2.&OUTFILA2.(WHERE=(_TYPE_ IN (8))) N NMISS MIN MAX MEAN SUM;
 TITLE4 "SUMMARY OF AREA-LEVEL RATES (_TYPE_=8)";
 RUN;

 * -------------------------------------------------------------- ;
 * --- PRINT AREA OBSERVED MEANS FILE --------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PD,TEXT);

 PROC  PRINT DATA=OUTA2.&OUTFILA2. LABEL SPLIT='*';
 VAR   MAREA POPCAT SEXCAT RACECAT TAPD&PD. PAPD&PD. OAPD&PD. ;
 LABEL MAREA    = "MAREA"
       POPCAT   = "POPCAT"
       SEXCAT   = "SEXCAT"
       RACECAT  = "RACECAT"
       TAPD&PD.   = "TAPD&PD.*(Numerator)"
       PAPD&PD.   = "PAPD&PD.*(Denominator)"
       OAPD&PD.   = "OAPD&PD.*(Observed)"
       ;
 FORMAT POPCAT POPCAT.   
        SEXCAT SEXCAT.
        RACECAT RACECAT.
        TAPD&PD. PAPD&PD. COMMA13.0
        OAPD&PD. 8.6
        ;
 TITLE4 "Indicator # &PD.: &TEXT";
 RUN;

 %MEND PRT;

 %PRT(14,ASTHMA);
 %PRT(15,DIABETES SHORT TRM COMPLICATN);
 %PRT(16,GASTROENTERITIS);
 %PRT(17,PERFORATED APPENDIX);
 %PRT(18,URINARY INFECTION);

 %END;

 %MEND PRT2;

 %PRT2; 

 * -------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
 * --- FOR EXPORT INTO SPREADSHEETS ----------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO TEXT;

 %IF &TEXTA2. = 1  %THEN %DO;

 DATA _NULL_;
 SET OUTA2.&OUTFILA2;
 FILE PDTEXTA2 LRECL=1000;
 IF _N_=1 THEN PUT "MAREA"  "," "Age"  "," "Sex"  "," "Race"  "," "Type" ","
 "TAPD14" "," "TAPD15" "," "TAPD16" "," 
 "TAPD17" "," "TAPD18" ","
 "TAPD90" "," "TAPD91" "," "TAPD92" ","
 "PAPD14" "," "PAPD15" "," "PAPD16" ","
 "PAPD17" "," "PAPD18" ","
 "PAPD90" "," "PAPD91" "," "PAPD92" ","
 "OAPD14" "," "OAPD15" "," "OAPD16" ","
 "OAPD17" "," "OAPD18" ","
 "OAPD90" "," "OAPD91" "," "OAPD92";

 PUT MAREA $5. "," POPCAT 3. "," SEXCAT 3. "," RACECAT 3.  "," _TYPE_ 2.  ","
 (TAPD14-TAPD18 TAPD90-TAPD92) (7.0 ",")
 ","
 (PAPD14-PAPD18 PAPD90-PAPD92) (13.2 ",")
 ","
 (OAPD14-OAPD18 OAPD90-OAPD92) (12.10 ",")
 ;
 RUN;

 %END;

 %MEND TEXT;

 %TEXT;
