*===================================================================;
*  Title:  PROGRAM P2 CALCULATES OBSERVED PROVIDER RATES FOR AHRQ
*          PEDIATRIC QUALITY INDICATORS
*
*  Description:;
*         USES PROC SUMMARY TO CALCULATE OBSERVED RATES FOR
*         PEDIATRIC QUALITY INDICATORS ACROSS STRATIFIERS.
*         PROGRAM USES HOSPID, BWHTCAT, AGEDCAT, PAGECAT, SEXCAT, 
*         PAYCAT, RACECAT.
*
*          >>>  VERSION 3.2, March 2008 <<<
*
*===================================================================;
FILENAME CONTROL 'C:\PATHNAME\CONTROL_PDI.SAS';  *<===USER MUST modify;

%INCLUDE CONTROL;

 TITLE2 'PROGRAM: P2';
 TITLE3 'AHRQ PEDIATRIC QUALITY INDICATORS: CALCULATE OBSERVED PROVIDER RATES';

 * -------------------------------------------------------------- ;
 * --- PROVIDER LEVEL MEANS ON PEDIATRIC DATA FILE  ------------- ;
 * -------------------------------------------------------------- ;

 PROC   SUMMARY DATA=INP2.&INFILEP2.;
 CLASS  HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT;
 VAR    TPPD01-TPPD13;
 OUTPUT OUT=&OUTFILP2.
        SUM (TPPD01-TPPD13)=
        SUMWGT(TPPD01-TPPD06 TPPD08-TPPD13)=PPPD01-PPPD06 PPPD08-PPPD13
        MEAN(TPPD01-TPPD06 TPPD08-TPPD13)=OPPD01-OPPD06 OPPD08-OPPD13;
 WEIGHT DISCWT;
 RUN;

 PROC   SORT DATA=&OUTFILP2.;
 BY HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT;
 RUN;

 DATA   OUTP2.&OUTFILP2.;
 SET    &OUTFILP2. (WHERE=(_TYPE_ &TYPELVLP))
;

 LABEL
 TPPD01 = 'ACCIDENTAL PUNCTURE AND LACERATION (Num)'
 TPPD02 = 'DECUBITUS ULCER (Numerator)'
 TPPD03 = 'FOREIGN BODY LEFT IN DURING PROC (Num)'
 TPPD04 = 'IATROGENIC PNEUMOTHORAX NEONATE (Num)'
 TPPD05 = 'IATROGENIC PNEUMOTHORAX (Numerator)'
 TPPD06 = 'IN-HOSP MORT PEDIATRIC HEART SURG (Num)'
 TPPD07 = 'VOLUME PEDIATRIC HEART SURGERY (Num)'
 TPPD08 = 'POSTOP HEMORRHAGE OR HEMATOMA (Num)'
 TPPD09 = 'POSTOP RESPIRATORY FAILURE (Numerator)'
 TPPD10 = 'POSTOPERATIVE SEPSIS (Numerator)' 
 TPPD11 = 'POSTOPERATIVE WOUND DEHISCENCE (Num)'
 TPPD12 = 'INFECTION DUE TO MEDICAL CARE (Num)'
 TPPD13 = 'TRANSFUSION REACTION (Numerator)'
 PPPD01 = 'ACCIDENTAL PUNCTURE AND LACERATION (Pop)'
 PPPD02 = 'DECUBITUS ULCER (Population)'
 PPPD03 = 'FOREIGN BODY LEFT IN DURING PROC (Pop)'
 PPPD04 = 'IATROGENIC PNEUMOTHORAX NEONATE (Pop)'
 PPPD05 = 'IATROGENIC PNEUMOTHORAX (Population)'
 PPPD06 = 'IN-HOSP MORT PEDIATRIC HEART SURG (Pop)'
 PPPD08 = 'POSTOP HEMORRHAGE OR HEMATOMA (Pop)'
 PPPD09 = 'POSTOP RESPIRATORY FAILURE (Population)'
 PPPD10 = 'POSTOPERATIVE SEPSIS (Population)' 
 PPPD11 = 'POSTOPERATIVE WOUND DEHISCENCE (Pop)'
 PPPD12 = 'INFECTION DUE TO MEDICAL CARE (Pop)'
 PPPD13 = 'TRANSFUSION REACTION (Population)'
 OPPD01 = 'ACCIDENTAL PUNCTURE AND LACERATION (Obs)'
 OPPD02 = 'DECUBITUS ULCER (Observed)'
 OPPD03 = 'FOREIGN BODY LEFT IN DURING PROC (Obs)'
 OPPD04 = 'IATROGENIC PNEUMOTHORAX NEONATE (Obs)'
 OPPD05 = 'IATROGENIC PNEUMOTHORAX (Observed)'
 OPPD06 = 'IN-HOSP MORT PEDIATRIC HEART SURG (Obs)'
 OPPD08 = 'POSTOP HEMORRHAGE OR HEMATOMA (Obs)'
 OPPD09 = 'POSTOP RESPIRATORY FAILURE (Observed)'
 OPPD10 = 'POSTOPERATIVE SEPSIS (Observed)' 
 OPPD11 = 'POSTOPERATIVE WOUND DEHISCENCE (Obs)'
 OPPD12 = 'INFECTION DUE TO MEDICAL CARE (Obs)'
 OPPD13 = 'TRANSFUSION REACTION (Observed)'
 _TYPE_ = 'STRATIFICATION LEVEL'
;
 DROP _FREQ_ ;

 RUN;

 * -------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF PROVIDER OBSERVED MEANS FILE ------- ;
 * -------------------------------------------------------------- ;

 PROC   CONTENTS DATA=OUTP2.&OUTFILP2. POSITION;
 RUN;

 PROC   MEANS DATA=OUTP2.&OUTFILP2. (WHERE=(_TYPE_ IN (64))) N NMISS MIN MAX MEAN SUM;
 TITLE4 "SUMMARY OF PROVIDER-LEVEL RATES (_TYPE_=64)";
 RUN;

 * -------------------------------------------------------------- ;
 * --- PRINT PROVIDER OBSERVED MEANS FILE ----------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PD,TEXT,VOLUME);

 PROC   PRINT DATA=OUTP2.&OUTFILP2. LABEL SPLIT='*';
 %IF &VOLUME=0 %THEN %DO;
 VAR    HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT TPPD&PD. PPPD&PD. OPPD&PD. ;
 LABEL HOSPID  = "HOSPID"
       BWHTCAT = "BWHTCAT"
       AGEDCAT = "AGEDCAT"
       PAGECAT = "PAGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TPPD&PD.   = "TPPD&PD.*(Numerator)"
       PPPD&PD.   = "PPPD&PD.*(Denominator)"
       OPPD&PD.   = "OPPD&PD.*(Observed)"
       ;
 FORMAT BWHTCAT BWHTCAT.
        AGEDCAT AGEDCAT.
        PAGECAT PAGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
        TPPD&PD. PPPD&PD. 13.0 OPPD&PD. 8.6;
 %END;
 %ELSE %DO;
 VAR    HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT TPPD&PD.  ;
 LABEL HOSPID  = "HOSPID"
       BWHTCAT = "BWHTCAT"
       AGEDCAT = "AGEDCAT"
       PAGECAT = "PAGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TPPD&PD.   = "TPPD&PD.*(Numerator)"
       ;
 FORMAT BWHTCAT BWHTCAT.
        AGEDCAT AGEDCAT.
        PAGECAT PAGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
        TPPD&PD. 13.0;
 %END;
 TITLE4 "Indicator # &PD.: &TEXT";

 RUN;

 %MEND PRT;

 %PRT(01,ACCIDENTAL PUNCTURE AND LACERATION,0);
 %PRT(02,DECUBITUS ULCER,0);
 %PRT(03,FOREIGN BODY LEFT IN DURING PROC,0);
 %PRT(04,IATROGENIC PNEUMOTHORAX NEONATE,0); 
 %PRT(05,IATROGENIC PNEUMOTHORAX,0);
 %PRT(06,IN-HOSP MORT PEDIATRIC HEART SURG,0);
 %PRT(07,VOLUME PEDIATRIC HEART SURGERY,1);
 %PRT(08,POSTOP HEMORRHAGE OR HEMATOMA,0);
 %PRT(09,POSTOP RESPIRATORY FAILURE,0);
 %PRT(10,POSTOPERATIVE SEPSIS,0);
 %PRT(11,POSTOPERATIVE WOUND DEHISCENCE,0);
 %PRT(12,INFECTION DUE TO MEDICAL CARE,0);
 %PRT(13,TRANSFUSION REACTION,0);

 %END;

 %MEND PRT2;

 %PRT2;


 * -------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
 * --- FOR EXPORT INTO SPREADSHEETS ----------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO TEXTP2;

 %IF &TEXTP2. = 1  %THEN %DO;

 DATA _NULL_;
   SET OUTP2.&OUTFILP2.;
 FILE PDTEXTP2 LRECL=2000;
 IF _N_=1 THEN PUT "Hosp Id" "," "BWht" "," "AgeD" "," "Age"  "," "Sex"  "," "Payer" "," "Race" "," "Type" ","
 "TPPD01" "," "TPPD02" "," "TPPD03" "," "TPPD04" ","
 "TPPD05" "," "TPPD06" "," "TPPD07" "," "TPPD08" ","
 "TPPD09" "," "TPPD10" "," "TPPD11" "," "TPPD12" ","
 "TPPD13" "," 
 "PPPD01" "," "PPPD02" "," "PPPD03" "," "PPPD04" ","
 "PPPD05" "," "PPPD06" ","              "PPPD08" ","
 "PPPD09" "," "PPPD10" "," "PPPD11" "," "PPPD12" ","
 "PPPD13" "," 
 "OPPD01" "," "OPPD02" "," "OPPD03" "," "OPPD04" ","
 "OPPD05" "," "OPPD06" ","              "OPPD08" ","
 "OPPD09" "," "OPPD10" "," "OPPD11" "," "OPPD12" ","
 "OPPD13" 
 ;

 PUT HOSPID 13. "," BWHTCAT 3. "," AGEDCAT 3. "," PAGECAT 3. "," SEXCAT 3. "," PAYCAT 3. "," RACECAT 3. "," _TYPE_ 2.  ","
 (TPPD01-TPPD13) (7.0 ",")
  ","
 (PPPD01-PPPD06 PPPD08-PPPD13) (13.2 ",")
 ","
 (OPPD01-OPPD06 OPPD08-OPPD13) (12.10 ",")
 ;
 RUN;

 %END;

 %MEND TEXTP2;

 %TEXTP2;
