*============================================================================;
* Title:
*     Format Library for Pediatric Quality Indicators Program;
*
* Description:
*     FORMAT LIB FOR AHRQ PEDIATRIC QUALITY INDICATORS;
*
*          >>>  VERSION 3.2, March 2008 <<<
*
*     Note: Codes valid from 10/1/1994 to 9/30/2008
* 
*============================================================================;
FILENAME CONTROL "C:\PATHNAME\CONTROL_PDI.SAS";          *<==USER MUST modify;

%INCLUDE CONTROL;

PROC FORMAT DDNAME=LIBRARY;

 /* -------------------------------------------------------------- */
 /* --- FORMATS FOR STRATIFIERS ---------------------------------- */
 /* -------------------------------------------------------------- */

 /* --- FORMAT FOR SEX CATEGORY ---------------------------------- */
VALUE SEXCAT
 1 = 'Male'
 2 = 'Female'
  ;

 /* --- FORMAT FOR AGE CATEGORY ---------------------------------- */
VALUE PAGECAT
 1 = "<1"
 2 = "1 TO 2"
 3 = "3 TO 5"
 4 = "6 TO 12"
 5 = "13 TO 17"
 ;

 /* --- FORMAT FOR AGEDAY CATEGORY ------------------------------- */
VALUE AGEDCAT
 0 = "NA"
 1 = "0 TO 28"
 2 = "29 TO 60"
 3 = "61 TO 90"
 4 = "91+"
 ;

 /* --- FORMAT FOR BIRTH WEIGHT CATEGORY ------------------------- */
VALUE BWHTCAT
 0 = "NA"
 1 = "0 TO 499g"
 2 = "500 TO 999g"
 3 = "1000 TO 1499g"
 4 = "1500 TO 1999g"
 5 = "2000 TO 2500g"
 ;

 /* --- FORMAT FOR RACE CATEGORY --------------------------------- */
VALUE RACECAT
 1 = 'White'
 2 = 'Black'
 3 = 'Hispanic'
 4 = 'Asian and NH/PI'
 5 = 'Amer Indian/AN'
 6 = 'Other'
  ;

 /* --- FORMAT FOR PAYER CATEGORY ---------------------------------- */
VALUE PAYCAT
 1 = 'Medicare'
 2 = 'Medicaid'
 3 = 'Private'
 4 = 'Self Pay'
 5 = 'No Charge'
 6 = 'Other'
  ;

 /* --- FORMAT FOR POPULATION CATEGORY ----------------------------- */
VALUE POPCAT
 1 = '0 to 4'
 2 = '5 to 9'
 3 = '10 to 14'
 4 = '15 to 17'
  ;

/* -------------------------------------------------------------- */
 /* --- FORMATS FOR stratification variables--------------------- */
 /* -------------------------------------------------------------- */

  /* ---ACCIDENTAL PUNCTURE AND LACERATION------------- */

  VALUE GP01CAT
  1='Eye, ear, nose, mouthm throat, skin, breast and other low-risk procedures'
  2='Thoracic, cardiovascular, and specified neoplastic procedures'
  3='Kidney, and male/female reproductive procedures'
  4='Infectious, immunological, hematological, and ungroupable procedures'
  5='Trauma, orthopedic, and neurologic procedures'
  6='Gastrointestinal, hepatobiliary, and endocrine procedures';


  /* --- DECUBITUS ULCER------------- */

  VALUE GP02CAT
  1='Low risk'
  2='High risk';


  /* --- POSTOPERATIVE HEMORRHAGE OR HEMATOMA------------- */

  VALUE GP08CAT
  1='Low risk'
  2='High risk';

  /* --- POSTOPERATIVE SEPSIS------------- */

  VALUE GP10CAT
  1='Clean, elective'
  2='Clean, non-elective'
  3='Contaminated, elective'
  4='Contaminated, non-elective'
  5='Dirty';


  /* --- POSTOPERATIVE WOUND DEHISCENCE------------- */

  VALUE GP11CAT
  1='Clean, elective'
  2='Clean, non-elective'
  3='Contaminated, elective'
  4='Contaminated, non-elective'
  5='Dirty';


   /* --- SELECTED INFECTION DUE TO MEDICAL CARE----- */

 VALUE GP12CAT
  1='Low risk immunodeficient'
  2='Intermediate risk immunodeficient'
  3='High risk immunodeficient';





 * -------------------------------------------------------------- ;
 * --- PSI DEFINING FORMATS ------------------------------------- ;
 * -------------------------------------------------------------- ;

 * -------------------------------------------------------------- ;
 * --- FORMATS - PROVIDER AND AREA LEVEL INDICATORS ------------- ;
 * -------------------------------------------------------------- ;

 /* ------------------------------ */
 /* NEONATE AND NEWBORN            */
 /* ------------------------------ */

 /* Liveborn (Populaton at Risk)           */
 /* ICD-9-CM Diagnosis Codes:              */

VALUE $LIVEBND
'V3000' = 1  /* SINGLE LB IN-HOSP W/O CS */
'V3001' = 1  /* SINGLE LB IN-HOSP W CS */
'V3100' = 1  /* TWIN-MATE LB-HOSP W/O CS */
'V3101' = 1  /* TWIN-MATE LB-IN HOS W CS */
'V3200' = 1  /* TWIN-MATE SB-HOSP W/O CS */
'V3201' = 1  /* TWIN-MATE SB-HOSP W CS */
'V3300' = 1  /* TWIN-NOS-IN HOSP W/O CS */
'V3301' = 1  /* TWIN-NOS-IN HOSP W CS */
'V3400' = 1  /* OTH MULT LB-HOSP W/O CS */
'V3401' = 1  /* OTH MULT LB-IN HOSP W CS */
'V3500' = 1  /* OTH MULT SB-HOSP W/O CS */
'V3501' = 1  /* OTH MULT SB-IN HOSP W CS */
'V3600' = 1  /* MULT LB/SB-IN HOS W/O CS */
'V3601' = 1  /* MULT LB/SB-IN HOSP W CS */
'V3700' = 1  /* MULT BRTH NOS-HOS W/O CS */
'V3701' = 1  /* MULT BIRTH NOS-HOSP W CS */
'V3900' = 1  /* LIVEBORN NOS-HOSP W/O CS */
'V3901' = 1  /* LIVEBORN NOS-HOSP W CS */
OTHER   = 0 ;

VALUE $V29D
"V290"  = "1" /* OBSERVATIONS FOR SUSPECTED INFECTIOUS CONDITION */
"V291"  = "1" /* OBSERVATIONS FOR SUSPECTED NEUROLOGICAL CONDITION */
"V292"  = "1" /* OBSERVATIONS FOR SUSPECTED RESPIRATORY CONDITION */
"V293"  = "1" /* OBSERVATIONS FOR SUSPECTED GENETIC OR METABOLIC CONDITION */
"V298"  = "1" /* OBSERVATIONS FOR OTHER SPECIFIED SUSPECTED CONDITION */
"V299"  = "1" /* OBSERVATIONS FOR UNSPECIFIED SUSPECTED CONDITION */
OTHER   = "0";

VALUE $LIVEB2D
'V301 ' = 1  /* SINGL LIVEBRN-BEFORE ADM */
'V302 ' = 1  /* SINGLE LIVEBORN-NONHOSP */
'V311 ' = 1  /* TWIN, MATE LB-BEFORE ADM */
'V312 ' = 1  /* TWIN, MATE LB-NONHOSP */
'V321 ' = 1  /* TWIN, MATE SB-BEFORE ADM */
'V322 ' = 1  /* TWIN, MATE SB-NONHOSP */
'V331 ' = 1  /* TWIN NOS-BEFORE ADMISSN */
'V332 ' = 1  /* TWIN NOS-NONHOSP */
'V341 ' = 1  /* OTH MULT NB-BEFORE ADM */
'V342 ' = 1  /* OTH MULTIPLE NB-NONHOSP */
'V351 ' = 1  /* OTH MULT SB-BEFORE ADM */
'V352 ' = 1  /* OTH MULTIPLE SB-NONHOSP */
'V361 ' = 1  /* MULT NB/SB-BEFORE ADM */
'V362 ' = 1  /* MULTIPLE NB/SB-NONHOSP */
'V371 ' = 1  /* MULT BRTH NOS-BEFORE ADM */
'V372 ' = 1  /* MULT BIRTH NOS-NONHOSP */
'V391 ' = 1  /* LIVEBORN NOS-BEFORE ADM */
'V392 ' = 1  /* LIVEBORN NOS-NONHOSP */
OTHER   = 0 ;

 /* ---------------------------------------------------------------- */
 /* ADULT DRGS                                                       */
 /* ---------------------------------------------------------------- */

 /* DIAGNOSTIC RELATED GROUPS (DRGS): */

VALUE $ADULTDR
"001" = "1" /* CRANIOTOMY, AGE GREATER THAN 17 EXCEPT FOR TRAUMA */
"002" = "1" /* CRANIOTOMY FOR TRAUMA, AGE GREATER THAN 17 */
"024" = "1" /* SEIZURE AND HEADACHE, AGE GREATER THAN 17 WITH CC */
"025" = "1" /* SEIZURE AND HEADACHE, AGE GREATER THAN 17 WITHOUT CC */
"028" = "1" /* TRAUMATIC STUPOR AND COMA, COMA LESS THAN ONE HOUR, AGE GREATER THAN 17 WITH CC */
"029" = "1" /* TRAUMATIC STUPOR AND COMA, COMA LESS THAN ONE HOUR, AGE GREATER THAN 17 WITHOUT CC */
"031" = "1" /* CONCUSSION, AGE GREATER THAN 17 WITH CC */
"032" = "1" /* CONCUSSION, AGE GREATER THAN 17 WITHOUT CC */
"040" = "1" /* EXTRAOCULAR PROCEDURES EXCEPT ORBIT, AGE GREATER THAN 17 */
"046" = "1" /* OTHER DISORDERS OF THE EYE, AGE GREATER THAN 17 WITH CC */
"047" = "1" /* OTHER DISORDER OF THE EYE, AGE GREATER THAN 17 WITHOUT CC */
"053" = "1" /* SINUS AND MASTOID PROCEDURES, AGE GREATER THAN 17 */
"057" = "1" /* TONSILLECTOMY AND ADENOIDECTOMY PROCEDURES EXCEPT TONSILLECTOMY AND/OR ADENOIDECTOMY ONLY, AGE GREATER THAN 17 */
"059" = "1" /* TONSILLECTOMY AND/OR ADENOIDECTOMY ONLY, AGE GREATER THAN 17 */
"061" = "1" /* MYRINGOTOMY WITH TUBE INSERTION, AGE GREATER THAN 17 */
"068" = "1" /* OTITIS MEDIA AND URI, AGE GREATER THAN 17 WITH CC */
"069" = "1" /* OTITIS MEDIA AND URI, AGE GREATER THAN 17 WITHOUT CC */
"073" = "1" /* OTHER EAR, NOSE, MOUTH AND THROAT DIAGNOSES, AGE GREATER THAN 17 */
"079" = "1" /* RESPIRATORY INFECTIONS AND INFLAMMATIONS, AGE GREATER THAN 17 WITH CC */
"080" = "1" /* RESPIRATORY INFECTIONS AND INFLAMMATIONS, AGE GREATER THAN 17 WITHOUT CC */
"089" = "1" /* SIMPLE PNEUMONIA AND PLEURISY, AGE GREATER THAN 17 WITH CC */
"090" = "1" /* SIMPLE PNEUMONIA AND PLEURISY, AGE GREATER THAN 17 WITHOUT CC */
"096" = "1" /* BRONCHITIS AND ASTHMA, AGE GREATER THAN 17 WITH CC */
"097" = "1" /* BRONCHITIS AND ASTHMA, AGE GREATER THAN 17 WITHOUT CC */
"135" = "1" /* CARDIAC CONGENITAL AND VALVULAR DISORDERS, AGE GREATER THAN 17 WITH CC */
"136" = "1" /* CARDIAC CONGENITAL AND VALVULAR DISORDERS, AGE GREATER THAN 17 WITHOUT CC */ 
"154" = "1" /* STOMACH, ESOPHAGEAL AND DUODENAL PROCEDURES, AGE GREATER THAN 17 WITH CC */
"155" = "1" /* STOMACH, ESOPHAGEAL AND DUODENAL PROCEDURES, AGE GREATER THAN 17 WIHOUT CC*/
"159" = "1" /* HERMIA PROCEDURES EXCEPT INGUINAL AND FEMORAL , AGE GREATER THAN 17 WITH CC */
"160" = "1" /* HERNIA PROCEDURES EXCEPT INGUINAL AND FEMORAL, AGE GREATER THAN 17 WITHOUT CC */
"161" = "1" /* INGUINAL AND FEMORAL HERNIA PROCEDURES, AGE GREATER THAN 17 WITH CC */
"162" = "1" /* INGUINAL AND FEMORAL HERNIA PROCEDURES, AGE GREATER THAN 17 WITHOUT CC */
"182" = "1" /* ESOPHAGITIS, GASTROENTERITIS AND MISCELLANEOUS DIGESTIVE DISORDERS, AGE GREATER THAN 17 WITH CC */
"183" = "1" /* ESOPHAGITIS, GASTROENTERITIS AND MISCELLANEOUS DIGESTIVE DISORDERS, AGE GREATER THAN 17 WITHOUT CC */
"185" = "1" /* DENTAL AND ORAL DISEASES EXCEPT EXTRACTIONS AND RESTORATIONS, AGE GREATER THAN 17 */
"188" = "1" /* OTHER DIGESTIVE SYSTEM DIAGNOSES, AGE GREATER THAN 17 WITH CC */
"189" = "1" /* OTHER DIGESTIVE SYSTEM DIAGNOSES, AGE GREATER THAN 17 WITHOUT CC */
"210" = "1" /* HIP AND FEMUR PROCEDURES EXCEPT MAJOR JOINT PROCEDURES, AGE GREATER THAN 17 WITH CC */
"211" = "1" /* HIP AND FEMUR PROCEDURES EXCEPT MAJOR JOINT PROCEDURES, AGE GREATER THAN 17 WITHOUT CC */
"218" = "1" /* LOWER EXTREMITY AND HUMERUS PROCEURES EXCEPT HIP, FOOT AND FEMUR, AGE GREATER THAN 17 WITH CC */
"219" = "1" /* LOWER EXTREMITY AND HUMERUS PROCEDURES EXCEPT HIP, FOOT AND FEMUR, AGE GREATER THAN 17 WITHOUT CC */
"250" = "1" /* FRACTURES, SPRAINS, STRAINS AND DISLOCATIONS OF FOREARM, HAND AND FOOT, AGE GREATER THAN 17 WITH CC */
"251" = "1" /* FRACTURES, SPRAINS, STRAINS AND DISLOCATIONS OF FOREARM, HAND AND FOOT, AGE GREATER THAN 17 WITHOUT CC */
"253" = "1" /* FRACTURES, SPRAINS, STRAINS AND DISLOCATIONS OF UPPER ARM AND LOWER LEG EXCEPT FOOT, AGE GREATER THAN 17 WITH CC */
"254" = "1" /* FRACTURES, SPRAINS, STRAINS AND DISLOCATIONS OF UPPER ARM AND LOWER LEG EXCEPT FOOT, AGE GREATER THAN 17 WITHOUT CC */
"277" = "1" /* CELLULITIS, AGE GREATER THAN 17 WITH CC */
"278" = "1" /* CELLULTIIS, AGE GREATER THAN 17 WITHOUT CC */
"280" = "1" /* TRAUMA TO SKIN, SUBCUTANEOUS TISSUE AND BREAST, AGE GREATER THAN 17 WITH CC */
"281" = "1" /* TRAUMA TO SKIN, SUBCUTANEOUS TISSUE AND BREAST, AGE GREATER THAN 17 WITHOUT CC */
"294" = "1" /* DIABETES, AGE GREATER THAN 35 */
"296" = "1" /* NUTRITIONAL AND MISCELLANEOUS METABOLIC DISORDERS, AGE GREATER THAN 17 WITH CC */
"297" = "1" /* NUTRITIONAL AND MISCELLANEOUS METABOLIC DISORDERS, AGE GREATER THAN 17 WITHOUT CC */
"312" = "1" /* URETHRAL PROCEDURES, AGE GREATER THAN 17 WITH CC */
"313" = "1" /* URETHRAL PROCEDURES, AGE GREATER THAN 17 WITHOUT CC */
"320" = "1" /* KIDNEY AND URINARY TRACT INFECTIONS, AGE GREATER THAN 17 WITH CC */
"321" = "1" /* KIDNEY AND URINARY TRACT INFECTIONS, AGE GREATER THAN 17 WITHOUT CC */
"325" = "1" /* KIDNEY AND URINARY TRACT SIGNS AND SYMPTOMS, AGE GREATER THAN 17 WITH CC */
"326" = "1" /* KIDNEY AND URINARY TRACT SIGNS AND SYMPTOMS, AGE GREATER THAN 17 WITHOUT CC */
"328" = "1" /* URETHRAL STRICTURE, AGE GREATER THAN 17 WITH CC */
"329" = "1" /* URETHRAL STRICTURE, AGE GREATER THAN 17 WITHOUT CC */
"331" = "1" /* OTHER KIDNEY AND URINARY TRACT DIAGNOSES, AGE GREATER THAN 17 WITH CC */
"332" = "1" /* OTHER KIDNEY AND URINARY TRACT DIAGNOSES, AGE GREATER THAN 17 WITHOUT CC */
"339" = "1" /* TESTES PROCEDURES FOR NONMALIGNANCY, AGE GREATER THAN 17 */
"342" = "1" /* CIRCUMCISION, AGE GREATER THAN 17 */
"392" = "1" /* SPLENECTOMY, AGE GREATER THAN 17 */
"395" = "1" /* RED BLOOD CELL DISORDERS, AGE GREATER THAN 17 */
"416" = "1" /* SEPTICEMIA, AGE GREATER THAN 17 */
"419" = "1" /* FEVER OF UNKNOWN ORIGIN, AGE GREATER THAN 17 WITH CC */
"420" = "1" /* FEVER OF UNKNOWN ORIGIN, AGE GREATER THAN 17 WITHOUT CC */
"421" = "1" /* VIRAL ILLNESS, AGE GREATER THAN 17 */
"444" = "1" /* TRAUMATIC INJURY, AGE GREATER THAN 17 WITH CC */
"445" = "1" /* TRAUMATIC INJURY, AGE GREATER THAN 17 WITHOUT CC */
"447" = "1" /* ALLERGIC REACTIONS, AGE GREATER THAN 17 */
"449" = "1" /* POISONING AND TOXIC EFFECTS OF DRUGS, AGE GREATER THAN 17 WITH CC */
"450" = "1" /* POISONING AND TOXIC EFFECTS OF DRUGS, AGE GREATER THAN 17 WITHOUT CC */
"473" = "1" /* ACUTE LEUKEMIA WITHOUT MAJOR OR PROCEDURE, AGE GREATER THAN 17 */
"562" = "1" /* SEIZURE AGE > 17 W CC */
"563" = "1" /* SEIZURE AGE > 17 W/O CC */
"564" = "1" /* HEADACHES AGE >17 */
"567" = "1" /* STOMACH, ESOPHAGEAL & DUODENAL PROC AGE > 17 W CC W MAJOR GI DX */
"568" = "1" /* STOMACH, ESOPHAGEAL & DUODENAL PROCEDURES PROC AGE > 17 W CC W/O MAJOR GI DX */
"575" = "1" /* SEPTICEMIA W MV96+ HOURS  AGE  >17 */
"576" = "1" /* SEPTICEMIA W/O MV96+ HOURS AGE  >17 */
OTHER  = "0" ;

 /* ---------------------------------------------------------------- */
 /* MEDICAL DRGS (deleted Adult DRGs)                                */
 /* ---------------------------------------------------------------- */

 /* DIAGNOSTIC RELATED GROUPS (DRGS): */

VALUE $MEDICDR
"009" = "1" /* SPINAL DISORDERS AND INJURIES */
"010" = "1" /* NERVOUS SYSTEM NEOPLASMS WITH CC */
"011" = "1" /* NERVOUS SYSTEM NEOPLASMS WITH CC */
"012" = "1" /* DEGENERATIVE NERVOUS SYSTEM DISORDERS */
"013" = "1" /* MULTIPLE SCLEROSIS AND CEREBELLAR ATAXIA */
"014" = "1" /* SPECIFIC CEREBROVASCULAR DISORDERS EXCEPT TRANSIENT ISCHEMIC ATTACK */
"015" = "1" /* TRANSIENT ISCHEMIC ATTACK AND PRECEREBRAL OCCLUSIONS */
"016" = "1" /* NONSPECIFIC CEREBROVASCULAR DISORDERS WITH CC */
"017" = "1" /* NONSPECIFIC CEREBROVASCULAR DISORDERS WITHOUT CC */
"018" = "1" /* CRANIAL AND PERIPHERAL NERVE DISORDERS WITH CC */
"019" = "1" /* CRANIAL AND PERIPHERAL NERVE DISORDERS WITHOUT CC */
"020" = "1" /* NERVOUS SYSTEM INFECTION EXCEPT VIRAL MENINGITIS */
"021" = "1" /* VIRAL MENINGITIS */
"022" = "1" /* HYPERTENSIVE ENCEPHALOPATHY */
"023" = "1" /* NONTRAUMATIC STUPOR AND COMA */
"026" = "1" /* SEIZURE AND HEADACHE, AGE 0-17 */
"027" = "1" /* TRAUMATIC STUPOR AND COMA, COMA GREATER THAN ONE HOUR */
"030" = "1" /* TRAUMATIC STUPOR AND COMA, COMA LESS THAN ONE HOUR, AGE 0-17 */
"033" = "1" /* CONCUSSION, AGE 0-17 */
"034" = "1" /* OTHER DISORDERS OF NERVOUS SYSTEM WITH CC */
"035" = "1" /* OTHER DISORDERS OF NERVOUS SYSTEM WITHOUT CC */
"043" = "1" /* HYPHEMA */
"044" = "1" /* ACUTE MAJOR EYE INFECTIONS */
"045" = "1" /* NEUROLOGICAL EYE DISORDERS */
"048" = "1" /* OTHER DISORDERS OF THE EYE, AGE 0-17 */
"064" = "1" /* EAR, NOSE, MOUTH AND THROAT MALIGNANCY */
"065" = "1" /* DISEQUILIBRIA */
"066" = "1" /* EPISTAXIS */
"067" = "1" /* EPIGLOTTITIS */
"070" = "1" /* OTITIS MEDIA AND URI, AGE 0-17 */
"071" = "1" /* LARYNGOTRACHEITIS */
"072" = "1" /* NASAL TRAUMA AND DEFORMITY */
"074" = "1" /* OTHER EAR, NOSE, MOUTH AND THROAT DIAGNOSES, AGE 0-17 */
"078" = "1" /* PULMONARY EMBOLISM */
"081" = "1" /* RESPIRATORY INFECTIONS AND INFLAMMATIONS, AGE 0-17 */
"082" = "1" /* RESPIRATORY NEOPLASMS */
"083" = "1" /* MAJOR CHEST TRAUMA WITH CC */
"084" = "1" /* MAJOR CHEST TRAUMA WITHOUT CC*/
"085" = "1" /* PLEURAL EFFUSION WITH CC */
"086" = "1" /* PLEURAL EFFUSION WITHOUT CC */
"087" = "1" /* PULMONARY EDEMA AND RESPIRATORY FAILURE */
"088" = "1" /* CHRONIC OBSTRUCTIVE PULMONARY DISEASE */
"091" = "1" /* SIMPLE PNEUMONIA AND PLEURISY, AGE 0-17 */
"092" = "1" /* INTERSTITIAL LUNG DISEASE WITH CC */
"093" = "1" /* INTERSTITIAL LUNG DISEASE WITHOUT CC */
"094" = "1" /* PNEUMOTHORAX WITH CC */
"095" = "1" /* PNEUMOTHORAX WITHOUT CC */
"098" = "1" /* BRONCHITIS AND ASTHMA, AGE 0-17 */
"099" = "1" /* RESPIRATORY SIGNS AND SYMPTOMS WITH CC */
"100" = "1" /* RESPIRATORY SIGNS AND SYMPTOMS WITHOUT CC */
"101" = "1" /* OTHER RESPIRATORY SYSTEM DIAGNOSES WITH CC */
"102" = "1" /* OTHER RESPIRATORY SYSTEM DIAGNOSES WITHOUT CC */
"121" = "1" /* CIRCULATORY DISORDERS WITH ACUTE MYOCARDIAL INFARCTION AND MAJOR COMPLICATION, DISCHARGED ALIVE */
"122" = "1" /* CIRCULATORY DISORDERS WITH ACUTE MYOCARDIAL INFARCTION WITHOUT MAJOR COMPLICATION, DISCHARGED ALIVE */
"123" = "1" /* CIRCULATORY DISORDERS WITH ACUTE MYOCARDIAL INFARCTION, EXPIRED */
"124" = "1" /* CIRCULATORY DISORDERS EXCEPT ACUTE MYOCARDIAL INFARCTION WITH CARDIAC CATHETERIZATION AND COMPLEX DIAGNOSIS */
"125" = "1" /* CIRCULATORY DISORDERS EXCEPT ACUTE MYOCARDIAL INFARCTION WITH CARDIAC CATHETERIZATION WITHOUT COMPLEX DIAGNOSIS */
"126" = "1" /* ACUTE AND SUB ACUTE ENDOCARDITIS */
"127" = "1" /* HEART FAILURE AND SHOCK */
"128" = "1" /* DEEP VEIN THROMBOPHLEBITIS */
"129" = "1" /* CARDIAC ARREST, UNEXPLAINED */
"130" = "1" /* PERIPHERAL VASCULAR DISORDERS WITH CC */
"131" = "1" /* PERIPHERAL VASCULAR DISORDERS WITHOUT CC */
"132" = "1" /* ATHEROSCLEROSIS WITH CC */
"133" = "1" /* ATHEROSCLEROSIS WITHOUT CC */
"134" = "1" /* HYPERTENSION */
"137" = "1" /* CARDIAC CONGENITAL AND VALVULAR DISORDERS, AGE 0 - 17*/
"138" = "1" /* CARDIAC ARRHYTHMIA AND CONDUCTION DISORDERS WITH CC */
"139" = "1" /* CARDIAC ARRHYTHMIA AND CONDUCTION DISORDERS WITHOUT CC */
"140" = "1" /* ANGINA PECTORIS*/
"141" = "1" /* SYNCOPE AND COLLAPSE WITH CC */
"142" = "1" /* SYNCOPE AND COLLAPSE WITHOUT CC */
"143" = "1" /* CHEST PAIN */
"144" = "1" /* OTHER CIRCULATORY SYSTEM DIAGNOSES WITH CC*/
"145" = "1" /* OTHER CIRCULATORY SYSTEM DIAGNOSES WITHOUT CC */
"172" = "1" /* DIGESTIVE MALIGNANCY WITH CC */
"173" = "1" /* DIGESTIVE MALIGNANCY WITHOUT CC */
"174" = "1" /* GI HEMORRHAGE WITH CC*/
"175" = "1" /* GI HEMORRHAGE WITHOUT CC */
"176" = "1" /* COMPLICATED PEPTIC ULCER */
"177" = "1" /* UNCOMPLICATED PEPTIC ULCER WITH CC */
"178" = "1" /* UNCOMPLICATED PEPTIC ULCER WITHOUT CC*/
"179" = "1" /* INFLAMMATORY BOWEL DISEASE */
"180" = "1" /* GI OBSTRUCTION WITH CC */
"181" = "1" /* GI OBSTRUCTION WITHOUT CC */
"184" = "1" /* ESOPHAGITIS, GASTROENTERITIS AND MISCELLANESOU DIGESTIVE DISORDERS, AGE 0-17 */
"186" = "1" /* DENTAL AND ORAL DISEASED EXCEPT EXTRACTIONS AND RESTORATIONS, AGE 0-17 */
"187" = "1" /* DENTAL EXTRACTIONS AND RESTORATIONS */
"190" = "1" /* OTHER DIGESTIVE SYSTEM DIAGNOSES, AGE 0-17 */
"202" = "1" /* CIRRHOSIS AND ALCOHOLIC HEPATITIS */
"203" = "1" /* MALIGNANCY OF HEPATOBILIARY SYSTEM OR PANCREAS */
"204" = "1" /* DISORDERS OF PANCREAS EXCEPT MALIGNANCY */
"205" = "1" /* DISORDERS OF LIVER EXCEPT MALIGNANCY, CIRRHOSIS AND ALCOHOLIC HEPATITIS WITH CC */
"206" = "1" /* DISORDERS OF LIVER EXCEPT MALIGNANCY, CIRRHOSIS AND ALCOHOLIC HEPATITIS WITHOUT CC */
"207" = "1" /* DISORDERS OF THE BILIARY TRACT WITH CC */
"208" = "1" /* DISORDERS OF THE BILIARY TRACT WITHOUT CC */
"235" = "1" /* FRACTURES OF FEMUR */
"236" = "1" /* FRACTURES OF HIP AND PELVIS */
"237" = "1" /* SPRAINS, STRAINS AND DISLOCATIONS OF HIP, PELVIS AND THIGH */
"238" = "1" /* OSTEOMYELITIS */
"239" = "1" /* PATHOLOGICAL FRACTURES AND MUSCULOSKELETAL AND CONNECTIVE TISSUE MALIGNANCY */
"240" = "1" /* CONNECTIVE TISSUE DISORDERS WITH CC */
"241" = "1" /* CONNECTIVE TISSUE DISORDERS WITHOUT CC */
"242" = "1" /* SEPTIC ARTHRITIS */
"243" = "1" /* MEDICAL BACK PROBLEMS */
"244" = "1" /* BONE DISEASES AND SPECIFIC ARTHROPATHIES WITH CC */
"245" = "1" /* BONE DISEASES AND SPECIFIC ARTHROPATHIES WITHOUT CC */
"246" = "1" /* NONSPECIFIC ARTHROPATHIES */
"247" = "1" /* SIGNS AND SYMPTOMS OF MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE */
"248" = "1" /* TENDONITIS, MYOSITIS AND BURSITIS */
"249" = "1" /* AFTERCARE, MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE */
"252" = "1" /* FRACTURES, SPRAINS, STRAINS AND DISLOCATIONS OF FOREARM, HAND AND FOOT, AGE 0-17 */
"255" = "1" /* FRACTURES, SPRAINS, STRAINS AND DISLOCATIONS OF UPPER ARM AND LOWER LEG EXCEPT FOOT, AGE 0-17 */
"256" = "1" /* OTHER MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE DIAGNOSES */
"271" = "1" /* SKIN ULCERS */
"272" = "1" /* MAJOR SKIN DISORDERS WITH CC */
"273" = "1" /* MAJOR SKIN DISORDERS WITHOUT CC */
"274" = "1" /* MALIGNANT BREAST DISORDERS WITH CC */
"275" = "1" /* MALIGNANT BREAST DISORDERS WITHOUT CC */
"276" = "1" /* NONMALIGNANT BREAST DISORDERS */
"279" = "1" /* CELLULITIS, AGE 0-17 */
"282" = "1" /* TRAUMA TO SKIN, SUBCUTANEOUS TISSUE AND BREAST, AGE 0-17 */
"283" = "1" /* MINOR SKIN DISORDERS WITH CC */
"284" = "1" /* MINOR SKIN DISORDERS WITHOUT CC */
"295" = "1" /* DIABETES, AGE 0-35 */
"298" = "1" /* NUTRITIONAL AND MISCELLANEOUS METABOLIC DISORDERS, AGE 0-17 */
"299" = "1" /* INBORN ERRORS OF METABOLISM */
"300" = "1" /* ENDOCRINE DISORDERS WITH CC */
"301" = "1" /* ENDOCRINE DISORDERS WITHOUT CC */
"316" = "1" /* RENAL FAILURE */
"317" = "1" /* ADMISSION FOR RENAL DIALYSIS */
"318" = "1" /* KIDNEY AND URINARY TRACT NEOPLASMS WITH CC */
"319" = "1" /* KIDNEY AND URINARY TRACT NEOPLASMS WITHOUT CC */
"322" = "1" /* KIDNEY AND URINARY TRACT INFECTION, AGE 0-17 */
"323" = "1" /* URINARY STONES WITH CC AND/ OR ESW LITHOTRIPSY */
"324" = "1" /* URINARY STONES WITHOUT CC */
"327" = "1" /* KIDNEY AND URINARY TRACT SIGNS AND SYMPTOMS, AGE 0-17 */
"330" = "1" /* URETHRAL STRICTURE, AGE 0-17 */
"333" = "1" /* OTHER KIDNEY AND URINARY TRACT DIAGNOSES, AGE 0-17 */
"346" = "1" /* MALIGNANCY OF MALE REPRODUCTIVE SYSTEM WITH CC */
"347" = "1" /* MALIGNANCY OF MALE REPRODUCTIVE SYSTEM WITHOUT CC */
"348" = "1" /* BENIGN PROSTATIC HYPERTROPHY WITH CC */
"349" = "1" /* BENIGN PROSTATIC HYPERTROPHY WITHOUT CC */
"350" = "1" /* INFLAMMATION OF THE MALE REPRODUCTIVE SYSTEM */
"351" = "1" /* STERILIZATION, MALE */
"352" = "1" /* OTHER MALE REPRODUCTIVE SYSTEM DIAGNOSES */
"366" = "1" /* MALIGNANCY OF FEMALE REPRODUCTIVE SYSTEM WITH CC */
"367" = "1" /* MALIGNANCY OF FEMALE REPRODUCTIVE SYSTEM WITHOUT CC */
"368" = "1" /* INFECTIONS OF FEMALE REPRODUCTIVE SYSTEM */
"369" = "1" /* MENSTRUAL AND OTHER FEMALE REPRODUCTIVE SYSTEM DISORDERS */
"372" = "1" /* VAGINAL DELIVERY WITH COMPLICATING DIAGNOSES */
"373" = "1" /* VAGINAL DELIVERY WITHOUT COMPLICATING DIAGNOSES */
"376" = "1" /* POSTPARTUM AND POSTABORTION DIAGNOSES WITHOUT OR PROCEDURE */
"378" = "1" /* ENTOPIC PREGNANCY */
"379" = "1" /* THREATENED ABORTION */
"380" = "1" /* ABORTION WITHOUT D AND G */
"382" = "1" /* FALSE LABOR */
"383" = "1" /* OTHER ANTEPARTUM DIAGNOSES WITH MEDICAL COMPLICATIONS */
"384" = "1" /* OTHER ANTEPARTUM DIAGNOSES WITHOUT MEDICAL COMPLICATIONS */
"385" = "1" /* NEONATES DIED OR TRANSFERRED TO ANOTHER ACUTE FACILITY */
"386" = "1" /* EXTREME IMMATURITY OR RESPIRATORY DISTRESS SYNDROME NEONATE */
"387" = "1" /* PREMATURITY W MAJOR PROBLEMS */
"388" = "1" /* PREMATURITY W/O MAJOR PROBLEMS */
"389" = "1" /* FULL TERM NEONATE W MAJOR PROBLEMS */
"390" = "1" /* NEONATE W OTHER SIGNIFICANT PROBLEMS */
"391" = "1" /* NORMAL NEWBORN */
"396" = "1" /* RED BLOOD CELL DISORDERS, AGE 0-17 */
"397" = "1" /* COAGULATION DISORDERS */
"398" = "1" /* RETICULOENDOTHELIAL AND IMMUNITY DISORDERS WITH CC */
"399" = "1" /* RETICULOENDOTHELIAL AND IMMUNITY DISORDERS WITHOUT CC */
"403" = "1" /* LYMPHOMA AND NONACUTE LEUKEMIA WITH CC */
"404" = "1" /* LYMPHOMA AND NONACUTE LEUKEMIA WITHOUT CC */
"405" = "1" /* ACUTE LEUKEMIA WITHOUT MAJOR OR PROCEDURE, AGE 0-17 */
"409" = "1" /* RADIOTHERAPY */
"410" = "1" /* CHEMOTHERAPY WITHOUT ACUTE LEUKEMIA AS SECONDARY DIAGNOSIS */
"411" = "1" /* HISTORY OF MALIGNANCY WITHOUT ENDOSCOPY */
"412" = "1" /* HISTORY OF MALIGNANCY WITH ENDOSCOPY */
"413" = "1" /* OTHER MYELOPROLIFERATIVE DISORDERS OR POORLY DIFFERENTIATED NEOPLASM DIAGNOSES WITH CC */
"414" = "1" /* OTHER MYELOPROLIFERATIVE DISORDERS OR POORLY DIFFERENTIATED NEOPLASM DIAGNOSES WITHOUT CC */
"417" = "1" /* SEPTICEMIA, AGE 0-17 */
"418" = "1" /* POSTOPERATIVE AND POSTTRAUMATIC INFECTIONS */
"422" = "1" /* VIRAL ILLNESS AND FEVER OF UNKNOWN ORIGIN, AGE 0-17 */
"423" = "1" /* OTHER INFECTIOUS AND PARASITIC DISEASES DIAGNOSES */
"425" = "1" /* ACUTE ADJUSTMENT REACTIONS AND DISTURBANCES OF PSYCHOSOCIAL DYSFUNCTION */
"426" = "1" /* DEPRESSIVE NEUROSES */
"427" = "1" /* NEUROSES EXCEPT DEPRESSIVE */
"428" = "1" /* DISORDERS OF PERSONALITY AND IMPULSE CONTROL */
"429" = "1" /* ORGANIC DISTURBANCES AND MENTAL RETARDATION */
"430" = "1" /* PSYCHOSES */
"431" = "1" /* CHILDHOOD MENTAL DISORDERS */
"432" = "1" /* OTHER MENTAL DISORDER DIAGNOSES */
"433" = "1" /* ALCOHOL/DRUG ABUSE OR DEPENDENCE, LEFT AGAINST MEDICAL ADVICE */
"434" = "1" /* ALCOHOL/DRUG ABUSE OR DEPENDENCE, DETOXIFICATION OR OTHER SYMPTOMATIC TREATMENT WITH CC */
"435" = "1" /* ALCOHOL/DRUG ABUSE OR DEPENDENCE, DETOXIFICATION OR OTHER SYMPTOMATIC TREATMENT WITHOUT CC */
"436" = "1" /* ALCOHOL/DRUG DEPENDENCE WITH REHABILITATION THERAPY */
"437" = "1" /* ALCOHOL DRUG DEPENDENCE WITH COMBINED REHABILITATION AND DETOXIFICATION THERAPY */
"446" = "1" /* TRAUMATIC INJURY, AGE 0-17 */
"448" = "1" /* ALLERGIC REACTIONS, AGE 0-17 */
"451" = "1" /* POISONING AND TOXIC EFFECTS OF DRUGS, AGE 0-17 */
"452" = "1" /* COMPLICATIONS OF TREATMENT WITH CC */
"453" = "1" /* COMPLICATIONS OF TREATMENT WITHOUT CC */
"454" = "1" /* OTHER INJURY, POISONING AND TOXIC EFFECT DIAGNOSES WITH CC */
"455" = "1" /* OTHER INJURY, POISONING AND TOXIC EFFECT DIAGNOSES WITHOUT CC */
"456" = "1" /* BURNS, TRANSFERRED TO ANOTHER ACUTE CARE FACILITY */
"457" = "1" /* EXTENSIVE BURNS W/O O.R. PROCEDUR */
"460" = "1" /* NON-EXTENSIVE BURNS W/O O.R. PROCEDURE */
"462" = "1" /* REHABILITATION */
"463" = "1" /* SIGNS AND SYMPTOMS WITH CC */
"464" = "1" /* SIGNS AND SYMPTOMS WITHOUT CC */
"465" = "1" /* AFTERCARE WITH HISTORY OF MALIGNANCY AS SECONDARY DIAGNOSIS */
"466" = "1" /* AFTERCARE WITHOUT HISTORY OF MALIGNANCY AS SECONDARY DIAGNOSIS */
"467" = "1" /* OTHER FACTORS INFLUENCING HEALTH STATUS */
"475" = "1" /* RESPIRATORY SYSTEM DIAGNOSIS WITH VENTILATOR SUPPORT */
"487" = "1" /* OTHER MULTIPLE SIGNIFICANT TRAUMA */
"489" = "1" /* HIV WITH MAJOR RELATED CONDITION */
"490" = "1" /* HIV WITH OR WITHOUT OTHER RELATED CONDITION */
"492" = "1" /* CHEMOTHERAPY WITH ACUTE LEUKEMIA AS SECONDARY DIAGNOSIS */
"505" = "1" /* EXTENSIVE 3RD DEGREE BURNS W/O SKIN GRAFT */
"508" = "1" /* FULL THICKNESS BURN W/O SKIN GRFT OR INHAL INJ W CC OR SIG TRAUMA */
"509" = "1" /* FULL THICKNESS BURN W/O SKIN GRFT OR INH INJ W/O CC OR SIG TRAUMA */
"510" = "1" /* NON-EXTENSIVE BURNS W CC OR SIGNIFICANT TRAUMA */
"511" = "1" /* NON-EXTENSIVE BURNS W/O CC OR SIGNIFICANT TRAUMA */
"521" = "1" /* ALCOHOL/DRUG ABUSE OR DEPENDENCE W CC */
"522" = "1" /* ALC/DRUG ABUSE OR DEPEND W REHABILITATION THERAPY W/O CC */
"523" = "1" /* ALC/DRUG ABUSE OR DEPEND W/O REHABILITATION THERAPY W/O CC */
"524" = "1" /* TRANSIENT ISCHEMIA */
"559" = "1" /* ACUTE ISCHEMIC STROKE WITH USE OF THROMBOLYTIC AGENT */
"560" = "1" /* BACTERIAL & TUBERCULOUS INFECTIONS OF NERVOUS SYSTEM */
"561" = "1" /* NON-BACTERIAL INFECTIONS OF NERVOUS SYSTEM EXCEPT VIRAL MENINGITIS */
"565" = "1" /* RESPIRATORY SYSTEM DIAGNOSIS WITH VENTILATOR SUPPORT 96+ HOURS */
"566" = "1" /* RESPIRATORY SYSTEM DIAGNOSIS WITH VENTILATOR SUPPORT < 96 HOURS */
"571" = "1" /* MAJOR ESOPHAGEAL DISORDERS */
"572" = "1" /* MAJOR GASTROINTESTINAL DISORDERS AND PERITONEAL INFECTIONS */
"574" = "1" /* MAJOR HEMATOLOGIC/IMMUNOLOGIC DIAG EXC SICKLE CELL CRISIS & COAGUL */
OTHER  = "0" ;

 /* ---------------------------------------------------------------- */
 /* SURGICAL DRGS  (deleted Adult DRGs)                              */
 /* ---------------------------------------------------------------- */

 /* DIAGNOSTIC RELATED GROUPS (DRGS): */

VALUE $SURGIDR
"003" = "1" /* CRANIOTOMY, AGE 0-17 */
"004" = "1" /* SPINAL PROCEDURES */
"005" = "1" /* EXTRACRANIAL VASCULAR PROCEDURES */
"006" = "1" /* CARPAL TUNNEL RELEASE */
"007" = "1" /* PERIPHERAL AND CRANIAL NERVE AND OTHER NERVOUS SYSTEM PROCEDURES WITH CC */
"008" = "1" /* PERIPHERAL AND CRANIAL NERVE AND OTHER NERVOUS SYSTEM PROCEDURES WITHOUT CC */
"036" = "1" /* RETINAL PROCEDURES */
"037" = "1" /* ORBITAL PROCEDURES */
"038" = "1" /* PRIMARY IRIS PROCEDURES */
"039" = "1" /* LENS PROCEDURES WITH OR WITHOUT VITRECTOMY */
"041" = "1" /* EXTRAOCULAR PROCEDURES EXCEPT ORBIT, AGE 0-17 */
"042" = "1" /* INTRAOCULAR PROCEDURES EXCEPT RETINA, IRIS AND LENS */
"049" = "1" /* MAJOR HEAD AND NECK PROCEDURES */
"050" = "1" /* SIALOADENECTOMY */
"051" = "1" /* SALIVARY GLAND PROCEDURES EXCEPT SIALOADENECTOMY */
"052" = "1" /* CLEFT LIP AND PALATE REPAIR */
"054" = "1" /* SINUS AND MASTOID PROCEDURES, AGE 0-17 */
"055" = "1" /* MISCELLANEOUS EAR, NOSE, MOUTH AND THROAT PROCEDURES */
"056" = "1" /* RHINOPLASTY */
"058" = "1" /* TONSILLECTOMY AND ADNOIDECTOMY PROCEDURES EXCEPT TONSILLECTOMY AND/OR ADENOIDECTOMY ONLY, AGE 0-17 */
"060" = "1" /* TONSILLECTOMY AND/OR ADENOIDECTOMY ONLY, AGE 0 - 17 */
"062" = "1" /* MYRINGOTOMY WITH TUBE INSERTION, AGE 0-17 */
"063" = "1" /* OTHER EAR, NOSE, MOUTH AND THROAT OR PROCEDURES */
"075" = "1" /* MAJOR CHEST PROCEDURES */
"076" = "1" /* OTHER RESPIRATORY SYSTEM OR PROCEDURES WITH CC */
"077" = "1" /* OTHER RESPIRATORY SYSTEM OR PROCEDURES WITHOUT CC */
"103" = "1" /* HEART TRANSPLANT */
"104" = "1" /* CARDIAC VALVE AND OTHER MAJOR CARDIOTHORACIC PROCEDURES WITH CARDIAC CATHETERIZATION */
"105" = "1" /* CARDIAC VALVE AND OTHER MAJOR CARDIOTHORACIC PROCEDURES WITHOUT CARDIAC CATHETERIZATION */
"106" = "1" /* CORONARY BYPASS WITH PTCA */
"107" = "1" /* CORONARY BYPASS WITH CARDIAC CATHETERIZATION */
"108" = "1" /* OTHER CARDIOTHORACIC PROCEDURES */
"109" = "1" /* CORONARY BYPASS WITHOUT CARDIAC CATHETERIZATION */
"110" = "1" /* MAJOR CARDIOVASCULAR PROCEDURES WITH CC */
"111" = "1" /* MAJOR CARDIOVASCULAR PROCEDURES WITHOUT CC */
"112" = "1" /* PERCUTANEOUS CARDIOVASCULAR PROCEDURES */
"113" = "1" /* AMPUTATION FOR CIRCULATORY SYSTEM DISORDERS EXCEPT UPPER LIMB AND TOE */
"114" = "1" /* UPPER LIMB AND TOES AMPUTATION FOR CIRCULATORY SITE */
"115" = "1" /* PERMANENT CARDIAC PACEMAKER IMPLANT WITH ACUTE MYOCARDIAL INFARCTION, HEART FAILURE OR SHOCK OR ACID LEAD OR GENERATOR PROCEDURE */
"116" = "1" /* OTHER PERMANENT CARDIAC PACEMAKER IMPLANT OR PTCA WITH CORONARY ARTERIAL STENT */
"117" = "1" /* CARDIAC PACEMAKER REVISION EXCEPT DEVICE REPLACEMENT */
"118" = "1" /* CARDIAC PACEMAKER DEVICE REPLACEMENT */
"119" = "1" /* VEIN LIGATION AND STRIPPING */
"120" = "1" /* OTHER CIRCULATORY SYSTEM OR PROCEDURES */
"146" = "1" /* RECTAL RESECTION WITH CC */
"147" = "1" /* RECTAL RESECTION WITHOUT CC */
"148" = "1" /* MAJOR SMALL AND LARGE BOWEL PROCEDURES WITH CC */
"149" = "1" /* MAJOR SMALL AND LARGE BOWEL PROCEDURES WITHOUT CC */
"150" = "1" /* PERITONEAL ADHESIOLYSIS WITH CC */
"151" = "1" /* PERITONEAL ADHESIOLYSIS WITHOUT CC */
"152" = "1" /* MINOR SMALL AND LARGE BOWEL PROCEDURES WITH CC */
"153" = "1" /* MINOR SMALL AND LARGE BOWEL PROCEDURES WITHOUT CC */
"156" = "1" /* STOMACH, ESOPHAGEAL AND DUODENAL PROCEDURES, AGE 0-17 */
"157" = "1" /* ANAL AND STOMAL PROCEDURES WITH CC */
"158" = "1" /* ANAL AND STOMAL PROCEDURES WITHOUT CC */
"163" = "1" /* HERNIA PROCEDURES, AGE 0-17 */
"164" = "1" /* APPENDECTOMY WITH COMPLICATED PRINCIPAL DIAGNOSIS WITH CC */
"165" = "1" /* APPENDECTOMY WITH COMPLICATED PRINCIPAL DIAGNOSIS WIHTOUT CC */
"166" = "1" /* APPENDECTOMY WITHOUT COMPLICATED PRINCIPAL IAGNOSIS WITH CC */
"167" = "1" /* APPENDECTOMY WITHOUT COMPLICATED PRINCIPAL DIAGNOSIS WITHOUT CC */
"168" = "1" /* MOUTH PROCEDURES WITH CC */
"169" = "1" /* MOUTH PROCEDURES WITHOUT CC */
"170" = "1" /* OTHER DIGESTIVE SYSTEM OR PROCEDURES WITH CC */
"171" = "1" /* OTHER DIGESTIVE SYSTEM OR PROCEDURES WITHOUT CC */
"191" = "1" /* PANCREAS, LIVER AND SHUNT PROCEDURES WITH CC */
"192" = "1" /* PANCREAS, LIVER AND SHUNT PROCEDURES WITHOUT CC */
"193" = "1" /* BILIARY TRACT PROCEDURES EXCEPT ONLY CHOLECYSTECTOIMY WITH OR WITHOUT COMMON DUCT EXPLORATION WITH CC */
"194" = "1" /* BILIARY TRACT PROCEDURES EXCEPT ONLY CHOLECYSTECTOMY WITH OR WITHOUT COMMON DUCT EXPLORATION WITHOUT CC */
"195" = "1" /* CHOLECYSTECTOMY WITH COMMON DUCT EXPLORATION WITH CC */
"196" = "1" /* CHOLECYSTECTOMY WITH COMMON DUCT EXPLORATION WITHOUT CC */
"197" = "1" /* CHOLECYSTECTOMY EXCEPT BY LAPAROSCOPE WITHOUT COMMON DUCT EXPLORATION WITH CC */
"198" = "1" /* CHOLECYSTECTOMY EXCEPT BY LAPAROSCOPE WITHOUT COMMON DUCT EXPORTATION WITHOUT CC */
"199" = "1" /* HEPATOBILIARY DIAGNOSTIC PROCEDURE FOR MALIGNANCY */
"200" = "1" /* HEPATOBILIARY DIAGNOSTIC PROCEDURE FOR NONMALIGNANCY */
"201" = "1" /* OTHER HEPATOBILIARY OR PANCREAS OR PROCEDURES */
"209" = "1" /* MAJOR JOINT AND LIMB REATTACHMENT PROCEDURES OF LOWER EXTREMITY */
"212" = "1" /* HIP AND FEMUR PROCEDURES EXCEPT MAJOR JOINT PROCEDURE, AGE 0-17 */
"213" = "1" /* AMPUTATION FOR MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE DISORDERS */
"214" = "1" /* BACK & NECK PROCEDURES WITH CC */
"215" = "1" /* BACK & NECK PROCEDURES WITHOUT CC */
"216" = "1" /* BIOPSIES OF MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE */
"217" = "1" /* WOUND DEBRIDEMENT AND SKIN GRAFT EXCEPT HAND FOR MUSCULOSKELETAL AND CONNECTIVE TISSUE DISORDERS */
"220" = "1" /* LOWER EXTREMITY AND HUMERUS PROCEDURES EXCEPT HIP, FOOT AND FEMUR, AGE 0-17 */
"221" = "1" /* KNEE PROCEDURES WITH CC */
"222" = "1" /* KNEE PROCEDURES WITHOUT CC */
"223" = "1" /* MAJOR SHOULDER/ELBOW PROCEDURES OR OTHER UPPER EXTREMITY PROCEDURES WITH CC */
"224" = "1" /* SHOULDER, ELBOW OR FOREARM PROCEDURES EXCEPT MAJOR JOINT PROCEDURES WITHOUT CC */
"225" = "1" /* FOOT PROCEDURES*/
"226" = "1" /* SOFT TISSUE PROCEDURES WITH CC */
"227" = "1" /* SOFT TISSUE PROCEDURES WITHOUT CC */
"228" = "1" /* MAJOR THUMB OR JOINT PROCEDURES OR OTHER HAND OR WRIST PROCEDURES WITH CC */
"229" = "1" /* HAND OR WRIST PROCEDURES EXCEPT MAJOR JOINT PROCEDURES WITHOUT CC */
"230" = "1" /* LOCAL EXCISION AND REMOVAL OF INTERNAL FIXATION DEVICES OF HIP AND FEMUR */
"231" = "1" /* LOCAL EXCISION AND REMOVAL OF INTERNAL FIXATION DEVICES EXCEPT HIP AND FEMUR */
"232" = "1" /* ARTHROSCOPY */
"233" = "1" /* OTHER MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE OR PROCEDURES WITH CC */
"234" = "1" /* OTHER MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE OR PROCEDURES WITHOUT CC */
"257" = "1" /* TOTAL MASTECTOMY FOR MALIGNANCY WITH CC */
"258" = "1" /* TOTAL MASTECTOMY FOR MALIGNANCY WITHOUT CC */
"259" = "1" /* SUBTOTAL MASTECTOMY FOR MALIGNANCY WITH CC */
"260" = "1" /* SUBTOTAL MASTECTOMY FOR MALIGNANCY WITHOUT CC */
"261" = "1" /* BREAST PROCEDURE FOR NONMALIGNANCY EXCEPT BIOPSY AND LOCAL EXCISION */
"262" = "1" /* BREAST BIOPSY AND LOCAL EXCISION FOR NONMALIGNANCY */
"263" = "1" /* SKIN GRAFT AND/OR DEBRIDEMENT FOR SKIN ULCER OR CELLULITIS WITH CC */
"264" = "1" /* SKIN GRAFT AND OR DEBRIDEMENT FOR SKIN ULCER OR CELLULITIS WITHOUT CC */
"265" = "1" /* SKIN GRAFT AND OR DEBRIDEMENT EXCEPT FOR SKIN ULCER OR CELLULITIS WITH CC */
"266" = "1" /* SKIN GRAFT AND/OR DEBRIDEMENT EXCEPT FOR SKIN ULCER OR CELLUTLITIES WITHOUT CC */
"267" = "1" /* PERIANAL AND PILONIDAL PROCEDURES */
"268" = "1" /* SKIN, SUBCUTANEOUS TISSUE AND BREAST PLASTIC PROCEDURES */
"269" = "1" /* OTHER SKIN, SUBCUTANEOUS TISSUE AND BREAST PROCEDURES WITH CC */
"270" = "1" /* OTHER SKIN, SUBCUTANEOUS TISSUE AND BREAST PROCEDURS WITHOUT CC */
"285" = "1" /* AMPUTAETION OF LOWER LIMB FOR ENDOCRINE, NUTRITIONAL AND METABOLIC DISORDERS */
"286" = "1" /* ADRENAL AND PITUITARY PROCEDURES */
"287" = "1" /* SKIN GRAFTS AND WOUND DEBRIDEMENTS FOR ENDOCRINE, NUTRITIONAL AND METABOLIC DISORDERS */
"288" = "1" /* OR PROCEDURES FOR OBESITY */
"289" = "1" /* PARATHYROID PROCEDURES */
"290" = "1" /* THYROID PROCEDURES */
"291" = "1" /* THYROGLOSSAL PROCEDURES */
"292" = "1" /* OTHER ENDOCRINE, NUTRITIONAL AND METABOLIC OR PROCEDURES WITH CC */
"293" = "1" /* OTHER ENDOCRINE, NUTRITIONAL AND METABOLIC OR PROCEDURES WITHOUT CC */
"302" = "1" /* KIDNEY TRANSPLANT */
"303" = "1" /* KIDNEY, URETER AND MAJOR BLADDER PROCEDURES FOR NEOPLASM */
"304" = "1" /* KIDNEY, URETER AND MAJOR BLADDER PROCEDURES FOR NONNEOPLASMS WITH CC */
"305" = "1" /* KIDNEY, URETER AND MAJOR BLADDER PROCEDURES FOR NONEOPLSMS WITHOUT CC */
"306" = "1" /* PROSTATECTOMY WITH CC */
"307" = "1" /* PROSTATECTOMY WITHOUT CC */
"308" = "1" /* MINOR BLADDER PROCEDURES WITH CC */
"309" = "1" /* MINOR BLADDER PROCEDURES WITHOUT CC */
"310" = "1" /* TRANSURETHRAL PROCEDURES WITH CC */
"311" = "1" /* TRANSURETHRAL PROCEDURES WITHOUT CC */
"314" = "1" /* URETHRAL PROCEDURES, AGE 0-17 */
"315" = "1" /* OTHER KIDNEY AND URINARY TRACT OR PROCEDURES */
"334" = "1" /* MAJOR MALE PELVIC PROCEDURES WITH CC */
"335" = "1" /* MAJOR MALE PELVIC PROCEDURES WITHOUT CC */
"336" = "1" /* TRANSURETHRAL PROSTATECTOMY WITH CC */
"337" = "1" /* TRANSURETHRAL PROSTATECTOMY WITHOUT CC */
"338" = "1" /* TESTES PROCEDURES FOR MALIGNANCY */
"340" = "1" /* TESTES PROCEDURES FOR NONMALIGNANCY, AGE 0-17 */
"341" = "1" /* PENIS PROCEDURES */
"343" = "1" /* CIRCUMCISION, AGE 0-17 */
"344" = "1" /* OTHER MALE REPRODUCTIVE SYSTEM OR PROCEDURES FOR MALIGNANCY */
"345" = "1" /* OTHER MALE REPRODUCTIVE SYSTEM OR PROCEDURES EXCEPT FOR MALIGNANCY */
"353" = "1" /* PELVIC EVISCERATION, RADICAL HYSTERECTOMY AND RADICAL VULVECTOMY */
"354" = "1" /* UTERINE AND ADNEXA PROCEDURES FOR NONOVARIAN/ADNEXAL MALIGNANCY WITH CC */
"355" = "1" /* UTERINE AND ADNEXA PROCEDURES FOR NONOVARIAN/ADNEXA PROCEDURES WITHOUT CC*/
"356" = "1" /* FEMALE REPRODUCTIVE SYSTEM RECONSTRUCTIVE PROCEDURES */
"357" = "1" /* UTERINE AND ADNEXA PROCEDURES FOR OVARIAN OR ADNEXAL MALIGNANCY */
"358" = "1" /* UTERINE AND ADNEXA PROCEDURES FOR NONMALIGNANCY WITH CC */
"359" = "1" /* UTERINE AND ADNEXA PROCEDURES FOR NONMALIGNANCY WITHOUT CC */
"360" = "1" /* VAGINA, CERVIX AND VULVA PROCEDURES */
"361" = "1" /* LAPAROSCOPY AND INCISIONAL TUBAL INTERRUPTION */
"362" = "1" /* ENDOSCOPIC TUBAL INTERRUPTION */
"363" = "1" /* D AND C, CONIZATION AND RADIOIMPLANT FOR MALIGNANCY */
"364" = "1" /* D AND C, CONIZATION EXCEPT FOR MALIGNANCY */
"365" = "1" /* OTHER FEMALE REPRODUCTIVE SYSTEM OR PROCEDURES */
"370" = "1" /* CESAREAN SECTION WITH CC */
"371" = "1" /* CESAREAN SECTION WITHOUT CC */
"374" = "1" /* VAGINAL DELIVERY WITH STERILIZATION AND/OR D AND C */
"375" = "1" /* VAGINAL DELIVERY WITH OR PROCEDURE EXCEPT STERILIZATION AND/OR D AND C */
"377" = "1" /* POSTPARTUM AND POSTABORTION DIAGNOSES WITH OR PROCEDURE */
"381" = "1" /* ABORTION WITH D AND C ASPIRATION CURETTAGE OR HYSTERECTOMY */
"393" = "1" /* SPLENECTOMY, AGE 0-17 */
"394" = "1" /* OTHER OR PROCEDURES OF THE BLOOD AND BLOOD-FORMING ORGANS */
"400" = "1" /* LYMPHOMA AND LEUKEMIA WITH MAJOR OR PROCEDURES */
"401" = "1" /* LYMPHOMA AND NONACUTE LEUKEMIA WITH OTHER OR PROCEDURE WITH CC */
"402" = "1" /* LYMPHOMA AND NONACUTE LEUKEMIA WITH OTHER OR PROCEDURE WITHOUT CC */
"406" = "1" /* MYELOPROLIFERATIVE DISORDERS OR POORLY DIFFERENTIATED NEOPLASMS WITH MAJOR OR PROCEDURES WITH CC */
"407" = "1" /* MYELOPROLIFERATIVE DISORDERS OR POORLY DIFFERENTIATED NEOPLASMS WITH MAJOR OR PROCEDURES WITHOUT CC */
"408" = "1" /* MYELOPROLIFERATIVE DISORDERS OR POORLY DIFFERENTIATED NEOPLASMS WITH OTHER OR PROCEDURES */
"415" = "1" /* OR PROCEDURE FOR INFECTIOUS AND PARASITIC DISEASES */
"424" = "1" /* OR PROCEDURES WITH PRINCIPAL DIAGNOSIS OF MENTAL ILLNESS */
"439" = "1" /* SKIN GRAFTS FOR INJURIES */
"440" = "1" /* WOUND DEBRIDEMENTS FOR INJURIES */
"441" = "1" /* HAND PROCEDURES FOR INJURIES*/
"442" = "1" /* OTHER OR PROCEDURES FOR INJURIES WITH CC */
"443" = "1" /* OTHER OR PROCEDURES FOR INJURIES WITHOUT CC */
"458" = "1" /* NON-EXTENSIVE BURNS W SKIN GRAFT */
"459" = "1" /* NON-EXTENSIVE BURNS W WOUND DEBRIDEMENT OR OTHER O.R. PROC */
"461" = "1" /* OR PROCEDURES WITH DIAGNOSES OF OTHER CONTACT WITH HEALTH SERVICES */
"468" = "1" /* EXTENSIVE OR PROCEDURE UNRELATED TO PRINCIPAL DIAGNOSIS */
"471" = "1" /* BILATERAL OR MULTIPLE MAJOR JOINT PROCEDURES OF LOWER EXTREMITY */
"472" = "1" /* EXTENSIVE BURNS W O.R. PROCEDURE */
"476" = "1" /* PROSTATIC OR PROCEDURE UNRELATED TO PRINCIPAL DIAGNOSIS */
"477" = "1" /* NONEXTENSIVE OR PROCEDURE UNRELATED TO PRINCIPAL DIAGNOSIS */
"478" = "1" /* OTHER VASCULAR PROCEDURES WITH CC */
"479" = "1" /* OTHER VASCULAR PROCEDURES WITHOUT CC */
"480" = "1" /* LIVER TRANSPLANT */
"481" = "1" /* BONE MARROW TRANSPLANT */
"482" = "1" /* TRACHEOSTOMY FOR FACE, MOUTH AND NECK DIAGNOSES */
"483" = "1" /* TRACHEOSTOMY EXCEPT FOR FACE, MOUTH AND NECK DIAGNOSES */
"484" = "1" /* CRANIOTOMY FOR MULTIPLE SIGNIFICANT TRAUMA */
"485" = "1" /* LIMB REATTACHMENT, HIP AND FEMUR PROCEDURES FOR MULTIPLE SIGNIFICANT TRAUMA */
"486" = "1" /* OTHER OR PROCEDURES FOR MULTIPLE SIGNIFICANT TRAUMA */
"488" = "1" /* HIV WITH EXTENSIVE OR PROCEDURE */
"491" = "1" /* MAJOR JOINT AND LIMB REATTACHMENT PROCEDURES OF UPPER EXTREMITY */
"493" = "1" /* LAPAROSCOPIC CHOLECYSTECTOMY WITHOUT COMMON DUCT EXPLORATION WITH CC */
"494" = "1" /* LAPAROSCOPIC CHOLECYSTECTOMY WITHOUT COMMON DUCT EXPLORATION WITHOUT CC */
"495" = "1" /* LUNG TRANSPLANT */
"496" = "1" /* COMBINED ANTERIOR/POSTERIOR SPINAL FUSION */
"497" = "1" /* SPINAL FUSION WITH CC */
"498" = "1" /* SPINAL FUSION WITHOUT CC */
"499" = "1" /* BACK AND NECK PROCEDURES EXCEPT SPINAL FUSION WITH CC */
"500" = "1" /* BACK AND NECK PROCEDURES EXCEPT SPINAL FUSION WITHOUT CC */
"501" = "1" /* KNEE PROCEDURES WITH PRINCIPAL DIAGNOSIS OF INFECTION, WITH CC */
"502" = "1" /* KNEE PROCEDURES WITH PRINCIPAL DIAGNOSIS OF INFECTION, WITHOUT CC */
"503" = "1" /* KNEE PROCEDURES WITHOUT PRINCIPAL DIAGNOSIS OF INFECTION */
"504" = "1" /* EXTENSIVE 3RD DEGREE BURNS W SKIN GRAFT */
"506" = "1" /* FULL THICKNESS BURN W SKIN GRAFT OR INHAL INJ W CC OR SIG TRAUMA */
"507" = "1" /* FULL THICKNESS BURN W SKIN GRFT OR INHAL INJ W/O CC OR SIG TRAUMA */
"512" = "1" /* SIMULTANEOUS PANCREAS/KIDNEY TRANSPLANT */
"513" = "1" /* PANCREAS TRANSPLANT */
"514" = "1" /* CARDIAC DEFIBRILLATOR IMPLANT W CARDIAC CATH */
"515" = "1" /* CARDIAC DEFIBRILLATOR IMPLANT WITHOUT CARDIAC CATH */
"516" = "1" /* PERCUTANEOUS CARDIOVASC PROC W AMI */
"517" = "1" /* PERC CARDIO PROC W NON-DRUG ELUTING STENT WITHOUT AMI */
"518" = "1" /* PERC CARDIO PROC WITHOUT CORONARY ARTERY STENT OR AMI */
"519" = "1" /* CERVICAL SPINAL FUSION W CC */
"520" = "1" /* CERVICAL SPINAL FUSION WITHOUT CC */
"525" = "1" /* HEART ASSIST SYSTEM IMPLANT */
"526" = "1" /* PERCUTNEOUS CARDIOVASULAR PROC W DRUG ELUTING STENT W AMI */
"527" = "1" /* PERCUTNEOUS CARDIOVASULAR PROC W DRUG ELUTING STENT WITHOUT AMI */
"528" = "1" /* INTRACRANIAL VASCULAR PROC W PDX HEMORRHAGE */
"529" = "1" /* VENTRICULAR SHUNT PROCEDURES W CC */
"530" = "1" /* VENTRICULAR SHUNT PROCEDURES W/O CC */
"531" = "1" /* SPINAL PROCEDURES W CC */
"532" = "1" /* SPINAL PROCEDURES W/O CC */
"533" = "1" /* EXTRACRANIAL PROCEDURES W CC */
"534" = "1" /* EXTRACRANIAL PROCEDURES W/O CC */
"535" = "1" /* CARDIAC DEFIB IMPLANT W CARDIAC CATH W AMI/HF/SHOCK */
"536" = "1" /* CARDIAC DEFIB IMPLANT W CARDIAC CATH W/O AMI/HF/SHOCK */
"537" = "1" /* LOCAL EXCIS & REMOV OF INT FIX DEV EXCEPT HIP & FEMUR W CC */
"538" = "1" /* LOCAL EXCIS & REMOV OF INT FIX DEV EXCEPT HIP & FEMUR W/O CC */
"539" = "1" /* LYMPHOMA & LEUKEMIA W MAJOR OR PROCEDURE W CC */
"540" = "1" /* LYMPHOMA & LEUKEMIA W MAJOR OR PROCEDURE W/O CC */
"541" = "1" /* TRACH W MV 96+HRS OR PDX EXC FACE, MTH, FACE & NECK DX W/MAJ OR */
"542" = "1" /* TRACH W MV 96+HRS OR PDX EXC FACE, MTH, FACE & NECK DX W/O MJ OR */
"543" = "1" /* CRANIOTOMY WITH IMPLANTATION OF CHEMOTHERAPEUTIC AGENT OR ACUTE 
               COMPLEX CENTRAL NERVOUS SYSTEM PRINCIPAL DIAGNOSIS */
"544" = "1" /* MAJOR JOINT REPLACEMENT OR REATTACHMENT OF LOWER EXTREMITY */
"545" = "1" /* REVISION OF HIP OR KNEE REPLACEMENT */
"546" = "1" /* SPINAL FUSION EXC CERV WITH CURVATURE OF THE SPINE OR MALIG */
"547" = "1" /* CORONARY BYPASS W CARDIAC CATH W MAJOR CV DX */
"548" = "1" /* CORONARY BYPASS W CARDIAC CATH W/O MAJOR CV DX */
"549" = "1" /* CORONARY BYPASS W/O CARDIAC CATH W MAJOR CV DX */
"550" = "1" /* CORONARY BYPASS W/O CARDIAC CATH W/O MAJOR CV DX */
"551" = "1" /* PERMANENT CARDIAC PACEMAKER IMPL W MAJ CV DX OR AICD LEAD OR GNRTR */
"552" = "1" /* OTHER PERMANENT CARDIAC PACEMAKER IMPLANT W/O MAJOR CV DX */
"553" = "1" /* OTHER VASCULAR PROCEDURES W CC W MAJOR CV DX */
"554" = "1" /* OTHER VASCULAR PROCEDURES W CC W/O MAJOR CV DX */
"555" = "1" /* PERCUTANEOUS CARDIOVASCULAR PROC W MAJOR CV DX */
"556" = "1" /* PERCUTANEOUS CARDIOVASC PROC W NON-DRUG-ELUTING STENT W/O MAJ CV DX */
"557" = "1" /* PERCUTANEOUS CARDIOVASCULAR PROC W DRUG-ELUTING STENT W MAJOR CV DX */
"558" = "1" /* PERCUTANEOUS CARDIOVASCULAR PROC W DRUG-ELUTING STENT W/O MAJ CV DX */
"569" = "1" /* MAJOR SMALL & LARGE BOWEL PROCEDURES W CC W MAJOR GI DX */
"570" = "1" /* MAJOR SMALL & LARGE BOWEL PROCEDURES W CC W/O MAJOR GI DX */
"573" = "1" /* MAJOR BLADDER PROCEDURES */
"577" = "1" /* CAROTID ARTERY STENT PROCEDURE */
"578" = "1" /* INFECTIOUS & PARASITIC DISEASES W OR PROCEDURE */
"579" = "1" /* POSTOPERATIVE OR POST-TRAUMATIC INFECTIONS W OR PROCEDURE */
OTHER = "0" ;

 /* ---------------------------------------------------------------- */
 /* LOW BIRTH WEIGHT                                                 */
 /* ---------------------------------------------------------------- */

 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $LW500G
"76401" = "1"
"76411" = "1"
"76421" = "1"
"76491" = "1"
"76501" = "1"
"76511" = "1"
"V2131" = "1"
OTHER = "0" ;

VALUE $LW1000G
"76402" = "1"
"76403" = "1"
"76412" = "1"
"76413" = "1"
"76422" = "1"
"76423" = "1"
"76492" = "1"
"76493" = "1"
"76502" = "1"
"76503" = "1"
"76512" = "1"
"76513" = "1"
"V2132" = "1"
OTHER   = "0";

VALUE $LW1500G
"76404" = "1"
"76405" = "1"
"76414" = "1"
"76415" = "1"
"76424" = "1"
"76425" = "1"
"76494" = "1"
"76495" = "1"
"76504" = "1"
"76505" = "1"
"76514" = "1"
"76515" = "1"
"V2133" = "1"
OTHER   = "0";

VALUE $LW2000G
"76406" = "1"
"76407" = "1"
"76416" = "1"
"76417" = "1"
"76426" = "1"
"76427" = "1"
"76496" = "1"
"76497" = "1"
"76506" = "1"
"76507" = "1"
"76516" = "1"
"76517" = "1"
"V2134" = "1"
OTHER   = "0";

VALUE $LW2500G
"76408" = "1" /* LT-FOR-DATES 2000-2499G */
"76418" = "1" /* LT-DATE W/MAL 2000-2499G */
"76428" = "1" /* FETAL MALNUTR 2000-2499G */
"76498" = "1" /* FET GRWTH RET 2000-2499G */
"76508" = "1" /* EXTREME IMMAT 2000-2499G */
"76518" = "1" /* OTHER PRETERM INFANTS 2000-2499G */
"V2135" = "1"
OTHER   = "0";


 /* ------------------------------------ */
 /* ACCIDENTAL PUNCTURE OR LACERATION   */
 /*   PROVIDER INDICATOR / PSI #  1     */
 /*   AREA     INDICATOR / PSI # TBD    */
 /* ----------------------------------- */

 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $TECHNID
"9982"  = "1" /* ACCIDENTAL PUNCTURE OR LACERATION DURING A PROCEDURE */
"E8700" = "1" /* ACCIDENTAL CUT, PUNCTURE, PERFORATION, OR HEMORRHAGE DURING MEDICAL CARE, SURGICAL OPERATION */
"E8701" = "1" /* INFUSION OR TRANSFUSION */
"E8702" = "1" /* KIDNEY DIALYSIS OR OTHER PERFUSION */
"E8703" = "1" /* INJECTION OR VACCINATION */
"E8704" = "1" /* ENDOSCOPIC EXAMINATION */
"E8705" = "1" /* ASPIRATION OF FLUID OR TISSUE, PUNCTURE, AND CATHETERIZATION */
"E8706" = "1" /* HEART CATHETERIZATION */
"E8707" = "1" /* ADMINISTRATION OF ENEMA */
"E8708" = "1" /* OTHER SPECIFIED MEDICAL CARE */
"E8709" = "1" /* ACCIDENTAL CUT, PUNCTURE, PERFORATION, OR HEMORRHAGE DURING MEDICAL CARE, UNSPECIFIED MEDICAL CARE */
OTHER   = "0" ;

 /* ICD-9-CM PROCEDURE CODES: */

VALUE $SPINEP
"0301" = "1" /* REMOVAL FB SPINAL CANAL */
"0302" = "1" /* REOPEN LAMINECTOMY SITE */
"0309" = "1" /* SPINAL CANAL EXPLOR NEC */
"0353" = "1" /* VERTEBRAL FX REPAIR */
"036" = "1" /* SPINAL CORD ADHESIOLYSIS */
"8100" = "1" /* SPINAL FUSION NOS */
"8101" = "1" /* ATLAS-AXIS FUSION */
"8102" = "1" /* OTHER CERVICAL FUS ANT */
"8103" = "1" /* OTHER CERVICAL FUS POST */
"8104" = "1" /* DORSAL/DORSOLUM FUS ANT */
"8105" = "1" /* DORSAL/DORSOLUM FUS POST */
"8106" = "1" /* LUMBAR/LUMBOSAC FUS ANT */
"8107" = "1" /* LUMBAR/LUMBOSAC FUS LAT */
"8108" = "1" /* LUMBAR/LUMBOSAC FUS POST */
"8130" = "1" /* SPINAL REFUSION NOS */
"8131" = "1" /* REFUSION OF ATLAS-AXIS */
"8132" = "1" /* REFUSION OF OTH CERV ANT */
"8133" = "1" /* REFUS OF OTH CERV POST */
"8134" = "1" /* REFUSION OF DORSAL ANT */
"8135" = "1" /* REFUSION OF DORSAL POST */
"8136" = "1" /* REFUSION OF LUMBAR ANT */
"8137" = "1" /* REFUSION OF LUMBAR LAT */
"8138" = "1" /* REFUSION OF LUMBAR POST */
"8139" = "1" /* REFUSION OF SPINE NEC */
"8162" = "1" /* FUS/REFUS 2-3 VERTEBRAE */
"8163" = "1" /* FUS/REFUS 4-8 VERTEBRAE */
"8164" = "1" /* FUS/REFUS 9 VERTEBRAE */
"8165" = "1" /* VERTEBROPLASTY */
"8166" = "1" /* KYPHOPLASTY */
"8451" = "1" /* INS SPINAL FUSION DEVICE */
"8452" = "1" /* INSERT RECOMBINANT BMP */
"8458" = "1" /* IMP INTRSPINE DECOMP DEV */
"8459" = "1" /* INSERT OTHR SPIN DEVICE */
"8460" = "1" /* INSERT DISC PROS NOS */
"8461" = "1" /* INS PART DISC PROS CERV */
"8462" = "1" /* INS TOT DISC PROST CERV */
"8463" = "1" /* INS SPIN DISC PROS THOR */
"8464" = "1" /* INS PART DISC PROS LUMB */
"8465" = "1" /* INS TOTL DISC PROS LUMB */
"8466" = "1" /* REVISE DISC PROST CERV */
"8467" = "1" /* REVISE DISC PROST THORA */
"8468" = "1" /* REVISE DISC PROSTH LUMB */
"8469" = "1" /* REVISE DISC PROSTH NOS */
"8480" = "1" /* INS/REPL INTERSPINE DEV */
"8481" = "1" /* REV INTERSPINE DEVICE */
"8482" = "1" /* INS/REPL PDCL STABIL DEV */
"8483" = "1" /* REV PEDCL DYN STABIL DEV */
"8485" = "1" /* REV FACET REPLACE DEVICE */
OTHER   = "0" ;


 /* ------------------------------ */
 /* DECUBITUS ULCER                */
 /*   PROVIDER INDICATOR / PDI # 2 */
 /* ------------------------------ */

 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $DECUBID
"7070" = "1" /* DECUBITUS ULCER */
"70700" = "1" /* DECUBITUS ULCER SITE NOS */
"70701" = "1" /* DECUBITUS ULCER ELBOW */
"70702" = "1" /* DECUBITUS ULCER UP BACK */
"70703" = "1" /* DECUBITUS ULCER LOW BACK */
"70704" = "1" /* DECUBITUS ULCER HIP */
"70705" = "1" /* DECUBITUS ULCER BUTTOCK */
"70706" = "1" /* DECUBITUS ULCER ANKLE */
"70707" = "1" /* DECUBITUS ULCER HEEL */
"70709" = "1" /* DECUBITUS ULCER SITE NEC */
OTHER  = "0" ;

 /* EXCLUDE: DEBRIDEMENT OR PEDICLE GRAFT */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $DEBRIDP
"8345"  = "1" /* OTHER MYECTOMY */           
"8622"  = "1" /* EXC WOUND DEBRIDEMENT */    
"8628"  = "1" /* NONEXCIS DEBRIDEMENT WND */ 
"8670"  = "1" /* PEDICLE GRAFT/FLAP NOS */   
"8671"  = "1" /* CUT & PREP PEDICLE GRAFT */ 
"8672"  = "1" /* PEDICLE GRAFT ADVANCEMEN */ 
"8674"  = "1" /* ATTACH PEDICLE GRAFT NEC */ 
"8675"  = "1" /* REVISION OF PEDICLE GRFT */ 
OTHER   = "0" ;

 /* STRATIFIED BY: HEMIPLEGIA, PARAPLEGIA, OR QUADRIPLEGIA */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $HEMIPID
"33371" = "1" /* ATHETOID CEREBRAL PALSY */  
"3420"  = "1" /* FLACCID HEMIPLEGIA */
"34200" = "1" /* FLCCD HMIPLGA UNSPF SIDE */
"34201" = "1" /* FLCCD HMIPLGA DOMNT SIDE */
"34202" = "1" /* FLCCD HMIPLG NONDMNT SDE */
"3421"  = "1" /* SPASTIC HEMIPLEGIA */
"34210" = "1" /* SPSTC HMIPLGA UNSPF SIDE */
"34211" = "1" /* SPSTC HMIPLGA DOMNT SIDE */
"34212" = "1" /* SPSTC HMIPLG NONDMNT SDE */
"34280" = "1" /* OT SP HMIPLGA UNSPF SIDE */
"34281" = "1" /* OT SP HMIPLGA DOMNT SIDE */
"34282" = "1" /* OT SP HMIPLG NONDMNT SDE */
"3429"  = "1" /* HEMIPLEGIA, UNSPECIFIED */
"34290" = "1" /* UNSP HEMIPLGA UNSPF SIDE */
"34291" = "1" /* UNSP HEMIPLGA DOMNT SIDE */
"34292" = "1" /* UNSP HMIPLGA NONDMNT SDE */
"3430"  = "1" /* INFANTILE CEREBRAL PALSY, DIPLEGIC */
"3431"  = "1" /* INFANTILE CEREBRAL PALSY, HEMIPLEGIC */
"3432"  = "1" /* INFANTILE CEREBRAL PALSY, QUADRIPLEGIC */
"3433"  = "1" /* INFANTILE CEREBRAL PALSY, MONOPLEGIC */
"3434"  = "1" /* INFANTILE CEREBRAL PALSY INFANTILE HEMIPLEGIA */
"3438"  = "1" /* INFANTILE CEREBRAL PALSY OTHER SPECIFIED INFANTILE CEREBRAL PALSY */
"3439"  = "1" /* INFANTILE CEREBRAL PALSY, INFANTILE CEREBRAL PALSY, UNSPECIFIED */
"3440"  = "1" /* QUADRIPLEGIA AND QUADRIPARESIS */
"34400" = "1" /* QUADRIPLEGIA, UNSPECIFD */
"34401" = "1" /* QUADRPLG C1-C4, COMPLETE */
"34402" = "1" /* QUADRPLG C1-C4, INCOMPLT */
"34403" = "1" /* QUADRPLG C5-C7, COMPLETE */
"34404" = "1" /* QUADRPLG C5-C7, INCOMPLT */
"34409" = "1" /* OTHER QUADRIPLEGIA */
"3441"  = "1" /* PARAPLEGIA */
"3442"  = "1" /* DIPLEGIA OF UPPER LIMBS */
"3443"  = "1" /* MONOPLEGIA OF LOWER LIMB */
"34430" = "1" /* MONPLGA LWR LMB UNSP SDE */
"34431" = "1" /* MONPLGA LWR LMB DMNT SDE */
"34432" = "1" /* MNPLG LWR LMB NONDMNT SD */
"3444"  = "1" /* MONOPLEGIA OF UPPER LIMB */
"34440" = "1" /* MONPLGA UPR LMB UNSP SDE */
"34441" = "1" /* MONPLGA UPR LMB DMNT SDE */
"34442" = "1" /* MNPLG UPR LMB NONDMNT SD */
"3445"  = "1" /* UNSPECIFIED MONOPLEGIA */
"3446" = "1" /* CAUDA EQUINA SYNDROME */
"34460" = "1" /* CAUDA EQUINA SYNDROME, WITHOUT MENTION OF NEUROGENIC BLADDER */
"34461" = "1" /* CAUDA EQUINA SYNDROME, WITH NEUROGENIC BLADDER */
"3448"  = "1" /* OTHER SPECIFIED PARALYTIC SYNDROMES */
"34481" = "1" /* LOCKED-IN STATE */
"34489" = "1" /* OTH SPCF PARALYTIC SYND */
"3449"  = "1" /* PARALYSIS, UNSPECIFIED */
"43820" = "1" /* LATE EF-HEMPLGA SIDE NOS */
"43821" = "1" /* LATE EF-HEMPLGA DOM SIDE */
"43822" = "1" /* LATE EF-HEMIPLGA NON-DOM */
"43830" = "1" /* LATE EF-MPLGA UP LMB NOS */
"43831" = "1" /* LATE EF-MPLGA UP LMB DOM */
"43832" = "1" /* LT EF-MPLGA UPLMB NONDOM */
"43840" = "1" /* LTE EF-MPLGA LOW LMB NOS */
"43841" = "1" /* LTE EF-MPLGA LOW LMB DOM */
"43842" = "1" /* LT EF-MPLGA LOWLMB NONDM */
"43850" = "1" /* LT EF OTH PARAL SIDE NOS */
"43851" = "1" /* LT EF OTH PARAL DOM SIDE */
"43852" = "1" /* LT EF OTH PARALS NON-DOM */
"43853" = "1" /* LT EF OTH PARALS-BILAT */
"7687"  = "1" /* HYPOXIC-ISCHEMIC ENCEPH */  
OTHER   = "0" ;

 /* STRATIFIED BY: SPINA BIFIDA */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $SPIBIFD
"74100"  = "1" /* SPINA BIFIDA, W HYDROCEPHALUS UNSPECIFIED REGION */
"74101"  = "1" /* SPINA BIFIDA, W HYDROCEPHALUS CERVICAL REGION */
"74102"  = "1" /* SPINA BIFIDA, W HYDROCEPHALUS DORSAL REGION */
"74103"  = "1" /* SPINA BIFIDA, W HYDROCEPHALUS LUMBAR REGION */
"74190"  = "1" /* SPINA BIFIDA, W/O HYDROCEPHALUS UNSPECIFIED REGION */
"74191"  = "1" /* SPINA BIFIDA, W/O HYDROCEPHALUS CERVICAL REGION */
"74192"  = "1" /* SPINA BIFIDA, W/O HYDROCEPHALUS DORSAL REGION */
"74193"  = "1" /* SPINA BIFIDA, W/O HYDROCEPHALUS LUMBAR REGION */
OTHER   = "0" ;

 /* STRATIFIED BY: Anoxic Brain */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $ANOXBD
"3481"  = "1" /* ANOXIC BRAIN DAMAGE */
"7685"  = "1" /* SEVERE BIRTH ASPHYXIA */
OTHER   = "0" ;

 /* STRATIFIED BY: other continuous mechanical ventilation code for 96 or more consecutive hours */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $CMVENP
"9672"  = "1" /* CONTINUOUS MECHANICAL VENTILATION FOR 96 CONSECUTIVE HOURS OR MORE */
OTHER   = "0" ;


 /* -------------------------------------- */
 /* FOREIGN BODY LEFT IN DURING PROCEDURE */
 /*   PROVIDER INDICATOR / PDI #  3       */
 /*   AREA     INDICATOR / PDI # TBD      */
 /* ------------------------------------- */

 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $FOREIID
"9984"  = "1" /* FOREIGN BODY ACCIDENTALLY LEFT DURING A PROCEDURE */
"9987"  = "1" /* ACUTE REACTION TO FOREIGN SUBSTANCE ACCIDENTALLY LEFT DURING   A PROCEDURE */
"E8710" = "1" /* SURGICAL OPERATION */
"E8711" = "1" /* INFUSION OR TRANSFUSION */
"E8712" = "1" /* KIDNEY DIALYSIS OR OTHER PERFUSION */
"E8713" = "1" /* INJECTION OR VACCINATION */
"E8714" = "1" /* ENDOSCOPIC EXAMINATION */
"E8715" = "1" /* ASPIRATION OF FLUID OR TISSUE, PUNCTURE, AND CATHETERIZATION */
"E8716" = "1" /* HEART CATHETERIZATION */
"E8717" = "1" /* REMOVAL OF CATHETER OR PACKING */
"E8718" = "1" /* OTHER SPECIFIED PROCEDURES */
"E8719" = "1" /* UNSPECIFIED PROCEDURE */
OTHER   = "0" ;


 /* ------------------------------- */
 /* IATROGENIC PNEUMOTHORAX         */
 /*   PROVIDER INDICATOR / PDI #4&5 */
 /*   AREA     INDICATOR / PDI #TBD */
 /* ------------------------------- */

 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $IATROID
"5121"  = "1" /* IATROGENIC PNEUMOTHORAX */
OTHER   = "0" ;

/* EXCLUDE: CHEST TRAUMA */
/* ICD-9-CM DIAGNOSIS CODES: */

VALUE $CTRAUMD
"80700" = "1" /* FRACTURE RIB NOS-CLOSED */
"80701" = "1" /* FRACTURE ONE RIB-CLOSED */
"80702" = "1" /* FRACTURE TWO RIBS-CLOSED */
"80703" = "1" /* FRACTURE THREE RIBS-CLOS */
"80704" = "1" /* FRACTURE FOUR RIBS-CLOSE */
"80705" = "1" /* FRACTURE FIVE RIBS-CLOSE */
"80706" = "1" /* FRACTURE SIX RIBS-CLOSED */
"80707" = "1" /* FRACTURE SEVEN RIBS-CLOS */
"80708" = "1" /* FX EIGHT/MORE RIB-CLOSED */
"80709" = "1" /* FX MULT RIBS NOS-CLOSED */
"80710" = "1" /* FRACTURE RIB NOS-OPEN */
"80711" = "1" /* FRACTURE ONE RIB-OPEN */
"80712" = "1" /* FRACTURE TWO RIBS-OPEN */
"80713" = "1" /* FRACTURE THREE RIBS-OPEN */
"80714" = "1" /* FRACTURE FOUR RIBS-OPEN */
"80715" = "1" /* FRACTURE FIVE RIBS-OPEN */
"80716" = "1" /* FRACTURE SIX RIBS-OPEN */
"80717" = "1" /* FRACTURE SEVEN RIBS-OPEN */
"80718" = "1" /* FX EIGHT/MORE RIBS-OPEN */
"80719" = "1" /* FX MULT RIBS NOS-OPEN */
"8072"  = "1" /* FRACTURE OF STERNUM-CLOS */
"8073"  = "1" /* FRACTURE OF STERNUM-OPEN */
"8074"  = "1" /* FLAIL CHEST */
"8075"  = "1" /* FX LARYNX/TRACHEA-CLOSED */
"8076"  = "1" /* FX LARYNX/TRACHEA-OPEN */
"8090"  = "1" /* FRACTURE TRUNK BONE-CLOS */
"8091"  = "1" /* FRACTURE TRUNK BONE-OPEN */
"8600"  = "1" /* TRAUM PNEUMOTHORAX-CLOSE */
"8601"  = "1" /* TRAUM PNEUMOTHORAX-OPEN */
"8602"  = "1" /* TRAUM HEMOTHORAX-CLOSED */
"8603"  = "1" /* TRAUM HEMOTHORAX-OPEN */
"8604"  = "1" /* TRAUM PNEUMOHEMOTHOR-CL */
"8605"  = "1" /* TRAUM PNEUMOHEMOTHOR-OPN */
"86100" = "1" /* HEART INJURY NOS-CLOSED */
"86101" = "1" /* HEART CONTUSION-CLOSED */
"86102" = "1" /* HEART LACERATION-CLOSED */
"86103" = "1" /* HEART CHAMBER LACERAT-CL */
"86110" = "1" /* HEART INJURY NOS-OPEN */
"86111" = "1" /* HEART CONTUSION-OPEN */
"86112" = "1" /* HEART LACERATION-OPEN */
"86113" = "1" /* HEART CHAMBER LACER-OPN */
"86120" = "1" /* LUNG INJURY NOS-CLOSED */
"86121" = "1" /* LUNG CONTUSION-CLOSED */
"86122" = "1" /* LUNG LACERATION-CLOSED */
"86130" = "1" /* LUNG INJURY NOS-OPEN */
"86131" = "1" /* LUNG CONTUSION-OPEN */
"86132" = "1" /* LUNG LACERATION-OPEN */
"8620"  = "1" /* DIAPHRAGM INJURY-CLOSED */
"8621"  = "1" /* DIAPHRAGM INJURY-OPEN */
"86221" = "1" /* BRONCHUS INJURY-CLOSED */
"86222" = "1" /* ESOPHAGUS INJURY-CLOSED */
"86229" = "1" /* INTRATHORACIC INJ NEC-CL */
"86231" = "1" /* BRONCHUS INJURY-OPEN */
"86232" = "1" /* ESOPHAGUS INJURY-OPEN */
"86239" = "1" /* INTRATHORAC INJ NEC-OPEN */
"8628"  = "1" /* INTRATHORACIC INJ NOS-CL */
"8629"  = "1" /* INTRATHORAC INJ NOS-OPEN */
"8750"  = "1" /* OPEN WOUND OF CHEST */
"8751"  = "1" /* OPEN WOUND CHEST-COMPL */
"8760"  = "1" /* OPEN WOUND OF BACK */
"8761"  = "1" /* OPEN WOUND BACK-COMPL */
"9010"  = "1" /* INJURY THORACIC AORTA */
"9011"  = "1" /* INJ INNOMIN/SUBCLAV ART */
"9012"  = "1" /* INJ SUPERIOR VENA CAVA */
"9013"  = "1" /* INJ INNOMIN/SUBCLAV VEIN */
"90140" = "1" /* INJ PULMONARY VESSEL NOS */
"90141" = "1" /* INJURY PULMONARY ARTERY */
"90142" = "1" /* INJURY PULMONARY VEIN */
"90181" = "1" /* INJ INTERCOSTAL ART/VEIN */
"90182" = "1" /* INJ INT MAMMARY ART/VEIN */
"90183" = "1" /* INJ MULT THORACIC VESSEL */
"90189" = "1" /* INJ THORACIC VESSEL NEC */
"9019"  = "1" /* INJ THORACIC VESSEL NOS */
"9110"  = "1" /* SUPERFICIAL INJURY OF TRUNK, ABRASION OR FRICTION BURN WITHOUT MENTION OF INFECTION */
"9111"  = "1" /* SUPERFICIAL INJURY OF TRUNK, ABRASION OR FRICTION BURN, INFECTED */
"9118"  = "1" /* OTHER AND UNSPECIFIED SUPERFICIAL INJURY OF TRUNK, WITHOUT MENTION OF INFECTION */
"9119"  = "1" /* OTHER AND UNSPECIFIED SUPERFICIAL INJURY OF TRUNK, INFECTED */
"9220"  = "1" /* CONTUSION OF TRUNK, BREAST */
"9221"  = "1" /* CONTUSION OF TRUNK, CHEST WALL */
"9223"  = "1" /* CONTUSION OF TRUNK, BACK */
"92231" = "1" /* BACK CONTUSION */
"92233" = "1" /* INTERSCPLR REG CONTUSION */ 
"9228"  = "1" /* CONTUSION OF TRUNK, MULTIPLE SITES OF TRUNK */
"9229"  = "1" /* CONTUSION OF TRUNK, UNSPECIFIED PART */
"92611" = "1" /* CRUSHING INJURY BACK */
"92619" = "1" /* CRUSHING INJ TRUNK NEC */
"9268"  = "1" /* MULT CRUSHING INJ TRUNK */
"9269"  = "1" /* CRUSHING INJ TRUNK NOS */
"9290"  = "1" /* CRUSH INJ MULT SITE NEC */
"9299"  = "1" /* CRUSHING INJURY NOS */
"9541"  = "1" /* INJURY TO OTHER NERVES OF TRUNK, OTHER SYMPATHETIC */
"9548"  = "1" /* INJURY TO OTHER NERVES OF TRUNK, OTHER SPECIFIED NERVES OF TRUNK */
"9549"  = "1" /* INJURY TO OTHER NERVES OF TRUNK, UNSPECIFIED NERVES OF TRUNK */
"95911" = "1" /* OTHER INJURY TO CHEST WALL */
"95919" = "1" /* OTHER INJURY TO OTHER SITES OF TRUNK */
"9599"  = "1" /* INJURY, UNSPECIFIED SITE */
OTHER   = "0" ;

 /* EXCLUDE: PLEURAL EFFUSION */
 /* ICD-9-CM DIAGNOSIS CODES: */;

VALUE $PLEURAD
"0101 "  = "1" /* TUBERCULOUS PLEURISY IN PRIMARY PROGRESSIVE TUBERCULOSIS */
"01010"  = "1" /* TUBERCULOUS PLEURISY IN PRIMARY PROGRESSIVE TUBERCULOSIS, UNSPECIFIED */
"01011"  = "1" /* TPIPPT, BACTERIAL OR HISTOLOGICAL EXAM NOT DONE */
"01012"  = "1" /* TPIPPT, BACTERIAL OR HISTOLOGICAL EXAM UNKNOWN */
"01013"  = "1" /* TPIPPT, TUBERCLE BACILI FOUND BY MICROSCOPY */
"01014"  = "1" /* TPIPPT, TUBERCLE BACILI NOT FOUND BY MICROSCOPY BUT BY BACTERIAL CULTURE */
"01015"  = "1" /* TPIPPT, TUBERCLE BACILI NOT FOUND BY BACTERIOLOGICAL BUT CONFIRMED HISTOLOGICALLY */
"01016"  = "1" /* TPIPPT, TUBERCLE BACILI NOT FOUND BY BACTERILOGICAL OR HISTOLOGICAL BUT CONFIRMED OTHER METHODS */
"0117 "  = "1" /* TUBRCULOUS PNEUMOTHORAX */
"01170"  = "1" /* TUBRCULOUS PNEUMOTHORAX, UNSPECIFIED */
"01171"  = "1" /* TPNEU, BACTERIAL OR HISTOLOGICAL EXAM NOT DONE */
"01172"  = "1" /* TPNEU, BACTERIAL OR HISTOLOGICAL EXAM UNKNOWN */
"01173"  = "1" /* TPNEU, TUBERCLE BACILI FOUND BY MICROSCOPY */
"01174"  = "1" /* TPNEU, TUBERCLE BACILI NOT FOUND BY MICROSCOPY BUT BY BACTERIAL CULTURE */
"01175"  = "1" /* TPNEU, TUBERCLE BACILI NOT FOUND BY BACTERIOLOGICAL BUT CONFIRMED HISTOLOGICALLY */
"01176"  = "1" /* TPENU, TUBERCLE BACILI NOT FOUND BY BACTERILOGICAL OR HISTOLOGICAL BUT CONFIRMED OTHER METHODS */
"0120 "  = "1" /* TUBERCULOUS PLEURISY */
"01200"  = "1" /* TUBERCULOUS PLEURISY, UNSPECIFIED */
"01201"  = "1" /* TP, BACTERIAL OR HISTOLOGICAL EXAM NOT DONE */
"01202"  = "1" /* TP, BACTERIAL OR HISTOLOGICAL EXAM UNKNOWN */
"01203"  = "1" /* TP, TUBERCLE BACILI FOUND BY MICROSCOPY */
"01204"  = "1" /* TP, TUBERCLE BACILI NOT FOUND BY MICROSCOPY BUT BY BACTERIAL CULTURE */
"01205"  = "1" /* TP, TUBERCLE BACILI NOT FOUND BY BACTERIOLOGICAL BUT CONFIRMED HISTOLOGICALLY */
"01206"  = "1" /* TP, TUBERCLE BACILI NOT FOUND BY BACTERILOGICAL OR HISTOLOGICAL BUT CONFIRMED OTHER METHODS */
"1972 "  = "1" /* SECOND MALIG NEO PLEURA */  
"5111 "  = "1" /* WITH EFUSION, WITH MENTION OF A BACTERIAL CAUSE OTHER THAN TUBERCULOSIS */
"5118 "  = "1" /* OTHER SPECIFIED FORM OF EFFUSION, EXCEPT TUBERCULOUS */
"5119 "  = "1" /* UNSPECIFIED PLEURAL EFFUSION */
OTHER    = "0" ;

 /* EXCLUDE: THORACIC SURGERY */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $THORAIP
"3121" = "1" /* MEDIASTINAL TRACHEOSTOMY */
"3145" = "1" /* OPEN BIOPSY OF LARYNX OR TRACHEA */
"3173" = "1" /* CLOSURE OF OTHER FISTULA OF TRACHEA */
"3179" = "1" /* OTHER REPAIR AND PLASTIC OPERATIONS ON TRACHEA */
"3199" = "1" /* OTHER OPERATIONS ON TRACHEA */
"3209" = "1" /* OTHER LOCAL EXCISION OR DESTRUCTION OF LESION OR TISSUE OF BRONCHUS */
"321"  = "1" /* OTHER EXCISION OF BRONCHUS */
"3220" = "1" /* THORAC EXC LUNG LESION */
"3221" = "1" /* PLICATION OF EMPHYSEMATIOUS BLEB */
"3222" = "1" /* LUNG VOLUME REDUCTION SURGERY */
"3223" = "1" /* OPEN ABLTN LUNG LES/TISS */
"3224" = "1" /* PERC ABLTN LUNG LES/TISS */ 
"3225" = "1" /* THOR ABLTN LUNG LES/TISS */ 
"3226" = "1" /* ABLTN LUNG TISS NEC/NOS */  
"3228" = "1" /* ENDOSCOPIC EXCISION OR DETRUCTION OF LESION OR TISSUE OF LUNG */
"3229" = "1" /* OTHER LOCAL EXCISION OR DESTRUCTION OF LESION OR TISSUE OF LUNG */
"323"  = "1" /* SEGMENTAL RESECTION OF LUNG */
"3230" = "1" /* THORAC SEG LUNG RESECT */
"3239" = "1" /* OTH SEG LUNG RESECT NOS */
"324"  = "1" /* LOBECTOMY OF LUNG */
"3241" = "1" /* THORAC LOBECTOMY LUNG */
"325"  = "1" /* COMPLETE PNEUMONECTOMY */
"3250" = "1" /* THORACOSPC PNEUMONECTOMY */
"3259" = "1" /* OTHER PNEUMONECTOMY NOS */
"326"  = "1" /* RADICAL DISSECTION OF THORACIC STRUCTURES */
"329"  = "1" /* OTHER EXCISION OF LUNG */
"330"  = "1" /* INCISION OF BRONCHUS */
"331"  = "1" /* INCISION OF LUNG */
"3320" = "1" /* THORACOSCOPC LUNG BIOPSY */
"3325" = "1" /* OPEN BIOPSY OF BRONCHUS */
"3327" = "1" /* CLOSED ENDOSCOPIC BIOPSY OF LUNG */
"3331" = "1" /* DESTRUCTION OF PHRENIC NERVE FOR COLLAPSE OF LUNG (NO LONGER PERFORMED) */
"3332" = "1" /* ARTIFICAL PNEUMOTHORAX FOR COLLAPSE OF LUNG */
"3334" = "1" /* THORACOPLASTY */
"3339" = "1" /* OTHER SURGICAL COLLAPSE OF LUNG */
"3341" = "1" /* SUTURE OF LACERATION OF BRONCHUS */
"3342" = "1" /* CLOSURE OF BRONCHIAL FISTULA */
"3343" = "1" /* CLOSURE OF LACERATION OF LUNG */
"3348" = "1" /* OTHER REPAIR OAND PLASTIC OPERATIONS ON BRONCHUS */
"3349" = "1" /* OTHER REPAIR AND PLASTIC OPERATIONS ON LUNG */
"335"  = "1" /* LUNG TRANSPLANTATION */
"3350" = "1" /* LUNG TRANSPLANTATION, NOS */
"3351" = "1" /* UNILATERAL LUNG TRANSPLANTATION */
"3352" = "1" /* BILATERAL LUNG TRANSPLANTATION */
"336"  = "1" /* COMBINED HEART-LUNG TRANSPLANTATION */
"3392" = "1" /* LIGATION OF BRONCHUS */
"3393" = "1" /* PUNCTURE OF LUNG */
"3398" = "1" /* OTHER OPERATIONS ON BRONCHUS */
"3399" = "1" /* OTHER OPERATIONS ON LUNG */
"3329" = "1" /* OTHER DIAGNOSTIC PROCEDURE ON LUNG AND BRONCHUS */
"3333" = "1" /* PNEUMOPERITONEUM FOR COLLAPSE OF LUNG */
"3401" = "1" /* INCISION OF CHEST WALL */
"3402" = "1" /* EXPLORATORY THORACOTOMY */
"3403" = "1" /* REOPENING OF RECENT THORACOTOMY SITE */
"3405" = "1" /* CREATION OF PLEUROPERITONEAL SHUNT */
"3409" = "1" /* OTHER INCISION OF PLEURA */
"341"  = "1" /* INCISION OF MEDIASTINUM */
"3420" = "1" /* THORACOSCOPIC PLEURAL BX */
"3421" = "1" /* TRANSPLEURAL THORACOSOCOPY */
"3422" = "1" /* MEDIASTINOSCOPY */
"3423" = "1" /* BIOPSY OF CHEST WALL */
"3425" = "1" /* CLOSED [PERCUTANEOUS][NEEDLE] BIOPSY OF MEDIASTINUM */
"3426" = "1" /* OPEN BIOPSY OF MEDIASTINUM */
"3427" = "1" /* BIOPSY OF DIAPHRAGM */
"3428" = "1" /* OTHER DIAGNOSTIC PROCEDURES ON CHEST WALL, PLEURA, AND DIAPHRAGM */
"3429" = "1" /* OTHER DIAGNOSTIC PROCEDURES ON MEDIASTINUM */
"343"  = "1" /* EXCISION OR DESTRUCTION OF LESION OR TISSUE OF MEDIASTINUM */
"344"  = "1" /* EXCISION OR DESTRUCTION OF LESION OF CHEST WALL */
"3451" = "1" /* DECORTICATION OF LUNG */
"3452" = "1" /* THORACOSCOPC DECORT LUNG */
"3459" = "1" /* OTHER EXCISION OF PLEURA */
"3471" = "1" /* SUTURE OF LACERATION OF CHEST WALL */
"3472" = "1" /* CLOSURE OF THORACOSTOMY */
"3473" = "1" /* CLOSURE OF OTHER FISTULA OF THORAX */
"3474" = "1" /* REPAIR OF PECTUS DEFORMITY */
"3479" = "1" /* OTHER REPAIR OF CHEST WALL */
"3481" = "1" /* EXCISION OF LESION OR TISSUE OF DIAPHRAGM */
"3482" = "1" /* SUTURE OF LACERATION OF DIAPHRAGM */
"3483" = "1" /* CLOSURE OF FISTULA OF DIAPHRAGM */
"3484" = "1" /* OTHER REPAIR OF DIAPHRAGM */
"3485" = "1" /* IMPLANTATION OF DIAPHRAGMATIC PACEMAKER */
"3489" = "1" /* OTHER OPERATIONS ON DIAPHRAGM */
"3493" = "1" /* REPAIR OF PLEURA */
"3499" = "1" /* OTHER */
"4061" = "1" /* CANNULATION OF THORACIC DUCT */
"4062" = "1" /* FISTULIZATION OF THORACIC DUCT */
"4063" = "1" /* CLOSURE OF FISTULA OF THORACIC DUCT */
"4064" = "1" /* LIGATION OF THORACIC DUCT */
"4069" = "1" /* OTHER OPERATIONS ON THORACIC DUCT */
"4201" = "1" /* INCISION OF ESOPHAGEAL WEB */
"4209" = "1" /* OTHER INCISION OF EXOPHAGUS */
"4210" = "1" /* ESOPHAGOSTOMY, NOS */
"4211" = "1" /* CERVICAL ESOPHAGOSTOMY */
"4212" = "1" /* EXTERIORIZATION OF ESOPHAGEAL POUCH */
"4219" = "1" /* OTHER EXTERNAL FISTULIZATION OF ESOPHAGUS */
"4221" = "1" /* OPERATIVE ESOPHAGOSCOPY BY INCISION */
"4225" = "1" /* OPEN BIOPSY OF ESOPHAGUS */
"4231" = "1" /* LOCAL EXCISION OF ESOPHAGEAL DIVERTICULUM */
"4232" = "1" /* LOCAL EXCISION OF OTHER LESION OR TISSUE OF ESOPHAGUS */
"4239" = "1" /* OTHER DESTRUCTION OF LESION OR TISSUE OF ESOPHAGUS */
"4240" = "1" /* ESOPHAGECTOMY, NOS */
"4241" = "1" /* PARTIAL ESOPHAGECTOMY */
"4242" = "1" /* TOTAL ESOPHAGECTOMY */
"4251" = "1" /* INTRATHORACIC ESOPHAGOESOPHAGOSTOMY */
"4252" = "1" /* INTRATHORACIC ESOPHAGOGASTROSTOMY */
"4253" = "1" /* INTRATHORACIC ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF SMALL BOWEL */
"4254" = "1" /* OTHER INTRATHORACIC ESOPHAGOENTEROSOTOMY */
"4255" = "1" /* INTRATHORACIC ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF COLON */
"4256" = "1" /* OTHER INTRATHORACIC ESOPHAGOCOLOSTOMY */
"4258" = "1" /* INTRATHORACIC ESOPHAGEAL ANASTOMOSIS WITH OTHER INTERPOSITION */
"4259" = "1" /* OTHER INTRATHORACIC ANASTOMOSIS OF ESOPHAGUS */
"4261" = "1" /* ANTESTERNAL ESOPHAGOESOPHAGOSTOMY */
"4262" = "1" /* ANTESTERNAL ESOPHAGOGASTROSTOMY */
"4263" = "1" /* ANTESTERNAL ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF SMALL BOWEL */
"4264" = "1" /* OTHER ANTESTERNAL ESOPHAGOENTEROSTOMY */
"4265" = "1" /* ANTESTERNAL ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF COLON */
"4266" = "1" /* OTHER ANTESTERNAL ESOPHAGOCOLOSTOMY */
"4268" = "1" /* OTHER ANTESTERNAL ESOPHAGEAL ANASTOMOSIS WITH INTERPOSISION */
"4269" = "1" /* OTHER ANTESTERNAL ANASTOMOSIS OF ESOPHAGUS */
"427"  = "1" /* ESOPHAGOMYOTOMY */
"4281" = "1" /* INSERTION OF PERMANENT TUBE INTO ESOPHAGUS */
"4282" = "1" /* SUTURE OF LACERATION OF ESOPHAGUS */
"4283" = "1" /* CLOSURE OF ESOPHAGOSTOMY */
"4284" = "1" /* REPAIR OF ESOPHAGEAL FISTULA, NEC */
"4285" = "1" /* REPAIR OF ESOPHAGEAL STRICTURE */
"4286" = "1" /* PRODUCTION OF SUBCUTANEOUS TUNNEL WITHOUT ESOPHAGEAL ANASTOMOSIS */
"4287" = "1" /* OTHER GRAFT OF ESOPHAGUS */
"4289" = "1" /* OTHER REPAIR OF ESOPHAGUS */
"4465" = "1" /* ESOPHAGOGASTROPLASTY */
"4466" = "1" /* OTHER PROCEDURES FOR CREATION OF ESOPHAGOGASTRIC SPHINTERIC COMPETENCE */
"8104" = "1" /* DORSAL AND DORSO-LUMBAR FUSION, ANTERIOR TECHNIQUE */
"8134" = "1" /* REFUSION OF DORSAL AND DORSOLUMBAR SPINE, ANTERIOR TECHNIQUE */
OTHER  = "0" ;

 /* EXCLUDE: LUNG OR PLEURAL BIOPSY */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $LUNGBIP
"3326" = "1" /* CLOSED [PERCUTANEOUS] [NEEDLE] BIOPSY OF LUNG */
"3328" = "1" /* OPEN BIOPSY OF LUNG */
"3424" = "1" /* PLEURAL BIOPSY */
OTHER  = "0" ;

 /* EXCLUDE: CARDIAC SURGERY */
 /* DIAGNOSTIC RELATED GROUPS (DRGS): */

VALUE $CARDSDR
"103" = "1" /* HEART TRANSPLANT */
"104" = "1" /* CARDIAC VALVE AND OTHER MAJOR CARDIOTHORACIC PROCEDURES WITH CARDIAC CATHETERIZATION */
"105" = "1" /* CARDIAC VALVE AND OTHER MAJOR CARDIOTHORACIC PROCEDURES WITHOUT CARDIAC CATHETERIZATION */
"106" = "1" /* CORONARY BYPASS WITH PTCA */
"107" = "1" /* CORONARY BYPASS WITH CARDIAC CATHETERIZATION */
"108" = "1" /* OTHER CARDIOTHORACIC PROCEDURES */
"109" = "1" /* CORONARY BYPASS WITHOUT CARDIAC CATHETERIZATION */
"110" = "1" /* MAJOR CARDIOVASCULAR PROCEDURES WITH CC */
"111" = "1" /* MAJOR CARDIOVASCULAR PROCEDURES WITHOUT CC */
"525" = "1" /* HEART ASSIST SYSTEM IMPLANT */
"547" = "1" /* CORONARY BYPASS W CARDIAC CATH W MAJOR CV DX */
"548" = "1" /* CORONARY BYPASS W CARDIAC CATH W/O MAJOR CV DX */
"549" = "1" /* CORONARY BYPASS W/O CARDIAC CATH W MAJOR CV DX */
"550" = "1" /* CORONARY BYPASS W/O CARDIAC CATH W/O MAJOR CV DX */
OTHER = "0" ;

 /* EXCLUDE: DIAPHRAGMATIC SURGERY REPAIR */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $DIAPHRP
"537 " = "1" /* ABD REPAIR-DIAPHR HERNIA */
"5380" = "1" /* THOR REP-DIAPH HERN NOS */
"5381" = "1" /* DIAPHRAGMATIC PLICATION */
"5382" = "1" /* PARASTERN HERNIA REPAIR */
OTHER  = "0" ;

 /* ----------------------------------------- */
 /* Pediatric Heart Surgery (PRPEDH)          */
 /*   Mortality (post-op) Indicator / PDI #6  */
 /*   Volume Indicator / PDI #7               */
 /* ----------------------------------------- */

 /* Pediatric Heart Surgery (#1) */
 /* Procedures to repair congenital heart defect */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRPED1P
'3500' = "1"  /* CLOSED VALVOTOMY NOS */
'3501' = "1"  /* CLOSED AORTIC VALVOTOMY */
'3502' = "1"  /* CLOSED MITRAL VALVOTOMY */
'3503' = "1"  /* CLOSED PULMON VALVOTOMY */
'3504' = "1"  /* CLOSED TRICUSP VALVOTOMY */
'3510' = "1"  /* OPEN VALVULOPLASTY NOS */
'3511' = "1"  /* OPN AORTIC VALVULOPLASTY */
'3512' = "1"  /* OPN MITRAL VALVULOPLASTY */
'3513' = "1"  /* OPN PULMON VALVULOPLASTY */
'3514' = "1"  /* OPN TRICUS VALVULOPLASTY */
'3520' = "1"  /* REPLACE HEART VALVE NOS */
'3521' = "1"  /* REPLACE AORT VALV-TISSUE */
'3522' = "1"  /* REPLACE AORTIC VALVE NEC */
'3523' = "1"  /* REPLACE MITR VALV-TISSUE */
'3524' = "1"  /* REPLACE MITRAL VALVE NEC */
'3525' = "1"  /* REPLACE PULM VALV-TISSUE */
'3526' = "1"  /* REPLACE PULMON VALVE NEC */
'3527' = "1"  /* REPLACE TRIC VALV-TISSUE */
'3528' = "1"  /* REPLACE TRICUSP VALV NEC */
'3531' = "1"  /* PAPILLARY MUSCLE OPS */
'3532' = "1"  /* CHORDAE TENDINEAE OPS */
'3533' = "1"  /* ANNULOPLASTY */
'3534' = "1"  /* INFUNDIBULECTOMY */
'3535' = "1"  /* TRABECUL CARNEAE CORD OP */
'3539' = "1"  /* TISS ADJ TO VALV OPS NEC */
'3541' = "1"  /* ENLARGE EXISTING SEP DEF */
'3542' = "1"  /* CREATE SEPTAL DEFECT */
'3550' = "1"  /* PROSTH REP HRT SEPTA NOS */
'3551' = "1"  /* PROS REP ATRIAL DEF-OPN */
'3552' = "1"  /* PROS REPAIR ATRIA DEF-CL */
'3553' = "1"  /* PROST REPAIR VENTRIC DEF */
'3554' = "1"  /* PROS REP ENDOCAR CUSHION */
'3560' = "1"  /* GRFT REPAIR HRT SEPT NOS */
'3561' = "1"  /* GRAFT REPAIR ATRIAL DEF */
'3562' = "1"  /* GRAFT REPAIR VENTRIC DEF */
'3563' = "1"  /* GRFT REP ENDOCAR CUSHION */
'3570' = "1"  /* HEART SEPTA REPAIR NOS */
'3571' = "1"  /* ATRIA SEPTA DEF REP NEC */
'3572' = "1"  /* VENTR SEPTA DEF REP NEC */
'3573' = "1"  /* ENDOCAR CUSHION REP NEC */
'3581' = "1"  /* TOT REPAIR TETRAL FALLOT */
'3582' = "1"  /* TOTAL REPAIR OF TAPVC */
'3583' = "1"  /* TOT REP TRUNCUS ARTERIOS */
'3584' = "1"  /* TOT COR TRANSPOS GRT VES  */
'3591' = "1"  /* INTERAT VEN RETRN TRANSP */
'3592' = "1"  /* CONDUIT RT VENT-PUL ART */
'3593' = "1"  /* CONDUIT LEFT VENTR-AORTA */
'3594' = "1"  /* CONDUIT ARTIUM-PULM ART */
'3595' = "1"  /* HEART REPAIR REVISION */
'3598' = "1"  /* OTHER HEART SEPTA OPS */
'3599' = "1"  /* OTHER OP ON HRT VALVES */
'3699' = "1"  /* OTHER OPERATIONS ON VESSEL OF HEART */
'3733' = "1"  /* EXCISION OR DESTRUCTION OF OTHER LESION 
                 OR TISSUE OF HEART */
'375 ' = "1"  /* HEART TRANSPLANTATION */
'3751' = "1"  /* HEART TRANSPLANTATION */
'3752' = "1"  /* IMPLANT TOT REP HRT SYS */
'390 ' = "1"  /* SYSTEMIC-PULM ART SHUNT */
'3921' = "1"  /* CAVAL-PULMON ART ANASTOM */
OTHER  = "0" ;

 /* Pediatric Heart Surgery (#2): */
 /* Other cardiac surgery */

 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRPED2D
'7450 ' = "1"  /* COMMON TRUNCUS */
'74510' = "1"  /* COMPL TRANSPOS GREAT VES */
'74511' = "1"  /* DOUBLE OUTLET RT VENTRIC */
'74512' = "1"  /* CORRECT TRANSPOS GRT VES */
'74519' = "1"  /* TRANSPOS GREAT VESS NEC */
'7452 ' = "1"  /* TETRALOGY OF FALLOT */
'7453 ' = "1"  /* COMMON VENTRICLE */
'7454 ' = "1"  /* VENTRICULAR SEPT DEFECT */
'7455 ' = "1"  /* SECUNDUM ATRIAL SEPT DEF */
'74560' = "1"  /* ENDOCARD CUSHION DEF NOS */
'74561' = "1"  /* OSTIUM PRIMUM DEFECT */
'74569' = "1"  /* ENDOCARD CUSHION DEF NEC */
'7457 ' = "1"  /* COR BILOCULARE */
'7458 ' = "1"  /* SEPTAL CLOSURE ANOM NEC */
'7459 ' = "1"  /* SEPTAL CLOSURE ANOM NOS */
'74600' = "1"  /* PULMONARY VALVE ANOM NOS */
'74601' = "1"  /* CONG PULMON VALV ATRESIA */
'74602' = "1"  /* CONG PULMON VALVE STENOS */
'74609' = "1"  /* PULMONARY VALVE ANOM NEC */
'7461 ' = "1"  /* CONG TRICUSP ATRES/STEN */
'7462 ' = "1"  /* EBSTEIN'S ANOMALY */
'7463 ' = "1"  /* CONG AORTA VALV STENOSIS */
'7464 ' = "1"  /* CONG AORTA VALV INSUFFIC */
'7465 ' = "1"  /* CONGEN MITRAL STENOSIS */
'7466 ' = "1"  /* CONG MITRAL INSUFFICIENC */
'7467 ' = "1"  /* HYPOPLAS LEFT HEART SYND */
'74681' = "1"  /* CONG SUBAORTIC STENOSIS */
'74682' = "1"  /* COR TRIATRIATUM */
'74683' = "1"  /* INFUNDIB PULMON STENOSIS */
'74684' = "1"  /* OBSTRUCT HEART ANOM NEC */
'74685' = "1"  /* CORONARY ARTERY ANOMALY */
'74687' = "1"  /* MALPOSITION OF HEART */
'74689' = "1"  /* CONG HEART ANOMALY NEC */
'7469 ' = "1"  /* CONG HEART ANOMALY NOS */
'7470 ' = "1"  /* PATENT DUCTUS ARTERIOSUS */
'74710' = "1"  /* COARCTATION OF AORTA */
'74711' = "1"  /* INTERRUPT OF AORTIC ARCH */
'74720' = "1"  /* CONG ANOM OF AORTA NOS */
'74721' = "1"  /* ANOMALIES OF AORTIC ARCH */
'74722' = "1"  /* AORTIC ATRESIA/STENOSIS */
'74729' = "1"  /* CONG ANOM OF AORTA NEC */
'7473 ' = "1"  /* PULMONARY ARTERY ANOM */
'74740' = "1"  /* GREAT VEIN ANOMALY NOS */
'74741' = "1"  /* TOT ANOM PULM VEN CONNEC */
'74742' = "1"  /* PART ANOM PULM VEN CONN */
'74749' = "1"  /* GREAT VEIN ANOMALY NEC */
OTHER   = "0" ;

 /* ICD-9-CM Procedure Codes: */

VALUE $PRPED2P
'3834' = "1"  /* RESECTION OF ABDOMINAL AORTA WITH ANASTOMOSIS */
'3835' = "1"  /* THOR VESSEL RESECT/ANAST */
'3844' = "1"  /* RESECTION OF ABDOMINAL AORTA WITH REPLACEMENT */
'3845' = "1"  /* RESECT THORAC VES W REPL */
'3864' = "1"  /* OTHER EXCISION OF ABDOMINAL AORTA */
'3865' = "1"  /* OTHER EXCISION OF THORACIC VESSEL */
'3884' = "1"  /* OTHER SURGICAL OCCLUSION OF ABDOMINAL AORTA */
'3885' = "1"  /* OCCLUDE THORACIC VES NEC */
'3949' = "1"  /* OTHER REVISION OF VASCULAR PROCEDURE */
'3956' = "1"  /* REPAIR OF BLOOD VESSEL WITH TISSUE PATCH GRAFT */
'3957' = "1"  /* REPAIR OF BLOOD VESSEL WITH SYNTHETIC PATCH GRAFT */
'3958' = "1"  /* REPAIR OF BLOOD VESSEL WITH UNSPECIFIED TYPE OF PATCH GRAFT */
'3959' = "1"  /* REPAIR OF VESSEL NEC */
OTHER  = "0" ;

 /* Pediatric Heart Surgery */
 /* Exclusions */

 /* PHS Exclusion #1: */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRPED3D
'7470 ' = "1"  /* PATENT DUCTUS ARTERIOSUS */
OTHER  = "0" ;

 /* ICD-9-CM Procedure Codes: */

VALUE $PRPD3AP
'3500' = "1"  /* CLOSED HEART VALVOTOMY, UNSPECIFIED VALUE */
'3501' = "1"  /* CLOSED HEART VALVOTOMY, AORTIC VALUE */
'3502' = "1"  /* CLOSED HEART VALVOTOMY, MITRAL VALUE */
'3503' = "1"  /* CLOSED HEART VALVOTOMY, PULMONARY VALUE */
'3504' = "1"  /* CLOSED HEART VALVOTOMY, TRICUSPID VALUE */
OTHER  = "0" ;

VALUE $PRPD3BP
'3541' = "1"  /* ENLARGEMENT OF EXISTING ATRIAL SEPTAL DEFECT */
'3542' = "1"  /* CREATION OF SEPTAL DEFECT IN HEART */
OTHER  = "0" ;

VALUE $PRPD3CP
'3551' = "1"  /* REPAIR OF ATIAL SEPTAL DEFECT WITH PROSTHESIS, OPEN TECHNIQUE */
'3571' = "1"  /* OTHER AND UNSPECIFIED REPAIR OF ATRIAL SEPTAL DEFECT */
OTHER  = "0" ;

VALUE $PRPD3DP
'3553' = "1"  /* REPAIR OF VENTRICULAR SEPTAL DEFECT WITH PROSTHESIS */
'3572' = "1"  /* OTHER AND UNSPECIFIED REPAIR OF VENTRICULAR SEPTAL DEFECT */
OTHER  = "0" ;

VALUE $PRPD3EP
'3885' = "1"  /* OCCLUDE THORACIC VES NEC */
OTHER  = "0" ;

VALUE $PRPD3FP
'3884' = "1"  /* OTHER SURGICAL OCCLUSION OF AORTA, ABDOMINAL */
'3885' = "1"  /* OTHER SURGICAL OCCLUSION OF THORACIC VESSEL */
'3959' = "1"  /* OTHER REPAIR OF VESSEL */
OTHER  = "0" ;

VALUE $PRPED5P
'3961' = "1"  /* EXTRACORPOREAL CIRCULAT */
OTHER  = "0" ;

VALUE $PRPED6P
'3721' = "1"  /* RT HEART CARDIAC CATH */
'3722' = "1"  /* LEFT HEART CARDIAC CATH */
'3723' = "1"  /* RT/LEFT HEART CARD CATH */
'8842' = "1"  /* CONTRAST AORTOGRAM */
'8843' = "1"  /* CONTR PULMON ARTERIOGRAM */
'8844' = "1"  /* ARTERIOGRAPHY OF OTHER INTRATHORACIC VESSELS */
'8850' = "1"  /* ANGIOCARDIOGRAPHY, NOT OTHERWISE SPECIFIED */
'8851' = "1"  /* ANGIOCARDIOGRAPHY OF VENAE CAVAE */
'8852' = "1"  /* ANGIOCARDIOGRAPHY OF RIGHT HEART STRUCTURES */
'8853' = "1"  /* ANGIOCARDIOGRAPHY OF LEFT HEART STRUCTURES */
'8854' = "1"  /* COMBINED RIGHT AND LEFT HEART ANGIOCARDIOGRAPHY */
'8855' = "1"  /* CORONARY ARTERIOGRAPHY USING A SINGLE CATHETER */
'8856' = "1"  /* CORONARY ARTERIOGRAPHY USING TWO CATHETERS */
'8857' = "1"  /* OTHER AND UNSPECIFIED CORONARY ARTERIOGRAPHY */
'8858' = "1"  /* NEGATIVE-CONTRAST CARDIAC ROENTGENOGRAPHY */
OTHER  = "0" ;

 /* PHS Exclusion #2: */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRPED4P
'3541' = "1"  /* ENLARGE EXISTING SEP DEF */
'3552' = "1"  /* PROS REPAIR ATRIA DEF-CL */
OTHER  = "0" ;

 /* PHS Exclusion #3: */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRPED4D
'76500' = "1"  /* EXTREME IMMATUR WTNOS */
'76501' = "1"  /* EXTREME IMMATUR <500G */
'76502' = "1"  /* EXTREME IMMATUR 500-749G */
'76503' = "1"  /* EXTREME IMMATUR 750-999G */
'76504' = "1"  /* EXTREME IMMAT 1000-1249G */
'76505' = "1"  /* EXTREME IMMAT 1250-1499G */
'76506' = "1"  /* EXTREME IMMAT 1500-1749G */
'76507' = "1"  /* EXTREME IMMAT 1750-1999G */
'76508' = "1"  /* EXTREME IMMAT 2000-2499G */
'76509' = "1"  /* EXTREME IMMAT 2500+G */
'76510' = "1"  /* PRETERM INFANT NEC WTNOS */
'76511' = "1"  /* PRETERM NEC <500G */
'76512' = "1"  /* PRETERM NEC 500-749G */
'76513' = "1"  /* PRETERM NEC 750-999G */
'76514' = "1"  /* PRETERM NEC 1000-1249G */
'76515' = "1"  /* PRETERM NEC 1250-1499G */
'76516' = "1"  /* PRETERM NEC 1500-1749G */
'76517' = "1"  /* PRETERM NEC 1750-1999G */
'76518' = "1"  /* PRETERM NEC 2000-2499G */
'76519' = "1"  /* PRETERM NEC 2500+G */
OTHER  = "0" ; 

 /* ICD-9-CM Procedure Codes: */

VALUE $PRPED7P
'375 ' = "1"  /* HEART TRANSPLANTATION */
'3751' = "1"  /* HEART TRANSPLANTATION */
'3752' = "1"  /* IMPLANT TOT REP HRT SYS */
OTHER  = "0" ;


 /* ------------------------------------- */
 /* POST-OPERATIVE HEMORRHAGE OR HEMATOMA */
 /*   PROVIDER INDICATOR / PDI # 8        */
 /* ------------------------------------- */

 /* POST-OPERATIVE HEMATOMA */
 /* ICD-9-CM DIAGNOSIS CODE: */

VALUE $POHMAID
"99812" = "1" /* HEMATOMA COMPLICATING A PROCEDURE */
OTHER   = "0" ;

 /* CONTROL OF POST-OPERATIVE HEMATOMA */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $HEMATIP
"1809" = "1" /* OTHER INCISION OF EXTERNAL EAR */
"540"  = "1" /* INCISION OF ABDOMINAL WALL */
"5412" = "1" /* REOPENING OF RECENT LAPAROTOMY SITE */
"5919" = "1" /* OTHER INCISION OF PERIVESICLE TISSUE */
"610"  = "1" /* INCISION AND DRAINAGE OF SCROTUM AND TUNICA AND VAGINALIS */
"6998" = "1" /* OTHER OPERATIONS ON SUPPORTING STRUCTURES OF UTERUS */
"7014" = "1" /* OTHER VAGINOTOMY */
"7109" = "1" /* OTHER INCISION OF VULVA AND PERINEUM */
"7591" = "1" /* EVACUATION OF OBSTETRICAL INCISIONAL HEMATOMA OF PERINEUM */
"7592" = "1" /* EVACUATION OF OTHER HEMATOMA OF VULVA OR VAGINA */
"8604" = "1" /* OTHER INCISION WITH DRAINAGE OF SKIN AND SUBCUTANEOUS TISSUE */
OTHER  = "0" ;

 /* POST-OPERATIVE HEMORRHAGE */
 /* ICD-9-CM DIAGNOSIS CODE: */

VALUE $POHMRID
"99811" = "1" /* HEMORRHAGE COMPLICATING A PROCEDURE */
OTHER   = "0" ;

 /* CONTROL OF POST-OPERATIVE HEMORRHAGE */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $HEMORIP
"287"  = "1" /* CONTROL OF HEMORRHAGE AFTER TONSILLECTOMY AND ADENOIDECTOMY */
"3880" = "1" /* OTHER SURGICAL OCCLUSION OF UNSPECIFIED SITE */
"3881" = "1" /* OTHER SURGICAL OCCLUSION OF INTRACRANIAL VESSELS */
"3882" = "1" /* OTHER SURGICAL OCCLUSION OF OTHER VESSELS OF HEAD AND NECK */
"3883" = "1" /* OTHER SURGICAL OCCLUSION OF UPPER LIMB VESSELS */
"3884" = "1" /* OTHER SURGICAL OCCLUSION OF AORTA, ABDOMINAL */
"3885" = "1" /* OTHER SURGICAL OCCLUSION OF THORACIC VESSEL */
"3886" = "1" /* OTHER SURGICAL OCCLUSION OF ABDOMINAL ARTERIES */
"3887" = "1" /* OTHER SURGICAL OCCLUSION OF VESSELS ABDOMINAL VEINS */
"3888" = "1" /* OTHER SURGICAL OCCLUSION OF LOWER LIMB ARTERIES */
"3889" = "1" /* OTHER SURGICAL OCCLUSION OF LOWER LIMB VEINS */
"3941" = "1" /* CONTROL OF HEMORRHAGE FOLLOWING VASCULAR SURGERY*/
"3998" = "1" /* CONTROL OF HEMORRHAGE NOS */
"4995" = "1" /* CONTROL OF (POSTOPERATIVE) HEMORRHAGE OF ANUS */
"5793" = "1" /* CONTROL OF (POSTOPERATIVE HEMORRHAGE OF BLADDER) */
"6094" = "1" /* CONTROL OF (POSTOPERATIVE) HEMORRHAGE OF PROSTATE */
OTHER  = "0" ;

 /* COMBINED */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $HEMIP
"1809" = "1" /* OTHER INCISION OF EXTERNAL EAR */
"287"  = "1" /* CONTROL OF HEMORRHAGE AFTER TONSILLECTOMY AND ADENOIDECTOMY */
"3880" = "1" /* OTHER SURGICAL OCCLUSION OF UNSPECIFIED SITE */
"3881" = "1" /* OTHER SURGICAL OCCLUSION OF INTRACRANIAL VESSELS */
"3882" = "1" /* OTHER SURGICAL OCCLUSION OF OTHER VESSELS OF HEAD AND NECK */
"3883" = "1" /* OTHER SURGICAL OCCLUSION OF UPPER LIMB VESSELS */
"3884" = "1" /* OTHER SURGICAL OCCLUSION OF AORTA, ABDOMINAL */
"3885" = "1" /* OTHER SURGICAL OCCLUSION OF THORACIC VESSEL */
"3886" = "1" /* OTHER SURGICAL OCCLUSION OF ABDOMINAL ARTERIES */
"3887" = "1" /* OTHER SURGICAL OCCLUSION OF VESSELS ABDOMINAL VEINS */
"3888" = "1" /* OTHER SURGICAL OCCLUSION OF LOWER LIMB ARTERIES */
"3889" = "1" /* OTHER SURGICAL OCCLUSION OF LOWER LIMB VEINS */
"3941" = "1" /* CONTROL OF HEMORRHAGE FOLLOWING VASCULAR SURGERY*/
"3998" = "1" /* CONTROL OF HEMORRHAGE NOS */
"4995" = "1" /* CONTROL OF (POSTOPERATIVE) HEMORRHAGE OF ANUS */
"540"  = "1" /* INCISION OF ABDOMINAL WALL */
"5412" = "1" /* REOPENING OF RECENT LAPAROTOMY SITE */
"5793" = "1" /* CONTROL OF (POSTOPERATIVE HEMORRHAGE OF BLADDER) */
"5919" = "1" /* OTHER INCISION OF PERIVESICLE TISSUE */
"6094" = "1" /* CONTROL OF (POSTOPERATIVE) HEMORRHAGE OF PROSTATE */
"610"  = "1" /* INCISION AND DRAINAGE OF SCROTUM AND TUNICA AND VAGINALIS */
"6998" = "1" /* OTHER OPERATIONS ON SUPPORTING STRUCTURES OF UTERUS */
"7014" = "1" /* OTHER VAGINOTOMY */
"7109" = "1" /* OTHER INCISION OF VULVA AND PERINEUM */
"7591" = "1" /* EVACUATION OF OBSTETRICAL INCISIONAL HEMATOMA OF PERINEUM */
"7592" = "1" /* EVACUATION OF OTHER HEMATOMA OF VULVA OR VAGINA */
"8604" = "1" /* OTHER INCISION WITH DRAINAGE OF SKIN AND SUBCUTANEOUS TISSUE */
OTHER  = "0" ;

/* STRATIFIED BY: COAGULOPATHIES */
/* ICD-9-CM DIAGNOSIS CODE: */

VALUE $ACGOFD
"2860"  = "1" /* CONG FACTOR VIII DIORD */
"2861"  = "1" /* CONG FACTOR IX DISORDER */
"2862"  = "1" /* CONG FACTOR XI DISORDER */
"2863"  = "1" /* CONG DEF CLOT FACTOR NEC */
"2864"  = "1" /* VON WILLEBRAND'S DISEASE */
"2865"  = "1" /* CIRCULATING ANTICOAG DIS */
"2866"  = "1" /* DEFIBRINATION SYNDROME */
"2867"  = "1" /* ACQ COAGUL FACTOR DEFIC */
"2869"  = "1" /* COAGULAT DEFECT NEC NOS */
"2871"  = "1" /* THROMBOCYTOPATHY */
"2873"  = "1" /* PRIMARY THROMBOCYTOPENIA */
"28730" = "1" /* PRIM THROMBOCYTOPEN NOS */  
"28731" = "1" /* IMMUNE THROMBOCYT PURPRA */ 
"28732" = "1" /* EVANS' SYNDROME */          
"28733" = "1" /* CONG/HERID THROMB PURPRA */ 
"28739" = "1" /* PRIM THROMBOCYTOPEN NEC */  
"2874"  = "1" /* SECOND THROMBOCYTOPENIA */
"2875"  = "1" /* THROMBOCYTOPENIA NOS */
"2878"  = "1" /* HEMORRHAGIC COND NEC */
"2879"  = "1" /* HEMORRHAGIC COND NOS */
OTHER   = "0" ;

/*STRATIFIED: BY PR CODE FOR ECMO */
/* ICD-9-CM CODE PROCEDURE CODE: */

VALUE $ECMOP
"3965" = "1" /* ECMO */
OTHER  = "0" ;


 /* ---------------------------------- */
 /* POST-OPERATIVE RESPIRATORY FAILURE */
 /*   PROVIDER INDICATOR / PDI # 9     */
 /* ---------------------------------- */

 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $ACURFID
"51881" = "1" /* ACUTE RESPIRATRY FAILURE */
"51884" = "1" /* ACUTE & CHRONC RESP FAIL */
OTHER   = "0" ;

 /* ICD-9-CM PROCEDURE CODES: */

VALUE $BLANK
OTHER  = "0" ;

VALUE $PR9604P
"9604" = "1" /* INSERT OF SENSTAKEN TUBE */
OTHER  = "0" ;

VALUE $PR9670P
"9670" = "1" /* CONTINUOUS MECHANICAL VENTILATION OF UNSPEC DURATION */
OTHER  = "0" ;

VALUE $PR9671P
"9671" = "1" /* CONTINUOUS MECHANICAL VENTILATION FOR LESS THAN 96 CONSECUTIVE HRS */
OTHER  = "0" ;

VALUE $PR9672P
"9672" = "1" /* CONTINUOUS MECHANICAL VENTILATION FOR 96 CONSECUTIVE HRS OR MORE*/
OTHER  = "0" ;

 /* EXCLUDE: TRACHEOSTOMY */;
 /* ICD-9-CM PROCEDURE CODE: */;

VALUE $TRACHIP
"3121" = "1" /* MEDIASTINAL TRACHEOSTOMY */
"3129" = "1" /* OTHER PERM TRACHEOSTOMY */
"3174" = "1" /* REVISION OF TRACHEOSTOMY */
OTHER  = "0" ;

 /* EXCLUDE: NEUROMUSCULAR DISORDERS */;
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $NEUROMD
"3570 " = "1" /* AC INFECT POLYNEURITIS */
"35800" = "1" /* MYSTHNA GRVS W/O AC EXAC */
"35801" = "1" /* MYASTHNA GRAVS W AC EXAC */
"3581 " = "1" /* MYASTHENIA IN OTH DIS */
"3582 " = "1" /* TOXIC MYONEURAL DISORDER */
"3588 " = "1" /* MYONEURAL DISORDERS NEC */
"3589 " = "1" /* MYONEURAL DISORDERS NOS */
"3590 " = "1" /* CONG HERED MUSC DYSTRPHY */
"3591 " = "1" /* HERED PROG MUSC DYSTRPHY */
"3592 " = "1" /* MYOTONIC DISORDERS */
"35922" = "1" /* MYOTONIA CONGENITA */
"35923" = "1" /* MYOTONIC CHONDRODYSTRPHY */
"3593 " = "1" /* FAMIL PERIODIC PARALYSIS */
"3594 " = "1" /* TOXIC MYOPATHY */
"3595 " = "1" /* MYOPATHY IN ENDOCRIN DIS */
"3596 " = "1" /* INFL MYOPATHY IN OTH DIS */
"35981" = "1" /* CRITICAL ILLNESS MYOPTHY */
"35989" = "1" /* MYOPATHIES NEC */
"3599 " = "1" /* MYOPATHY NOS */
OTHER   = "0" ;

 /* ------------------------------- */
 /* POST-OPERATIVE SEPSIS           */
 /*   PROVIDER INDICATOR / PSI # 10 */
 /* ------------------------------- */

 /* SEPTICEMIA */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $SEPTIID
"0380"  = "1" /* STREPTOCOCCAL SEPTICEMIA */
"0381"  = "1" /* STAPHYLOCOCCAL SEPTICEMIA */
"03810" = "1" /* STAPHYLOCOCCAL SEPTICEMIA, UNSPECIFIED */
"03811" = "1" /* STAPHYLOCOCCUS AUREUS SEPTICEMIA */
"03819" = "1" /* OTHER STAPHYLOCOCCAL SEPTICEMIA */
"0382"  = "1" /* PNEUMOCOCCAL SEPTICEMIA (STREPTOCOCCUS PNEUMONIAE SEPTICEMIA) */
"0383"  = "1" /* SEPTICEMIA DUE TO ANAEROBES */
"03840" = "1" /* GRAM-NEGATIVE ORGANISM, UNSPECIFIED */
"03841" = "1" /* HEMOPHILUS INFLUENZAE */
"03842" = "1" /* ESCHERICHIA COLI */
"03843" = "1" /* PSEUDOMONAS */
"03844" = "1" /* SERRATIA */
"03849" = "1" /* SEPTICEMIA DUE TO OTHER GRAM-NEGATIVE ORGANISMS */
"0388"  = "1" /* OTHER SPECIFIED SEPTICEMIAS */
"0389"  = "1" /* UNSPECIFIED SEPTICEMIA */
"78552" = "1" /* SEPTIC SHOCK */             
"78559" = "1" /* SHOCK W/O TRAUMA NEC */     
"99591" = "1" /* SYSTEMIC INFLAMMATORY RESPONSE SYNDROME DUE TO INFECTIOUS 
                 PROCESS WITHOUT ORGAN DYSFUNCTION */
"99592" = "1" /* SYSTEMIC INFLAMMATORY RESPONSE SYNDROME DUE TO INFECTIOUS
                 PROCESS WITH ORGAN DYSFUNCTION */
"9980"  = "1" /* POSTOPERATIVE SHOCK */    
OTHER   = "0" ;

 /* EXCLUDE: INFECTION */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $INFECID
"0010" = "1" /* CHOLERA D/T VIB CHOLERAE */
"0011" = "1" /* CHOLERA D/T VIB EL TOR */
"0019" = "1" /* CHOLERA NOS */
"0020" = "1" /* TYPHOID FEVER */
"0021" = "1" /* PARATYPHOID FEVER A */
"0022" = "1" /* PARATYPHOID FEVER B */
"0023" = "1" /* PARATYPHOID FEVER C */
"0029" = "1" /* PARATYPHOID FEVER NOS */
"0030" = "1" /* SALMONELLA ENTERITIS */
"0031" = "1" /* SALMONELLA SEPTICEMIA */
"00320" = "1" /* LOCAL SALMONELLA INF NOS */
"00321" = "1" /* SALMONELLA MENINGITIS */
"00322" = "1" /* SALMONELLA PNEUMONIA */
"00323" = "1" /* SALMONELLA ARTHRITIS */
"00324" = "1" /* SALMONELLA OSTEOMYELITIS */
"00329" = "1" /* LOCAL SALMONELLA INF NEC */
"0038" = "1" /* SALMONELLA INFECTION NEC */
"0039" = "1" /* SALMONELLA INFECTION NOS */
"0040" = "1" /* SHIGELLA DYSENTERIAE */
"0041" = "1" /* SHIGELLA FLEXNERI */
"0042" = "1" /* SHIGELLA BOYDII */
"0043" = "1" /* SHIGELLA SONNEI */
"0048" = "1" /* SHIGELLA INFECTION NEC */
"0049" = "1" /* SHIGELLOSIS NOS */
"0050" = "1" /* STAPH FOOD POISONING */
"0051" = "1" /* BOTULISM */
"0052" = "1" /* FOOD POIS D/T C. PERFRIN */
"0053" = "1" /* FOOD POIS: CLOSTRID NEC */
"0054" = "1" /* FOOD POIS: V. PARAHAEM */
"00581" = "1" /* FOOD POISN D/T V. VULNIF */
"00589" = "1" /* BACT FOOD POISONING NEC */
"0059" = "1" /* FOOD POISONING NOS */
"00800" = "1" /* INTEST INFEC E COLI NOS */
"00801" = "1" /* INT INF E COLI ENTRPATH */
"00802" = "1" /* INT INF E COLI ENTRTOXGN */
"00803" = "1" /* INT INF E COLI ENTRNVSV */
"00804" = "1" /* INT INF E COLI ENTRHMRG */
"00809" = "1" /* INT INF E COLI SPCF NEC */
"0081" = "1" /* ARIZONA ENTERITIS */
"0082" = "1" /* AEROBACTER ENTERITIS */
"0083" = "1" /* PROTEUS ENTERITIS */
"00841" = "1" /* STAPHYLOCOCC ENTERITIS */
"00842" = "1" /* PSEUDOMONAS ENTERITIS */
"00843" = "1" /* INT INFEC CAMPYLOBACTER */
"00844" = "1" /* INT INF YRSNIA ENTRCLTCA */
"00845" = "1" /* INT INF CLSTRDIUM DFCILE */
"00846" = "1" /* INTES INFEC OTH ANEROBES */
"00847" = "1" /* INT INF OTH GRM NEG BCTR */
"00849" = "1" /* BACTERIAL ENTERITIS NEC */
"0085" = "1" /* BACTERIAL ENTERITIS NOS */
"0200" = "1" /* BUBONIC PLAGUE */
"0201" = "1" /* CELLULOCUTANEOUS PLAGUE */
"0202" = "1" /* SEPTICEMIC PLAGUE */
"0203" = "1" /* PRIMARY PNEUMONIC PLAGUE */
"0204" = "1" /* SECONDARY PNEUMON PLAGUE */
"0205" = "1" /* PNEUMONIC PLAGUE NOS */
"0208" = "1" /* OTHER TYPES OF PLAGUE */
"0209" = "1" /* PLAGUE NOS */
"0210" = "1" /* ULCEROGLANDUL TULAREMIA */
"0211" = "1" /* ENTERIC TULAREMIA */
"0212" = "1" /* PULMONARY TULAREMIA */
"0213" = "1" /* OCULOGLANDULAR TULAREMIA */
"0218" = "1" /* TULAREMIA NEC */
"0219" = "1" /* TULAREMIA NOS */
"0220" = "1" /* CUTANEOUS ANTHRAX */
"0221" = "1" /* PULMONARY ANTHRAX */
"0222" = "1" /* GASTROINTESTINAL ANTHRAX */
"0223" = "1" /* ANTHRAX SEPTICEMIA */
"0228" = "1" /* OTHER ANTHRAX MANIFEST */
"0229" = "1" /* ANTHRAX NOS */
"0230" = "1" /* BRUCELLA MELITENSIS */
"0231" = "1" /* BRUCELLA ABORTUS */
"0232" = "1" /* BRUCELLA SUIS */
"0233" = "1" /* BRUCELLA CANIS */
"0238" = "1" /* BRUCELLOSIS NEC */
"0239" = "1" /* BRUCELLOSIS NOS */
"024" = "1" /* GLANDERS */
"025" = "1" /* MELIOIDOSIS */
"0260" = "1" /* SPIRILLARY FEVER */
"0261" = "1" /* STREPTOBACILLARY FEVER */
"0269" = "1" /* RAT-BITE FEVER NOS */
"0270" = "1" /* LISTERIOSIS */
"0271" = "1" /* ERYSIPELOTHRIX INFECTION */
"0272" = "1" /* PASTEURELLOSIS */
"0278" = "1" /* ZOONOTIC BACT DIS NEC */
"0279" = "1" /* ZOONOTIC BACT DIS NOS */
"0320" = "1" /* FAUCIAL DIPHTHERIA */
"0321" = "1" /* NASOPHARYNX DIPHTHERIA */
"0322" = "1" /* ANT NASAL DIPHTHERIA */
"0323" = "1" /* LARYNGEAL DIPHTHERIA */
"03281" = "1" /* CONJUNCTIVAL DIPHTHERIA */
"03282" = "1" /* DIPHTHERITIC MYOCARDITIS */
"03283" = "1" /* DIPHTHERITIC PERITONITIS */
"03284" = "1" /* DIPHTHERITIC CYSTITIS */
"03285" = "1" /* CUTANEOUS DIPHTHERIA */
"03289" = "1" /* DIPHTHERIA NEC */
"0329" = "1" /* DIPHTHERIA NOS */
"0330" = "1" /* BORDETELLA PERTUSSIS */
"0331" = "1" /* BORDETELLA PARAPERTUSSIS */
"0338" = "1" /* WHOOPING COUGH NEC */
"0339" = "1" /* WHOOPING COUGH NOS */
"0340" = "1" /* STREP SORE THROAT */
"0341" = "1" /* SCARLET FEVER */
"035" = "1" /* ERYSIPELAS */
"0360" = "1" /* MENINGOCOCCAL MENINGITIS */
"0361" = "1" /* MENINGOCOCC ENCEPHALITIS */
"0362" = "1" /* MENINGOCOCCEMIA */
"0363" = "1" /* MENINGOCOCC ADRENAL SYND */
"03640" = "1" /* MENINGOCOCC CARDITIS NOS */
"03641" = "1" /* MENINGOCOCC PERICARDITIS */
"03642" = "1" /* MENINGOCOCC ENDOCARDITIS */
"03643" = "1" /* MENINGOCOCC MYOCARDITIS */
"03681" = "1" /* MENINGOCOCC OPTIC NEURIT */
"03682" = "1" /* MENINGOCOCC ARTHROPATHY */
"03689" = "1" /* MENINGOCOCCAL INFECT NEC */
"0369" = "1" /* MENINGOCOCCAL INFECT NOS */
"037" = "1" /* TETANUS */
"0380" = "1" /* STREPTOCOCCAL SEPTICEMIA */
"03810" = "1" /* STAPHYLCOCC SEPTICEM NOS */
"03811" = "1" /* STAPH AUREUS SEPTICEMIA */
"03819" = "1" /* STAPHYLCOCC SEPTICEM NEC */
"0382" = "1" /* PNEUMOCOCCAL SEPTICEMIA */
"0383" = "1" /* ANAEROBIC SEPTICEMIA */
"03840" = "1" /* GRAM-NEG SEPTICEMIA NOS */
"03841" = "1" /* H. INFLUENAE SEPTICEMIA */
"03842" = "1" /* E COLI SEPTICEMIA */
"03843" = "1" /* PSEUDOMONAS SEPTICEMIA */
"03844" = "1" /* SERRATIA SEPTICEMIA */
"03849" = "1" /* GRAM-NEG SEPTICEMIA NEC */
"0388" = "1" /* SEPTICEMIA NEC */
"0389" = "1" /* SEPTICEMIA NOS */
"0390" = "1" /* CUTANEOUS ACTINOMYCOSIS */
"0391" = "1" /* PULMONARY ACTINOMYCOSIS */
"0392" = "1" /* ABDOMINAL ACTINOMYCOSIS */
"0393" = "1" /* CERVICOFAC ACTINOMYCOSIS */
"0394" = "1" /* MADURA FOOT */
"0398" = "1" /* ACTINOMYCOSIS NEC */
"0399" = "1" /* ACTINOMYCOSIS NOS */
"0400" = "1" /* GAS GANGRENE */
"0401" = "1" /* RHINOSCLEROMA */
"0402" = "1" /* WHIPPLE"S DISEASE */
"0403" = "1" /* NECROBACILLOSIS */
"04041" = "1" /* INFANT BOTULISM */
"04042" = "1" /* WOUND BOTULISM */
"04081" = "1" /* TROPICAL PYOMYOSITIS */
"04082" = "1" /* TOXIC SHOCK SYNDROME */
"04089" = "1" /* BACTERIAL DISEASES NEC */
"04100" = "1" /* STREPTOCOCCUS UNSPECF */
"04101" = "1" /* STREPTOCOCCUS GROUP A */
"04102" = "1" /* STREPTOCOCCUS GROUP B */
"04103" = "1" /* STREPTOCOCCUS GROUP C */
"04104" = "1" /* ENTEROCOCCUS GROUP D */
"04105" = "1" /* STREPTOCOCCUS GROUP G */
"04109" = "1" /* OTHER STREPTOCOCCUS */
"04110" = "1" /* STAPHYLOCOCCUS UNSPCFIED */
"04111" = "1" /* STAPHYLOCOCCUS AUREUS */
"04119" = "1" /* OTHER STAPHYLOCOCCUS */
"0412" = "1" /* PNEUMOCOCCUS INFECT NOS */
"0413" = "1" /* KLEBSIELLA INFECT NOS */
"0414" = "1" /* E. COLI INFECT NOS */
"0415" = "1" /* H. INFLUENZAE INFECT NOS */
"0416" = "1" /* PROTEUS INFECTION NOS */
"0417" = "1" /* PSEUDOMONAS INFECT NOS */
"04182" = "1" /* BACTEROIDES FRAGILIS */
"04183" = "1" /* CLOSTRIDIUM PERFRINGENS */
"04184" = "1" /* OTHER ANAEROBES */
"04185" = "1" /* OTH GRAM NEGATV BACTERIA */
"04186" = "1" /* HELICOBACTER PYLORI */
"04189" = "1" /* OTH SPECF BACTERIA */
"0419" = "1" /* BACTERIAL INFECTION NOS */
"0980" = "1" /* ACUTE GC INFECT LOWER GU */
"09810" = "1" /* GC (ACUTE) UPPER GU NOS */
"09811" = "1" /* GC CYSTITIS (ACUTE) */
"09812" = "1" /* GC PROSTATITIS (ACUTE) */
"09813" = "1" /* GC ORCHITIS (ACUTE) */
"09814" = "1" /* GC SEM VESICULIT (ACUTE) */
"09815" = "1" /* GC CERVICITIS (ACUTE) */
"09816" = "1" /* GC ENDOMETRITIS (ACUTE) */
"09817" = "1" /* ACUTE GC SALPINGITIS */
"09819" = "1" /* GC (ACUTE) UPPER GU NEC */
"0982" = "1" /* CHR GC INFECT LOWER GU */
"09830" = "1" /* CHR GC UPPER GU NOS */
"09831" = "1" /* GC CYSTITIS, CHRONIC */
"09832" = "1" /* GC PROSTATITIS, CHRONIC */
"09833" = "1" /* GC ORCHITIS, CHRONIC */
"09834" = "1" /* GC SEM VESICULITIS, CHR */
"09835" = "1" /* GC CERVICITIS, CHRONIC */
"09836" = "1" /* GC ENDOMETRITIS, CHRONIC */
"09837" = "1" /* GC SALPINGITIS (CHRONIC) */
"09839" = "1" /* CHR GC UPPER GU NEC */
"09840" = "1" /* GONOCOCCAL CONJUNCTIVIT */
"09841" = "1" /* GONOCOCCAL IRIDOCYCLITIS */
"09842" = "1" /* GONOCOCCAL ENDOPHTHALMIA */
"09843" = "1" /* GONOCOCCAL KERATITIS */
"09849" = "1" /* GONOCOCCAL EYE NEC */
"09850" = "1" /* GONOCOCCAL ARTHRITIS */
"09851" = "1" /* GONOCOCCAL SYNOVITIS */
"09852" = "1" /* GONOCOCCAL BURSITIS */
"09853" = "1" /* GONOCOCCAL SPONDYLITIS */
"09859" = "1" /* GC INFECT JOINT NEC */
"0986" = "1" /* GONOCOCCAL INFEC PHARYNX */
"0987" = "1" /* GC INFECT ANUS & RECTUM */
"09881" = "1" /* GONOCOCCAL KERATOSIS */
"09882" = "1" /* GONOCOCCAL MENINGITIS */
"09883" = "1" /* GONOCOCCAL PERICARDITIS */
"09884" = "1" /* GONOCOCCAL ENDOCARDITIS */
"09885" = "1" /* GONOCOCCAL HEART DIS NEC */
"09886" = "1" /* GONOCOCCAL PERITONITIS */
"09889" = "1" /* GONOCOCCAL INF SITE NEC */
"3200" = "1" /* HEMOPHILUS MENINGITIS */
"3201" = "1" /* PNEUMOCOCCAL MENINGITIS */
"3202" = "1" /* STREPTOCOCCAL MENINGITIS */
"3203" = "1" /* STAPHYLOCOCC MENINGITIS */
"3207" = "1" /* MENING IN OTH BACT DIS */
"32081" = "1" /* ANAEROBIC MENINGITIS */
"32082" = "1" /* MNINGTS GRAM-NEG BCT NEC */
"32089" = "1" /* MENINGITIS OTH SPCF BACT */
"3209" = "1" /* BACTERIAL MENINGITIS NOS */
"3229" = "1" /* MENINGITIS NOS            */
"3240" = "1" /* INTRACRANIAL ABSCESS */
"3241" = "1" /* INTRASPINAL ABSCESS */
"3249" = "1" /* CNS ABSCESS NOS */
"36000" = "1" /* PURULENT ENDOPHTHALM NOS */
"36001" = "1" /* ACUTE ENDOPHTHALMITIS */
"36002" = "1" /* PANOPHTHALMITIS */
"36004" = "1" /* VITREOUS ABSCESS */
"37055" = "1" /* CORNEAL ABSCESS */
"37200" = "1" /* ACUTE CONJUNCTIVITIS NOS */
"37203" = "1" /* MUCOPUR CONJUNCTIVIT NEC */
"37204" = "1" /* PSEUDOMEMB CONJUNCTIVIT */
"37220" = "1" /* BLEPHAROCONJUNCTIVIT NOS */
"37221" = "1" /* ANGULAR BLEPHAROCONJUNCT */
"37230" = "1" /* CONJUNCTIVITIS NOS */
"37300" = "1" /* BLEPHARITIS NOS */
"37301" = "1" /* ULCERATIVE BLEPHARITIS */
"37311" = "1" /* HORDEOLUM EXTERNUM */
"37312" = "1" /* HORDEOLUM INTERNUM */
"37313" = "1" /* ABSCESS OF EYELID */
"37500" = "1" /* DACRYOADENITIS NOS */
"37501" = "1" /* ACUTE DACRYOADENITIS */
"37530" = "1" /* DACRYOCYSTITIS NOS */
"37531" = "1" /* ACUTE CANALICULITIS */
"37532" = "1" /* ACUTE DACRYOCYSTITIS */
"37600" = "1" /* ACUTE INFLAM NOS, ORBIT */
"37601" = "1" /* ORBITAL CELLULITIS */
"37602" = "1" /* ORBITAL PERIOSTITIS */
"37603" = "1" /* ORBITAL OSTEOMYELITIS */
"37604" = "1" /* TENONITIS */
"38010" = "1" /* INFEC OTITIS EXTERNA NOS */
"38011" = "1" /* ACUTE INFECTION OF PINNA */
"38012" = "1" /* ACUTE SWIMMERS" EAR */
"38013" = "1" /* AC INFECT EXTERN EAR NEC */
"38014" = "1" /* MALIGNANT OTITIS EXTERNA */
"38150" = "1" /* EUSTACHIAN SALPING NOS */
"38151" = "1" /* AC EUSTACHIAN SALPING */
"38200" = "1" /* AC SUPP OTITIS MEDIA NOS */
"38201" = "1" /* AC SUPP OM W DRUM RUPT */
"38202" = "1" /* AC SUPP OM IN OTH DIS */
"3821" = "1" /* CHR TUBOTYMP SUPP OTITIS MEDIA */
"3822" = "1" /* CHR ATTICOANTRAL SUPP OTITIS MEDIA */
"3823" = "1" /* CHR SUPP OTITIS MEDIA NOS */
"3824" = "1" /* SUPPUR OTITIS MEDIA NOS */
"3829" = "1" /* OTITIS MEDIA NOS */
"38300" = "1" /* AC MASTOIDITIS W/O COMPL */
"38301" = "1" /* SUBPERI MASTOID ABSCESS */
"38302" = "1" /* AC MASTOIDITIS-COMPL NEC */
"38320" = "1" /* PETROSITIS NOS */
"38321" = "1" /* ACUTE PETROSITIS */
"38400" = "1" /* ACUTE MYRINGITIS NOS */
"38630" = "1" /* LABYRINTHITIS NOS */
"38631" = "1" /* SEROUS LABYRINTHITIS */
"38632" = "1" /* CIRCUMSCRI LABYRINTHITIS */
"38633" = "1" /* SUPPURATIV LABYRINTHITIS */
"4200" = "1" /* AC PERICARDIT IN OTH DIS */
"42090" = "1" /* ACUTE PERICARDITIS NOS */
"42099" = "1" /* ACUTE PERICARDITIS NEC */
"4210" = "1" /* AC/SUBAC BACT ENDOCARD */
"4211" = "1" /* AC/SUBAC INFECT ENDOCARD */
"4219" = "1" /* AC/SUBAC ENDOCARDIT NOS */
"42292" = "1" /* SEPTIC MYOCARDITIS */
"4610" = "1" /* AC MAXILLARY SINUSITIS */
"4611" = "1" /* AC FRONTAL SINUSITIS */
"4612" = "1" /* AC ETHMOIDAL SINUSITIS */
"4613" = "1" /* AC SPHENOIDAL SINUSITIS */
"4618" = "1" /* OTHER ACUTE SINUSITIS */
"4619" = "1" /* ACUTE SINUSITIS NOS */
"462" = "1" /* ACUTE PHARYNGITIS */
"463" = "1" /* ACUTE TONSILLITIS */
"46430" = "1" /* AC EPIGLOTTITIS NO OBSTR */
"46431" = "1" /* AC EPIGLOTTITIS W OBSTR */
"4660" = "1" /* ACUTE BRONCHITIS */
"475" = "1" /* PERITONSILLAR ABSCESS */
"47822" = "1" /* PARAPHARYNGEAL ABSCESS */
"47824" = "1" /* RETROPHARYNGEAL ABSCESS */
"481" = "1" /* PNEUMOCOCCAL PNEUMONIA */
"4820" = "1" /* K. PNEUMONIAE PNEUMONIA */
"4821" = "1" /* PSEUDOMONAL PNEUMONIA */
"4822" = "1" /* H.INFLUENZAE PNEUMONIA */
"48230" = "1" /* STREPTOCOCCAL PNEUMN NOS */
"48231" = "1" /* PNEUMONIA STRPTOCOCCUS A */
"48232" = "1" /* PNEUMONIA STRPTOCOCCUS B */
"48239" = "1" /* PNEUMONIA OTH STREP */
"48240" = "1" /* STAPHYLOCOCCAL PNEU NOS */
"48241" = "1" /* STAPH AUREUS PNEUMONIA */
"48249" = "1" /* STAPH PNEUMONIA NEC */
"48281" = "1" /* PNEUMONIA ANAEROBES */
"48282" = "1" /* PNEUMONIA E COLI */
"48283" = "1" /* PNEUMO OTH GRM-NEG BACT */
"48284" = "1" /* LEGIONNAIRES" DISEASE */
"48289" = "1" /* PNEUMONIA OTH SPCF BACT */
"4829" = "1" /* BACTERIAL PNEUMONIA NOS */
"4843" = "1" /* PNEUMONIA IN WHOOPING COUGH */
"4845" = "1" /* PNEUMONIA IN ANTHRAX */
"4848" = "1" /* PNEUMONIA IN OTHER INF DIS  */
"485" = "1" /* BRONCHOPNEUMONIA ORG NOS */
"486" = "1" /* PNEUMONIA, ORGANISM NOS */
"490" = "1" /* BRONCHITIS NOS */
"49122" = "1" /* OBS CHR BRONC W AC BRONC */
"4941" = "1" /* BRONCHIECTASIS W AC EXAC */
"5100" = "1" /* EMPYEMA WITH FISTULA */
"5109" = "1" /* EMPYEMA W/O FISTULA */
"5111" = "1" /* BACT PLEUR/EFFUS NOT TB */
"5130" = "1" /* ABSCESS OF LUNG */
"5131" = "1" /* ABSCESS OF MEDIASTINUM */
"51901" = "1" /* TRACHEOSTOMY INFECTION */
"5192" = "1" /* MEDIASTINITIS */
"5220" = "1" /* PULPITIS */
"5225" = "1" /* PERIAPICAL ABSCESS */
"5227" = "1" /* PERIAPICAL ABSC W SINUS */
"5230" = "1" /* ACUTE GINGIVITIS */
"52300" = "1" /* ACUTE GINGITITIS, PLAQUE */ 
"52301" = "1" /* AC GINGIVITIS,NONPLAQUE */  
"5233"  = "1" /* ACUTE PERIODONTITIS       */
"52330" = "1" /* AGGRES PERIODONTITIS NOS */ 
"52331" = "1" /* AGGRES PERIODONTITIS,LOC */ 
"52332" = "1" /* AGGRES PERIODONTITIS,GEN */ 
"52333" = "1" /* ACUTE PERIODONTITIS */  
"5264" = "1" /* INFLAMMATION OF JAW */
"5273" = "1" /* SALIVARY GLAND ABSCESS */
"5283" = "1" /* CELLULITIS/ABSCESS MOUTH */
"53641" = "1" /* GASTROSTOMY INFECTION     */
"5400" = "1" /* AC APPEND W PERITONITIS */
"5401" = "1" /* ABSCESS OF APPENDIX */
"5409" = "1" /* ACUTE APPENDICITIS NOS */
"541" = "1" /* APPENDICITIS NOS */
"542" = "1" /* OTHER APPENDICITIS */
"56201" = "1" /* DVRTCLI SML INT W/O HMRG */
"56203" = "1" /* DVRTCLI SML INT W HMRHG */
"56211" = "1" /* DVRTCLI COLON W/O HMRHG */
"56213" = "1" /* DVRTCLI COLON W HMRHG */
"566" = "1" /* ANAL & RECTAL ABSCESS */
"5670" = "1" /* PERITONITIS IN INFEC DIS */
"5671" = "1" /* PNEUMOCOCCAL PERITONITIS */
"5672" = "1" /* SUPPURAT PERITONITIS NEC */
"56721" = "1" /* PERITONITIS (ACUTE) GEN  */
"56722" = "1" /* PERITONEAL ABSCESS  */
"56723" = "1" /* SPONTAN BACT PERITONITIS  */
"56729" = "1" /* SUPPURAT PERITONITIS NEC  */
"56731" = "1" /* PSOAS MUSCLE ABSCESS  */
"56738" = "1" /* RETROPERITON ABSCESS NEC  */
"56739" = "1" /* RETROPERITON INFECT NEC  */
"56781" = "1" /* CHOLEPERITONITIS  */
"56782" = "1" /* SCLEROSING MESENTERITIS  */
"56789" = "1" /* PERITONITIS NEC  */
"5679" = "1" /* PERITONITIS NOS */
"5695" = "1" /* INTESTINAL ABSCESS */
"56961" = "1" /* COLOSTY/ENTEROST INFECTN */
"5720" = "1" /* ABSCESS OF LIVER */
"5721" = "1" /* PORTAL PYEMIA */
"57400" = "1" /* CHOLELITH W AC CHOLECYST */
"57401" = "1" /* CHOLELITH/AC GB INF-OBST */
"57430" = "1" /* CHOLEDOCHOLITH/AC GB INF */
"57431" = "1" /* CHOLEDOCHLITH/AC GB-OBST */
"57460" = "1" /* GALL&BIL CAL W/AC W/O OB */
"57461" = "1" /* GALL&BIL CAL W/AC W OBS */
"57480" = "1" /* GAL&BIL CAL W/AC&CHR W/O */
"57481" = "1" /* GAL&BIL CAL W/AC&CH W OB */
"5750" = "1" /* ACUTE CHOLECYSTITIS */
"57510" = "1" /* CHOLECYSTITIS UNSPEC */
"57512" = "1" /* AC&CHRON CHOLECYSTITIS */
"5754" = "1" /* PERFORATION GALLBLADDER */
"5761" = "1" /* CHOLANGITIS */
"5763" = "1" /* PERFORATION OF BILE DUCT */
"5770" = "1" /* ACUTE PANCREATITIS */
"59010" = "1" /* AC PYELONEPHRITIS NOS */
"59011" = "1" /* AC PYELONEPHR W MED NECR */
"5902" = "1" /* RENAL/PERIRENAL ABSCESS */
"5903" = "1" /* PYELOURETERITIS CYSTICA */
"59080" = "1" /* PYELONEPHRITIS NOS        */
"59081" = "1" /* PYELONEPHRIT IN OTH DIS */
"5909" = "1" /* INFECTION OF KIDNEY NOS */
"5950" = "1" /* ACUTE CYSTITIS */
"5954" = "1" /* CYSTITIS IN OTH DIS */
"59581" = "1" /* CYSTITIS CYSTICA */
"59589" = "1" /* CYSTITIS NEC */
"5959" = "1" /* CYSTITIS NOS */
"5970" = "1" /* URETHRAL ABSCESS */
"59800" = "1" /* URETHR STRICT:INFECT NOS */
"59801" = "1" /* URETH STRICT:OTH INFECT */
"5990" = "1" /* URIN TRACT INFECTION NOS */
"6010" = "1" /* ACUTE PROSTATITIS */
"6012" = "1" /* ABSCESS OF PROSTATE */
"6013" = "1" /* PROSTATOCYSTITIS */
"6014" = "1" /* PROSTATITIS IN OTH DIS */
"6018" = "1" /* PROSTATITIS  */
"6019" = "1" /* PROSTATITIS NOS */
"6031" = "1" /* INFECTED HYDROCELE */
"6040" = "1" /* ORCHITIS WITH ABSCESS */
"60490" = "1" /* ORCHITIS/EPIDIDYMIT NOS */
"60491" = "1" /* ORCHITIS IN OTH DISEASE */
"6071" = "1" /* BALANOPOSTHITIS */
"6072" = "1" /* INFLAM DIS, PENIS NEC */
"6080" = "1" /* SEMINAL VESICULITIS */
"6084" = "1" /* MALE GEN INFLAM DIS NEC */
"6110" = "1" /* INFLAM DISEASE OF BREAST */
"6140" = "1" /* AC SALPINGO-OOPHORITIS */
"6141" = "1" /* CHRON SALPINGITIS OOPHORITIS */
"6142" = "1" /* SALPINGO-OOPHORITIS NOS */
"6143" = "1" /* ACUTE PARAMETRITIS */
"6144" = "1" /* CHRON OR UNSP CELLULITIS */
"6145" = "1" /* AC PELV PERITONITIS-FEM */
"6149" = "1" /* PID NOS */
"6150" = "1" /* AC UTERINE INFLAMMATION */
"6159" = "1" /* UTERINE INFLAM DIS NOS */
"6160" = "1" /* CERVICITIS */
"61610" = "1" /* VAGINITIS NOS */
"6163" = "1" /* BARTHOLIN"S GLND ABSCESS */
"6164" = "1" /* ABSCESS OF VULVA NEC */
"63400" = "1" /* SPON ABOR W PEL INF-UNSP */
"63401" = "1" /* SPON ABOR W PELV INF-INC */
"63402" = "1" /* SPON ABOR W PEL INF-COMP */
"63500" = "1" /* LEG ABOR W PELV INF-UNSP */
"63501" = "1" /* LEG ABOR W PELV INF-INC */
"63502" = "1" /* LEG ABOR W PELV INF-COMP */
"63600" = "1" /* ILLEG AB W PELV INF-UNSP */
"63601" = "1" /* ILLEG AB W PELV INF-INC */
"63602" = "1" /* ILLEG AB W PELV INF-COMP */
"63700" = "1" /* ABORT NOS W PEL INF-UNSP */
"63701" = "1" /* ABORT NOS W PEL INF-INC */
"63702" = "1" /* ABORT NOS W PEL INF-COMP */
"6380" = "1" /* ATTEM ABORT W PELVIC INF */
"6390" = "1" /* POSTABORTION GU INFECT */
"64650" = "1" /* BACTERIURIA PREG-UNSPEC */
"64651" = "1" /* ASYM BACTERIURIA-DELIVER */
"64652" = "1" /* ASY BACTERURIA-DEL W P/P */
"64653" = "1" /* ASY BACTERIURIA-ANTEPART */
"64654" = "1" /* ASY BACTERIURIA-POSTPART */
"64660" = "1" /* GU INFECT IN PREG-UNSPEC */
"64661" = "1" /* GU INFECTION-DELIVERED */
"64662" = "1" /* GU INFECTION-DELIV W P/P */
"64663" = "1" /* GU INFECTION-ANTEPARTUM */
"64664" = "1" /* GU INFECTION-POSTPARTUM */
"64710" = "1" /* GONORRHEA IN PREG-UNSPEC */
"64711" = "1" /* GONORRHEA-DELIVERED */
"64712" = "1" /* GONORRHEA-DELIVER W P/P */
"64713" = "1" /* GONORRHEA-ANTEPARTUM */
"64714" = "1" /* GONORRHEA-POSTPARTUM */
"64780" = "1" /* INF DIS IN PREG NEC-UNSP */
"64781" = "1" /* INFECT DIS NEC-DELIVERED */
"64782" = "1" /* INFECT DIS NEC-DEL W P/P */
"64783" = "1" /* INFECT DIS NEC-ANTEPART */
"64784" = "1" /* INFECT DIS NEC-POSTPART */
"64790" = "1" /* INFECT IN PREG NOS-UNSP */
"64791" = "1" /* INFECT NOS-DELIVERED */
"64792" = "1" /* INFECT NOS-DELIVER W P/P */
"64793" = "1" /* INFECT NOS-ANTEPARTUM */
"64794" = "1" /* INFECT NOS-POSTPARTUM */
"65840" = "1" /* AMNIOTIC INFECTION-UNSP */
"65841" = "1" /* AMNIOTIC INFECTION-DELIV */
"65843" = "1" /* AMNIOTIC INFECT-ANTEPART */
"67000" = "1" /* MAJOR PUERP INFECT-UNSP */
"67002" = "1" /* MAJOR PUERP INF-DEL P/P */
"67004" = "1" /* MAJOR PUERP INF-POSTPART */
"67500" = "1" /* INFECT NIPPLE PREG-UNSP */
"67501" = "1" /* INFECT NIPPLE-DELIVERED */
"67502" = "1" /* INFECT NIPPLE-DEL W P/P */
"67503" = "1" /* INFECT NIPPLE-ANTEPARTUM */
"67504" = "1" /* INFECT NIPPLE-POSTPARTUM */
"67510" = "1" /* BREAST ABSCESS PREG-UNSP */
"67511" = "1" /* BREAST ABSCESS-DELIVERED */
"67512" = "1" /* BREAST ABSCESS-DEL W P/P */
"67513" = "1" /* BREAST ABSCESS-ANTEPART */
"67514" = "1" /* BREAST ABSCESS-POSTPART */
"67580" = "1" /* BREAST INF PREG NEC-UNSP */
"67581" = "1" /* BREAST INFECT NEC-DELIV */
"67582" = "1" /* BREAST INF NEC-DEL W P/P */
"67583" = "1" /* BREAST INF NEC-ANTEPART */
"67584" = "1" /* BREAST INF NEC-POSTPART */
"67590" = "1" /* BREAST INF PREG NOS-UNSP */
"67591" = "1" /* BREAST INFECT NOS-DELIV */
"67592" = "1" /* BREAST INF NOS-DEL W P/P */
"67593" = "1" /* BREAST INF NOS-ANTEPART */
"67594" = "1" /* BREAST INF NOS-POSTPART */
"6800" = "1" /* CARBUNCLE OF FACE */
"6801" = "1" /* CARBUNCLE OF NECK */
"6802" = "1" /* CARBUNCLE OF TRUNK */
"6803" = "1" /* CARBUNCLE OF ARM */
"6804" = "1" /* CARBUNCLE OF HAND */
"6805" = "1" /* CARBUNCLE OF BUTTOCK */
"6806" = "1" /* CARBUNCLE OF LEG */
"6807" = "1" /* CARBUNCLE OF FOOT */
"6808" = "1" /* CARBUNCLE, SITE NEC */
"6809" = "1" /* CARBUNCLE NOS */
"68100" = "1" /* CELLULITIS, FINGER NOS */
"68101" = "1" /* FELON */
"68102" = "1" /* ONYCHIA OF FINGER */
"68110" = "1" /* CELLULITIS, TOE NOS */
"68111" = "1" /* ONYCHIA OF TOE */
"6819" = "1" /* CELLULITIS OF DIGIT NOS */
"6820" = "1" /* CELLULITIS OF FACE */
"6821" = "1" /* CELLULITIS OF NECK */
"6822" = "1" /* CELLULITIS OF TRUNK */
"6823" = "1" /* CELLULITIS OF ARM */
"6824" = "1" /* CELLULITIS OF HAND */
"6825" = "1" /* CELLULITIS OF BUTTOCK */
"6826" = "1" /* CELLULITIS OF LEG */
"6827" = "1" /* CELLULITIS OF FOOT */
"6828" = "1" /* CELLULITIS, SITE NEC */
"6829" = "1" /* CRLLULITIS, SITE NOS */
"683" = "1" /* ACUTE LYMPHADENITIS */
"684" = "1" /* IMPETIGO */
"68600" = "1" /* PYODERMA NOS */
"68601" = "1" /* PYODERMA GANGRENOSUM */
"68609" = "1" /* PYODERMA OTHER */
"6868" = "1" /* LOCAL SKIN INFECTION NEC */
"6869" = "1" /* LOCAL SKIN INFECTION NOS */
"69581" = "1" /* RITTER"S DISEASE */
"70700" = "1" /* DECUBITUS ULCER SITE NOS */
"70701" = "1" /* DECUBITUS ULCER,ELBOW */
"70702" = "1" /* DECUBITUS ULCER,UP BACK */
"70703" = "1" /* DECUBITUS ULCER,LOW BACK */
"70704" = "1" /* DECUBITUS ULCER,HIP */
"70705" = "1" /* DECUBITUS ULCER,BUTTOCK */
"70706" = "1" /* DECUBITUS ULCER,ANKLE */
"70707" = "1" /* DECUBITUS ULCER,HEEL */
"70709" = "1" /* DECUBITUS ULCER,SITE NEC */
"71100" = "1" /* PYOGEN ARTHRITIS-UNSPEC */
"71101" = "1" /* PYOGEN ARTHRITIS-SHLDER */
"71102" = "1" /* PYOGEN ARTHRITIS-UP/ARM */
"71103" = "1" /* PYOGEN ARTHRITIS-FOREARM */
"71104" = "1" /* PYOGEN ARTHRITIS-HAND */
"71105" = "1" /* PYOGEN ARTHRITIS-PELVIS */
"71106" = "1" /* PYOGEN ARTHRITIS-L/LEG */
"71107" = "1" /* PYOGEN ARTHRITIS-ANKLE */
"71108" = "1" /* PYOGEN ARTHRITIS NEC */
"71109" = "1" /* PYOGEN ARTHRITIS-MULT */
"71190" = "1" /* INF ARTHRITIS NOS-UNSPEC */
"71191" = "1" /* INF ARTHRITIS NOS-SHLDER */
"71192" = "1" /* INF ARTHRITIS NOS-UP/ARM */
"71193" = "1" /* INF ARTHRIT NOS-FOREARM */
"71194" = "1" /* INF ARTHRIT NOS-HAND */
"71195" = "1" /* INF ARTHRIT NOS-PELVIS */
"71196" = "1" /* INF ARTHRIT NOS-L/LEG */
"71197" = "1" /* INF ARTHRIT NOS-ANKLE */
"71198" = "1" /* INF ARTHRIT NOS-OTH SITE */
"71199" = "1" /* INF ARTHRITIS NOS-MULT */
"7280" = "1" /* INFECTIVE MYOSITIS */
"72886" = "1" /* NECROTIZING FASCIITIS */
"73000" = "1" /* AC OSTEOMYELITIS-UNSPEC */
"73001" = "1" /* AC OSTEOMYELITIS-SHLDER */
"73002" = "1" /* AC OSTEOMYELITIS-UP/ARM */
"73003" = "1" /* AC OSTEOMYELITIS-FOREARM */
"73004" = "1" /* AC OSTEOMYELITIS-HAND */
"73005" = "1" /* AC OSTEOMYELITIS-PELVIS */
"73006" = "1" /* AC OSTEOMYELITIS-L/LEG */
"73007" = "1" /* AC OSTEOMYELITIS-ANKLE */
"73008" = "1" /* AC OSTEOMYELITIS NEC */
"73009" = "1" /* AC OSTEOMYELITIS-MULT */
"73010" = "1" /* CHR OSTEOMYELITIS-UNSP */
"73011" = "1" /* CHR OSTEOMYELIT-SHLDER */
"73012" = "1" /* CHR OSTEOMYELIT-UP/ARM */
"73013" = "1" /* CHR OSTEOMYELIT-FOREARM */
"73014" = "1" /* CHR OSTEOMYELIT-HAND */
"73015" = "1" /* CHR OSTEOMYELIT-PELVIS */
"73016" = "1" /* CHR OSTEOMYELIT-L/LEG */
"73017" = "1" /* CHR OSTEOMYELIT-ANKLE */
"73018" = "1" /* CHR OSTEOMYELIT NEC */
"73019" = "1" /* CHR OSTEOMYELIT-MULT */
"73020" = "1" /* OSTEOMYELITIS NOS-UNSPEC */
"73021" = "1" /* OSTEOMYELITIS NOS-SHLDER */
"73022" = "1" /* OSTEOMYELITIS NOS-UP/ARM */
"73023" = "1" /* OSTEOMYELIT NOS-FOREARM */
"73024" = "1" /* OSTEOMYELITIS NOS-HAND */
"73025" = "1" /* OSTEOMYELITIS NOS-PELVIS */
"73026" = "1" /* OSTEOMYELITIS NOS-L/LEG */
"73027" = "1" /* OSTEOMYELITIS NOS-ANKLE */
"73028" = "1" /* OSTEOMYELIT NOS-OTH SITE */
"73029" = "1" /* OSTEOMYELITIS NOS-MULT */
"73030" = "1" /* PERIOSTITIS-UNSPEC */
"73031" = "1" /* PERIOSTITIS-SHLDER */
"73032" = "1" /* PERIOSTITIS-UP/ARM */
"73033" = "1" /* PERIOSTITIS-FOREARM */
"73034" = "1" /* PERIOSTITIS-HAND */
"73035" = "1" /* PERIOSTITIS-PELVIS */
"73036" = "1" /* PERIOSTITIS-L/LEG */
"73037" = "1" /* PERIOSTITIS-ANKLE */
"73038" = "1" /* PERIOSTITIS NEC */
"73039" = "1" /* PERIOSTITIS-MULT */
"73080" = "1" /* BONE INFECT NEC-UNSPEC */
"73081" = "1" /* BONE INFECT NEC-SHLDER */
"73082" = "1" /* BONE INFECT NEC-UP/ARM */
"73083" = "1" /* BONE INFECT NEC-FOREARM */
"73084" = "1" /* BONE INFECT NEC-HAND */
"73085" = "1" /* BONE INFECT NEC-PELVIS */
"73086" = "1" /* BONE INFECT NEC-L/LEG */
"73087" = "1" /* BONE INFECT NEC-ANKLE */
"73088" = "1" /* BONE INFECT NEC-OTH SITE */
"73089" = "1" /* BONE INFECT NEC-MULT */
"73090" = "1" /* BONE INFEC NOS-UNSP SITE */
"73091" = "1" /* BONE INFECT NOS-SHLDER */
"73092" = "1" /* BONE INFECT NOS-UP/ARM */
"73093" = "1" /* BONE INFECT NOS-FOREARM */
"73094" = "1" /* BONE INFECT NOS-HAND */
"73095" = "1" /* BONE INFECT NOS-PELVIS */
"73096" = "1" /* BONE INFECT NOS-L/LEG */
"73097" = "1" /* BONE INFECT NOS-ANKLE */
"73098" = "1" /* BONE INFECT NOS-OTH SITE */
"73099" = "1" /* BONE INFECT NOS-MULT */
"7713" = "1" /* TETANUS NEONATORUM */
"7714" = "1" /* OMPHALITIS OF NEWBORN */
"7715" = "1" /* NEONATAL INFEC MASTITIS */
"77181" = "1" /* NB SEPTICEMIA SEPSIS */
"77182" = "1" /* NB URINARY TRACT INFECTN */
"77183" = "1" /* BACTEREMIA OF NEWBORN */
"77189" = "1" /* PERINATAL INFECTION NEC */
"7775" = "1" /* NECROT ENTEROCOLITIS NB */
"7854" = "1" /* GANGRENE */
"78552" = "1" /* SEPTIC SHOCK */
"7907" = "1" /* BACTEREMIA */
"9101" = "1" /* ABRASION HEAD-INFECTED */
"9103" = "1" /* BLISTER HEAD-INFECTED */
"9105" = "1" /* INSECT BITE HEAD-INFECT */
"9107" = "1" /* FOREIGN BODY HEAD-INFECT */
"9109" = "1" /* SUPERF INJ HEAD NEC-INF */
"9111" = "1" /* ABRASION TRUNK-INFECTED */
"9113" = "1" /* BLISTER TRUNK-INFECTED */
"9115" = "1" /* INSECT BITE TRUNK-INFEC */
"9117" = "1" /* FOREIGN BODY TRUNK-INFEC */
"9119" = "1" /* SUPERF INJ TRNK NEC-INF */
"9121" = "1" /* ABRASION SHLDR/ARM-INFEC */
"9123" = "1" /* BLISTER SHOULDER/ARM-INF */
"9125" = "1" /* INSECT BITE SHLD/ARM-INF */
"9127" = "1" /* FB SHOULDER/ARM-INFECT */
"9129" = "1" /* SUPERF INJ SHLDR NEC-INF */
"9131" = "1" /* ABRASION FOREARM-INFECT */
"9133" = "1" /* BLISTER FOREARM-INFECTED */
"9135" = "1" /* INSECT BITE FOREARM-INF */
"9137" = "1" /* FOREIGN BODY FOREARM-INF */
"9139" = "1" /* SUPRF INJ FORARM NEC-INF */
"9141" = "1" /* ABRASION HAND-INFECTED */
"9143" = "1" /* BLISTER HAND-INFECTED */
"9145" = "1" /* INSECT BITE HAND-INFECT */
"9147" = "1" /* FOREIGN BODY HAND-INFECT */
"9149" = "1" /* SUPERF INJ HAND NEC-INF */
"9151" = "1" /* ABRASION FINGER-INFECTED */
"9153" = "1" /* BLISTER FINGER-INFECTED */
"9155" = "1" /* INSECT BITE FINGER-INFEC */
"9157" = "1" /* FOREIGN BODY FINGER-INF */
"9159" = "1" /* SUPRF INJ FINGER NEC-INF */
"9161" = "1" /* ABRASION HIP/LEG-INFECT */
"9163" = "1" /* BLISTER HIP & LEG-INFECT */
"9165" = "1" /* INSECT BITE HIP/LEG-INF */
"9167" = "1" /* FOREIGN BDY HIP/LEG-INF */
"9169" = "1" /* SUPERF INJ LEG NEC-INFEC */
"9171" = "1" /* ABRASION FOOT/TOE-INFEC */
"9173" = "1" /* BLISTER FOOT & TOE-INFEC */
"9175" = "1" /* INSECT BITE FOOT/TOE-INF */
"9177" = "1" /* FOREIGN BDY FOOT/TOE-INF */
"9179" = "1" /* SUPERF INJ FOOT NEC-INF */
"9191" = "1" /* ABRASION NEC-INFECTED */
"9193" = "1" /* BLISTER NEC-INFECTED */
"9195" = "1" /* INSECT BITE NEC-INFECTED */
"9197" = "1" /* SUPERFICIAL FB NEC-INFEC */
"9199" = "1" /* SUPERFIC INJ NEC-INFECT */
"99590" = "1" /* SIRS, NOS */
"99591" = "1" /* SIRS-INFECT W/O ORG DYSF */
"99592" = "1" /* SIRS-INFECT W ORGAN DYSF */
"99660" = "1" /* INFECT INFLAMM DEVICE IMPLANT GRAFT NOS */
"99661" = "1" /* INFECT INFLAMM CARDIAC DEVICE IMPLANT GRAFT */
"99662" = "1" /* INFECT INFLAMM VASCULAR DEVICE IMPLANT GRAFT  */
"99663" = "1" /* INFECT INFLAMM NERV DEVICE IMPLANT GRAFT  */
"99664" = "1" /* INFECT INFLAMM URINARY CATH */
"99665" = "1" /* INFECT INFLAMM GU DEVICE IMPLANT GRAFT  */
"99666" = "1" /* INFECT INFLAMM JOINT PROSTH */
"99667" = "1" /* INFECT INFLAMM OTH ORTHOP DEVICE IMPLANT GRAFT NOS */
"99669" = "1" /* INFECT INFLAMM OTH DEVICE IMPLANT GRAFT */
"99762" = "1" /* INFECTION AMPUTAT STUMP */
"99851" = "1" /* INFECTED POSTOP SEROMA */
"99859" = "1" /* OTHER POSTOP INFECTION */
"9993" = "1" /* INFEC COMPL MED CARE NEC */
OTHER   = "0" ;


 /* DRGS SURGICAL CLASS =1, TYPE OF DRGS = CLEAN */

VALUE $DRG1C
"003" = "1" /* CRANIOTOMY, AGE 0-17 */
"004" = "1" /* SPINAL PROCEDURES */
"005" = "1" /* EXTRACRANIAL VASCULAR PROCEDURES */
"006" = "1" /* CARPAL TUNNEL RELEASE */
"007" = "1" /* PERIPHERAL AND CRANIAL NERVE AND OTHER NERVOUS SYSTEM PROCEDURES WITH CC */
"008" = "1" /* PERIPHERAL AND CRANIAL NERVE AND OTHER NERVOUS SYSTEM PROCEDURES WITHOUT CC */
"036" = "1" /* RETINAL PROCEDURES */
"037" = "1" /* ORBITAL PROCEDURES */
"038" = "1" /* PRIMARY IRIS PROCEDURES */
"039" = "1" /* LENS PROCEDURES WITH OR WITHOUT VITRECTOMY */
"041" = "1" /* EXTRAOCULAR PROCEDURES EXCEPT ORBIT, AGE 0-17 */
"042" = "1" /* INTRAOCULAR PROCEDURES EXCEPT RETINA, IRIS AND LENS */
"049" = "1" /* MAJOR HEAD AND NECK PROCEDURES */
"050" = "1" /* SIALOADENECTOMY */
"051" = "1" /* SALIVARY GLAND PROCEDURES EXCEPT SIALOADENECTOMY */
"052" = "1" /* CLEFT LIP AND PALATE REPAIR */
"054" = "1" /* SINUS AND MASTOID PROCEDURES, AGE 0-17 */
"055" = "1" /* MISCELLANEOUS EAR, NOSE, MOUTH AND THROAT PROCEDURES */
"056" = "1" /* RHINOPLASTY */
"058" = "1" /* TONSILLECTOMY AND ADNOIDECTOMY PROCEDURES EXCEPT TONSILLECTOMY AND/OR ADENOIDECTOMY ONLY, AGE 0-17 */
"060" = "1" /* TONSILLECTOMY AND/OR ADENOIDECTOMY ONLY, AGE 0 - 17 */
"062" = "1" /* MYRINGOTOMY WITH TUBE INSERTION, AGE 0-17 */
"063" = "1" /* OTHER EAR, NOSE, MOUTH AND THROAT OR PROCEDURES */
"103" = "1" /* HEART TRANSPLANT */
"104" = "1" /* CARDIAC VALVE AND OTHER MAJOR CARDIOTHORACIC PROCEDURES WITH CARDIAC CATHETERIZATION */
"105" = "1" /* CARDIAC VALVE AND OTHER MAJOR CARDIOTHORACIC PROCEDURES WITHOUT CARDIAC CATHETERIZATION */
"106" = "1" /* CORONARY BYPASS WITH PTCA */
"107" = "1" /* CORONARY BYPASS WITH CARDIAC CATHETERIZATION */
"108" = "1" /* OTHER CARDIOTHORACIC PROCEDURES */
"109" = "1" /* CORONARY BYPASS WITHOUT CARDIAC CATHETERIZATION */
"110" = "1" /* MAJOR CARDIOVASCULAR PROCEDURES WITH CC */
"111" = "1" /* MAJOR CARDIOVASCULAR PROCEDURES WITHOUT CC */
"112" = "1" /* PERCUTANEOUS CARDIOVASCULAR PROCEDURES */
"113" = "1" /* AMPUTATION FOR CIRCULATORY SYSTEM DISORDERS EXCEPT UPPER LIMB AND TOE */
"114" = "1" /* UPPER LIMB AND TOES AMPUTATION FOR CIRCULATORY SITE */
"115" = "1" /* PERMANENT CARDIAC PACEMAKER IMPLANT WITH ACUTE MYOCARDIAL INFARCTION, HEART FAILURE OR SHOCK OR ACID LEAD OR GENERATOR PROCEDURE */
"116" = "1" /* OTHER PERMANENT CARDIAC PACEMAKER IMPLANT OR PTCA WITH CORONARY ARTERIAL STENT */
"117" = "1" /* CARDIAC PACEMAKER REVISION EXCEPT DEVICE REPLACEMENT */
"118" = "1" /* CARDIAC PACEMAKER DEVICE REPLACEMENT */
"119" = "1" /* VEIN LIGATION AND STRIPPING */
"120" = "1" /* OTHER CIRCULATORY SYSTEM OR PROCEDURES */
"163" = "1" /* HERNIA PROCEDURES, AGE 0-17 */
"168" = "1" /* MOUTH PROCEDURES WITH CC */
"169" = "1" /* MOUTH PROCEDURES WITHOUT CC */
"209" = "1" /* MAJOR JOINT AND LIMB REATTACHMENT PROCEDURES OF LOWER EXTREMITY */
"212" = "1" /* HIP AND FEMUR PROCEDURES EXCEPT MAJOR JOINT PROCEDURE, AGE 0-17 */
"213" = "1" /* AMPUTATION FOR MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE DISORDERS */
"216" = "1" /* BIOPSIES OF MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE */
"217" = "1" /* WOUND DEBRIDEMENT AND SKIN GRAFT EXCEPT HAND FOR MUSCULOSKELETAL AND CONNECTIVE TISSUE DISORDERS */
"220" = "1" /* LOWER EXTREMITY AND HUMERUS PROCEDURES EXCEPT HIP, FOOT AND FEMUR, AGE 0-17 */
"223" = "1" /* MAJOR SHOULDER/ELBOW PROCEDURES OR OTHER UPPER EXTREMITY PROCEDURES WITH CC */
"224" = "1" /* SHOULDER, ELBOW OR FOREARM PROCEDURES EXCEPT MAJOR JOINT PROCEDURES WITHOUT CC */
"225" = "1" /* FOOT PROCEDURES*/
"226" = "1" /* SOFT TISSUE PROCEDURES WITH CC */
"227" = "1" /* SOFT TISSUE PROCEDURES WITHOUT CC */
"228" = "1" /* MAJOR THUMB OR JOINT PROCEDURES OR OTHER HAND OR WRIST PROCEDURES WITH CC */
"229" = "1" /* HAND OR WRIST PROCEDURES EXCEPT MAJOR JOINT PROCEDURES WITHOUT CC */
"230" = "1" /* LOCAL EXCISION AND REMOVAL OF INTERNAL FIXATION DEVICES OF HIP AND FEMUR */
"231" = "1" /* LOCAL EXCISION AND REMOVAL OF INTERNAL FIXATION DEVICES EXCEPT HIP AND FEMUR */
"232" = "1" /* ARTHROSCOPY */
"233" = "1" /* OTHER MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE OR PROCEDURES WITH CC */
"234" = "1" /* OTHER MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE OR PROCEDURES WITHOUT CC */
"257" = "1" /* TOTAL MASTECTOMY FOR MALIGNANCY WITH CC */
"258" = "1" /* TOTAL MASTECTOMY FOR MALIGNANCY WITHOUT CC */
"259" = "1" /* SUBTOTAL MASTECTOMY FOR MALIGNANCY WITH CC */
"260" = "1" /* SUBTOTAL MASTECTOMY FOR MALIGNANCY WITHOUT CC */
"261" = "1" /* BREAST PROCEDURE FOR NONMALIGNANCY EXCEPT BIOPSY AND LOCAL EXCISION */
"262" = "1" /* BREAST BIOPSY AND LOCAL EXCISION FOR NONMALIGNANCY */
"268" = "1" /* SKIN, SUBCUTANEOUS TISSUE AND BREAST PLASTIC PROCEDURES */
"285" = "1" /* AMPUTAETION OF LOWER LIMB FOR ENDOCRINE, NUTRITIONAL AND METABOLIC DISORDERS */
"286" = "1" /* ADRENAL AND PITUITARY PROCEDURES */
"287" = "1" /* SKIN GRAFTS AND WOUND DEBRIDEMENTS FOR ENDOCRINE, NUTRITIONAL AND METABOLIC DISORDERS */
"289" = "1" /* PARATHYROID PROCEDURES */
"290" = "1" /* THYROID PROCEDURES */
"291" = "1" /* THYROGLOSSAL PROCEDURES */
"292" = "1" /* OTHER ENDOCRINE, NUTRITIONAL AND METABOLIC OR PROCEDURES WITH CC */
"293" = "1" /* OTHER ENDOCRINE, NUTRITIONAL AND METABOLIC OR PROCEDURES WITHOUT CC */
"338" = "1" /* TESTES PROCEDURES FOR MALIGNANCY */
"340" = "1" /* TESTES PROCEDURES FOR NONMALIGNANCY, AGE 0-17 */
"343" = "1" /* CIRCUMCISION, AGE 0-17 */
"393" = "1" /* SPLENECTOMY, AGE 0-17 */
"394" = "1" /* OTHER OR PROCEDURES OF THE BLOOD AND BLOOD-FORMING ORGANS */
"471" = "1" /* BILATERAL OR MULTIPLE MAJOR JOINT PROCEDURES OF LOWER EXTREMITY */
"478" = "1" /* OTHER VASCULAR PROCEDURES WITH CC */
"479" = "1" /* OTHER VASCULAR PROCEDURES WITHOUT CC */
"481" = "1" /* BONE MARROW TRANSPLANT */
"491" = "1" /* MAJOR JOINT AND LIMB REATTACHMENT PROCEDURES OF UPPER EXTREMITY*/
"496" = "1" /* COMBINED ANTERIOR/POSTERIOR SPINAL FUSION */
"497" = "1" /* SPINAL FUSION WITH CC */
"498" = "1" /* SPINAL FUSION WITHOUT CC */
"499" = "1" /* BACK AND NECK PROCEDURES EXCEPT SPINAL FUSION WITH CC */
"500" = "1" /* BACK AND NECK PROCEDURES EXCEPT SPINAL FUSION WITHOUT CC */
"501" = "1" /* KNEE PROCEDURES WITH PRINCIPAL DIAGNOSIS OF INFECTION, WITH CC */
"502" = "1" /* KNEE PROCEDURES WITH PRINCIPAL DIAGNOSIS OF INFECTION, WITHOUT CC */
"503" = "1" /* KNEE PROCEDURES WITHOUT PRINCIPAL DIAGNOSIS OF INFECTION */
"514" = "1" /* CARDIAC DEFIBRILLATOR IMPLANT W CARDIAC CATH */
"515" = "1" /* CARDIAC DEFIBRILLATOR IMPLANT WITHOUT CARDIAC CATH */
"516" = "1" /* PERCUTANEOUS CARDIOVASC PROC W AMI */
"517" = "1" /* PERC CARDIO PROC W NON-DRUG ELUTING STENT WITHOUT AMI */
"518" = "1" /* PERC CARDIO PROC WITHOUT CORONARY ARTERY STENT OR AMI */
"519" = "1" /* CERVICAL SPINAL FUSION W CC */
"520" = "1" /* CERVICAL SPINAL FUSION WITHOUT CC */
"525" = "1" /* HEART ASSIST SYSTEM IMPLANT */
"526" = "1" /* PERCUTNEOUS CARDIOVASULAR PROC W DRUG ELUTING STENT W AMI */
"527" = "1" /* PERCUTNEOUS CARDIOVASULAR PROC W DRUG ELUTING STENT WITHOUT AMI */
"528" = "1" /* INTRACRANIAL VASCULAR PROC W PDX HEMORRHAGE */
"529" = "1" /* VENTRICULAR SHUNT PROCEDURES W CC */
"530" = "1" /* VENTRICULAR SHUNT PROCEDURES W/O CC */
"531" = "1" /* SPINAL PROCEDURES W CC */
"532" = "1" /* SPINAL PROCEDURES W/O CC */
"533" = "1" /* EXTRACRANIAL PROCEDURES W CC */
"534" = "1" /* EXTRACRANIAL PROCEDURES W/O CC */
"535" = "1" /* CARDIAC DEFIB IMPLANT W CARDIAC CATH W AMI/HF/SHOCK */
"536" = "1" /* CARDIAC DEFIB IMPLANT W CARDIAC CATH W/O AMI/HF/SHOCK */
"537" = "1" /* LOCAL EXCIS & REMOV OF INT FIX DEV EXCEPT HIP & FEMUR W CC */
"538" = "1" /* LOCAL EXCIS & REMOV OF INT FIX DEV EXCEPT HIP & FEMUR W/O CC */
"543" = "1" /* CRANIOTOMY WITH IMPLANTATION OF CHEMOTHERAPEUTIC AGENT OR ACUTE COMPLEX CENTRAL NERVOUS SYSTEM PRINCIPAL DIAGNOSIS */
"544" = "1" /* MAJOR JOINT REPLACEMENT OR REATTACHMENT OF LOWER EXTERMITY*/
"545" = "1" /* REVISION OF HIP OR KNEE REPLACEMENT */
"546" = "1" /* SPINAL FUSION EXC CERV WITH CURVATURE OF THE SPINE OR MALIG */
"547" = "1" /* CORONARY BYPASS W CARDIAC CATH W MAJOR CV DX */
"548" = "1" /* CORONARY BYPASS W CARDIAC CATH W/O MAJOR CV DX */
"549" = "1" /* CORONARY BYPASS W/O CARDIAC CATH W MAJOR CV DX */
"550" = "1" /* CORONARY BYPASS W/O CARDIAC CATH W/O MAJOR CV DX*/
"551" = "1" /* PERMANENT CARDIAC PACEMAKER IMP W MAJ CV DX OR AICD LED OR GNRTR*/
"552" = "1" /* OTHER PERMANENT CARDIAC PACEMAKER IMPLANT W/O MAJOR CV DX */
"553" = "1" /* OTHER VASCULAR PROCEDURES W CC W MAJOR CV DX */
"554" = "1" /* OTHER VASCULAR PROCEDURES W CC W/O MAJOR CV DX */
"555" = "1" /* PERCUTANEOUS CARDIOVASCULAR PROC W MAJOR CV DX */
"556" = "1" /* PERCUTANEOUS CARDIOVASC PROC W NON-DRUG-ELUTING STENT W/O MAJOR CV DX */
"557" = "1" /* PRECUTANEOUS CARDIOVASCULAR PROC W DRUG-ELUTING STENT W MAJOR CV DX */
"558" = "1" /* PRECUTANEOUS CARIOVASCULAR PROC W DRUG-ELUTING STENT W/O MAJOR CV DX */
"577" = "1" /* CAROTID ARTERY STENT PROCEDURE */
OTHER = "0" ;

/* DRGS SURGICAL CLASS =2, TYPE OF DRGS = CLEAN CONTAMINATED */

VALUE $DRG2C
"075" = "1" /* MAJOR CHEST PROCEDURES */
"076" = "1" /* OTHER RESPIRATORY SYSTEM OR PROCEDURES WITH CC */
"077" = "1" /* OTHER RESPIRATORY SYSTEM OR PROCEDURES WITHOUT CC */
"146" = "1" /* RECTAL RESECTION WITH CC */
"147" = "1" /* RECTAL RESECTION WITHOUT CC */
"148" = "1" /* MAJOR SMALL AND LARGE BOWEL PROCEDURES WITH CC */
"149" = "1" /* MAJOR SMALL AND LARGE BOWEL PROCEDURES WITHOUT CC */
"150" = "1" /* PERITONEAL ADHESIOLYSIS WITH CC */
"151" = "1" /* PERITONEAL ADHESIOLYSIS WITHOUT CC */
"152" = "1" /* MINOR SMALL AND LARGE BOWEL PROCEDURES WITH CC */
"153" = "1" /* MINOR SMALL AND LARGE BOWEL PROCEDURES WITHOUT CC */
"156" = "1" /* STOMACH, ESOPHAGEAL AND DUODENAL PROCEDURES, AGE 0-17 */
"157" = "1" /* ANAL AND STOMAL PROCEDURES WITH CC */
"158" = "1" /* ANAL AND STOMAL PROCEDURES WITHOUT CC */
"166" = "1" /* APPENDECTOMY WITHOUT COMPLICATED PRINCIPAL IAGNOSIS WITH CC */
"167" = "1" /* APPENDECTOMY WITHOUT COMPLICATED PRINCIPAL DIAGNOSIS WITHOUT CC */
"170" = "1" /* OTHER DIGESTIVE SYSTEM OR PROCEDURES WITH CC */
"171" = "1" /* OTHER DIGESTIVE SYSTEM OR PROCEDURES WITHOUT CC */
"191" = "1" /* PANCREAS, LIVER AND SHUNT PROCEDURES WITH CC */
"192" = "1" /* PANCREAS, LIVER AND SHUNT PROCEDURES WITHOUT CC */
"193" = "1" /* BILIARY TRACT PROCEDURES EXCEPT ONLY CHOLECYSTECTOIMY WITH OR WITHOUT COMMON DUCT EXPLORATION WITH CC */
"194" = "1" /* BILIARY TRACT PROCEDURES EXCEPT ONLY CHOLECYSTECTOMY WITH OR WITHOUT COMMON DUCT EXPLORATION WITHOUT CC */
"195" = "1" /* CHOLECYSTECTOMY WITH COMMON DUCT EXPLORATION WITH CC */
"196" = "1" /* CHOLECYSTECTOMY WITH COMMON DUCT EXPLORATION WITHOUT CC */
"197" = "1" /* CHOLECYSTECTOMY EXCEPT BY LAPAROSCOPE WITHOUT COMMON DUCT EXPLORATION WITH CC */
"198" = "1" /* CHOLECYSTECTOMY EXCEPT BY LAPAROSCOPE WITHOUT COMMON DUCT EXPORTATION WITHOUT CC */
"199" = "1" /* HEPATOBILIARY DIAGNOSTIC PROCEDURE FOR MALIGNANCY */
"200" = "1" /* HEPATOBILIARY DIAGNOSTIC PROCEDURE FOR NONMALIGNANCY */
"201" = "1" /* OTHER HEPATOBILIARY OR PANCREAS OR PROCEDURES */
"265" = "1" /* SKIN GRAFT AND OR DEBRIDEMENT EXCEPT FOR SKIN ULCER OR CELLULITIS WITH CC */
"266" = "1" /* SKIN GRAFT AND/OR DEBRIDEMENT EXCEPT FOR SKIN ULCER OR CELLUTLITIES WITHOUT CC */
"267" = "1" /* PERIANAL AND PILONIDAL PROCEDURES */
"269" = "1" /* OTHER SKIN, SUBCUTANEOUS TISSUE AND BREAST PROCEDURES WITH CC */
"270" = "1" /* OTHER SKIN, SUBCUTANEOUS TISSUE AND BREAST PROCEDURS WITHOUT CC */
"288" = "1" /* OR PROCEDURES FOR OBESITY */
"302" = "1" /* KIDNEY TRANSPLANT */
"303" = "1" /* KIDNEY, URETER AND MAJOR BLADDER PROCEDURES FOR NEOPLASM */
"304" = "1" /* KIDNEY, URETER AND MAJOR BLADDER PROCEDURES FOR NONNEOPLASMS WITH CC */
"305" = "1" /* KIDNEY, URETER AND MAJOR BLADDER PROCEDURES FOR NONEOPLSMS WITHOUT CC */
"306" = "1" /* PROSTATECTOMY WITH CC */
"307" = "1" /* PROSTATECTOMY WITHOUT CC */
"308" = "1" /* MINOR BLADDER PROCEDURES WITH CC */
"309" = "1" /* MINOR BLADDER PROCEDURES WITHOUT CC */
"310" = "1" /* TRANSURETHRAL PROCEDURES WITH CC */
"311" = "1" /* TRANSURETHRAL PROCEDURES WITHOUT CC */
"314" = "1" /* URETHRAL PROCEDURES, AGE 0-17 */
"315" = "1" /* OTHER KIDNEY AND URINARY TRACT OR PROCEDURES */
"334" = "1" /* MAJOR MALE PELVIC PROCEDURES WITH CC */
"335" = "1" /* MAJOR MALE PELVIC PROCEDURES WITHOUT CC */
"336" = "1" /* TRANSURETHRAL PROSTATECTOMY WITH CC */
"337" = "1" /* TRANSURETHRAL PROSTATECTOMY WITHOUT CC */
"341" = "1" /* PENIS PROCEDURE */
"344" = "1" /* OTHER MALE REPRODUCTIVE SYSTEM OR PROCEDURES FOR MALIGNANCY */
"345" = "1" /* OTHER MALE REPRODUCTIVE SYSTEM OR PROCEDURES EXCEPT FOR MALIGNANCY */
"353" = "1" /* PELVIC EVISCERATION, RADICAL HYSTERECTOMY AND RADICAL VULVECTOMY */
"354" = "1" /* UTERINE AND ADNEXA PROCEDURES FOR NONOVARIAN/ADNEXAL MALIGNANCY WITH CC */
"355" = "1" /* UTERINE AND ADNEXA PROCEDURES FOR NONOVARIAN/ADNEXA PROCEDURES WITHOUT CC*/
"356" = "1" /* FEMALE REPRODUCTIVE SYSTEM RECONSTRUCTIVE PROCEDURES */
"357" = "1" /* UTERINE AND ADNEXA PROCEDURES FOR OVARIAN OR ADNEXAL MALIGNANCY */
"358" = "1" /* UTERINE AND ADNEXA PROCEDURES FOR NONMALIGNANCY WITH CC */
"359" = "1" /* UTERINE AND ADNEXA PROCEDURES FOR NONMALIGNANCY WITHOUT CC */
"360" = "1" /* VAGINA, CERVIX AND VULVA PROCEDURES */
"361" = "1" /* LAPAROSCOPY AND INCISIONAL TUBAL INTERRUPTION */
"362" = "1" /* ENDOSCOPIC TUBAL INTERRUPTION */
"363" = "1" /* D AND C, CONIZATION AND RADIOIMPLANT FOR MALIGNANCY */
"364" = "1" /* D AND C, CONIZATION EXCEPT FOR MALIGNANCY */
"365" = "1" /* OTHER FEMALE REPRODUCTIVE SYSTEM OR PROCEDURES */
"370" = "1" /* CESAREAN SECTION WITH CC */
"371" = "1" /* CESAREAN SECTION WITHOUT CC */
"374" = "1" /* VAGINAL DELIVERY WITH STERILIZATION AND/OR D AND C */
"375" = "1" /* VAGINAL DELIVERY WITH OR PROCEDURE EXCEPT STERILIZATION AND OR D AND C */
"377" = "1" /* POSTPARTUM AND POSTABORTION DIAGNOSES WITH OR PROCEDURE */
"381" = "1" /* ABORTION WITH D AND C ASPIRATION CURETTAGE OR HYSTERECTOMY */
"476" = "1" /* PROSTATIC OR PROCEDURE UNRELATED TO PRINCIPAL DIAGNOSIS */
"480" = "1" /* LIVER TRANSPLANT */
"482" = "1" /* TRACHEOSTOMY FOR FACE, MOUTH AND NECK DIAGNOSES */
"483" = "1" /* TRACHEOSTOMY EXCEPT FOR FACE, MOUTH AND NECK DIAGNOSES */
"493" = "1" /* LAPAROSCOPIC CHOLECYSTECTOMY WITHOUT COMMON DUCT EXPLORATION WITH CC */
"494" = "1" /* LAPAROSCOPIC CHOLECYSTECTOMY WITHOUT COMMON DUCT EXPLORATION WITHOUT CC */
"495" = "1" /* LUNG TRANSPLANT */
"512" = "1" /* SIMULTANEOUS PANCREAS/KIDNEY TRANSPLANT */
"513" = "1" /* PANCREAS TRANSPLANT */
"541" = "1" /* TRACH W MV 96+HRS OR PDX EXC FACE, MTH, FACE & NECK DX W MAJ OR */
"542" = "1" /* TRACH W MV 96+HRS OR PDX EXC FACE, MTH, FACE & NECK DX WO MJ OR */
"569" = "1" /* MAJOR SMALL & LARGE BOWEL PROCEDURES W CC W MAJOR GI DX */
"570" = "1" /* MAJOR SMALL & LARGE BOWEL PROCEDURES W CC W/O MAJOR GI DX */
"573" = "1" /* MAJOR BLADDER PROCEDURES */
OTHER = "0" ;

/* DRGS SURGICAL CLASS =3, TYPE OF DRGS = POTENTIALLY CONTAMINATED */

VALUE $DRG3C
"263" = "1" /* SKIN GRAFT AND OR DEBRIDEMENT FOR SKIN ULCER OR CELLULITIS WITH CC */
"264" = "1" /* SKIN GRAFT AND OR DEBRIDEMENT FOR SKIN ULCER OR CELLULITIS WITHOUT CC */
"439" = "1" /* SKIN GRAFTS FOR INJURIES */
"440" = "1" /* WOUND DEBRIDEMENTS FOR INJURIES */
"441" = "1" /* HAND PROCEDURES FOR INJURIES*/
"442" = "1" /* OTHER OR PROCEDURES FOR INJURIES WITH CC */
"443" = "1" /* OTHER OR PROCEDURES FOR INJURIES WITHOUT CC */
"484" = "1" /* CRANIOTOMY FOR MULTIPLE SIGNIFICANT TRAUMA */
"485" = "1" /* LIMB REATTACHMENT, HIP AND FEMUR PROCEDURES FOR MULTIPLE SIGNIFICANT TRAUMA */
"486" = "1" /* OTHER OR PROCEDURES FOR MULTIPLE SIGNIFICANT TRAUMA */
"504" = "1" /* EXTENSIVE 3RD DEGREE BURNS W SKIN GRAFT */
"506" = "1" /* FULL THICKNESS BURN W SKIN GRAFT OR INHAL INJ W CC OR SIG TRAUMA */
"507" = "1" /* FULL THICKNESS BURN W SKIN GRFT OR INHAL INJ W/O CC OR SIG TRAUMA */
OTHER = "0" ;

/* DRGS CLASS =4, TYPE OF DRGS = LIKELY INFECTED                    */

VALUE $DRG4C
"164" = "1" /* APPENDECTOMY WITH COMPLICATED PRINCIPAL DIAGNOSIS WITH CC */
"165" = "1" /* APPENDECTOMY WITH COMPLICATED PRINCIPAL DIAGNOSIS WIHTOUT CC */
"415" = "1" /* OR PROCEDURE FOR INFECTIOUS AND PARASITIC DISEASES */
"578" = "1" /* INFECTIOUS & PARASITIC DISEASES W OR PROCEDURE */
"579" = "1" /* POSTOPERATIVE OR POST-TRAUMATIC INFECTIONS W OR PROCEDURE */
OTHER = "0" ;

/* DRGS CLASS =9, TYPE OF DRGS = SURGICAL PROCEDURES NOT SPECIFIED  */

VALUE $DRG9C
"400" = "1" /* LYMPHOMA AND LEUKEMIA WITH MAJOR OR PROCEDURES */
"401" = "1" /* LYMPHOMA AND NONACUTE LEUKEMIA WITH OTHER OR PROCEDURE WITH CC */
"402" = "1" /* LYMPHOMA AND NONACUTE LEUKEMIA WITH OTHER OR PROCEDURE WITHOUT CC */
"406" = "1" /* MYELOPROLIFERATIVE DISORDERS OR POORLY DIFFERENTIATED NEOPLASMS WITH MAJOR OR PROCEDURES WITH CC */
"407" = "1" /* MYELOPROLIFERATIVE DISORDERS OR POORLY DIFFERENTIATED NEOPLASMS WITH MAJOR OR PROCEDURES WITHOUT CC */
"408" = "1" /* MYELOPROLIFERATIVE DISORDERS OR POORLY DIFFERENTIATED NEOPLASMS WITH OTHER OR PROCEDURES */
"424" = "1" /* OR PROCEDURES WITH PRINCIPAL DIAGNOSIS OF MENTAL ILLNESS */
"461" = "1" /* OR PROCEDURES WITH DIAGNOSES OF OTHER CONTACT WITH HEALTH SERVICES */
"468" = "1" /* EXTENSIVE OR PROCEDURE UNRELATED TO PRINCIPAL DIAGNOSIS */
"477" = "1" /* NONEXTENSIVE OR PROCEDURE UNRELATED TO PRINCIPAL DIAGNOSIS */
"488" = "1" /* HIV WITH EXTENSIVE OR PROCEDURE */
"539" = "1" /* LYMPHOMA & LEUKEMIA W MAJOR OR PROCEDURE W CC */
"540" = "1" /* LYMPHOMA & LEUKEMIA W MAJOR OR PROCEDURE W/O CC */
OTHER = "0" ;


 /* -------------------------------- */
 /* POST-OPERATIVE WOUND DEHISCENCE  */
 /*   PROVIDER INDICATOR / PDI # 11  */
 /*   AREA     INDICATOR / PDI # TBD */
 /* -------------------------------- */

 /* ABDOMINOPELVIC */;
 /* ICD-9-CM PROCEDURE CODES: */;

VALUE $ABDOMIP
"3804" = "1" /* INCISION OF AORTA */
"3806" = "1" /* INCISION OF ABDOMINAL ARTERIES */
"3807" = "1" /* INCISION OF ABDOMINAL VEINS */
"3814" = "1" /* ENDARTERECTOMY OF AORTA */
"3816" = "1" /* ENDARTERECTOMY OF ABDOMINAL ARTERIES */
"3834" = "1" /* RESECTION OF AORTA WITH ANASTOMOSIS */
"3836" = "1" /* RESECTION OF ABDOMINAL ARTERIES WITH ANASTOMOSIS */
"3837" = "1" /* RESECTION OF ABDOMINAL VEINS WITH ANASTOMOSIS */
"3844" = "1" /* RESECTION OF AORTA, ABDOMINAL WITH REPLACEMENT */
"3846" = "1" /* RESECTION OF ABDOMINAL ARTERIES WITH REPLACEMENT */
"3847" = "1" /* RESECTION OF ABDOMINAL VEINS WITH REPLACEMENT */
"3857" = "1" /* LIGATION AND STRIPPING OF VARICOSE VEINS, ABDOMINCAL VEINS */
"3864" = "1" /* OTHER EXCISION OF AORTA, ABDOMINAL */
"3866" = "1" /* OTHER EXCISION OF ABDOMINAL ARTERIES */
"3867" = "1" /* OTHER EXCISION OF ABDOMINAL VEINS */
"3884" = "1" /* OTHER SURGICAL OCCLUSION OF AORTA, ABDOMINAL */
"3886" = "1" /* OTHER SURGICAL OCCLUSION OF ABDOMINAL ARTERIES */
"3887" = "1" /* OTHER SURGICAL OCCLUSION OF ABDOMINAL VEINS */
"391"  = "1" /* INTRA-ABDOMINAL VENOUS SHUNT */
"3924" = "1" /* AORTA-RENAL BYPASS */
"3925" = "1" /* AORTA-ILIAC-FEMORAL BYPASS */
"3926" = "1" /* OTHER INTRA-ABDOMINAL VASCULAR SHUNT OR BYPASS */
"4052" = "1" /* RADICAL EXCISION OF PERIAORTIC LYMPH NODES */
"4053" = "1" /* RADICAL EXCISION OF ILIAC LYMPH NODES */
"412"  = "1" /* SPLENOTOMY */
"4133" = "1" /* OPEN BIOPSY OF SPLEEN */
"4141" = "1" /* MARSUPIALIZATION OF SPLENIC CYST */
"4142" = "1" /* EXCISION OF LESION OR TISSUE OF SPLEEN */
"4143" = "1" /* PARTIAL SPLENECTOMY */
"415"  = "1" /* TOTAL SPLENECTOMY */
"4193" = "1" /* EXCISION OF ACCESSORY SPLEEN */
"4194" = "1" /* TRANSPLANTATION OF SPLEEN */
"4195" = "1" /* REPAIR AND PLASTIC OPERATIONS ON SPLEEN */
"4199" = "1" /* OTHER OPERATIONS ON SPLEEN */
"4240" = "1" /* ESOPHAGECTOMY, NOS */
"4241" = "1" /* PARTIAL EXOPHAGECTOMY */
"4242" = "1" /* TOTAL ESOPHAGECTOMY */
"4253" = "1" /* INTRATHORACIC ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF SMALL BOWEL */
"4254" = "1" /* OTHER INTRATHORACIC ESOPHAGOENTEROSTOMY */
"4255" = "1" /* INTRATHORACIC ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF COLON */
"4256" = "1" /* OTHER INTRATHORACIC ESOPHAGOCOLOSTOMY */
"4263" = "1" /* ANTESTERNAL ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF SMALL BOWEL */
"4264" = "1" /* OTHER ANTESTERNAL ESOPHAGOENTEROSTOMY */
"4265" = "1" /* ANTESTERNAL ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF COLON */
"4266" = "1" /* OTHER ANTESTERNAL ESOPHAGOCOLOSTOMY */
"4291" = "1" /* LIGATION OF ESOPHAGEAL VARICES */
"430"  = "1" /* GASTROSTOMY */
"433"  = "1" /* PYLOROMYOTOMY */
"4342" = "1" /* LOCAL EXCISION OF OTHER LESION OR TISSUE OF STOMACH */
"4349" = "1" /* OTHER DESTRUCTION OF LESION OR TISSUE OF STOMACH */
"435"  = "1" /* PARTIAL GASTRECTOMY WITH ANASTOMOSIS TO ESOPHAGUS */
"436"  = "1" /* PARTIAL GASTRECTOMY WITH ANASTOMOSIS TO DUODENUM */
"437"  = "1" /* PARTIAL GASTRECTOMY WITH ANASTOMOSIS TO JEJUNUM */
"4381" = "1" /* PARTIAL GASTRECTOMY WITH JEJUNA TRANSPOSITION */
"4389" = "1" /* OTHER PARTIAL GASTRECTOMY */
"4391" = "1" /* TOTAL GASTRECTOMY WITH INTESTINAL INTERPOSITION */
"4399" = "1" /* OTHER TOTAL GASTRECTOMY */
"4400" = "1" /* VAGOTOMY, NOS */
"4401" = "1" /* TRUNCAL VAGOTOMY */
"4402" = "1" /* HIGHLY SELECTIVE VAGOTOMY */
"4403" = "1" /* OTHER SELECTIVE VAGOTOMOY */
"4411" = "1" /* TRANSABDOMINAL GASTROSCOPY */
"4415" = "1" /* OPEN BIOPSY OF STOMACH */
"4421" = "1" /* DILATION OF PYLORUS BY INCISION */
"4429" = "1" /* OTHER PYLOROPLASTY */
"4431" = "1" /* HIGH GASTRIC BYPASS */
"4439" = "1" /* OTHER GASTROENTEROSTOMY */
"4440" = "1" /* SUTURE OF PEPTIC ULCER, NOS */
"4441" = "1" /* SUTURE OF GASTRIC ULCER SITE */
"4442" = "1" /* SUTURE OF DUODENAL ULCER SITE */
"445"  = "1" /* REVISION OF GASTRIC ANASTOMOSIS */
"4461" = "1" /* SUTURE OF LACERATION OF STOMACH */
"4463" = "1" /* CLOSURE OF OTHER GASTRIC FISTULA */
"4464" = "1" /* GASTROPEXY */
"4465" = "1" /* ESOPHAGOGASTROPLASTY */
"4466" = "1" /* OTHER PROCEDURES FOR CREATION OF ESOPHAGOGASTRIC SPHINCTERIC COMPETENCE */
"4469" = "1" /* OTHER REPAIR OF STOMACH */
"4491" = "1" /* LIGATION OF GASTRIC VARICES */
"4492" = "1" /* INTRAOPERATIVE MANIPULATION OF STOMACH */
"4500" = "1" /* INCISION OF INTESTINE, NOS */
"4501" = "1" /* INCISION OF DUODENUM */
"4502" = "1" /* OTHER INCISION OF SMALL INTESTINE */
"4503" = "1" /* INCISION OF LARGE INTESTINE */
"4531" = "1" /* OTHER LOCAL EXCISION OF LESION OF DUODENUM */
"4532" = "1" /* OTHER DESTRUCTION OF LESION OF DUODENUM */
"4533" = "1" /* LOCAL EXCISION OF LESION OR TISSUE OF SMALL INTESTINE, EXCEPT DUODENUM */
"4534" = "1" /* OTHER DESTRUCTION OF LESION OF SMALL INTESTINE, EXCEPT DUODENUM */
"4541" = "1" /* EXCISION OF LESION OR TISSUE OF LARGE INTESTINE */
"4549" = "1" /* OTHER DESTRUCTION OF LESION OF LARGE INTESTINE */
"4550" = "1" /* ISOLATION OF INTESTINAL SEGMENT, NOS */
"4551" = "1" /* ISOLATION OF SEGMENT OF SMALL INTESTINE */
"4552" = "1" /* ISOLATION OF SEGMENT OF LARGE INTESTINE */
"4561" = "1" /* MULTIPLE SEGMENTAL RESECTION OF SMALL INTESTINE */
"4562" = "1" /* OTHER PARTIAL RESECTION OF SMALL INTESTINE */
"4563" = "1" /* TOTAL REMOVAL OF SMALL INTESTINE */
"4571" = "1" /* MULTIPLE SEGMENTAL RESECTION OF LARGE INTESTINE */
"4572" = "1" /* CESECTOMY */
"4573" = "1" /* RIGHT HEMICOLECTOMY */
"4574" = "1" /* RESECTION OF TRANSVERSE COLON */
"4575" = "1" /* LEFT HEMICOLECTOMY */
"4576" = "1" /* SIGMOIDECTOMY */
"4579" = "1" /* OTHER PARTIAL EXCISION OF LARGE INTESTINE */
"458"  = "1" /* TOTAL INTRA-ABDOMINAL COLECTOMY */
"4590" = "1" /* INTESTINAL ANASTOMOSIS, NOS */
"4591" = "1" /* SMALL-TO-SMALL INTESTINAL ANASTOMOSIS */
"4592" = "1" /* ANASTOMOSIS OF SMALL INTESTINE TO RECTAL STUMP */
"4593" = "1" /* OTHER SMALL-TO-LARGE INTESTINAL ANASTOMOSIS */
"4594" = "1" /* LARGE-TO-LARGE INTESTINAL ANASTOMOSIS */
"4595" = "1" /* ANASTOMOSIS TO ANUS */
"4601" = "1" /* EXTERIORIZATION OF SMALL INTESTINE */
"4603" = "1" /* EXTERIORIZATION OF LARGE INTESTINE */
"4610" = "1" /* COLOSTOMY, NOS */
"4611" = "1" /* TEMPORARY COLOSTOMY */
"4613" = "1" /* PERMANENT COLOSTOMY */
"4620" = "1" /* ILEOSTOMY, NOS */
"4621" = "1" /* TEMPORARY ILESOSTOMY */
"4622" = "1" /* CONTINENT ILEOSTOMY */
"4623" = "1" /* OTHER PERMANENT ILEOSTOMY */
"4640" = "1" /* REVISION OF INTESTINA STOMA, NOS */
"4641" = "1" /* REVISION OF STOMA OF SMALL INTESTINE */
"4642" = "1" /* REPAIR OF PERICOLOSTOMY HERNIA */
"4643" = "1" /* OTHER REVISION OF STOMA OF LARGE INTESTINE */
"4650" = "1" /* CLOSURE OF INTESTINAL STOMA, NOS */
"4651" = "1" /* CLOSURE OF STOMA OF SMALL INTESTINE */
"4652" = "1" /* CLOSURE OF STOMA OF LARGE INTESTINE */
"4660" = "1" /* FIXATION OF INTESTINE, NOS */
"4661" = "1" /* FIXATION OF SMALL INTESTINE TO ABDOMINAL WALL */
"4662" = "1" /* OTHER FIXATION OF SMALL INTESTINE */
"4663" = "1" /* FIXATION OF LARGE INTESTINE TO ABDOMINAL WALL */
"4664" = "1" /* OTHER FIXATION OF LARGE INTESTINE */
"4672" = "1" /* CLOSURE OF FISTULA OF DUODENUM */
"4674" = "1" /* CLOSURE OF FISTULA OF SMALL INTESTINE, EXCEPT DUODENUM */
"4676" = "1" /* CLOSURE OF FISTULA OF LARGE INTESTINE */
"4680" = "1" /* INTRA-ABDOMINAL MANIPULATION OF INTESTINE, NOS */
"4681" = "1" /* INTRA-ABDOMINAL MANIPULATION OF SMALL INTESTINE */
"4682" = "1" /* INTRA-ABDOMINAL MANIPULATION OF LARGE INTESTINE */
"4691" = "1" /* MYOTOMY OF SIGMOID COLON */
"4692" = "1" /* MYOTOMY OF OTHER PARTS OF COLON */
"4693" = "1" /* REVISION OF ANASTOMOSIS OF SMALL INTESTINE */
"4694" = "1" /* REVISION OF ANASTOMOSIS OF LARGE INTESTINE */
"4699" = "1" /* OTHER OPERATIONS ON INTESTINES */
"4709" = "1" /* OTHER APPENDECTOMY */
"4719" = "1" /* OTHER INCIDENTAL APPENDECTOMY */
"472"  = "1" /* DRAINAGE OF APPENDICEAL ABSCESS */
"4791" = "1" /* APPENDECTOMY */
"4792" = "1" /* CLOSURE OF APPENDICEAL FISTULA */
"4799" = "1" /* OTHER */
"4841" = "1" /* SUBMUCOSAL RESECTION OF RECTUM */
"4849" = "1" /* OTHER PULL-THROUGH RESECTION OF RECTUM */
"485"  = "1" /* ABDOMINOPERINEAL RESECTION OF RECTUM */
"4875" = "1" /* ABDOMINAL PROCTOPEXY */
"500"  = "1" /* HEPATOTOMY */
"5012" = "1" /* OPEN BIOPSY OF LIVER */
"5021" = "1" /* MARSUPIALIZATION OF LESION OF LIVER */
"5022" = "1" /* PARTIAL HEPATECTOMY */
"5023" = "1" /* OPN ABLTN LIVER LES/TISS */ 
"5026" = "1" /* ABLTN LIVER LES/TISS NEC */ 
"5029" = "1" /* OTHER DESTRUCTION OF LESION OF LIVER */
"503"  = "1" /* LOBECTOMY OF LIVER */
"504"  = "1" /* TOTAL HEPATECTOMY */
"5051" = "1" /* AUXILIARY LIVER TRANSPLANT */
"5059" = "1" /* OTHER TRANSPLANT OF LIVER */
"5069" = "1" /* OTHER REPAIR OF LIVER */
"5103" = "1" /* OTHER CHOLECYSTOTSTOMY */
"5104" = "1" /* OTHER CHOLECYSTOTOMY */
"5113" = "1" /* OPEN BIOPSY OF GALLBLADDER OR BILE DUCTS */
"5121" = "1" /* OTHER PARTIAL CHOLECYSTECTOMY */
"5122" = "1" /* CHOLECYSTECTOMY */
"5131" = "1" /* ANASTOMOSIS OF GALLBLADDER TO HEPATIC DUCTS */
"5132" = "1" /* ANASTOMOSIS OF GALLBLADDER TO INTESTINE */
"5133" = "1" /* ANASTOMOSIS OF GALLBLADDER TO PANCREAS */
"5134" = "1" /* ANASTOMOSIS OF GALLBLADDER TO STOMACH */
"5135" = "1" /* OTHER GALLBLADDER ANASTOMOSIS */
"5136" = "1" /* CHOLEDOCHOENTEROSTOMY */
"5137" = "1" /* ANASTOMOSIS OF HEPATIC DUCT TO GASTROINTESTINAL TRACT */
"5139" = "1" /* OTHER BILE DUCT ANASTOMOSIS */
"5141" = "1" /* COMMON DUCT EXPLORATION FOR REMOVAL OF CALCULUS */
"5142" = "1" /* COMMON DUCT EXPLORATION FOR RELIEF OF OTHER OBSTRUCTION */
"5143" = "1" /* INSERTION OF CHOLEDOCHOHEPATIC TUBE FOR DECOMPRESSION */
"5149" = "1" /* INCISION OF OTHER BILE DUCTS FOR RELIEF OF OBSTRUCTION */
"5151" = "1" /* EXPLORATION OF COMMON DUCT */
"5159" = "1" /* INCISION OF OTHER BILE DUCT */
"5161" = "1" /* EXCISION OF CYSTIC DUCT REMNANT */
"5162" = "1" /* EXCISION OF AMPULLA OF VATER WITH REIMPLANTATION OF COMMON DUCT */
"5163" = "1" /* OTHER EXCISION OF COMMON DUCT */
"5169" = "1" /* EXCISION OF OTHER BILE DUCT */
"5171" = "1" /* SIMPLE SUTURE OF COMMON BILE DUCT */
"5172" = "1" /* CHOLEDOCHOPLASTY */
"5179" = "1" /* REPAIR OF OTHER BILE DUCTS */
"5181" = "1" /* DILATION OF SPHINCTER OF ODDI */
"5182" = "1" /* PANCREATIC SPHINCTEROTOMY */
"5183" = "1" /* PANCREATIC SPHINCTEROPLSTY */
"5189" = "1" /* OTHER OPERATIONS ON SPHINCTER OF ODDI */
"5192" = "1" /* CLOSURE OF CHOLECYSTOSTOMY */
"5193" = "1" /* CLOSURE OF OTHER BILIARY FISTULA */
"5194" = "1" /* REVISION OF ANASTOMOSIS OF BILIARY TRACT */
"5195" = "1" /* REMOVAL OF PROSTHETIC DEVICE FROM BILE DUCT */
"5199" = "1" /* OTHER OPERATIONS ON BILIARY TRACT */
"5201" = "1" /* DRAINAGE OF PANCREATIC CYST BY CATHETER */
"5209" = "1" /* OTHER PANCREATOTOMY */
"5212" = "1" /* OPEN BIOPSY OF PANCREAS */
"5222" = "1" /* OTHER EXCISION OR DESTRUCTION OF LESION OR TISSUE OF PANCREAS OR PANCREATIC DUCT */
"523"  = "1" /* GINGIVAL AND PERIODONTAL DISEASES */
"524"  = "1" /* INTERNAL DRAINAGE OF PANCREATIC CYST */
"5251" = "1" /* PROXIMAL PANCREATECTOMY */
"5252" = "1" /* DISTAL PANCREATECTOMY */
"5253" = "1" /* RADIAL SUBTOTAL PANCREATECTOMY */
"5259" = "1" /* OTHER PARTIAL PANCREATECTOMY */
"526"  = "1" /* TOTAL PANCREATECTOMY */
"527"  = "1" /* RADICAL PANCREATICODUODENCECTOMY */
"5280" = "1" /* PANCREATIC TRANSPLANT, NOS */
"5281" = "1" /* REIMPLANTATION */
"5282" = "1" /* HOMOTRANSPLANT OF PANCREAS */
"5283" = "1" /* HETEROTRANSPLANT OF PANCREAS */
"5292" = "1" /* CANNULATION OF PANCREATIC DUCT */
"5295" = "1" /* OTHER REPAIR OF PANCREAS */
"5296" = "1" /* ANASTOMOSIS OF PANCREAS */
"5299" = "1" /* OTHER OPERATIONS ON PANCREAS */
"5300" = "1" /* UNILATERAL REPAIR OF INGUINAL HERNIA, NOS */
"5301" = "1" /* REPAIR OF DIRECT INGUINAL HERNIA */
"5302" = "1" /* REPAIR OF INDIRECT INGUINAL HERNIA */
"5303" = "1" /* REPAIR OF DIRECT INGUINAL HERNIA WITH GRAFT OR PROSTHESIS */
"5304" = "1" /* REPAIR OF INDIRECT INGUINAL HERNIA WITH GRAFT OR PROSTHESIS */
"5305" = "1" /* REAPIR OF INGUINAL HERNIA WITH GRAFT OR PROSTHESIS, NOS */
"5310" = "1" /* BILATERAL REPAIR OF INGUINAL HERNIA, NOS */
"5311" = "1" /* BILATERAL REPAIR OF DIRECT INGUINAL YERNIA */
"5312" = "1" /* BILATERAL REPAIR OF INDIRECT INGUINAL HERNIA */
"5313" = "1" /* BILATERAL REPAIR OF INGUINAL HERNIA, ONE DIRECT AND ONE INDIRECT */
"5314" = "1" /* BILATERAL REPAIR OF DIRECT INGUINAL HERNIA WITH GRAFT OR PROSTHESIS */
"5315" = "1" /* BILATERAL REPAIR OF INDIRECT INGUINAL HERNIA WITH GRAFT OR PROSTHESIS */
"5316" = "1" /* BILATERAL REPAIR OF INGUINAL HERNIA, ONE DIRECT AND ONE INDIRECT, WITH GRAFT OR PROSTHESIS */
"5317" = "1" /* BILATERAL INGUINAL HERNIA REPAIR WITH GRAFT OR PROSTHESIS, NOS */
"5321" = "1" /* UNILATERAL REPAIR OF FEMORAL HERNIA */
"5329" = "1" /* OTHER UNILATERAL FEMORAL HERNIORHAPHY */
"5331" = "1" /* BILATERAL REPAIR OF FEMORAL HERNIA WITH GRAFT OR PROSTHESIS */
"5339" = "1" /* OTHER BILATERAL FEMORAL HERNIORRHAPHY */
"5341" = "1" /* REPAIR OF UMBILICAL HERNIA WITH PROSTHESIS */
"5349" = "1" /* OTHER UMBILICAL HERNIORRHAPHY */
"5351" = "1" /* INCISIONAL HERNIA REPAIR */
"5359" = "1" /* REPAIR OF OTHER HERNIA OF ANTERIOR ABDOMINAL WALL */
"5361" = "1" /* INCISIONAL HERNIA REPAIR WITH PROSTHESIS */
"5369" = "1" /* REPAIR OF OTHER HERNIA OF ANTERIOR ABDOMINAL WALL WITH PROSTHESIS */
"537"  = "1" /* REPAIR OF DIAPHRAGMATIC HERNIA, ABDOMINAL APPROACH */
"540"  = "1" /* INCISION OF ABDOMINAL WALL */
"5411" = "1" /* EXPLORATORY LAPAROTOMY */
"5419" = "1" /* OTHER LAPAROTOMY */
"5422" = "1" /* BIOPSY OF ABDOMINAL WALL OR UMBILICUS */
"5423" = "1" /* BIOPSY OF ABDOMINAL WALL OR UMBILICUS */
"543"  = "1" /* EXCISION OR DESTRUCTION OF LESION OR TISSUE OF ABDOMINAL WALL OR UMBILICUS */
"544"  = "1" /* EXCISION OR DESTRUCTION OF PERITONEAL TISSUE */
"5459" = "1" /* OTHER LYSIS OF PERITONEAL ADHESIONS */
"5463" = "1" /* OTHER SUTURE OF ABDOMINAL WALL */
"5464" = "1" /* SUTURE OF PERITONEUM */
"5471" = "1" /* REPAIR OF GASTROSCHISIS */
"5472" = "1" /* OTHER REPAIRE OF ABDOMINAL WALLS */
"5473" = "1" /* OTHER REPAIR OF PERITONEUM */
"5474" = "1" /* OTHER REPAIR OF OMENTUM */
"5475" = "1" /* OTHER REPAIR OF MESENTERY */
"5492" = "1" /* REMOVAL OF FOREIGN BODY FROM PERITONEAL CAVITY */
"5493" = "1" /* CREATION OF CUTANEOPERITONEAL FISTULA */
"5494" = "1" /* CREATION OF PERITONEOVASCULAR SHUNT */
"5495" = "1" /* INCISION OF PERITONEUM */
"5532" = "1" /* OPN ABLTN RENAL LES/TISS */ 
"5535" = "1" /* ABLTN RENAL LES/TISS NEC */ 
"5551" = "1" /* NEPHROURETERECTOMY */
"5552" = "1" /* NEPHRECTOMY OF REMAINING KIDNEY */
"5553" = "1" /* REMOVAL OF TRANSPLANTED OR REGECTED KDINEY */
"5554" = "1" /* BILATERAL NEPHRECTOMY */
"5561" = "1" /* RENAL AUTOTRANSPLANTATION */
"5569" = "1" /* KIDNEY TRANSPLANT NEC */
"557"  = "1" /* NEPHROPEXY */
"5583" = "1" /* CLOSURE OF OTHER FISTULA OF KIDNEY */
"5584" = "1" /* REDUCTION OF TORSION OF RENAL */
"5585" = "1" /* SYMPHYSIOTOMY FOR HORESHOE KIDNEY */
"5586" = "1" /* ANASTOMOSIS OF KIDNEY */
"5587" = "1" /* CORRECTION OF URETEROPELVIC JUNCTION */
"5591" = "1" /* DECAPSULATION OF KEDNEY */
"5597" = "1" /* IMPLANTATION OR REPLACEMENT OF MECHANICAL KIDNEY */
"5598" = "1" /* REMOVAL OF MECHANICAL KIDNEY */
"5651" = "1" /* FORMATION OF CUTANEOUS URETEROILEOSTOMY */
"5652" = "1" /* REVISION OF CUTANEOUS URETER OILEOSTOMY */
"5661" = "1" /* FORMATION OF OTHER CUTANEOUS URETEROSTOMY */
"5662" = "1" /* REVISION OF OTHER CUTANEOUS URETEROSTOMY */
"5671" = "1" /* URINARY DIVERSION TO INTESTINE */
"5672" = "1" /* REVISION OF URETEROINTESTINAL ANASTOMOSIS */
"5673" = "1" /* NEPHROCYSTANASTOMOSIS, NO */
"5674" = "1" /* URETERONEOXYSTOSTOMY */
"5675" = "1" /* TRANSURETEROURETEROSTOMY */
"5683" = "1" /* CLOSURE OF URETEROSTOMY */
"5684" = "1" /* CLOSURE OF OTHER FISTULA OF URETER */
"5685" = "1" /* URETEROPEXY */
"5686" = "1" /* REMOVAL OF LIGATURE FORM URETER */
"5689" = "1" /* OTHER REPAIR OF URETER */
"5695" = "1" /* LIGATION OF URETER */
"5771" = "1" /* RADICAL CYSTECTOMY */
"5779" = "1" /* OTHER TOTAL CYSTECTOMY */
"5782" = "1" /* CLOSRUE OF CYSTOSTOMY */
"5787" = "1" /* RECONSTRUCTION OF URNIARY BLADDER */
"5900" = "1" /* RETROPERITONEAL DISSECTION, NOS */
"5902" = "1" /* OTHER LYSIS OF PERIRENAL OR PERIURETERAL ADHESIONS */
"5909" = "1" /* OTHER INCISION OF PERIRENAL OR PERIURETERAL TISSUE */
"6012" = "1" /* OPEN BIOPSY OF PROSTATE */
"6014" = "1" /* OPEN BIOPSY OF SEMINAL VESICLES */
"6015" = "1" /* BIOPSY OF PERIPROSTATIC TISSUE */
"603"  = "1" /* SUPRAPUBIC PROSTATECTOMY */
"604"  = "1" /* RETROPUBIC PROSTATECTOMY */
"605"  = "1" /* RADICAL PROSTATECTOMY */
"6061" = "1" /* LOCAL EXCISION OF LESION OF PROSTATE */
"6072" = "1" /* INCISION OF SEMINAL VESICLE */
"6073" = "1" /* EXCISION OF SEMINAL VESICLE */
"6079" = "1" /* OTHER OPERATIONS ON SEMINAL VESICLES */
"6093" = "1" /* REPAIR OF PROSTATE */
"6509" = "1" /* OTHER OOPHORECTOMY */
"6512" = "1" /* OTHER BIOPSY OF OVARY */
"6521" = "1" /* MARSUPIALIZATION OF OVARIAN CYST */
"6522" = "1" /* WEDGE RESECTION OF OVARY*/
"6529" = "1" /* OTHER LOCAL EXCISION OR DESTRUCTION OF OVARY */
"6539" = "1" /* OTHER UNLILATERAL OOPHORECTOMY */
"6549" = "1" /* OTHER UNLIATERAL SALPINGOOPHORECTOMY */
"6551" = "1" /* OTHER REMOVAL OF BOTH OVARIES AT SAME OPERATIVE EPISODE */
"6552" = "1" /* OTHER REMOVAL OF REMAINING OVARY */
"6561" = "1" /* OTHER REMOVAL OF BOTH OVARIES AND TUBES AT SAME OPERATIVE EPISODE */
"6562" = "1" /* OTHER REMOVAL OF REMAINING OVARY AND TUBE */
"6571" = "1" /* OTHER SIMPLE SUTURE OF OVARY */
"6572" = "1" /* OTHER REIMPLANTATION OF OVARY */
"6573" = "1" /* OTHER SALPINGO OOPHOROPLASTY */
"6579" = "1" /* OTHER REPAIR OF OVARY */
"6589" = "1" /* OTHER LYSIS OF ADHESIONS OF AVARY AND FALLOPIAN TUBE */
"6592" = "1" /* TRANSPLANTATION OF OVARY */
"6593" = "1" /* MANUAL RUPTURE OF OVARIAN CYST */
"6594" = "1" /* OVARIAN DENERVATION */
"6595" = "1" /* RELEASE OF TORSION OF OVARY */
"6599" = "1" /* OTHER OPERATIONS ON OVARY */
"6601" = "1" /* SALPINGOTOMY */
"6602" = "1" /* SALPINGOSTOMY */
"6631" = "1" /* OTHER BILATERAL LIGATION AND CRUSHING OF FALLOPIAN TUBES */
"6632" = "1" /* OTHER BILATERAL LIGATION AND DIVISION OF FALLOPIAN TUBES */
"6639" = "1" /* OTHER BILATERAL DESTRUCTION OR OCCLUSION OF FALLOPIAN TUBES */
"664"  = "1" /* TOTAL UNILATERAL SALPINGECTOMY */
"6651" = "1" /* REMOVAL OF BOTH FALLOPIAN TUBES AT SAME OPERATIVE EPISODE */
"6652" = "1" /* REMOVAL OF REMAINING FALLOPIAN TUBE */
"6661" = "1" /* EXCISION OR DESTRUCTION OF LESION OF FALLOPIAN TUBE */
"6662" = "1" /* SALPINGECTOMY WITH REMOVAL OF TUBAL PREGNANCY */
"6663" = "1" /* BILATERAL PARTIAL SALPINGECTOMY, NOS */
"6669" = "1" /* OTHER PARTIAL SALPINGECTOMY */
"6671" = "1" /* SIMPLE SUTURE OF FALLOPIAN TUBE */
"6672" = "1" /* SALPINGO-OOPHOROSTOMY*/
"6673" = "1" /* SALPINGO-SALPINGOSTOMY */
"6674" = "1" /* SALPING0-UTEROSTOMY */
"6679" = "1" /* OTHER REPAIR OF FALLOPIAN TUBE */
"6692" = "1" /* UNILATERAL DESTRUCTION OR OCCLUSION OF FALLOPIAN TUBE */
"6697" = "1" /* BURYING OF FIMBRIAE IN UTERINE WALL */
"680"  = "1" /* OTHER INCISION AND EXCISION OF UTERUS */
"6813" = "1" /* OPEN BIOPSY OF UTERUS */
"6814" = "1" /* OPEN BIOPSY OF UTERINE LIGAMENTS */
"683"  = "1" /* SUBTOTAL ABDOMINAL HYSTERECTOMY */
"6839" = "1" /* OTH SUBTOT ABD HYSTERECT */
"684"  = "1" /* TOTAL ABDOMINAL HYSTERECTOMY */
"6841" = "1" /* LAP TOTAL ABDOMINAL HYST */ 
"6849" = "1" /* TOTAL ABD HYST NEC/NOS */   
"686"  = "1" /* RADICAL ABDOMINAL HYSTERECTOMY */
"6861" = "1" /* LAP RADICAL ABDOMNL HYST */ 
"6869" = "1" /* RADICAL ABD HYST NEC/NOS */ 
"688"  = "1" /* PELVIC EVISCERATION */
"6922" = "1" /* OTHER UTERINE SUSPENSION */
"693"  = "1" /* PARACERVICAL UTERINE DENERVATION */
"6941" = "1" /* SUTURE OF LACERATION OF UTERUS */
"6942" = "1" /* CLOSURE OF FISTULA OF UTERUS */
"6949" = "1" /* OTHER REPAIR OF UTERUS */
OTHER  = "0" ;

VALUE $ABDOM2P
"4499" = "1" /* GASTRIC OPERATION NEC */
OTHER  = "0" ;

 /* RECLOSURE OF POSTOPERATIVE DISRUPTION OF ABDOMINAL WALL */;
 /* ICD-9-CM PROCEDURE CODE: */

VALUE $RECLOIP
"5461"  = "1"  /* RECLOSURE OF POSTOPERATIVE DISRUPTION OF ABDOMINAL WALL */
OTHER   = "0" ;

 /* REPAIR OF GASTROSCHISIS OR UMBILICAL HERNIA */;
 /* ICD-9-CM PROCEDURE CODE: */

VALUE $REPGAST
"5341"  = "1" /* REPAIR OF UMBILICAL HERNIA WITH PROSTHESIS */
"5349"  = "1" /* OTHER UMBILICAL HERNIORRHAPHY */
"5471"  = "1"  /* REPAIR OF GASTROSCHISIS */
OTHER   = "0" ;

/* EXCLUDE: */
/* HIGH RISK GROUP */
/* ICD-9-CM DIAGNOSIS CODES: */

VALUE $IMMUNHD
"042"   =  "1" /* HUMAN IMMUNODEFICIENCY VIRUS (HIV) DISEASE */
"1363"  =  "1" /* PNEUMOCYSTOSIS*/
"20000" =  "1" /* RETCLSRC UNSP XTRNDL ORG */
"20001" =  "1" /* RETICULOSARCOMA HEAD */
"20002" =  "1" /* RETICULOSARCOMA THORAX */
"20003" =  "1" /* RETICULOSARCOMA ABDOM */
"20004" =  "1" /* RETICULOSARCOMA AXILLA */
"20005" =  "1" /* RETICULOSARCOMA INGUIN */
"20006" =  "1" /* RETICULOSARCOMA PELVIC */
"20007" =  "1" /* RETICULOSARCOMA SPLEEN */
"20008" =  "1" /* RETICULOSARCOMA MULT */
"20010" =  "1" /* LYMPHSRC UNSP XTRNDL ORG */
"20011" =  "1" /* LYMPHOSARCOMA HEAD */
"20012" =  "1" /* LYMPHOSARCOMA THORAX */
"20013" =  "1" /* LYMPHOSARCOMA ABDOM */
"20014" =  "1" /* LYMPHOSARCOMA AXILLA */
"20015" =  "1" /* LYMPHOSARCOMA INGUIN */
"20016" =  "1" /* LYMPHOSARCOMA PELVIC */
"20017" =  "1" /* LYMPHOSARCOMA SPLEEN */
"20018" =  "1" /* LYMPHOSARCOMA MULT */
"20020" =  "1" /* BRKT TMR UNSP XTRNDL ORG */
"20021" =  "1" /* BURKITTS TUMOR HEAD */
"20022" =  "1" /* BURKITTS TUMOR THORAX */
"20023" =  "1" /* BURKITTS TUMOR ABDOM */
"20024" =  "1" /* BURKITTS TUMOR AXILLA */
"20025" =  "1" /* BURKITTS TUMOR INGUIN */
"20026" =  "1" /* BURKITTS TUMOR PELVIC */
"20027" =  "1" /* BURKITTS TUMOR SPLEEN */
"20028" =  "1" /* BURKITTS TUMOR MULT */
"20080" =  "1" /* OTH VARN UNSP XTRNDL ORG */
"20081" =  "1" /* MIXED LYMPHOSARC HEAD */
"20082" =  "1" /* MIXED LYMPHOSARC THORAX */
"20083" =  "1" /* MIXED LYMPHOSARC ABDOM */
"20084" =  "1" /* MIXED LYMPHOSARC AXILLA */
"20085" =  "1" /* MIXED LYMPHOSARC INGUIN */
"20086" =  "1" /* MIXED LYMPHOSARC PELVIC */
"20087" =  "1" /* MIXED LYMPHOSARC SPLEEN */
"20088" =  "1" /* MIXED LYMPHOSARC MULT */
"2050"  =  "1" /* ACUTE MYELOID LEUKEMIA */
"20500" =  "1" /* ACT MYL LEUK W/O RMSION */
"20501" =  "1" /* ACT MYL LEUK W RMSION */
"2051"  =  "1" /* CHRONIC MYELOID LEUKEMIA */
"20510" =  "1" /* CHR MYL LEUK W/O RMSION */
"20511" =  "1" /* CHR MYL LEUK W RMSION */
"2052"  =  "1" /* SUBACUT MYELOID LEUKEMIA */
"20520" =  "1" /* SBAC MYL LEUK W/O RMSION */
"20521" =  "1" /* SBAC MYL LEUK W RMSION */
"2053"  =  "1" /* MYELOID SARCOMA */
"20530" =  "1" /* MYL SRCOMA W/O RMSION */
"20531" =  "1" /* MYL SRCOMA W RMSION */
"2058"  =  "1" /* MYELOID LEUKEMIA NEC */
"20580" =  "1" /* OTH MYL LEUK W/O RMSION */
"20581" =  "1" /* OTH MYL LEUK W RMSION */
"2059"  =  "1" /* MYELOID LEUKEMIA NOS */
"20590" =  "1" /* UNS MYL LEUK W/O RMSION */
"20591" =  "1" /* UNS MYL LEUK W RMSION */
"2060"  =  "1" /* ACUTE MONOCYTIC LEUKEMIA */
"20600" =  "1" /* ACT MONO LEUK W/O RMSION */
"20601" =  "1" /* ACT MONO LEUK W RMSION */
"2061"  =  "1" /* CHR MONOCYTIC LEUKEMIA */
"20610" =  "1" /* CHR MONO LEUK W/O RMSION */
"20611" =  "1" /* CHR MONO LEUK W RMSION */
"2062"  =  "1" /* SUBAC MONOCYTIC LEUKEMIA */
"20620" =  "1" /* SBAC MONO LEUK W/O RMSON */
"20621" =  "1" /* SBAC MONO LEUK W RMSION */
"2068"  =  "1" /* MONOCYTIC LEUKEMIA NEC */
"20680" =  "1" /* OTH MONO LEUK W/O RMSION */
"20681" =  "1" /* OTH MONO LEUK W RMSION */
"2069"  =  "1" /* MONOCYTIC LEUKEMIA NOS */
"20690" =  "1" /* UNS MONO LEUK W/O RMSION */
"20691" =  "1" /* UNS MONO LEUK W RMSION */
"2070"  =  "1" /* ACUTE ERYTHREMIA */
"20700" =  "1" /* ACT ERTH/ERYLK W/O RMSON */
"20701" =  "1" /* ACT ERTH/ERYLK W RMSON */
"2071"  =  "1" /* CHRONIC ERYTHREMIA */
"20710" =  "1" /* CHR ERYTHRM W/O REMISION */
"20711" =  "1" /* CHR ERYTHRM W REMISION */
"2072"  =  "1" /* MEGAKARYOCYTIC LEUKEMIA */
"20720" =  "1" /* MGKRYCYT LEUK W/O RMSION */
"20721" =  "1" /* MGKRYCYT LEUK W RMSION */
"2078"  =  "1" /* SPECIFIED LEUKEMIA NEC */
"20780" =  "1" /* OTH SPF LEUK W/O REMSION */
"20781" =  "1" /* OTH SPF LEUK W REMSION */
"2080"  =  "1" /* ACT LEUK UNS CL W/O RMSN */
"20800" =  "1" /* ACT LEUK UNS CL W/O RMSN */
"20801" =  "1" /* ACT LEUK UNS CL W RMSON */
"2081"  =  "1" /* CHRONIC LEUKEMIA NOS */
"20810" =  "1" /* CHR LEUK UNS CL W/O RMSN */
"20811" =  "1" /* CHR LEUK UNS CL W RMSON */
"2082"  =  "1" /* SUBACUTE LEUKEMIA NOS */
"20820" =  "1" /* SBAC LEUK UNS CL W/O RMS */
"20821" =  "1" /* SBAC LEUK UNS CL W RMSON */
"2088"  =  "1" /* LEUKEMIA-UNSPEC CELL NEC */
"20880" =  "1" /* OTH LEUK UNS CL W/O RMSN */
"20881" =  "1" /* OTH LEUK UNS CL W RMSON */
"2089"  =  "1" /* LEUKEMIA-UNSPEC CELL NOS */
"20890" =  "1" /* LEUKEMIA NOS W/O REMSION */
"20891" =  "1" /* LEUKEMIA NOS W REMISSIO */
"23873" =  "1" /* HI GRDE MYELODYS SYN LES */
"23876" =  "1" /* MYELOFI W MYELO METAPLAS */
"260"   =  "1" /* KWASHIORKOR */
"261"   =  "1" /* NUTRITIONAL MARASMUS */
"262"   =  "1" /* OTHER SEVERE PROTEIN CALORIE MALNUTRITION */
"27900" =  "1" /* HYPOGAMMAGLOBULINEMIA NOS */
"27901" =  "1" /* SELECTIVE IGA IMMUNODEFICIENCY */
"27902" =  "1" /* SELECTIVE IGM IMMUNODEFICIENCY */
"27903" =  "1" /* OTHER SELECTIVE IMMUNOGLOBULIN DEFICIENCIES */
"27904" =  "1" /* CONGENITAL HYPOGAMMAGLOBULINEMIA */
"27905" =  "1" /* IMMUNODEFICIENCY WITH INCREASED IGM */
"27906" =  "1" /* COMMON VARIABLE IMMUNODEFICIENCY */
"27909" =  "1" /* DEFICIENCY OF HUMORAL IMMUNITY, OTHER*/
"27910" =  "1" /* IMMUNODEFICIENCY WITH PREDOMINANT T-CELL DEFECT NOS */
"27911" =  "1" /* DIGEORGE"S SYNDROME */
"27912" =  "1" /* WISKOTT-ALDRICH SYNDROME */
"27913" =  "1" /* NEZLOF"S SYNDROME */
"27919" =  "1" /* DEFICIENCY OF CELL-MEDIATED IMMUNITY, OTHER */
"2792"  =  "1" /* COMBINED IMMUNITY DEFICIENCY */
"2793"  =  "1" /* UNSPECIFIED IMMUNITY DEFICIENCY */
"2794"  =  "1" /* AUTOIMMUNE DISEASE, NOT ELSEWHERE CLASSIFIED */
"2798"  =  "1" /* OTHER SPECIFIED DISORDERS INVOLVING THE IMMUNE MECHANISM */
"2799"  =  "1" /* UNDSPECIFIED DISORDER OF IMMUNE MECHANISM */
"28409" =  "1" /* CONST APLASTC ANEMIA NEC */
"2841 " =  "1" /* PANCYTOPENIA */
"2880"  =  "1" /* AGRANULOCYTOSIS */
"28800" =  "1" /* NEUTROPENIA NOS */
"28801" =  "1" /* CONGENITAL NEUTROPENIA */
"28802" =  "1" /* CYCLIC NEUTROPENIA */
"28803" =  "1" /* DRUG INDUCED NEUTROPENIA */
"28809" =  "1" /* NEUTROPENIA NEC */
"2881"  =  "1" /* FUNCTIONAL DISORDERS OF POLYMORPHONUCLEAR NEUTROPHILS */
"2882"  =  "1" /* GENETIC ANOMALIES OF LUKOCYTES */
"2884 " =  "1" /* HEMOPHAGOCYTIC SYNDROMES */
"28850" =  "1" /* LEUKOCYTOPENIA NOS */
"28851" =  "1" /* LYMPHOCYTOPENIA */
"28859" =  "1" /* DECREASED WBC COUNT NEC */
"28953" =  "1" /* NEUTROPENIC SPLENOMEGALY */
"28983" =  "1" /* MYELOFIBROSIS */
"40301" =  "1"  /* HYPERTENSIVE RENAL DISEASE, MALIGNANT W RENAL FAILURE */
"40311" =  "1"  /* HYPERTENSIVE RENAL DISEASE, BENIGH W RENAL FAILURE */
"40391" =  "1"  /* HYPERTENSIVE RENAL DISEASE, NOS W RENAL FAILURE */
"40402" =  "1"  /* HYPERTENSIVE HEART AND RENAL DISEASE MALIGNANT W RENAL FAILURE */
"40403" =  "1"  /* HYPERTENSIVE HEART AND RENAL DISEASE MALIGNANT W CONGESTIVE HEART AND RENAL FAILURE */
"40412" =  "1"  /* HYPERTENSIVE HEART AND RENAL DISEASE BENIGH W RENAL FAILURE */
"40413" =  "1"  /* HYPERTENSIVE HEART AND RENAL DISEASE BENIGH W CONGESTIVE HEART AND RENAL FAILURE*/
"40492" =  "1"  /* HYPERTENSIVE HEART AND RENAL DISEASE NOS W RENAL FAILURE */
"40493" =  "1"  /* HYPERTENSIVE HEART AND RENAL DISEASE NOS W CONGESTIVE HEART AND RENAL FAILURE */
"5793"  =  "1" /* OTHER AND UNSPECIFIED POSTSURGICAL NONABSORPTION */
"585"   =  "1"  /* CHRONIC KIDNEY DISEASE */
"5855"  =  "1"  /* CHRONIC KIDNEY DISEASE STAGE V */
"5856"  =  "1"  /* END STAGE RENAL DISEASE */
"9968"  =  "1" /* COMPLICATIONS OF TRANSPLANTED ORGAN */
"99680" =  "1" /* COMP ORGAN TRANSPLNT NOS */
"99681" =  "1" /* COMPL KIDNEY TRANSPLANT */
"99682" =  "1" /* COMPL LIVER TRANSPLANT */
"99683" =  "1" /* COMPL HEART TRANSPLANT */
"99684" =   "1" /* COMPL LUNG TRANSPLANT */
"99685" =  "1" /* COMPL MARROW TRANSPLANT */
"99686" =  "1" /* COMPL PANCREAS TRANSPLNT */
"99687" =  "1" /* COMP INTESTINE TRANSPLNT */
"99689" =  "1" /* COMP OTH ORGAN TRANSPLNT */
"V420"  =  "1" /* KIDNEY REPLACED BY TRANSPLANT */
"V421"  =  "1" /* HEART REPLACED BY TRANSPLANT */
"V426"  =  "1" /* LUNG REPLACED BY TRANSPLANT */
"V427"  =  "1" /* LIVER REPLACED BY TRANSPLANT */
"V428"  =  "1" /* OTHER SPECIFIED ORGAN OR TISSUE */
"V4281" =  "1" /* BONE MARROW SPECIFIED BY TRANSPLANT */
"V4282" =  "1" /* PERIPHERAL STEM CELLS REPLACED BY TRANSPLANT */
"V4283" =  "1" /* PANCREAS REPLACED BY TRANSPLANT */
"V4284" =  "1" /* INTESTINES REPLACE BY TRANSPLANT */
"V4289" =  "1" /* OTHER REPLACED BY TRANSPLANT */
"V451"  =  "1"  /* RENAL DIALYSIS STATUS */
"V560"  =  "1"  /* EXTRACORPOREAL DIALYSIS */
"V561"  =  "1"  /* FITTING AND ADJUSTMENT OF EXTRACORPOREAL DIALYSIS CATHETER */
"V562"  =  "1"  /* FITTING AND ADJUSTMENT OF PERITONEAL DIALYSIS CATHETER */
"V563"  =  "1"  /* ENCOUNTER FOR ADEQUACY TESTING FOR DIALYSIS */
"V5631" =  "1"  /* ENCOUNTER FOR ADEQUACY TESTING FOR HEMODIALYSIS */
"V5632" =  "1"  /* ENCOUNTER FOR ADEQUACY TESTING FOR PERIONEAL DIALYSIS */
"V568"  =  "1"  /* OTHER DIALYSIS */
OTHER   = "0" ;

/* ICD-9-CM PROCEDURE CODES: */

VALUE $TRANSPP
"335"  = "1" /* LUNG TRANSPLANT */
"3350" = "1" /* LUNG TRANSPLANT NOS */
"3351" = "1" /* UNILAT LUNG TRANSPLANT */
"3352" = "1" /* BILAT LUNG TRANSPLANT */
"336"  = "1" /* COMBINED HEART-LUNG TRANSPLANTATION */
"375"  = "1" /* HEART TRANSPLANTATION */
"3751" = "1" /* HEART TRANSPLANTATION */
"410"  = "1" /* OPERATIONS ON BONE MAROW AND SPLEEN */
"4100" = "1" /* BONE MARROW TRNSPLNT NOS */
"4101" = "1" /* AUTO BONE MT W/O PURG */
"4102" = "1" /* ALO BONE MARROW TRNSPLNT */
"4103" = "1" /* ALLOGRFT BONE MARROW NOS */
"4104" = "1" /* AUTO HEM STEM CT W/O PUR */
"4105" = "1" /* ALLO HEM STEM CT W/O PUR */
"4106" = "1" /* CORD BLD STEM CELL TRANS */
"4107" = "1" /* AUTO HEM STEM CT W PURG */
"4108" = "1" /* ALLO HEM STEM CT W PURG */
"4109" = "1" /* AUTO BONE MT W PURGING */
"5051" = "1" /* AUXILIARY LIVER TRANSPL */
"5059" = "1" /* LIVER TRANSPLANT NEC */
"5280" = "1" /* PANCREATIC TRANSPLANT, NOS */
"5281" = "1" /* REIMPLANTATION OF PANCREATIC TISSUE */
"5282" = "1" /* REIMPLANTATION OF PANCREATIC TISSUE */
"5283" = "1" /* HETEROTRANSPLANT OF PANCREAS */
"5285" = "1" /* ALLOTRANSPLANTATION OF CELLS OF ISLETS OF LNGERHANS */
"5286" = "1" /* TRANSPLANTATION OF CELLS OF ISLETS OF LANGERHANS, NOS */
"5569" = "1" /* OTHER KIDNEY TRANSPLANTATION */
OTHER  = "0" ;

/* EXCLUDE: */
/* INTERMEDIATE RISK GROUP */
/* ICD-9-CM DIAGNOSIS CODES: */

VALUE $IMMUITD
"07022" =  "1"    /* VIRAL HEPATITIS B W HEPATIC COMA, CHRONIC WO MENTION OF HEPATITIS DELTA */
"07023" =  "1"    /* VIRAL HEPATITIS B W HEPACTIC COMA, CHRONIC W HEPATITIS DELTA */
"07044" =  "1"    /* CHRONIC HEPATITIS C WITH HEPACTIC COMMA */
"2894"  =  "1"    /* HYPERSPLENISM */
"28950" =  "1"    /* DISEASE OF SPLEEN NOS */
"28951" =  "1"    /* CHRONIC DIGESTIVE SPLENOMEGALY */
"28952" =  "1"    /* SPLENIC SEQUESTRATION */
"28959" =  "1"    /* OTHER DISEASE OF SPLEEN, OTHER */
"4560"  =  "1"    /* ESOPHAGEAL VARICES W BLEEDING */
"4561"  =  "1"    /* ESOPHAGEAL VARICES WO MENTION OF BLEEDING */
"45620" =  "1"    /* ESOPHAGEAL VARICES IN DISEASE CLASSIFIED ELSEWHERE, W BLEEDING */
"45621" =  "1"    /* ESOPHAGEAL VARICES IN DISEASE CLASSIFIED ELSEWHERE, WO MENTION OF BLEEDING */
"5723"  =  "1"    /* PORTAL HYPERTENSION */
"5728"  =  "1"    /* OTHER SEQUELAE OF CHRONIC LIVER DISEASE */
"580"   =  "1"  /* ACUTE GLOMERULONEPHRITIS */
"5800"  =  "1"  /* WITH LESION OF PROLIFERATIVE GLOMERULONEPHRITIS */
"5804"  =  "1"  /* WITH LESION OF RAPIDLY PROGRESSIVE GLOMERULONEPHRITIS */
"5808"  =  "1"  /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY */
"58081" =  "1"  /* ACUTE GLOMERULONEPHRITIS IN DISEASES CLASSIFIED ELSEWHERE */
"58089" =  "1"  /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY, OTHER   */
"5809"  =  "1"  /* ACUTE GLOMERULONEPHRITIS WITH UNSPECIFIED PATHOLOGICAL LESION IN KIDNEY  */
"581"   =  "1"  /* NEPHROTIC SYNDROME */
"5810"  =  "1"  /* WITH LESION OF PROLIFERATIVE GLOMERULONEPHRITIS */
"5811"  =  "1"  /* WITH LESION OF MEMBRANOUS GLOMERULONEPHRITIS */
"5812"  =  "1"  /* WITH LESION OF MEMBRANOPROLIFERATIVE GLOMERULONEPHRITIS */
"5813"  =  "1"  /* WITH LESION OF MINIMAL CHANGE GLOMERULONEPHRITIS */
"5818"  =  "1"  /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY  */
"58181" =  "1"  /* NEPHROTIC SYNDROME IN DISEASE CLASSIFIED ELSEWHERE  */
"58189" =  "1"  /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY,OTHER  */
"5819"  =  "1"  /* NEPHROTIC SYNDROME WITH UNSPECIFIED PATHOLOGICAL LESION IN KIDNEY */
"582"   =  "1"  /* CHRONIC GLOMERULONEPHRITIS  */
"5820"  =  "1"  /* WITH LESION OF PROLIFERATIVE GLOMERULONEPHRITIS */
"5821"  =  "1"  /* WITH LESION OF MEMBRANOUS GLOMERULONEPHRITIS */
"5822"  =  "1"  /* WITH LESION OF MEMBRANEPROLIFERATIVE GLOMERULONEPHRITIS */
"5824"  =  "1"  /* WITH LESION OF RAPIDLY PROGRESSIVE GLOMERULONEPHRITIS */
"5828"  =  "1"  /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY */
"58281" =  "1"  /* CHRONIC GLOMERULONEPHRITIS IN DISEASES CLASSIFIED ELSEWHERE */
"58289" =  "1"  /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY, OTHER   */
"5829"  =  "1"  /* CHORNIC GLOMERULONEPHRITIS WITH UNSPECIFIED PATHOLOGICAL LESION IN KIDNEY  */
"583"   =  "1"  /* NEPHRITIS AND NEPHROPATHY, NOT SPECFIED AS ACUTE OR CHRONIC  */
"5830"  =  "1"  /* WITH LESION OF PROLIFERATIVE GLOMERULONEPHRITIS */
"5831"  =  "1"  /* WITH LESION OF MEMBRANOUS GLOMERULONEPHRITIS */
"5832"  =  "1"  /* WITH LESION OF MEMBRANEPROLIFERATIVE GLOMERULONEPHRITIS */
"5834"  =  "1"  /* WITH LESION OF RAPIDLY PROGRESSIVE GLOMERULONEPHRITIS */
"5836"  =  "1"  /* WITH LESION OF RENAL CORTICAL NECROSIS */
"5837"  =  "1"  /* WITH LESION OF RENAL MEDULLARY NECROSIS */
"5838"  =  "1"  /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY */
"58381" =  "1"  /* NEPHRITIS AND NEPHROPATHY, NOT SPECIFIED AS ACUTE OR CHRONIC, IN DISEASE CLASSIFIED ELSEWHERE */
"58389" =  "1"  /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY, OTHER   */
"5839"  =  "1"  /* WITH UNSPECIFIED PATHOLOGICAL LESION IN KIDNEY */
"7100"  =  "1" /* SYSTEMIC LUPUS ERYTHEMATOSUS */
"7101"  =  "1" /* SYSTEMIC SCLEROSIS */
"7102"  =  "1" /* SICCA SYNDROME */
"7103"  =  "1" /* DERMATOMYOSITIS */
"7104"  =  "1" /* POLYMYOSITIS */
"7105"  =  "1" /* EOSINOPHILIA MYALGIA SYNDROME */
"7108"  =  "1" /* OTHER SPECIFIED DIFFUSE DISEASE OF CONNECTIVE TISSUE */
"7109"  =  "1" /* UNSPECIFIED DIFFUSE CONNECTIVE TISSUE DISEASE */
"7590"  =  "1"    /* ANOMALIES OF SPLEEN */
"7994"  =  "1"    /* CACHEXIA */
"86500" =  "1"    /* INJURY TO SPLEEN,WO MENTION OF OPEN WOUND INTO CAVITY NOS INJURY */
"86501" =  "1"    /* INJURY TO SPLEEN,WO MENTION OF OPEN WOUND INTO CAVITY HEMATOMA WO RUPTURE OF CAPSULE */
"86502" =  "1"    /* INJURY TO SPLEEN,WO MENTION OF OPEN WOUND INTO CAVITY CAPSULE TEARS WO MAJOR DISRUPTION OF PARENCHYMA */
"86503" =  "1"    /* INJURY TO SPLEEN,WO MENTION OF OPEN WOUND INTO CAVITY LACERATION EXTENDING INTO PARENCHYMA */
"86504" =  "1"    /* INJURY TO SPLEEN,WO MENTION OF OPEN WOUND INTO CAVITY MASSIVE PARENCHYMAL DISRUPTION */
"86509" =  "1"    /* INJURY TO SPLEEN,WO MENTION OF OPEN WOUND INTO CAVITY OTHER */
"86510" =  "1"    /* INJURY TO SPLEEN,W OPEN WOUND INTO CAVITY NOS INJURY */
"86511" =  "1"    /* INJURY TO SPLEEN,W OPEN WOUND INTO CAVITY HEMATOMA WO RUPTURE OF CAPSULE */
"86512" =  "1"    /* INJURY TO SPLEEN,W OPEN WOUND INTO CAVITY CAPSULAR TEARS WO MAJOR DISRUPTION OF PARENCHYMA */
"86513" =  "1"    /* INJURY TO SPLEEN,W OPEN WOUND INTO CAVITY LACERATION EXTENDING INTO PARENCHYMA */
"86514" =  "1"    /* INJURY TO SPLEEN,W OPEN WOUND INTO CAVITY MASSIVE PARENCHYMAL DISRUPTION */
"86519" =  "1"    /* INJURY TO SPLEEN,W OPEN WOUND INTO CAVITY OTHER */
"V427"  =  "1"    /* ORGAN OR TISSUE REPLACED BY TRANSPLANT, LIVER */
OTHER   = "0" ;

/* HEPTIC FAILURE CONDITION PART II */
VALUE $HEPFA2D
"5712"   = "1"    /* ALCOHOLIC CIRRHOSIS OF LIVER */
"5715"   = "1"    /* CIRRHOSIS OF LIVER WITHOUT MENTION OF ALCOHOL */
"5716"   = "1"    /* BILIARY CIRRHOSIS */
OTHER   = "0" ;

VALUE $HEPFA3D
"5722"   = "1"    /* HEPATIC COMA */
"5724"   = "1"    /* HEPATORENAL SYNDROME */
OTHER   = "0" ;


 /* ---------------------------------------- */
 /* SELECTED INFECTION DUE TO MEDICAL CARE   */
 /*   PROVIDER INDICATOR / PDI#  12          */
 /* ---------------------------------------- */

 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $IDTMCID
"99662" = "1" /* DUE TO OTHER VASCULAR DEVICE, IMPLANT, AND GRAFT */
"9993"  = "1" /* OTHER INFECTION */
"99931" = "1" /* INFECT DT CENT VEN CATH */
OTHER   = "0" ;

/* STRATIFY BY: HIGH RISK GROUP */
/* ICD-9-CM DIAGNOSIS CODES: */

VALUE $CANITD
"1400 " = "1" /* MAL NEO UPPER VERMILION*/
"1401 " = "1" /* MAL NEO LOWER VERMILION */
"1403 " = "1" /* MAL NEO UPPER LIP, INNER */
"1404 " = "1" /* MAL NEO LOWER LIP, INNER */
"1405 " = "1" /* MAL NEO LIP, INNER NOS */
"1406 " = "1" /* MAL NEO LIP, COMMISSURE */
"1408 " = "1" /* MAL NEO LIP NEC */
"1409 " = "1" /* MAL NEO LIP/VERMIL NOS */
"1410 " = "1" /* MAL NEO TONGUE BASE */
"1411 " = "1" /* MAL NEO DORSAL TONGUE */
"1412 " = "1" /* MAL NEO TIP/LAT TONGUE */
"1413 " = "1" /* MAL NEO VENTRAL TONGUE */
"1414 " = "1" /* MAL NEO ANT 2/3 TONGUE */
"1415 " = "1" /* MAL NEO TONGUE JUNCTION */
"1416 " = "1" /* MAL NEO LINGUAL TONSIL */
"1418 " = "1" /* MALIG NEO TONGUE NEC */
"1419 " = "1" /* MALIG NEO TONGUE NOS */
"1420 " = "1" /* MALIG NEO PAROTID */
"1421 " = "1" /* MALIG NEO SUBMANDIBULAR */
"1422 " = "1" /* MALIG NEO SUBLINGUAL */
"1428 " = "1" /* MAL NEO MAJ SALIVARY NEC */
"1429 " = "1" /* MAL NEO SALIVARY NOS */
"1430 " = "1" /* MALIG NEO UPPER GUM */
"1431 " = "1" /* MALIG NEO LOWER GUM */
"1438 " = "1" /* MALIG NEO GUM NEC */
"1439 " = "1" /* MALIG NEO GUM NOS */
"1440 " = "1" /* MAL NEO ANT FLOOR MOUTH */
"1441 " = "1" /* MAL NEO LAT FLOOR MOUTH */
"1448 " = "1" /* MAL NEO MOUTH FLOOR NEC */
"1449 " = "1" /* MAL NEO MOUTH FLOOR NOS */
"1450 " = "1" /* MAL NEO CHEEK MUCOSA */
"1451 " = "1" /* MAL NEO MOUTH VESTIBULE */
"1452 " = "1" /* MALIG NEO HARD PALATE */
"1453 " = "1" /* MALIG NEO SOFT PALATE */
"1454 " = "1" /* MALIGNANT NEOPLASM UVULA */
"1455 " = "1" /* MALIGNANT NEO PALATE NOS */
"1456 " = "1" /* MALIG NEO RETROMOLAR */
"1458 " = "1" /* MALIG NEOPLASM MOUTH NEC */
"1459 " = "1" /* MALIG NEOPLASM MOUTH NOS */
"1460 " = "1" /* MALIGNANT NEOPL TONSIL */
"1461 " = "1" /* MAL NEO TONSILLAR FOSSA */
"1462 " = "1" /*  MAL NEO TONSIL PILLARS */
"1463 " = "1" /* MALIGN NEOPL VALLECULA */
"1464 " = "1" /* MAL NEO ANT EPIGLOTTIS */
"1465 " = "1" /* MAL NEO EPIGLOTTIS JUNCT */
"1466 " = "1" /* MAL NEO LAT OROPHARYNX */
"1467 " = "1" /* MAL NEO POST OROPHARYNX */
"1468 " = "1" /* MAL NEO OROPHARYNX NEC */
"1469 " = "1" /* MALIG NEO OROPHARYNX NOS */
"1470 " = "1" /* MAL NEO SUPER NASOPHARYN */
"1471 " = "1" /* MAL NEO POST NASOPHARYNX */
"1472 " = "1" /* MAL NEO LAT NASOPHARYNX */
"1473 " = "1" /* MAL NEO ANT NASOPHARYNX */
"1478 " = "1" /* MAL NEO NASOPHARYNX NEC */
"1479 " = "1" /* MAL NEO NASOPHARYNX NOS */
"1480 " = "1" /* MAL NEO POSTCRICOID */
"1481 " = "1" /* MAL NEO PYRIFORM SINUS */
"1482 " = "1" /* MAL NEO ARYEPIGLOTT FOLD */
"1483 " = "1" /* MAL NEO POST HYPOPHARYNX */
"1488 " = "1" /* MAL NEO HYPOPHARYNX NEC */
"1489 " = "1" /* MAL NEO HYPOPHARYNX NOS */
"1490 " = "1" /* MAL NEO PHARYNX NOS */
"1491 " = "1" /* MAL NEO WALDEYERS RING */
"1498 " = "1" /* MAL NEO ORAL/PHARYNX NEC */
"1499 " = "1" /* MAL NEO OROPHRYN ILL-DEF */
"1500 " = "1" /* MAL NEO CERVICAL ESOPHAG */
"1501 " = "1" /* MAL NEO THORACIC ESOPHAG */
"1502 " = "1" /* MAL NEO ABDOMIN ESOPHAG */
"1503 " = "1" /* MAL NEO UPPER 3RD ESOPH */
"1504 " = "1" /* MAL NEO MIDDLE 3RD ESOPH */
"1505 " = "1" /* MAL NEO LOWER 3RD ESOPH */
"1508 " = "1" /* MAL NEO ESOPHAGUS NEC */
"1509 " = "1" /* MAL NEO ESOPHAGUS NOS */
"1510 " = "1" /* MAL NEO STOMACH CARDIA */
"1511 " = "1" /* MALIGNANT NEO PYLORUS */
"1512 " = "1" /* MAL NEO PYLORIC ANTRUM */
"1513 " = "1" /* MAL NEO STOMACH FUNDUS */
"1514 " = "1" /* MAL NEO STOMACH BODY */
"1515 " = "1" /* MAL NEO STOM LESSER CURV */
"1516 " = "1" /* MAL NEO STOM GREAT CURV */
"1518 " = "1" /* MALIG NEOPL STOMACH NEC */
"1519 " = "1" /* MALIG NEOPL STOMACH NOS */
"1520 " = "1" /* MALIGNANT NEOPL DUODENUM */
"1521 " = "1" /* MALIGNANT NEOPL JEJUNUM */
"1522 " = "1" /* MALIGNANT NEOPLASM ILEUM */
"1523 " = "1" /* MAL NEO MECKELS DIVERT */
"1528 " = "1" /* MAL NEO SMALL BOWEL NEC */
"1529 " = "1" /* MAL NEO SMALL BOWEL NOS */
"1530 " = "1" /* MAL NEO HEPATIC FLEXURE */
"1531 " = "1" /* MAL NEO TRANSVERSE COLON */
"1532 " = "1" /* MAL NEO DESCEND COLON */
"1533 " = "1" /* MAL NEO SIGMOID COLON */
"1534 " = "1" /* MALIGNANT NEOPLASM CECUM */
"1535 " = "1" /* MALIGNANT NEO APPENDIX */
"1536 " = "1" /* MALIG NEO ASCEND COLON */
"1537 " = "1" /* MAL NEO SPLENIC FLEXURE */
"1538 " = "1" /* MALIGNANT NEO COLON NEC */
"1539 " = "1" /* MALIGNANT NEO COLON NOS */
"1540 " = "1" /* MAL NEO RECTOSIGMOID JCT */
"1541 " = "1" /* MALIGNANT NEOPL RECTUM */
"1542 " = "1" /* MALIG NEOPL ANAL CANAL */
"1543 " = "1" /* MALIGNANT NEO ANUS NOS */
"1548 " = "1" /* MAL NEO RECTUM/ANUS NEC */
"1550 " = "1" /* MAL NEO LIVER, PRIMARY */
"1551 " = "1" /* MAL NEO INTRAHEPAT DUCTS */
"1552 " = "1" /* MALIGNANT NEO LIVER NOS */
"1560 " = "1" /* MALIG NEO GALLBLADDER */
"1561 " = "1" /* MAL NEO EXTRAHEPAT DUCTS */
"1562 " = "1" /* MAL NEO AMPULLA OF VATER */
"1568 " = "1" /* MALIG NEO BILIARY NEC */
"1569 " = "1" /* MALIG NEO BILIARY NOS */
"1570 " = "1" /* MAL NEO PANCREAS HEAD */
"1571 " = "1" /* MAL NEO PANCREAS BODY */
"1572 " = "1" /* MAL NEO PANCREAS TAIL */
"1573 " = "1" /* MAL NEO PANCREATIC DUCT */
"1574 " = "1" /* MAL NEO ISLET LANGERHANS */
"1578 " = "1" /* MALIG NEO PANCREAS NEC */
"1579 " = "1" /* MALIG NEO PANCREAS NOS */
"1580 " = "1" /* MAL NEO RETROPERITONEUM */
"1588 " = "1" /* MAL NEO PERITONEUM NEC */
"1589 " = "1" /* MAL NEO PERITONEUM NOS */
"1590 " = "1" /* MALIG NEO INTESTINE NOS */
"1591 " = "1" /* MALIGNANT NEO SPLEEN NEC */
"1598 " = "1" /* MAL NEO GI/INTRA-ABD NEC */
"1599 " = "1" /* MAL NEO GI TRACT ILL-DEF */
"1600 " = "1" /* MAL NEO NASAL CAVITIES */
"1601 " = "1" /* MALIG NEO MIDDLE EAR */
"1602 " = "1" /* MAL NEO MAXILLARY SINUS */
"1603 " = "1" /* MAL NEO ETHMOIDAL SINUS */
"1604 " = "1" /* MALIG NEO FRONTAL SINUS */
"1605 " = "1" /* MAL NEO SPHENOID SINUS */
"1608 " = "1" /* MAL NEO ACCESS SINUS NEC */
"1609 " = "1" /* MAL NEO ACCESS SINUS NOS */
"1610 " = "1" /* MALIGNANT NEO GLOTTIS */
"1611 " = "1" /* MALIG NEO SUPRAGLOTTIS */
"1612 " = "1" /* MALIG NEO SUBGLOTTIS */
"1613 " = "1" /* MAL NEO CARTILAGE LARYNX */
"1618 " = "1" /* MALIGNANT NEO LARYNX NEC */
"1619 " = "1" /* MALIGNANT NEO LARYNX NOS */
"1620 " = "1" /* MALIGNANT NEO TRACHEA */
"1622 " = "1" /* MALIG NEO MAIN BRONCHUS */
"1623 " = "1" /* MAL NEO UPPER LOBE LUNG */
"1624 " = "1" /* MAL NEO MIDDLE LOBE LUNG */
"1625 " = "1" /* MAL NEO LOWER LOBE LUNG */
"1628 " = "1" /* MAL NEO BRONCH/LUNG NEC */
"1629 " = "1" /* MAL NEO BRONCH/LUNG NOS */
"1630 " = "1" /* MAL NEO PARIETAL PLEURA */
"1631 " = "1" /* MAL NEO VISCERAL PLEURA */
"1638 " = "1" /* MALIG NEOPL PLEURA NEC */
"1639 " = "1" /* MALIG NEOPL PLEURA NOS */
"1640 " = "1" /* MALIGNANT NEOPL THYMUS */
"1641 " = "1" /* MALIGNANT NEOPL HEART */
"1642 " = "1" /* MAL NEO ANT MEDIASTINUM */
"1643 " = "1" /* MAL NEO POST MEDIASTINUM */
"1648 " = "1" /* MAL NEO MEDIASTINUM NEC */
"1649 " = "1" /* MAL NEO MEDIASTINUM NOS */
"1650 " = "1" /* MAL NEO UPPER RESP NOS */
"1658 " = "1" /* MAL NEO THORAX/RESP NEC */
"1659 " = "1" /* MAL NEO RESP SYSTEM NOS */
"1700 " = "1" /* MAL NEO SKULL/FACE BONE */
"1701 " = "1" /* MALIGNANT NEO MANDIBLE */
"1702 " = "1" /* MALIG NEO VERTEBRAE */
"1703 " = "1" /* MAL NEO RIBS/STERN/CLAV */
"1704 " = "1" /* MAL NEO LONG BONES ARM */
"1705 " = "1" /* MAL NEO BONES WRIST/HAND */
"1706 " = "1" /* MAL NEO PELVIC GIRDLE */
"1707 " = "1" /* MAL NEO LONG BONES LEG */
"1708 " = "1" /* MAL NEO BONES ANKLE/FOOT */
"1709 " = "1" /* MALIG NEOPL BONE NOS */
"1710 " = "1" /* MAL NEO SOFT TISSUE HEAD */
"1712 " = "1" /* MAL NEO SOFT TISSUE ARM */
"1713 " = "1" /* MAL NEO SOFT TISSUE LEG */
"1714 " = "1" /* MAL NEO SOFT TIS THORAX */
"1715 " = "1" /* MAL NEO SOFT TIS ABDOMEN */
"1716 " = "1" /* MAL NEO SOFT TIS PELVIS */
"1717 " = "1" /* MAL NEOPL TRUNK NOS */
"1718 " = "1" /* MAL NEO SOFT TISSUE NEC */
"1719 " = "1" /* MAL NEO SOFT TISSUE NOS */
"1720 " = "1" /* MALIG MELANOMA LIP */
"1721 " = "1" /* MALIG MELANOMA EYELID */
"1722 " = "1" /* MALIG MELANOMA EAR */
"1723 " = "1" /* MAL MELANOM FACE NEC NOS */
"1724 " = "1" /* MAL MELANOMA SCALP/NECK */
"1725 " = "1" /* MALIG MELANOMA TRUNK */
"1726 " = "1" /* MALIG MELANOMA ARM */
"1727 " = "1" /* MALIG MELANOMA LEG */
"1728 " = "1" /* MALIG MELANOMA SKIN NEC */
"1729 " = "1" /* MALIG MELANOMA SKIN NOS */
"1740 " = "1" /* MALIG NEO NIPPLE */
"1741 " = "1" /* MAL NEO BREAST-CENTRAL */
"1742 " = "1" /* MAL NEO BREAST UP-INNER */
"1743 " = "1" /* MAL NEO BREAST LOW-INNER */
"1744 " = "1" /* MAL NEO BREAST UP-OUTER */
"1745 " = "1" /* MAL NEO BREAST LOW-OUTER */
"1746 " = "1" /* MAL NEO BREAST-AXILLARY */
"1748 " = "1" /* MALIGN NEOPL BREAST NEC */
"1749 " = "1" /* MALIGN NEOPL BREAST NOS */
"1750 " = "1" /* MAL NEO MALE NIPPLE */
"1759 " = "1" /* MAL NEO MALE BREAST NEC */
"1760 " = "1" /* SKIN - KAPOSIS SARCOMA */
"1761 " = "1" /* SFT TISUE - KPSIS SRCMA */
"1762 " = "1" /* PALATE - KPSIS SARCOMA */
"1763 " = "1" /* GI SITES - KPSIS SRCOMA */
"1764 " = "1" /* LUNG - KAPOSIS SARCOMA */
"1765 " = "1" /* LYM NDS - KPSIS SARCOMA */
"1768 " = "1" /* SPF STS - KPSIS SARCOMA */
"1769 " = "1" /* KAPOSIS SARCOMA NOS */
"179  " = "1" /* MALIG NEOPL UTERUS NOS */
"1800 " = "1" /* MALIG NEO ENDOCERVIX */
"1801 " = "1" /* MALIG NEO EXOCERVIX */
"1808 " = "1" /* MALIG NEO CERVIX NEC */
"1809 " = "1" /* MAL NEO CERVIX UTERI NOS */
"181  " = "1" /* MALIGNANT NEOPL PLACENTA */
"1820 " = "1" /* MALIG NEO CORPUS UTERI */
"1821 " = "1" /* MAL NEO UTERINE ISTHMUS */
"1828 " = "1" /* MAL NEO BODY UTERUS NEC */
"1830 " = "1" /* MALIGN NEOPL OVARY */
"1832 " = "1" /* MAL NEO FALLOPIAN TUBE */
"1833 " = "1" /* MAL NEO BROAD LIGAMENT */
"1834 " = "1" /* MALIG NEO PARAMETRIUM */
"1835 " = "1" /* MAL NEO ROUND LIGAMENT */
"1838 " = "1" /* MAL NEO ADNEXA NEC */
"1839 " = "1" /* MAL NEO ADNEXA NOS */
"1840 " = "1" /* MALIGN NEOPL VAGINA */
"1841 " = "1" /* MAL NEO LABIA MAJORA */
"1842 " = "1" /* MAL NEO LABIA MINORA */
"1843 " = "1" /* MALIGN NEOPL CLITORIS */
"1844 " = "1" /* MALIGN NEOPL VULVA NOS */
"1848 " = "1" /* MAL NEO FEMALE GENIT NEC */
"1849 " = "1" /* MAL NEO FEMALE GENIT NOS */
"185  " = "1" /* MALIGN NEOPL PROSTATE */
"1860 " = "1" /* MAL NEO UNDESCEND TESTIS */
"1869 " = "1" /* MALIG NEO TESTIS NEC */
"1871 " = "1" /* MALIGN NEOPL PREPUCE */
"1872 " = "1" /* MALIG NEO GLANS PENIS */
"1873 " = "1" /* MALIG NEO PENIS BODY */
"1874 " = "1" /* MALIG NEO PENIS NOS */
"1875 " = "1" /* MALIG NEO EPIDIDYMIS */
"1876 " = "1" /* MAL NEO SPERMATIC CORD */
"1877 " = "1" /* MALIGN NEOPL SCROTUM */
"1878 " = "1" /* MAL NEO MALE GENITAL NEC */
"1879 " = "1" /* MAL NEO MALE GENITAL NOS */
"1880 " = "1" /* MAL NEO BLADDER-TRIGONE */
"1881 " = "1" /* MAL NEO BLADDER-DOME */
"1882 " = "1" /* MAL NEO BLADDER-LATERAL */
"1883 " = "1" /* MAL NEO BLADDER-ANTERIOR */
"1884 " = "1" /* MAL NEO BLADDER-POST */
"1885 " = "1" /* MAL NEO BLADDER NECK */
"1886 " = "1" /* MAL NEO URETERIC ORIFICE */
"1887 " = "1" /* MALIG NEO URACHUS */
"1888 " = "1" /* MALIG NEO BLADDER NEC */
"1889 " = "1" /* MALIG NEO BLADDER NOS */
"1890 " = "1" /* MALIG NEOPL KIDNEY */
"1891 " = "1" /* MALIG NEO RENAL PELVIS */
"1892 " = "1" /* MALIGN NEOPL URETER */
"1893 " = "1" /* MALIGN NEOPL URETHRA */
"1894 " = "1" /* MAL NEO PARAURETHRAL */
"1898 " = "1" /* MAL NEO URINARY NEC */
"1899 " = "1" /* MAL NEO URINARY NOS */
"1900 " = "1" /* MALIGN NEOPL EYEBALL */
"1901 " = "1" /* MALIGN NEOPL ORBIT */
"1902 " = "1" /* MAL NEO LACRIMAL GLAND */
"1903 " = "1" /* MAL NEO CONJUNCTIVA */
"1904 " = "1" /* MALIGN NEOPL CORNEA */
"1905 " = "1" /* MALIGN NEOPL RETINA */
"1906 " = "1" /* MALIGN NEOPL CHOROID */
"1907 " = "1" /* MAL NEO LACRIMAL DUCT */
"1908 " = "1" /* MALIGN NEOPL EYE NEC */
"1909 " = "1" /* MALIGN NEOPL EYE NOS */
"1910 " = "1" /* MALIGN NEOPL CEREBRUM */
"1911 " = "1" /* MALIG NEO FRONTAL LOBE */
"1912 " = "1" /* MAL NEO TEMPORAL LOBE */
"1913 " = "1" /* MAL NEO PARIETAL LOBE */
"1914 " = "1" /* MAL NEO OCCIPITAL LOBE */
"1915 " = "1" /* MAL NEO CEREB VENTRICLE */
"1916 " = "1" /* MAL NEO CEREBELLUM NOS */
"1917 " = "1" /* MAL NEO BRAIN STEM */
"1918 " = "1" /* MALIG NEO BRAIN NEC */
"1919 " = "1" /* MALIG NEO BRAIN NOS */
"1920 " = "1" /* MAL NEO CRANIAL NERVES */
"1921 " = "1" /* MAL NEO CEREBRAL MENING */
"1922 " = "1" /* MAL NEO SPINAL CORD */
"1923 " = "1" /* MAL NEO SPINAL MENINGES */
"1928 " = "1" /* MAL NEO NERVOUS SYST NEC */
"1929 " = "1" /* MAL NEO NERVOUS SYST NOS */
"193  " = "1" /* MALIGN NEOPL THYROID */
"1940 " = "1" /* MALIGN NEOPL ADRENAL */
"1941 " = "1" /* MALIG NEO PARATHYROID */
"1943 " = "1" /* MALIG NEO PITUITARY */
"1944 " = "1" /* MALIGN NEO PINEAL GLAND */
"1945 " = "1" /* MAL NEO CAROTID BODY */
"1946 " = "1" /* MAL NEO PARAGANGLIA NEC */
"1948 " = "1" /* MAL NEO ENDOCRINE NEC */
"1949 " = "1" /* MAL NEO ENDOCRINE NOS */
"1950 " = "1" /* MAL NEO HEAD/FACE/NECK */
"1951 " = "1" /* MALIGN NEOPL THORAX */
"1952 " = "1" /* MALIG NEO ABDOMEN */
"1953 " = "1" /* MALIGN NEOPL PELVIS */
"1954 " = "1" /* MALIGN NEOPL ARM */
"1955 " = "1" /* MALIGN NEOPL LEG */
"1958 " = "1" /* MALIG NEO SITE NEC */
"1960 " = "1" /* MAL NEO LYMPH-HEAD/NECK */
"1961 " = "1" /* MAL NEO LYMPH-INTRATHOR */
"1962 " = "1" /* MAL NEO LYMPH INTRA-ABD */
"1963 " = "1" /* MAL NEO LYMPH-AXILLA/ARM */
"1965 " = "1" /* MAL NEO LYMPH-INGUIN/LEG */
"1966 " = "1" /* MAL NEO LYMPH-INTRAPELV */
"1968 " = "1" /* MAL NEO LYMPH NODE-MULT */
"1969 " = "1" /* MAL NEO LYMPH NODE NOS */
"1970 " = "1" /* SECONDARY MALIG NEO LUNG */
"1971 " = "1" /* SEC MAL NEO MEDIASTINUM */
"1972 " = "1" /* SECOND MALIG NEO PLEURA */
"1973 " = "1" /* SEC MALIG NEO RESP NEC */
"1974 " = "1" /* SEC MALIG NEO SM BOWEL */
"1975 " = "1" /* SEC MALIG NEO LG BOWEL */
"1976 " = "1" /* SEC MAL NEO PERITONEUM */
"1977 " = "1" /* SECOND MALIG NEO LIVER */
"1978 " = "1" /* SEC MAL NEO GI NEC */
"1980 " = "1" /* SECOND MALIG NEO KIDNEY */
"1981 " = "1" /* SEC MALIG NEO URIN NEC */
"1982 " = "1" /* SECONDARY MALIG NEO SKIN */
"1983 " = "1" /* SEC MAL NEO BRAIN/SPINE */
"1984 " = "1" /* SEC MALIG NEO NERVE NEC */
"1985 " = "1" /* SECONDARY MALIG NEO BONE */
"1986 " = "1" /* SECOND MALIG NEO OVARY */
"1987 " = "1" /* SECOND MALIG NEO ADRENAL */
"19881" = "1" /* SECOND MALIG NEO BREAST */
"19882" = "1" /* SECOND MALIG NEO GENITAL */
"19889" = "1" /* SECONDARY MALIG NEO NEC */
"1990 " = "1" /* MALIG NEO DISSEMINATED */
"1991 " = "1" /* MALIGNANT NEOPLASM NOS */
"20100" = "1" /* HDGK PRG UNSP XTRNDL ORG */
"20101" = "1" /* HODGKINS PARAGRAN HEAD */
"20102" = "1" /* HODGKINS PARAGRAN THORAX */
"20103" = "1" /* HODGKINS PARAGRAN ABDOM */
"20104" = "1" /* HODGKINS PARAGRAN AXILLA */
"20105" = "1" /* HODGKINS PARAGRAN INGUIN */
"20106" = "1" /* HODGKINS PARAGRAN PELVIC */
"20107" = "1" /* HODGKINS PARAGRAN SPLEEN */
"20108" = "1" /* HODGKINS PARAGRAN MULT */
"20110" = "1" /* HDGK GRN UNSP XTRNDL ORG */
"20111" = "1" /* HODGKINS GRANULOM HEAD */
"20112" = "1" /* HODGKINS GRANULOM THORAX */
"20113" = "1" /* HODGKINS GRANULOM ABDOM */
"20114" = "1" /* HODGKINS GRANULOM AXILLA */
"20115" = "1" /* HODGKINS GRANULOM INGUIN */
"20116" = "1" /* HODGKINS GRANULOM PELVIC */
"20117" = "1" /* HODGKINS GRANULOM SPLEEN */
"20118" = "1" /* HODGKINS GRANULOM MULT */
"20120" = "1" /* HDGK SRC UNSP XTRNDL ORG */
"20121" = "1" /* HODGKINS SARCOMA HEAD */
"20122" = "1" /* HODGKINS SARCOMA THORAX */
"20123" = "1" /* HODGKINS SARCOMA ABDOM */
"20124" = "1" /* HODGKINS SARCOMA AXILLA */
"20125" = "1" /* HODGKINS SARCOMA INGUIN */
"20126" = "1" /* HODGKINS SARCOMA PELVIC */
"20127" = "1" /* HODGKINS SARCOMA SPLEEN */
"20128" = "1" /* HODGKINS SARCOMA MULT */
"20140" = "1" /* LYM-HST UNSP XTRNDL ORGN */
"20141" = "1" /* HODG LYMPH-HISTIO HEAD */
"20142" = "1" /* HODG LYMPH-HISTIO THORAX */
"20143" = "1" /* HODG LYMPH-HISTIO ABDOM */
"20144" = "1" /* HODG LYMPH-HISTIO AXILLA */
"20145" = "1" /* HODG LYMPH-HISTIO INGUIN */
"20146" = "1" /* HODG LYMPH-HISTIO PELVIC */
"20147" = "1" /* HODG LYMPH-HISTIO SPLEEN */
"20148" = "1" /* HODG LYMPH-HISTIO MULT */
"20150" = "1" /* NDR SCLR UNSP XTRNDL ORG */
"20151" = "1" /* HODG NODUL SCLERO HEAD */
"20152" = "1" /* HODG NODUL SCLERO THORAX */
"20153" = "1" /* HODG NODUL SCLERO ABDOM */
"20154" = "1" /* HODG NODUL SCLERO AXILLA */
"20155" = "1" /* HODG NODUL SCLERO INGUIN */
"20156" = "1" /* HODG NODUL SCLERO PELVIC */
"20157" = "1" /* HODG NODUL SCLERO SPLEEN */
"20158" = "1" /* HODG NODUL SCLERO MULT */
"20160" = "1" /* MXD CELR UNSP XTRNDL ORG */
"20161" = "1" /* HODGKINS MIX CELL HEAD */
"20162" = "1" /* HODGKINS MIX CELL THORAX */
"20163" = "1" /* HODGKINS MIX CELL ABDOM */
"20164" = "1" /* HODGKINS MIX CELL AXILLA */
"20165" = "1" /* HODGKINS MIX CELL INGUIN */
"20166" = "1" /* HODGKINS MIX CELL PELVIC */
"20167" = "1" /* HODGKINS MIX CELL SPLEEN */
"20168" = "1" /* HODGKINS MIX CELL MULT */
"20170" = "1" /* LYM DPLT UNSP XTRNDL ORG */
"20171" = "1" /* HODG LYMPH DEPLET HEAD */
"20172" = "1" /* HODG LYMPH DEPLET THORAX */
"20173" = "1" /* HODG LYMPH DEPLET ABDOM */
"20174" = "1" /* HODG LYMPH DEPLET AXILLA */
"20175" = "1" /* HODG LYMPH DEPLET INGUIN */
"20176" = "1" /* HODG LYMPH DEPLET PELVIC */
"20177" = "1" /* HODG LYMPH DEPLET SPLEEN */
"20178" = "1" /* HODG LYMPH DEPLET MULT */
"20190" = "1" /* HDGK DIS UNSP XTRNDL ORG */
"20191" = "1" /* HODGKINS DIS NOS HEAD */
"20192" = "1" /* HODGKINS DIS NOS THORAX */
"20193" = "1" /* HODGKINS DIS NOS ABDOM */
"20194" = "1" /* HODGKINS DIS NOS AXILLA */
"20195" = "1" /* HODGKINS DIS NOS INGUIN */
"20196" = "1" /* HODGKINS DIS NOS PELVIC */
"20197" = "1" /* HODGKINS DIS NOS SPLEEN */
"20198" = "1" /* HODGKINS DIS NOS MULT */
"20200" = "1" /* NDLR LYM UNSP XTRNDL ORG */
"20201" = "1" /* NODULAR LYMPHOMA HEAD */
"20202" = "1" /* NODULAR LYMPHOMA THORAX */
"20203" = "1" /* NODULAR LYMPHOMA ABDOM */
"20204" = "1" /* NODULAR LYMPHOMA AXILLA */
"20205" = "1" /* NODULAR LYMPHOMA INGUIN */
"20206" = "1" /* NODULAR LYMPHOMA PELVIC */
"20207" = "1" /* NODULAR LYMPHOMA SPLEEN */
"20208" = "1" /* NODULAR LYMPHOMA MULT */
"20210" = "1" /* MYCS FNG UNSP XTRNDL ORG */
"20211" = "1" /* MYCOSIS FUNGOIDES HEAD */
"20212" = "1" /* MYCOSIS FUNGOIDES THORAX */
"20213" = "1" /* MYCOSIS FUNGOIDES ABDOM */
"20214" = "1" /* MYCOSIS FUNGOIDES AXILLA */
"20215" = "1" /* MYCOSIS FUNGOIDES INGUIN */
"20216" = "1" /* MYCOSIS FUNGOIDES PELVIC */
"20217" = "1" /* MYCOSIS FUNGOIDES SPLEEN */
"20218" = "1" /* MYCOSIS FUNGOIDES MULT */
"20220" = "1" /* SZRY DIS UNSP XTRNDL ORG */
"20221" = "1" /* SEZARYS DISEASE HEAD */
"20222" = "1" /* SEZARYS DISEASE THORAX */
"20223" = "1" /* SEZARYS DISEASE ABDOM */
"20224" = "1" /* SEZARYS DISEASE AXILLA */
"20225" = "1" /* SEZARYS DISEASE INGUIN */
"20226" = "1" /* SEZARYS DISEASE PELVIC */
"20227" = "1" /* SEZARYS DISEASE SPLEEN */
"20228" = "1" /* SEZARYS DISEASE MULT */
"20230" = "1" /* MLG HIST UNSP XTRNDL ORG */
"20231" = "1" /* MAL HISTIOCYTOSIS HEAD */
"20232" = "1" /* MAL HISTIOCYTOSIS THORAX */
"20233" = "1" /* MAL HISTIOCYTOSIS ABDOM */
"20234" = "1" /* MAL HISTIOCYTOSIS AXILLA */
"20235" = "1" /* MAL HISTIOCYTOSIS INGUIN */
"20236" = "1" /* MAL HISTIOCYTOSIS PELVIC */
"20237" = "1" /* MAL HISTIOCYTOSIS SPLEEN */
"20238" = "1" /* MAL HISTIOCYTOSIS MULT */
"20240" = "1" /* LK RTCTL UNSP XTRNDL ORG */
"20241" = "1" /* HAIRY-CELL LEUKEM HEAD */
"20242" = "1" /* HAIRY-CELL LEUKEM THORAX */
"20243" = "1" /* HAIRY-CELL LEUKEM ABDOM */
"20244" = "1" /* HAIRY-CELL LEUKEM AXILLA */
"20245" = "1" /* HAIRY-CELL LEUKEM INGUIN */
"20246" = "1" /* HAIRY-CELL LEUKEM PELVIC */
"20247" = "1" /* HAIRY-CELL LEUKEM SPLEEN */
"20248" = "1" /* HAIRY-CELL LEUKEM MULT */
"20250" = "1" /* LTR-SIWE UNSP XTRNDL ORG */
"20251" = "1" /* LETTERER-SIWE DIS HEAD */
"20252" = "1" /* LETTERER-SIWE DIS THORAX */
"20253" = "1" /* LETTERER-SIWE DIS ABDOM */
"20254" = "1" /* LETTERER-SIWE DIS AXILLA */
"20255" = "1" /* LETTERER-SIWE DIS INGUIN */
"20256" = "1" /* LETTERER-SIWE DIS PELVIC */
"20257" = "1" /* LETTERER-SIWE DIS SPLEEN */
"20258" = "1" /* LETTERER-SIWE DIS MULT */
"20260" = "1" /* MLG MAST UNSP XTRNDL ORG */
"20261" = "1" /* MAL MASTOCYTOSIS HEAD */
"20262" = "1" /* MAL MASTOCYTOSIS THORAX */
"20263" = "1" /* MAL MASTOCYTOSIS ABDOM */
"20264" = "1" /* MAL MASTOCYTOSIS AXILLA */
"20265" = "1" /* MAL MASTOCYTOSIS INGUIN */
"20266" = "1" /* MAL MASTOCYTOSIS PELVIC */
"20267" = "1" /* MAL MASTOCYTOSIS SPLEEN */
"20268" = "1" /* MAL MASTOCYTOSIS MULT */
"20280" = "1" /* OTH LYMP UNSP XTRNDL ORG */
"20281" = "1" /* LYMPHOMAS NEC HEAD */
"20282" = "1" /* LYMPHOMAS NEC THORAX */
"20283" = "1" /* LYMPHOMAS NEC ABDOM */
"20284" = "1" /* LYMPHOMAS NEC AXILLA */
"20285" = "1" /* LYMPHOMAS NEC INGUIN */
"20286" = "1" /* LYMPHOMAS NEC PELVIC */
"20287" = "1" /* LYMPHOMAS NEC SPLEEN */
"20288" = "1" /* LYMPHOMAS NEC MULT */
"20290" = "1" /* UNSP LYM UNSP XTRNDL ORG */
"20291" = "1" /* LYMPHOID MAL NEC HEAD */
"20292" = "1" /* LYMPHOID MAL NEC THORAX */
"20293" = "1" /* LYMPHOID MAL NEC ABDOM */
"20294" = "1" /* LYMPHOID MAL NEC AXILLA */
"20295" = "1" /* LYMPHOID MAL NEC INGUIN */
"20296" = "1" /* LYMPHOID MAL NEC PELVIC */
"20297" = "1" /* LYMPHOID MAL NEC SPLEEN */
"20298" = "1" /* LYMPHOID MAL NEC MULT */
"2030 " = "1" /* MULTIPLE MYELOMA */
"20300" = "1" /* MULT MYELM W/O REMISSION */
"20301" = "1" /* MULT MYELM W REMISSION */
"2031 " = "1" /* PLASMA CELL LEUKEMIA */
"20310" = "1" /* PLSM CELL LEUK W/O RMSON */
"20311" = "1" /* PLSM CELL LEUK W RMSON */
"2038 " = "1" /* IMMUNOPROLIFERAT NEO NEC */
"20380" = "1" /* OTH IMNPRFL NPL W/O RMSN */
"20381" = "1" /* OTH IMNPRFL NPL W RMSN */
"2040 " = "1" /* ACUTE LYMPHOID LEUKEMIA */
"20400" = "1" /* ACT LYM LEUK W/O RMSION */
"20401" = "1" /* ACT LYM LEUK W RMSION */
"2041 " = "1" /* CHR LYMPHOID LEUKEMIA */
"20410" = "1" /* CHR LYM LEUK W/O RMSION */
"20411" = "1" /* CHR LYM LEUK W RMSION */
"2042 " = "1" /* SUBAC LYMPHOID LEUKEMIA */
"20420" = "1" /* SBAC LYM LEUK W/O RMSION */
"20421" = "1" /* SBAC LYM LEUK W RMSION */
"2048 " = "1" /* LYMPHOID LEUKEMIA NEC */
"20480" = "1" /* OTH LYM LEUK W/O RMSION */
"20481" = "1" /* OTH LYM LEUK W RMSION */
"2049 " = "1" /* LYMPHOID LEUKEMIA NOS */
"20490" = "1" /* UNS LYM LEUK W/O RMSION */
"20491" = "1" /* UNS LYM LEUK W RMSION */
"2386 " = "1" /* NEOPLASM OF UNCERTAIN BEHAVIOR OF OTHER AND UNSPECIFIED SITES AND TISSUES, PLASMA CELLS */
"2733 " = "1" /* DISORDERS OF PLASMA PROTEIN METABOLISM-MACROGLOBULINEMIA */
OTHER  = "0" ;

/* STRATIFY BY: INTERMEDIATE RISK GROUP */
/* ICD-9-CM DIAGNOSIS CODES: */

/* HEMOPHILIA */

VALUE $HEMOPHD
"2860" = "1" /* CONG FACTOR VIII DIORD */
"2861" = "1" /* CONG FACTOR IX DISORDER */
"2862" = "1" /* CONG FACTOR XI DISORDER */
"2863" = "1" /* CONG DEF CLOT FACTOR NEC */
"2864" = "1" /* VON WILLEBRAND'S DISEASE */
OTHER  = "0" ;


 /* -------------------------------- */
 /* TRANSFUSION REACTION             */
 /*   PROVIDER INDICATOR / PDI # 13  */
 /*   AREA     INDICATOR / PSI # TBD */
 /* -------------------------------- */

 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $TRANFID
"9996"  = "1" /* ABO INCOMPATIBILITY REACTION */
"9997"  = "1" /* RH INCOMPATIBILITY REACTION */
"E8760" = "1" /* MISMATCHED BLOOD IN TRANSFUSION */
OTHER   = "0" ;


 /* ---------------------------------------------- */
 /* Asthma rate (ACSAST)                           */
 /*   PDI #14                                      */
 /* ---------------------------------------------- */

 /* Asthma                    */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSASTD
'49300' = "1"  /* EXT ASTHMA W/O STAT ASTH */
'49301' = "1"  /* EXT ASTHMA W STATUS ASTH */
'49302' = "1"  /* EXT ASTHMA W ACUTE EXAC */
'49310' = "1"  /* INT ASTHMA W/O STAT ASTH */
'49311' = "1"  /* INT ASTHMA W STATUS ASTH */
'49312' = "1"  /* INT ASTHMA W ACUTE EXAC */
'49320' = "1"  /* CH OB ASTH W/O STAT ASTH */
'49321' = "1"  /* CH OB ASTHMA W STAT ASTH */
'49322' = "1"  /* CH OBS ASTH W ACUTE EXAC */
'49381' = "1"  /* EXERCSE IND BRONCHOSPASM */
'49382' = "1"  /* COUGH VARIANT ASTHMA */
'49390' = "1"  /* ASTHMA W/O STATUS ASTHM */
'49391' = "1"  /* ASTHMA W STATUS ASTHMAT */
'49392' = "1"  /* ASTHMA W ACUTE EXACERBTN */
OTHER   = "0" ;

 /* Exclude: CYSTIC FIBROSIS      */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSCYFD
'27700' = "1"  /* CYSTIC FIBROS W/O ILEUS */
'27701' = "1"  /* CYSTIC FIBROS W ILEUS */
'27702' = "1"  /* CYSTIC FIBROS W PUL MAN */
'27703' = "1"  /* CYSTIC FIBROSIS  W GI MAN */
'27709' = "1"  /* CYSTIC FIBROSIS NEC*/
OTHER   = "0" ;

 /* EXCLUDE: CYSTIC FIBROSIS AND ANOMALIES OF RESPIRATORY SYSTEM */
 /* ICD-9-CM DIAGNOSIS CODES */

VALUE $RESPAN
'27700' = 1  /* CYSTIC FIBROS W/O ILEUS */
'27701' = 1  /* CYSTIC FIBROS W ILEUS */
'27702' = 1  /* CYSTIC FIBROS W PUL MAN */
'27703' = 1  /* CYSTIC FIBROSIS  W GI MAN */
'27709' = 1  /* CYSTIC FIBROSIS NEC */
'74721' = 1  /* ANOMALIES OF AORTIC ARCH */
'7483 ' = 1  /* LARYNGOTRACH ANOMALY NEC */
'7484 ' = 1  /* CONGENITAL CYSTIC LUNG */
'7485 ' = 1  /* AGENESIS OF LUNG */
'74860' = 1  /* LUNG ANOMALY NOS */
'74861' = 1  /* CONGEN BRONCHIECTASIS */
'74869' = 1  /* LUNG ANOMALY NEC */
'7488 ' = 1  /* RESPIRATORY ANOMALY NEC */
'7489 ' = 1  /* RESPIRATORY ANOMALY NOS */
'7503 ' = 1  /* CONG ESOPH FISTULA/ATRES */
'7593 ' = 1  /* SITUS INVERSUS */
'7707 ' = 1  /* PERINATAL CHR RESP DIS*/
OTHER   = 0;


 /* ---------------------------------------------- */
 /* Diabetes short term complication rate (ACDIAS) */
 /*   PDI #15                                      */
 /* ---------------------------------------------- */

 /* Diabetes with Short Term Complications */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACDIASD
'25010' = "1"  /* DM KETO T2, DM CONT */
'25011' = "1"  /* DM KETO T1, DM CONT */
'25012' = "1"  /* DM KETO T2, DM UNCONT */
'25013' = "1"  /* DM KETO T1, DM UNCONT */
'25020' = "1"  /* DM W/ HYPROSM T2, DM CONT */
'25021' = "1"  /* DM W/ HYPROSM T1, DM CONT */
'25022' = "1"  /* DM W/ HYPROSM T2, DM UNCNT */
'25023' = "1"  /* DM W/ HYPROSM T1, DM UNCNT */
'25030' = "1"  /* DM COMA NEC TYP II, DM CNT */
'25031' = "1"  /* DM COMA NEC T1, DM CONT */
'25032' = "1"  /* DM COMA NEC T2, DM UNCONT */
'25033' = "1"  /* DM COMA NEC T1, DM UNCONT */
OTHER   = "0" ;


 /* ---------------------------------------------- */
 /* Pediatric Gastroenteritis rate (ACPGAS)        */
 /*   PDI #16                                      */
 /* ---------------------------------------------- */

 /* Gastroenteritis */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACPGASD
'00861' = "1"  /* INTES INFEC ROTAVIRUS */
'00862' = "1"  /* INTES INFEC ADENOVIRUS */
'00863' = "1"  /* INT INF NORWALK VIRUS */
'00864' = "1"  /* INT INF OTH SML RND VRUS */
'00865' = "1"  /* INTES INFEC CALCIVIRUS */
'00866' = "1"  /* INTES INFEC ASTROVIRUS */
'00867' = "1"  /* INT INF ENTEROVIRUS NEC */
'00869' = "1"  /* ENTERITIS NOS  */
'0088 ' = "1"  /* VIRAL ENTERITIS NOS */
'0090 ' = "1"  /* INFECTIOUS ENTERITIS NOS */
'0091 ' = "1"  /* ENTERITIS OF INFECT ORIG */
'0092 ' = "1"  /* INFECTIOUS DIARRHEA NOS */
'0093 ' = "1"  /* DIARRHEA OF INFECT ORIG */
'5589 ' = "1"  /* NONINF GASTROENTERIT NEC */
OTHER   = "0" ;

 /* Dehydration */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSDEHD
'2765 ' = "1"  /* HYPOVOLEMIA */
'27650' = "1"  /* VOLUME DEPLETION NOS */    
'27651' = "1"  /* DEHYDRATION */             
'27652' = "1"  /* HYPOVOLEMIA */             
OTHER   = "0" ;

/* EXCLUDE: */
/* Gastrintestinal Abnormalities */
/* ICD-9-CM Diagnosis Codes: */

VALUE $ACGDISD
'5550 ' = "1"  /* REGIONAL ENTERITIS, SMALL INTESTINE */
'5551 ' = "1"  /* REGIONAL ENTERITIS, LARGE INTESTINE */
'5552 ' = "1"  /* REGIONAL ENTERITIS, SMALL INTESTINE WITH LARGE INTESTINE */
'5559 ' = "1"  /* REGIONAL ENTERITIS, UNSPECIFIED SITE */
'5560 ' = "1"  /* ULCERATIVE CHRONIC ENTEROCOLITIS */
'5561 ' = "1"  /* ULCERATIVE CHRONIC ILEOCOLITIS */
'5562 ' = "1"  /* ULCERATIVE CHRONIC PROCTITIS */
'5563 ' = "1"  /* ULCERATIVE CHRONIC PROCTOSIGMOIDITIS */
'5564 ' = "1"  /* PSEUDOPOLYPOSIS OF COLON */
'5565 ' = "1"  /* LEFT-SIDED ULCERATIVE CHRONIC COLITIS */
'5566 ' = "1"  /* UNIVERSAL ULCERATIVE CHRONIC COLITIS */
'5568 ' = "1"  /* OTHER ULCERATIVE COLITIS */
'5569 ' = "1"  /* ULCERATIVE COLITIS NOS */
'5581 ' = "1"  /* GASTROENTERITIS AND COLITIS DUE TO RADIATION */
'5582 ' = "1"  /* TOXIC GASTROENTERITIS AND COLITIS */
'5583 ' = "1"  /* ALLERGIC GASTROENTERITIS AND COLITIS */
'5790 ' = "1"  /* CELIAC DISEASE */
'5791 ' = "1"  /* TROPICAL SPRUE */
'5792 ' = "1"  /* BLIND LOOP SYNDROME */
'5793 ' = "1"  /* OTHER AND UNSPECIFIED POSTSURGICAL NONABSORPTION */
'5794 ' = "1"  /* PANCREATIC STEATORRHEA */
'5798 ' = "1"  /* OTHER SPECIFIED INTESTINAL MALABSORPTION */
'5799 ' = "1"  /* UNSPECIFIED INTESTINAL MALABSORPTION */
OTHER   = "0" ;

/* Bacterial Gastoenteritis  */
/* ICD-9-CM Diagnosis Codes: */

VALUE $ACBACGD
'0030 ' = "1"  /* SALMONELLA GASTROENTERITIS */
'0040 ' = "1"  /* SHIGELLA DYSENTERIAE */
'0041 ' = "1"  /* SHIGELLA FLEXNERI */
'0042 ' = "1"  /* SHIGELLA BOYDII */
'0043 ' = "1"  /* SHIGELLA SONNEI */
'0048 ' = "1"  /* OTHER SPECIFIED SHIGELLA INFECTIONS */
'0049 ' = "1"  /* SHIGELLOSIS, NOS */
'0050 ' = "1"  /* STAPHYLOCOCCAL FOOD POISONING */
'0051 ' = "1"  /* BOTULISM */
'0052 ' = "1"  /* FOOD POISONING DUE TO CLOSTRIDIUM PERFRINGENS  */
'0053 ' = "1"  /* FOOD POISONING DUE TO OTHER CLOSTRIDIA */
'0054 ' = "1"  /* FOOD POISONING DUE TO VIBRIO PARAHAEMOLYTICUS */
'0058 ' = "1"  /* OTHER BACTERIAL FOOD POISONING */
'00581' = "1"  /* FOOD POISONING DUE TO VIBRIO VULNIFICUS */
'00589' = "1"  /* OTHER BACTERIAL FOOD POISONING */
'0059 ' = "1"  /* FOOD POISONING NOS */
'0060 ' = "1"  /* ACUTE AMEBIC DYSENTERY WO MENTION OF ABSCESS */
'0061 ' = "1"  /* CHRONIC INTESTINAL AMEBIASIS WO MENTION OF ABSCESS */
'0062 ' = "1"  /* AMEBIC NONDYSENTERIC COLLITIS */
'0070 ' = "1"  /* BALANTIDIASIS */
'0071 ' = "1"  /* GIARDIASIS */
'0072 ' = "1"  /* COCCIDIOSIS */
'0073 ' = "1"  /* INTESTINAL TRICHOMONIASIS */
'0074 ' = "1"  /* CRYPTOSPORIDIOSIS */
'0075 ' = "1"  /* CYCLOSPORIASIS */
'0078 ' = "1"  /* OTHER SPECIFIED PROTOZOAL INTESTINAL DISEASES */
'0079 ' = "1"  /* UNSPECIFIED PROTOZOAL INTESTINAL DISEASE */
'0080 ' = "1"  /* ESCHERICHIA COLI */
'00800' = "1"  /* E. COLI NOS */
'00801' = "1"  /* ENTEROPATHOGENIC E. COLI */
'00802' = "1"  /* ENTEROTOXIGENIC E. COLI */
'00803' = "1"  /* ENTEROINVASIVE E. COLI */
'00804' = "1"  /* ENTEROHEMORRHAGE E. COLI */
'00809' = "1"  /* OTHER INTESTINAL E. COLI INFECTIONS */
'0081 ' = "1"  /* ARIZONA GROUP OF PARACOLON BACILLI */
'0082 ' = "1"  /* AEROBACTER AEROGENES */
'0083 ' = "1"  /* PROTEUS  */
'0084 ' = "1"  /* OTHER SPECIFIED BACTERIA  */
'00841' = "1"  /* OTHER SPECIFIED BACTERIA, STAPHYLOCOCCUS */
'00842' = "1"  /* OTHER SPECIFIED BACTERIA, PSEUDOMONAS */
'00843' = "1"  /* OTHER SPECIFIED BACTERIA, CAMPYLOBACTER */
'00844' = "1"  /* OTHER SPECIFIED BACTERIA, YERSINIA ENTEROCOLITICA */
'00845' = "1"  /* OTHER SPECIFIED BACTERIA, CLOSTRIDIUM DIFFICILE */
'00846' = "1"  /* OTHER SPECIFIED BACTERIA, OTHER ANAEROBES */
'00847' = "1"  /* OTHER SPECIFIED BACTERIA, OTHER GRAM-NEGATIVE BACTERIA */
'00849' = "1"  /* OTHER SPECIFIED BACTERIA, OTHER */
'0085 ' = "1"  /* BACTERIAL ENTERITIS, NOS */
'11285' = "1"  /* CANDIDAL ENTERITIS */
OTHER   = "0" ;


 /* ---------------------------------------------- */
 /* Perforated Appendix rate (ACSAPP)              */
 /*   PDI #17                                      */
 /* ---------------------------------------------- */

 /* Perforated Appendix (Outcome of Interest) */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSAPPD
'5400 ' = "1"  /* AC APPEND W PERITONITIS */
'5401 ' = "1"  /* ABSCESS OF APPENDIX */
OTHER   = "0" ;

 /* Appendicitis (Population at Risk) */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSAP2D
'5400 ' = "1"  /* AC APPEND W PERITONITIS */
'5401 ' = "1"  /* ABSCESS OF APPENDIX */
'5409 ' = "1"  /* ACUTE APPENDICITIS NOS */
'541  ' = "1"  /* APPENDICITIS NOS */
OTHER   = "0" ;


 /* ---------------------------------------------- */
 /* Urinary Infection rate (ACSUTI)                */
 /*   PDI #18                                      */
 /* ---------------------------------------------- */

 /* Urinary Infection */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSUTID
'59010' = "1"  /* AC PYELONEPHRITIS NOS */
'59011' = "1"  /* AC PYELONEPHR W MED NECR */
'5902 ' = "1"  /* RENAL/PERIRENAL ABSCESS */
'5903 ' = "1"  /* PYELOURETERITIS CYSTICA */
'59080' = "1"  /* PYELONEPHRITIS NOS */
'59081' = "1"  /* PYELONEPHRIT IN OTH DIS */
'5909 ' = "1"  /* INFECTION OF KIDNEY NOS */
'5950 ' = "1"  /* ACUTE CYSTITIS */
'5959 ' = "1"  /* CYSTITIS NOS */
'5990 ' = "1"  /* URIN TRACT INFECTION NOS */
OTHER   = "0" ;

 /* EXCLUDE: KIDNEY OR URINARY TRACT DISORDER */
 /* ICD-9-CM DIAGNOSIS CODES */

VALUE $KIDNEY
'59000' = 1  /* CHR PYELONEPHRITIS NOS */
'59001' = 1  /* CHR PYELONEPH W MED NECR */
'59370' = 1  /* VESCOURETRL RFLUX UNSPCF */
'59371' = 1  /* VESICOURETERAL REFLUX UNILTRL */
'59372' = 1  /* VESICOURETERAL REFLUX NPHT BLTRL */
'59373' = 1  /* VESICOURETERAL REFLUX W NPHT NOS */
'7530 ' = 1  /*  RENAL AGENESIS */
'75310' = 1  /* CYSTIC KIDNEY DISEAS NOS */
'75311' = 1  /* CONGENITAL RENAL CYST */
'75312' = 1  /* POLYCYSTIC KIDNEY NOS */
'75313' = 1  /* POLYCYST KID-AUTOSOM DOM */
'75314' = 1  /* POLYCYST KID-AUTOSOM REC */
'75315' = 1  /* RENAL DYSPLASIA */
'75316' = 1  /* MEDULLARY CYSTIC KIDNEY */
'75317' = 1  /* MEDULLARY SPONGE KIDNEY */
'75319' = 1  /* CYSTIC KIDNEY DISEAS NEC */
'75320' = 1  /* OBS DFCT REN PLV&URT NOS */
'75321' = 1  /* CONGEN OBST URTROPLV JNC */
'75322' = 1  /* CONG OBST URETEROVES JNC */
'75323' = 1  /* CONGENITAL URETEROCELE */
'75329' = 1  /* OBST DEF REN PLV&URT NEC */
'7533 ' = 1  /*  KIDNEY ANOMALY NEC */
'7534 ' = 1  /*  URETERAL ANOMALY NEC */
'7535 ' = 1  /*  EXSTROPHY OF URNIARY BLADDER */
'7536 ' = 1  /*  ATRESIA AND STENOSIS OF URETHRA AND BLADDER NECK */
'7538 ' = 1  /*  CYSTOURETHRAL ANOM NEC */
'7539 ' = 1  /*  URINARY ANOMALY NOS */
OTHER   = 0;


 * ----------------------------------------------------- ;
 * ---   AREA FORMATS     ------------------------------ ;
 * ---   TRANSLATES FIPS STATE AND COUNTY CODE (SSCCC)   ;
 * ---   TO MSA (METROPOLITAN STATISTICAL AREA)          ;
 * ----------------------------------------------------- ;

/* MODIFIED FIPS */

VALUE $M1AREA
'02013' = '02001'
'02016' = '02001'
'02020' = '02001'
'02050' = '02001'
'02060' = '02001'
'02068' = '02001'
'02070' = '02001'
'02090' = '02001'
'02100' = '02001'
'02110' = '02001'
'02122' = '02001'
'02130' = '02001'
'02150' = '02001'
'02164' = '02001'
'02170' = '02001'
'02180' = '02001'
'02185' = '02001'
'02188' = '02001'
'02201' = '02001'
'02220' = '02001'
'02232' = '02001'
'02240' = '02001'
'02261' = '02001'
'02270' = '02001'
'02280' = '02001'
'02282' = '02001'
'02290' = '02001'
'15005' = '15009'
'24510' = '24007'
'29510' = '29191'
'32510' = '32025'
'51515' = '51019'
'51520' = '51119'
'51530' = '51163'
'51540' = '51003'
'51560' = '51005'
'51570' = '51041'
'51580' = '51005'
'51590' = '51143'
'51595' = '51081'
'51600' = '51059'
'51610' = '51059'
'51620' = '51175'
'51630' = '51177'
'51640' = '51077'
'51660' = '51165'
'51670' = '51149'
'51678' = '51163'
'51680' = '51031'
'51683' = '51153'
'51685' = '51153'
'51690' = '51089'
'51710' = '51129'
'51720' = '51195'
'51730' = '51053'
'51735' = '51199'
'51740' = '51129'
'51750' = '51121'
'51760' = '51087'
'51770' = '51161'
'51775' = '51161'
'51780' = '51083'
'51790' = '51015'
'51800' = '51123'
'51820' = '51015'
'51830' = '51095'
'51840' = '51069'
;

/* OMB 1999 METRO AREA */

VALUE $M2AREA
'01001' = '5240 '
'01003' = '5160 '
'01009' = '1000 '
'01015' = '0450 '
'01033' = '2650 '
'01045' = '2180 '
'01051' = '5240 '
'01055' = '2880 '
'01069' = '2180 '
'01073' = '1000 '
'01077' = '2650 '
'01079' = '2030 '
'01081' = '0580 '
'01083' = '3440 '
'01089' = '3440 '
'01097' = '5160 '
'01101' = '5240 '
'01103' = '2030 '
'01113' = '1800 '
'01115' = '1000 '
'01117' = '1000 '
'01125' = '8600 '
'02020' = '0380 '
'04005' = '2620 '
'04013' = '6200 '
'04015' = '4120 '
'04019' = '8520 '
'04021' = '6200 '
'04027' = '9360 '
'05007' = '2580 '
'05031' = '3700 '
'05033' = '2720 '
'05035' = '4920 '
'05045' = '4400 '
'05069' = '6240 '
'05085' = '4400 '
'05091' = '8360 '
'05119' = '4400 '
'05125' = '4400 '
'05131' = '2720 '
'05143' = '2580 '
'06001' = '5775 '
'06007' = '1620 '
'06013' = '5775 '
'06017' = '6920 '
'06019' = '2840 '
'06029' = '0680 '
'06037' = '4480 '
'06039' = '2840 '
'06041' = '7360 '
'06047' = '4940 '
'06053' = '7120 '
'06055' = '8720 '
'06059' = '5945 '
'06061' = '6920 '
'06065' = '6780 '
'06067' = '6920 '
'06071' = '6780 '
'06073' = '7320 '
'06075' = '7360 '
'06077' = '8120 '
'06079' = '7460 '
'06081' = '7360 '
'06083' = '7480 '
'06085' = '7400 '
'06087' = '7485 '
'06089' = '6690 '
'06095' = '8720 '
'06097' = '7500 '
'06099' = '5170 '
'06101' = '9340 '
'06107' = '8780 '
'06111' = '8735 '
'06113' = '9270 '
'06115' = '9340 '
'08001' = '2080 '
'08005' = '2080 '
'08013' = '1125 '
'08031' = '2080 '
'08035' = '2080 '
'08041' = '1720 '
'08059' = '2080 '
'08069' = '2670 '
'08077' = '2995 '
'08101' = '6560 '
'08123' = '3060 '
'09001' = '5483 '
'09003' = '3283 '
'09007' = '3283 '
'09009' = '5483 '
'09011' = '5523 '
'09013' = '3283 '
'10001' = '2190 '
'10003' = '9160 '
'11001' = '8840 '
'12001' = '2900 '
'12005' = '6015 '
'12009' = '4900 '
'12011' = '2680 '
'12015' = '6580 '
'12019' = '3600 '
'12021' = '5345 '
'12031' = '3600 '
'12033' = '6080 '
'12035' = '2020 '
'12039' = '8240 '
'12053' = '8280 '
'12057' = '8280 '
'12069' = '5960 '
'12071' = '2700 '
'12073' = '8240 '
'12081' = '7510 '
'12083' = '5790 '
'12085' = '2710 '
'12086' = '5000 '
'12089' = '3600 '
'12091' = '2750 '
'12095' = '5960 '
'12097' = '5960 '
'12099' = '8960 '
'12101' = '8280 '
'12103' = '8280 '
'12105' = '3980 '
'12109' = '3600 '
'12111' = '2710 '
'12113' = '6080 '
'12115' = '7510 '
'12117' = '5960 '
'12127' = '2020 '
'13013' = '0520 '
'13015' = '0520 '
'13021' = '4680 '
'13029' = '7520 '
'13045' = '0520 '
'13047' = '1560 '
'13051' = '7520 '
'13053' = '1800 '
'13057' = '0520 '
'13059' = '0500 '
'13063' = '0520 '
'13067' = '0520 '
'13073' = '0600 '
'13077' = '0520 '
'13083' = '1560 '
'13089' = '0520 '
'13095' = '0120 '
'13097' = '0520 '
'13103' = '7520 '
'13113' = '0520 '
'13117' = '0520 '
'13121' = '0520 '
'13135' = '0520 '
'13145' = '1800 '
'13151' = '0520 '
'13153' = '4680 '
'13169' = '4680 '
'13177' = '0120 '
'13189' = '0600 '
'13195' = '0500 '
'13215' = '1800 '
'13217' = '0520 '
'13219' = '0500 '
'13223' = '0520 '
'13225' = '4680 '
'13227' = '0520 '
'13245' = '0600 '
'13247' = '0520 '
'13255' = '0520 '
'13289' = '4680 '
'13295' = '1560 '
'13297' = '0520 '
'15003' = '3320 '
'16001' = '1080 '
'16005' = '6340 '
'16027' = '1080 '
'17007' = '6880 '
'17019' = '1400 '
'17027' = '7040 '
'17031' = '1600 '
'17037' = '1600 '
'17043' = '1600 '
'17063' = '1600 '
'17073' = '1960 '
'17083' = '7040 '
'17089' = '1600 '
'17091' = '3740 '
'17093' = '1600 '
'17097' = '1600 '
'17111' = '1600 '
'17113' = '1040 '
'17115' = '2040 '
'17119' = '7040 '
'17129' = '7880 '
'17133' = '7040 '
'17141' = '6880 '
'17143' = '6120 '
'17161' = '1960 '
'17163' = '7040 '
'17167' = '7880 '
'17179' = '6120 '
'17197' = '1600 '
'17201' = '6880 '
'17203' = '6120 '
'18001' = '2760 '
'18003' = '2760 '
'18011' = '3480 '
'18019' = '4520 '
'18021' = '8320 '
'18023' = '3920 '
'18029' = '1640 '
'18033' = '2760 '
'18035' = '5280 '
'18039' = '2330 '
'18043' = '4520 '
'18057' = '3480 '
'18059' = '3480 '
'18061' = '4520 '
'18063' = '3480 '
'18067' = '3850 '
'18069' = '2760 '
'18081' = '3480 '
'18089' = '2960 '
'18095' = '3480 '
'18097' = '3480 '
'18105' = '1020 '
'18109' = '3480 '
'18115' = '1640 '
'18127' = '2960 '
'18129' = '2440 '
'18141' = '7800 '
'18143' = '4520 '
'18145' = '3480 '
'18157' = '3920 '
'18159' = '3850 '
'18163' = '2440 '
'18165' = '8320 '
'18167' = '8320 '
'18173' = '2440 '
'18179' = '2760 '
'18183' = '2760 '
'19013' = '8920 '
'19049' = '2120 '
'19061' = '2200 '
'19103' = '3500 '
'19113' = '1360 '
'19153' = '2120 '
'19155' = '5920 '
'19163' = '1960 '
'19181' = '2120 '
'19193' = '7720 '
'20015' = '9040 '
'20045' = '4150 '
'20079' = '9040 '
'20091' = '3760 '
'20103' = '3760 '
'20121' = '3760 '
'20173' = '9040 '
'20177' = '8440 '
'20209' = '3760 '
'21015' = '1640 '
'21017' = '4280 '
'21019' = '3400 '
'21029' = '4520 '
'21037' = '1640 '
'21043' = '3400 '
'21047' = '1660 '
'21049' = '4280 '
'21059' = '5990 '
'21067' = '4280 '
'21077' = '1640 '
'21081' = '1640 '
'21089' = '3400 '
'21101' = '2440 '
'21111' = '4520 '
'21113' = '4280 '
'21117' = '1640 '
'21151' = '4280 '
'21185' = '4520 '
'21191' = '1640 '
'21209' = '4280 '
'21239' = '4280 '
'22001' = '3880 '
'22005' = '0760 '
'22015' = '7680 '
'22017' = '7680 '
'22019' = '3960 '
'22033' = '0760 '
'22051' = '5560 '
'22055' = '3880 '
'22057' = '3350 '
'22063' = '0760 '
'22071' = '5560 '
'22073' = '5200 '
'22075' = '5560 '
'22079' = '0220 '
'22087' = '5560 '
'22089' = '5560 '
'22093' = '5560 '
'22095' = '5560 '
'22097' = '3880 '
'22099' = '3880 '
'22103' = '5560 '
'22109' = '3350 '
'22119' = '7680 '
'22121' = '0760 '
'23001' = '4243 '
'23005' = '6403 '
'23019' = '0733 '
'24001' = '1900 '
'24003' = '0720 '
'24005' = '0720 '
'24009' = '8840 '
'24013' = '0720 '
'24015' = '9160 '
'24017' = '8840 '
'24021' = '8840 '
'24025' = '0720 '
'24027' = '0720 '
'24031' = '8840 '
'24033' = '8840 '
'24035' = '0720 '
'24043' = '3180 '
'24510' = '0720 '
'25001' = '0743 '
'25003' = '6323 '
'25005' = '1123 '
'25009' = '1123 '
'25013' = '8003 '
'25015' = '8003 '
'25017' = '1123 '
'25021' = '1123 '
'25023' = '1123 '
'25025' = '1123 '
'25027' = '1123 '
'26005' = '3000 '
'26017' = '6960 '
'26021' = '0870 '
'26025' = '3720 '
'26037' = '4040 '
'26045' = '4040 '
'26049' = '2640 '
'26065' = '4040 '
'26075' = '3520 '
'26077' = '3720 '
'26081' = '3000 '
'26087' = '2160 '
'26091' = '0440 '
'26093' = '0440 '
'26099' = '2160 '
'26111' = '6960 '
'26115' = '2160 '
'26121' = '3000 '
'26125' = '2160 '
'26139' = '3000 '
'26145' = '6960 '
'26147' = '2160 '
'26159' = '3720 '
'26161' = '0440 '
'26163' = '2160 '
'27003' = '5120 '
'27009' = '6980 '
'27019' = '5120 '
'27025' = '5120 '
'27027' = '2520 '
'27037' = '5120 '
'27053' = '5120 '
'27055' = '3870 '
'27059' = '5120 '
'27109' = '6820 '
'27119' = '2985 '
'27123' = '5120 '
'27137' = '2240 '
'27139' = '5120 '
'27141' = '5120 '
'27145' = '6980 '
'27163' = '5120 '
'27171' = '5120 '
'28033' = '4920 '
'28035' = '3285 '
'28045' = '0920 '
'28047' = '0920 '
'28049' = '3560 '
'28059' = '0920 '
'28073' = '3285 '
'28089' = '3560 '
'28121' = '3560 '
'29003' = '7000 '
'29019' = '1740 '
'29021' = '7000 '
'29037' = '3760 '
'29043' = '7920 '
'29047' = '3760 '
'29049' = '3760 '
'29071' = '7040 '
'29077' = '7920 '
'29095' = '3760 '
'29097' = '3710 '
'29099' = '7040 '
'29107' = '3760 '
'29113' = '7040 '
'29145' = '3710 '
'29165' = '3760 '
'29177' = '3760 '
'29183' = '7040 '
'29189' = '7040 '
'29219' = '7040 '
'29225' = '7920 '
'29510' = '7040 '
'30013' = '3040 '
'30063' = '5140 '
'30111' = '0880 '
'31025' = '5920 '
'31043' = '7720 '
'31055' = '5920 '
'31109' = '4360 '
'31153' = '5920 '
'31177' = '5920 '
'32003' = '4120 '
'32023' = '4120 '
'32031' = '6720 '
'33011' = '1123 '
'33015' = '1123 '
'33017' = '1123 '
'34001' = '0560 '
'34003' = '0875 '
'34005' = '6160 '
'34007' = '6160 '
'34009' = '0560 '
'34011' = '8760 '
'34013' = '5640 '
'34015' = '6160 '
'34017' = '3640 '
'34019' = '5015 '
'34021' = '8480 '
'34023' = '5015 '
'34025' = '5190 '
'34027' = '5640 '
'34029' = '5190 '
'34031' = '0875 '
'34033' = '6160 '
'34035' = '5015 '
'34037' = '5640 '
'34039' = '5640 '
'34041' = '5640 '
'35001' = '0200 '
'35013' = '4100 '
'35028' = '7490 '
'35043' = '0200 '
'35049' = '7490 '
'35061' = '0200 '
'36001' = '0160 '
'36005' = '5600 '
'36007' = '0960 '
'36011' = '8160 '
'36013' = '3610 '
'36015' = '2335 '
'36027' = '2281 '
'36029' = '1280 '
'36037' = '6840 '
'36043' = '8680 '
'36047' = '5600 '
'36051' = '6840 '
'36053' = '8160 '
'36055' = '6840 '
'36057' = '0160 '
'36059' = '5380 '
'36061' = '5600 '
'36063' = '1280 '
'36065' = '8680 '
'36067' = '8160 '
'36069' = '6840 '
'36071' = '5660 '
'36073' = '6840 '
'36075' = '8160 '
'36079' = '5600 '
'36081' = '5600 '
'36083' = '0160 '
'36085' = '5600 '
'36087' = '5600 '
'36091' = '0160 '
'36093' = '0160 '
'36095' = '0160 '
'36103' = '5380 '
'36107' = '0960 '
'36113' = '2975 '
'36115' = '2975 '
'36117' = '6840 '
'36119' = '5600 '
'37001' = '3120 '
'37003' = '3290 '
'37019' = '9200 '
'37021' = '0480 '
'37023' = '3290 '
'37025' = '1520 '
'37027' = '3290 '
'37035' = '3290 '
'37037' = '6640 '
'37051' = '2560 '
'37053' = '5720 '
'37057' = '3120 '
'37059' = '3120 '
'37063' = '6640 '
'37065' = '6895 '
'37067' = '3120 '
'37069' = '6640 '
'37071' = '1520 '
'37081' = '3120 '
'37101' = '6640 '
'37109' = '1520 '
'37115' = '0480 '
'37119' = '1520 '
'37127' = '6895 '
'37129' = '9200 '
'37133' = '3605 '
'37135' = '6640 '
'37147' = '3150 '
'37151' = '3120 '
'37159' = '1520 '
'37169' = '3120 '
'37179' = '1520 '
'37183' = '6640 '
'37191' = '2980 '
'37197' = '3120 '
'38015' = '1010 '
'38017' = '2520 '
'38035' = '2985 '
'38059' = '1010 '
'39003' = '4320 '
'39007' = '1680 '
'39011' = '4320 '
'39013' = '9000 '
'39015' = '1640 '
'39017' = '3200 '
'39019' = '1320 '
'39023' = '2000 '
'39025' = '1640 '
'39029' = '9320 '
'39033' = '4800 '
'39035' = '1680 '
'39041' = '1840 '
'39045' = '1840 '
'39049' = '1840 '
'39051' = '8400 '
'39055' = '1680 '
'39057' = '2000 '
'39061' = '1640 '
'39081' = '8080 '
'39085' = '1680 '
'39087' = '3400 '
'39089' = '1840 '
'39093' = '1680 '
'39095' = '8400 '
'39097' = '1840 '
'39099' = '9320 '
'39103' = '1680 '
'39109' = '2000 '
'39113' = '2000 '
'39129' = '1840 '
'39133' = '0080 '
'39139' = '4800 '
'39151' = '1320 '
'39153' = '0080 '
'39155' = '9320 '
'39165' = '1640 '
'39167' = '6020 '
'39173' = '8400 '
'40017' = '5880 '
'40027' = '5880 '
'40031' = '4200 '
'40037' = '8560 '
'40047' = '2340 '
'40083' = '5880 '
'40087' = '5880 '
'40109' = '5880 '
'40113' = '8560 '
'40125' = '5880 '
'40131' = '8560 '
'40135' = '2720 '
'40143' = '8560 '
'40145' = '8560 '
'41003' = '1890 '
'41005' = '6440 '
'41009' = '6440 '
'41029' = '4890 '
'41039' = '2400 '
'41047' = '7080 '
'41051' = '6440 '
'41053' = '7080 '
'41067' = '6440 '
'41071' = '6440 '
'42003' = '6280 '
'42007' = '6280 '
'42011' = '6680 '
'42013' = '0280 '
'42017' = '6160 '
'42019' = '6280 '
'42021' = '3680 '
'42025' = '0240 '
'42027' = '8050 '
'42029' = '6160 '
'42037' = '7560 '
'42041' = '3240 '
'42043' = '3240 '
'42045' = '6160 '
'42049' = '2360 '
'42051' = '6280 '
'42069' = '7560 '
'42071' = '4000 '
'42075' = '3240 '
'42077' = '0240 '
'42079' = '7560 '
'42081' = '9140 '
'42085' = '7610 '
'42091' = '6160 '
'42095' = '0240 '
'42099' = '3240 '
'42101' = '6160 '
'42103' = '5660 '
'42111' = '3680 '
'42125' = '6280 '
'42129' = '6280 '
'42131' = '7560 '
'42133' = '9280 '
'44001' = '6483 '
'44003' = '6483 '
'44007' = '6483 '
'44009' = '6483 '
'45003' = '0600 '
'45007' = '3160 '
'45015' = '1440 '
'45019' = '1440 '
'45021' = '3160 '
'45035' = '1440 '
'45037' = '0600 '
'45041' = '2655 '
'45045' = '3160 '
'45051' = '5330 '
'45063' = '1760 '
'45077' = '3160 '
'45079' = '1760 '
'45083' = '3160 '
'45085' = '8140 '
'45091' = '1520 '
'46083' = '7760 '
'46099' = '7760 '
'46103' = '6660 '
'47001' = '3840 '
'47009' = '3840 '
'47019' = '3660 '
'47021' = '5360 '
'47023' = '3580 '
'47037' = '5360 '
'47043' = '5360 '
'47047' = '4920 '
'47065' = '1560 '
'47073' = '3660 '
'47093' = '3840 '
'47105' = '3840 '
'47113' = '3580 '
'47115' = '1560 '
'47125' = '1660 '
'47147' = '5360 '
'47149' = '5360 '
'47155' = '3840 '
'47157' = '4920 '
'47163' = '3660 '
'47165' = '5360 '
'47167' = '4920 '
'47171' = '3660 '
'47173' = '3840 '
'47179' = '3660 '
'47187' = '5360 '
'47189' = '5360 '
'48009' = '9080 '
'48021' = '0640 '
'48027' = '3810 '
'48029' = '7240 '
'48037' = '8360 '
'48039' = '1145 '
'48041' = '1260 '
'48055' = '0640 '
'48061' = '1240 '
'48071' = '3360 '
'48085' = '1920 '
'48091' = '7240 '
'48099' = '3810 '
'48113' = '1920 '
'48121' = '1920 '
'48135' = '5800 '
'48139' = '1920 '
'48141' = '2320 '
'48157' = '3360 '
'48167' = '2920 '
'48181' = '7640 '
'48183' = '4420 '
'48187' = '7240 '
'48199' = '0840 '
'48201' = '3360 '
'48203' = '4420 '
'48209' = '0640 '
'48213' = '1920 '
'48215' = '4880 '
'48221' = '2800 '
'48231' = '1920 '
'48245' = '0840 '
'48251' = '2800 '
'48257' = '1920 '
'48291' = '3360 '
'48303' = '4600 '
'48309' = '8800 '
'48329' = '5800 '
'48339' = '3360 '
'48355' = '1880 '
'48361' = '0840 '
'48367' = '2800 '
'48375' = '0320 '
'48381' = '0320 '
'48397' = '1920 '
'48409' = '1880 '
'48423' = '8640 '
'48439' = '2800 '
'48441' = '0040 '
'48451' = '7200 '
'48453' = '0640 '
'48459' = '4420 '
'48469' = '8750 '
'48473' = '3360 '
'48479' = '4080 '
'48485' = '9080 '
'48491' = '0640 '
'48493' = '7240 '
'49011' = '7160 '
'49025' = '2620 '
'49035' = '7160 '
'49049' = '6520 '
'49057' = '7160 '
'50007' = '1303 '
'50011' = '1303 '
'50013' = '1303 '
'51003' = '1540 '
'51009' = '4640 '
'51013' = '8840 '
'51019' = '4640 '
'51023' = '6800 '
'51031' = '4640 '
'51036' = '6760 '
'51041' = '6760 '
'51043' = '8840 '
'51047' = '8840 '
'51053' = '6760 '
'51059' = '8840 '
'51061' = '8840 '
'51065' = '1540 '
'51073' = '5720 '
'51075' = '6760 '
'51079' = '1540 '
'51085' = '6760 '
'51087' = '6760 '
'51093' = '5720 '
'51095' = '5720 '
'51099' = '8840 '
'51107' = '8840 '
'51115' = '5720 '
'51127' = '6760 '
'51143' = '1950 '
'51145' = '6760 '
'51149' = '6760 '
'51153' = '8840 '
'51161' = '6800 '
'51169' = '3660 '
'51177' = '8840 '
'51179' = '8840 '
'51187' = '8840 '
'51191' = '3660 '
'51199' = '5720 '
'51510' = '8840 '
'51515' = '4640 '
'51520' = '3660 '
'51540' = '1540 '
'51550' = '5720 '
'51570' = '6760 '
'51590' = '1950 '
'51600' = '8840 '
'51610' = '8840 '
'51630' = '8840 '
'51650' = '5720 '
'51670' = '6760 '
'51680' = '4640 '
'51683' = '8840 '
'51685' = '8840 '
'51700' = '5720 '
'51710' = '5720 '
'51730' = '6760 '
'51735' = '5720 '
'51740' = '5720 '
'51760' = '6760 '
'51770' = '6800 '
'51775' = '6800 '
'51800' = '5720 '
'51810' = '5720 '
'51830' = '5720 '
'53005' = '6740 '
'53011' = '6440 '
'53021' = '6740 '
'53029' = '7600 '
'53033' = '7600 '
'53035' = '1150 '
'53053' = '8200 '
'53061' = '7600 '
'53063' = '7840 '
'53067' = '5910 '
'53073' = '0860 '
'53077' = '9260 '
'54003' = '8840 '
'54009' = '8080 '
'54011' = '3400 '
'54029' = '8080 '
'54037' = '8840 '
'54039' = '1480 '
'54051' = '9000 '
'54057' = '1900 '
'54069' = '9000 '
'54079' = '1480 '
'54099' = '3400 '
'54107' = '6020 '
'55009' = '3080 '
'55015' = '0460 '
'55017' = '2290 '
'55025' = '4720 '
'55031' = '2240 '
'55035' = '2290 '
'55059' = '3800 '
'55063' = '3870 '
'55073' = '8940 '
'55079' = '5080 '
'55087' = '0460 '
'55089' = '5080 '
'55093' = '5120 '
'55101' = '6600 '
'55105' = '3620 '
'55109' = '5120 '
'55117' = '7620 '
'55131' = '5080 '
'55133' = '5080 '
'55139' = '0460 '
'56021' = '1580 '
'56025' = '1350 '
;

/* OMB 2003 METRO AREA */

VALUE $M3AREA
'01001' = '33860'
'01003' = '19300'
'01005' = '21640'
'01007' = '13820'
'01009' = '13820'
'01015' = '11500'
'01017' = '46740'
'01021' = '13820'
'01031' = '21460'
'01033' = '22520'
'01037' = '10760'
'01043' = '18980'
'01045' = '21460'
'01047' = '42820'
'01049' = '22840'
'01051' = '33860'
'01055' = '23460'
'01061' = '20020'
'01063' = '46220'
'01065' = '46220'
'01067' = '20020'
'01069' = '20020'
'01071' = '42460'
'01073' = '13820'
'01077' = '22520'
'01079' = '19460'
'01081' = '12220'
'01083' = '26620'
'01085' = '33860'
'01087' = '46260'
'01089' = '26620'
'01095' = '10700'
'01097' = '33660'
'01101' = '33860'
'01103' = '19460'
'01109' = '45980'
'01113' = '17980'
'01115' = '13820'
'01117' = '13820'
'01121' = '45180'
'01123' = '10760'
'01125' = '46220'
'01127' = '13820'
'02020' = '11260'
'02090' = '21820'
'02110' = '27940'
'02130' = '28540'
'02150' = '28980'
'02170' = '11260'
'04003' = '43420'
'04005' = '22380'
'04007' = '37740'
'04009' = '40940'
'04011' = '40940'
'04013' = '38060'
'04015' = '29420'
'04019' = '46060'
'04021' = '38060'
'04023' = '35700'
'04025' = '39140'
'04027' = '49740'
'05005' = '34260'
'05007' = '22220'
'05009' = '25460'
'05013' = '15780'
'05019' = '11660'
'05025' = '38220'
'05027' = '31620'
'05031' = '27860'
'05033' = '22900'
'05035' = '32820'
'05045' = '30780'
'05047' = '22900'
'05051' = '26300'
'05053' = '30780'
'05055' = '37500'
'05057' = '26260'
'05063' = '12900'
'05069' = '38220'
'05079' = '38220'
'05085' = '30780'
'05087' = '22220'
'05091' = '45500'
'05093' = '14180'
'05099' = '26260'
'05101' = '25460'
'05103' = '15780'
'05105' = '30780'
'05107' = '48340'
'05111' = '27860'
'05115' = '40780'
'05119' = '30780'
'05123' = '22620'
'05125' = '30780'
'05131' = '22900'
'05139' = '20980'
'05143' = '22220'
'05145' = '42620'
'05149' = '40780'
'06001' = '41860'
'06007' = '17020'
'06013' = '41860'
'06015' = '18860'
'06017' = '40900'
'06019' = '23420'
'06023' = '21700'
'06025' = '20940'
'06027' = '13860'
'06029' = '12540'
'06031' = '25260'
'06033' = '17340'
'06035' = '45000'
'06037' = '31100'
'06039' = '31460'
'06041' = '41860'
'06045' = '46380'
'06047' = '32900'
'06053' = '41500'
'06055' = '34900'
'06057' = '46020'
'06059' = '31100'
'06061' = '40900'
'06065' = '40140'
'06067' = '40900'
'06069' = '41940'
'06071' = '40140'
'06073' = '41740'
'06075' = '41860'
'06077' = '44700'
'06079' = '42020'
'06081' = '41860'
'06083' = '42060'
'06085' = '41940'
'06087' = '42100'
'06089' = '39820'
'06095' = '46700'
'06097' = '42220'
'06099' = '33700'
'06101' = '49700'
'06103' = '39780'
'06107' = '47300'
'06109' = '38020'
'06111' = '37100'
'06113' = '40900'
'06115' = '49700'
'08001' = '19740'
'08005' = '19740'
'08013' = '14500'
'08014' = '19740'
'08019' = '19740'
'08031' = '19740'
'08035' = '19740'
'08037' = '20780'
'08039' = '19740'
'08041' = '17820'
'08043' = '15860'
'08047' = '19740'
'08059' = '19740'
'08065' = '20780'
'08067' = '20420'
'08069' = '22660'
'08075' = '44540'
'08077' = '24300'
'08085' = '33940'
'08087' = '22820'
'08093' = '19740'
'08101' = '39380'
'08117' = '43540'
'08119' = '17820'
'08123' = '24540'
'09001' = '14860'
'09003' = '25540'
'09005' = '45860'
'09007' = '25540'
'09009' = '35300'
'09011' = '35980'
'09013' = '25540'
'09015' = '48740'
'10001' = '20100'
'10003' = '37980'
'10005' = '42580'
'11001' = '47900'
'12001' = '23540'
'12003' = '27260'
'12005' = '37460'
'12009' = '37340'
'12011' = '33100'
'12015' = '39460'
'12017' = '26140'
'12019' = '27260'
'12021' = '34940'
'12023' = '29380'
'12027' = '11580'
'12031' = '27260'
'12033' = '37860'
'12035' = '37380'
'12039' = '45220'
'12041' = '23540'
'12049' = '48100'
'12051' = '17500'
'12053' = '45300'
'12055' = '42700'
'12057' = '45300'
'12061' = '46940'
'12065' = '45220'
'12069' = '36740'
'12071' = '15980'
'12073' = '45220'
'12081' = '42260'
'12083' = '36100'
'12085' = '38940'
'12086' = '33100'
'12087' = '28580'
'12089' = '27260'
'12091' = '23020'
'12093' = '36380'
'12095' = '36740'
'12097' = '36740'
'12099' = '33100'
'12101' = '45300'
'12103' = '45300'
'12105' = '29460'
'12107' = '37260'
'12109' = '27260'
'12111' = '38940'
'12113' = '37860'
'12115' = '42260'
'12117' = '36740'
'12119' = '45540'
'12127' = '19660'
'12129' = '45220'
'13003' = '20060'
'13007' = '10500'
'13009' = '33300'
'13013' = '12060'
'13015' = '12060'
'13017' = '22340'
'13021' = '31420'
'13025' = '15260'
'13027' = '46660'
'13029' = '42340'
'13031' = '44340'
'13033' = '12260'
'13035' = '12060'
'13039' = '41220'
'13045' = '12060'
'13047' = '16860'
'13051' = '42340'
'13053' = '17980'
'13055' = '44900'
'13057' = '12060'
'13059' = '12020'
'13063' = '12060'
'13067' = '12060'
'13069' = '20060'
'13071' = '34220'
'13073' = '12260'
'13077' = '12060'
'13079' = '31420'
'13081' = '18380'
'13083' = '16860'
'13085' = '12060'
'13087' = '12460'
'13089' = '12060'
'13095' = '10500'
'13097' = '12060'
'13101' = '46660'
'13103' = '42340'
'13113' = '12060'
'13115' = '40660'
'13117' = '12060'
'13121' = '12060'
'13127' = '15260'
'13129' = '15660'
'13135' = '12060'
'13137' = '18460'
'13139' = '23580'
'13141' = '33300'
'13143' = '12060'
'13145' = '17980'
'13149' = '12060'
'13151' = '12060'
'13153' = '47580'
'13155' = '22340'
'13159' = '12060'
'13167' = '20140'
'13169' = '31420'
'13171' = '12060'
'13173' = '46660'
'13175' = '20140'
'13177' = '10500'
'13179' = '25980'
'13183' = '25980'
'13185' = '46660'
'13189' = '12260'
'13191' = '15260'
'13195' = '12020'
'13197' = '17980'
'13199' = '12060'
'13207' = '31420'
'13209' = '47080'
'13213' = '19140'
'13215' = '17980'
'13217' = '12060'
'13219' = '12020'
'13221' = '12020'
'13223' = '12060'
'13225' = '22980'
'13227' = '12060'
'13229' = '48180'
'13231' = '12060'
'13233' = '16340'
'13239' = '21640'
'13245' = '12260'
'13247' = '12060'
'13249' = '11140'
'13255' = '12060'
'13257' = '45740'
'13261' = '11140'
'13273' = '10500'
'13275' = '45620'
'13277' = '45700'
'13279' = '47080'
'13285' = '29300'
'13289' = '31420'
'13293' = '45580'
'13295' = '16860'
'13297' = '12060'
'13299' = '48180'
'13305' = '27700'
'13313' = '19140'
'13321' = '10500'
'15001' = '25900'
'15003' = '26180'
'15007' = '28180'
'15009' = '27980'
'16001' = '14260'
'16005' = '38540'
'16011' = '13940'
'16015' = '14260'
'16019' = '26820'
'16027' = '14260'
'16031' = '15420'
'16039' = '34300'
'16041' = '30860'
'16043' = '39940'
'16045' = '14260'
'16051' = '26820'
'16053' = '46300'
'16055' = '17660'
'16057' = '34140'
'16065' = '39940'
'16067' = '15420'
'16069' = '30300'
'16073' = '14260'
'16075' = '36620'
'16077' = '38540'
'16081' = '27220'
'16083' = '46300'
'17001' = '39500'
'17003' = '16020'
'17005' = '41180'
'17007' = '40420'
'17011' = '36860'
'17013' = '41180'
'17019' = '16580'
'17021' = '45380'
'17027' = '41180'
'17029' = '16660'
'17031' = '16980'
'17035' = '16660'
'17037' = '16980'
'17043' = '16980'
'17049' = '20820'
'17053' = '16580'
'17057' = '15900'
'17063' = '16980'
'17065' = '34500'
'17071' = '15460'
'17073' = '19340'
'17077' = '16060'
'17081' = '34500'
'17083' = '41180'
'17089' = '16980'
'17091' = '28100'
'17093' = '16980'
'17095' = '23660'
'17097' = '16980'
'17099' = '36860'
'17103' = '19940'
'17105' = '38700'
'17107' = '30660'
'17109' = '31380'
'17111' = '16980'
'17113' = '14060'
'17115' = '19500'
'17117' = '41180'
'17119' = '41180'
'17121' = '16460'
'17123' = '37900'
'17127' = '37140'
'17129' = '44100'
'17131' = '19340'
'17133' = '41180'
'17137' = '27300'
'17141' = '40300'
'17143' = '37900'
'17147' = '16580'
'17155' = '36860'
'17161' = '19340'
'17163' = '41180'
'17165' = '25380'
'17167' = '44100'
'17171' = '27300'
'17175' = '37900'
'17177' = '23300'
'17179' = '37900'
'17183' = '19180'
'17187' = '23660'
'17195' = '44580'
'17197' = '16980'
'17199' = '32060'
'17201' = '40420'
'17203' = '37900'
'18001' = '19540'
'18003' = '23060'
'18005' = '18020'
'18007' = '29140'
'18011' = '26900'
'18013' = '26900'
'18015' = '29140'
'18017' = '30900'
'18019' = '31140'
'18021' = '45460'
'18023' = '23140'
'18027' = '47780'
'18029' = '17140'
'18031' = '24700'
'18033' = '12140'
'18035' = '34620'
'18037' = '27540'
'18039' = '21140'
'18041' = '18220'
'18043' = '31140'
'18047' = '17140'
'18051' = '21780'
'18053' = '31980'
'18055' = '14020'
'18057' = '26900'
'18059' = '26900'
'18061' = '31140'
'18063' = '26900'
'18065' = '35220'
'18067' = '29020'
'18069' = '26540'
'18071' = '42980'
'18073' = '16980'
'18077' = '31500'
'18079' = '35860'
'18081' = '26900'
'18083' = '47180'
'18085' = '47700'
'18089' = '16980'
'18091' = '33140'
'18093' = '13260'
'18095' = '11300'
'18097' = '26900'
'18099' = '38500'
'18103' = '37940'
'18105' = '14020'
'18107' = '18820'
'18109' = '26900'
'18111' = '16980'
'18113' = '28340'
'18115' = '17140'
'18119' = '14020'
'18125' = '27540'
'18127' = '16980'
'18129' = '21780'
'18133' = '26900'
'18141' = '43780'
'18143' = '42500'
'18145' = '26900'
'18151' = '11420'
'18153' = '45460'
'18157' = '29140'
'18159' = '29020'
'18163' = '21780'
'18165' = '45460'
'18167' = '45460'
'18169' = '47340'
'18173' = '21780'
'18175' = '31140'
'18177' = '39980'
'18179' = '23060'
'18183' = '23060'
'19011' = '16300'
'19013' = '47940'
'19015' = '14340'
'19017' = '47940'
'19021' = '44740'
'19033' = '32380'
'19041' = '43980'
'19045' = '17540'
'19049' = '19780'
'19057' = '15460'
'19059' = '44020'
'19061' = '20220'
'19075' = '47940'
'19077' = '19780'
'19085' = '36540'
'19099' = '35500'
'19103' = '26980'
'19105' = '16300'
'19111' = '28460'
'19113' = '16300'
'19115' = '34700'
'19121' = '19780'
'19123' = '36820'
'19125' = '37800'
'19127' = '32260'
'19129' = '36540'
'19139' = '34700'
'19153' = '19780'
'19155' = '36540'
'19163' = '19340'
'19169' = '11180'
'19179' = '36900'
'19181' = '19780'
'19183' = '26980'
'19187' = '22700'
'19193' = '43580'
'19195' = '32380'
'20005' = '11860'
'20009' = '24460'
'20015' = '48620'
'20017' = '21380'
'20035' = '49060'
'20037' = '38260'
'20043' = '41140'
'20045' = '29940'
'20051' = '25700'
'20055' = '23780'
'20057' = '19980'
'20059' = '28140'
'20061' = '31740'
'20079' = '48620'
'20085' = '45820'
'20087' = '45820'
'20091' = '28140'
'20099' = '37660'
'20103' = '28140'
'20107' = '28140'
'20111' = '21380'
'20113' = '32700'
'20121' = '28140'
'20125' = '17700'
'20139' = '45820'
'20143' = '41460'
'20149' = '31740'
'20155' = '26740'
'20161' = '31740'
'20169' = '41460'
'20173' = '48620'
'20175' = '30580'
'20177' = '45820'
'20191' = '48620'
'20197' = '45820'
'20209' = '28140'
'21005' = '23180'
'21007' = '37140'
'21009' = '23980'
'21011' = '34460'
'21013' = '33180'
'21015' = '17140'
'21017' = '30460'
'21019' = '26580'
'21021' = '19220'
'21023' = '17140'
'21029' = '31140'
'21035' = '34660'
'21037' = '17140'
'21047' = '17300'
'21049' = '30460'
'21059' = '36980'
'21061' = '14540'
'21067' = '30460'
'21073' = '23180'
'21075' = '46460'
'21077' = '17140'
'21081' = '17140'
'21083' = '32460'
'21089' = '26580'
'21091' = '36980'
'21093' = '21060'
'21101' = '21780'
'21103' = '31140'
'21107' = '31580'
'21111' = '31140'
'21113' = '30460'
'21117' = '17140'
'21123' = '21060'
'21125' = '30940'
'21135' = '32500'
'21137' = '19220'
'21139' = '37140'
'21145' = '37140'
'21149' = '36980'
'21151' = '40080'
'21161' = '32500'
'21163' = '31140'
'21165' = '34460'
'21169' = '23980'
'21173' = '34460'
'21177' = '16420'
'21179' = '31140'
'21185' = '31140'
'21191' = '17140'
'21199' = '43700'
'21203' = '40080'
'21209' = '30460'
'21211' = '31140'
'21215' = '31140'
'21217' = '15820'
'21221' = '17300'
'21223' = '31140'
'21227' = '14540'
'21233' = '21780'
'21235' = '18340'
'21239' = '30460'
'22001' = '18940'
'22005' = '12940'
'22007' = '38200'
'22011' = '19760'
'22015' = '43340'
'22017' = '43340'
'22019' = '29340'
'22023' = '29340'
'22029' = '35020'
'22031' = '43340'
'22033' = '12940'
'22037' = '12940'
'22043' = '10780'
'22045' = '35340'
'22047' = '12940'
'22049' = '40820'
'22051' = '35380'
'22053' = '27660'
'22055' = '29180'
'22057' = '26380'
'22061' = '40820'
'22063' = '12940'
'22065' = '45260'
'22067' = '12820'
'22069' = '35060'
'22071' = '35380'
'22073' = '33740'
'22075' = '35380'
'22077' = '12940'
'22079' = '10780'
'22087' = '35380'
'22089' = '35380'
'22091' = '12940'
'22095' = '35380'
'22097' = '36660'
'22099' = '29180'
'22101' = '34020'
'22103' = '35380'
'22105' = '25220'
'22109' = '26380'
'22111' = '33740'
'22113' = '10020'
'22115' = '22860'
'22117' = '14220'
'22119' = '33380'
'22121' = '12940'
'22125' = '12940'
'23001' = '30340'
'23005' = '38860'
'23011' = '12300'
'23013' = '40500'
'23019' = '12620'
'23023' = '38860'
'23031' = '38860'
'24001' = '19060'
'24003' = '12580'
'24005' = '12580'
'24009' = '47900'
'24013' = '12580'
'24015' = '37980'
'24017' = '47900'
'24019' = '15700'
'24021' = '47900'
'24025' = '12580'
'24027' = '12580'
'24031' = '47900'
'24033' = '47900'
'24035' = '12580'
'24037' = '30500'
'24039' = '41540'
'24041' = '20660'
'24043' = '25180'
'24045' = '41540'
'24047' = '36180'
'24510' = '12580'
'25001' = '12700'
'25003' = '38340'
'25005' = '39300'
'25009' = '14460'
'25011' = '44140'
'25013' = '44140'
'25015' = '44140'
'25017' = '14460'
'25021' = '14460'
'25023' = '14460'
'25025' = '14460'
'25027' = '49340'
'26005' = '10880'
'26007' = '10980'
'26015' = '24340'
'26017' = '13020'
'26019' = '45900'
'26021' = '35660'
'26023' = '17740'
'26025' = '12980'
'26027' = '43780'
'26033' = '42300'
'26037' = '29620'
'26041' = '21540'
'26043' = '27020'
'26045' = '29620'
'26049' = '22420'
'26055' = '45900'
'26057' = '10940'
'26061' = '26340'
'26065' = '29620'
'26067' = '24340'
'26073' = '34380'
'26075' = '27100'
'26077' = '28020'
'26079' = '45900'
'26081' = '24340'
'26083' = '26340'
'26087' = '19820'
'26089' = '45900'
'26091' = '10300'
'26093' = '19820'
'26099' = '19820'
'26103' = '32100'
'26107' = '13660'
'26109' = '31940'
'26111' = '33220'
'26113' = '15620'
'26115' = '33780'
'26121' = '34740'
'26123' = '24340'
'26125' = '19820'
'26139' = '26100'
'26145' = '40980'
'26147' = '19820'
'26149' = '44780'
'26155' = '37020'
'26159' = '28020'
'26161' = '11460'
'26163' = '19820'
'26165' = '15620'
'27003' = '33460'
'27007' = '13420'
'27009' = '41060'
'27013' = '31860'
'27015' = '35580'
'27017' = '20260'
'27019' = '33460'
'27021' = '14660'
'27025' = '33460'
'27027' = '22020'
'27035' = '14660'
'27037' = '33460'
'27039' = '40340'
'27041' = '10820'
'27047' = '10660'
'27049' = '39860'
'27053' = '33460'
'27055' = '29100'
'27059' = '33460'
'27067' = '48820'
'27083' = '32140'
'27085' = '26780'
'27091' = '21860'
'27099' = '12380'
'27103' = '31860'
'27105' = '49380'
'27109' = '40340'
'27111' = '22260'
'27119' = '24220'
'27123' = '33460'
'27131' = '22060'
'27137' = '20260'
'27139' = '33460'
'27141' = '33460'
'27145' = '41060'
'27147' = '36940'
'27157' = '40340'
'27163' = '33460'
'27167' = '47420'
'27169' = '49100'
'27171' = '33460'
'28001' = '35020'
'28003' = '18420'
'28005' = '32620'
'28011' = '17380'
'28015' = '24900'
'28023' = '32940'
'28025' = '48500'
'28027' = '17260'
'28029' = '27140'
'28033' = '32820'
'28035' = '25620'
'28039' = '37700'
'28043' = '24980'
'28045' = '25060'
'28047' = '25060'
'28049' = '27140'
'28057' = '46180'
'28059' = '37700'
'28061' = '29860'
'28067' = '29860'
'28069' = '32940'
'28071' = '37060'
'28073' = '25620'
'28075' = '32940'
'28081' = '46180'
'28083' = '24900'
'28085' = '15020'
'28087' = '18060'
'28089' = '27140'
'28093' = '32820'
'28105' = '44260'
'28109' = '38100'
'28111' = '25620'
'28113' = '32620'
'28115' = '46180'
'28121' = '27140'
'28127' = '27140'
'28131' = '25060'
'28133' = '26940'
'28137' = '32820'
'28143' = '32820'
'28149' = '46980'
'28151' = '24740'
'28163' = '49540'
'29001' = '28860'
'29003' = '41140'
'29007' = '33020'
'29013' = '28140'
'29017' = '16020'
'29019' = '17860'
'29021' = '41140'
'29023' = '38740'
'29025' = '28140'
'29027' = '27620'
'29031' = '16020'
'29037' = '28140'
'29043' = '44180'
'29045' = '28460'
'29047' = '28140'
'29049' = '28140'
'29051' = '27620'
'29059' = '44180'
'29063' = '41140'
'29069' = '28380'
'29071' = '41180'
'29077' = '44180'
'29089' = '17860'
'29091' = '48460'
'29095' = '28140'
'29097' = '27900'
'29099' = '41180'
'29101' = '47660'
'29105' = '30060'
'29107' = '28140'
'29111' = '39500'
'29113' = '41180'
'29119' = '22220'
'29127' = '25300'
'29135' = '27620'
'29145' = '27900'
'29147' = '32340'
'29151' = '27620'
'29159' = '42740'
'29161' = '40620'
'29165' = '28140'
'29167' = '44180'
'29169' = '22780'
'29173' = '25300'
'29175' = '33620'
'29177' = '28140'
'29183' = '41180'
'29187' = '22100'
'29189' = '41180'
'29195' = '32180'
'29197' = '28860'
'29201' = '43460'
'29209' = '14700'
'29213' = '14700'
'29219' = '41180'
'29221' = '41180'
'29225' = '44180'
'29510' = '41180'
'30009' = '13740'
'30013' = '24500'
'30029' = '28060'
'30031' = '14580'
'30041' = '25660'
'30043' = '25740'
'30049' = '25740'
'30063' = '33540'
'30093' = '15580'
'30111' = '13740'
'31001' = '25580'
'31007' = '42420'
'31019' = '28260'
'31025' = '36540'
'31035' = '25580'
'31043' = '43580'
'31047' = '30420'
'31051' = '43580'
'31053' = '23340'
'31055' = '36540'
'31067' = '13100'
'31073' = '30420'
'31079' = '24260'
'31093' = '24260'
'31099' = '28260'
'31109' = '30700'
'31111' = '35820'
'31113' = '35820'
'31117' = '35820'
'31119' = '35740'
'31121' = '24260'
'31139' = '35740'
'31141' = '18100'
'31153' = '36540'
'31155' = '36540'
'31157' = '42420'
'31159' = '30700'
'31167' = '35740'
'31177' = '36540'
'32001' = '21980'
'32003' = '29820'
'32005' = '23820'
'32007' = '21220'
'32011' = '21220'
'32023' = '37220'
'32029' = '39900'
'32031' = '39900'
'32510' = '16180'
'33001' = '29060'
'33005' = '28300'
'33007' = '13620'
'33009' = '30100'
'33011' = '31700'
'33013' = '18180'
'33015' = '14460'
'33017' = '14460'
'33019' = '17200'
'34001' = '12100'
'34003' = '35620'
'34005' = '37980'
'34007' = '37980'
'34009' = '36140'
'34011' = '47220'
'34013' = '35620'
'34015' = '37980'
'34017' = '35620'
'34019' = '35620'
'34021' = '45940'
'34023' = '35620'
'34025' = '35620'
'34027' = '35620'
'34029' = '35620'
'34031' = '35620'
'34033' = '37980'
'34035' = '35620'
'34037' = '35620'
'34039' = '35620'
'34041' = '10900'
'35001' = '10740'
'35005' = '40740'
'35006' = '24380'
'35009' = '17580'
'35013' = '29740'
'35015' = '16100'
'35017' = '43500'
'35025' = '26020'
'35028' = '31060'
'35029' = '19700'
'35031' = '23700'
'35035' = '10460'
'35039' = '21580'
'35041' = '38780'
'35043' = '10740'
'35045' = '22140'
'35047' = '29780'
'35049' = '42140'
'35055' = '45340'
'35057' = '10740'
'35061' = '10740'
'36001' = '10580'
'36005' = '35620'
'36007' = '13780'
'36009' = '36460'
'36011' = '12180'
'36013' = '27460'
'36015' = '21300'
'36019' = '38460'
'36021' = '26460'
'36023' = '18660'
'36027' = '39100'
'36029' = '15380'
'36033' = '31660'
'36035' = '24100'
'36037' = '12860'
'36043' = '46540'
'36045' = '48060'
'36047' = '35620'
'36051' = '40380'
'36053' = '45060'
'36055' = '40380'
'36057' = '11220'
'36059' = '35620'
'36061' = '35620'
'36063' = '15380'
'36065' = '46540'
'36067' = '45060'
'36069' = '40380'
'36071' = '39100'
'36073' = '40380'
'36075' = '45060'
'36077' = '36580'
'36079' = '35620'
'36081' = '35620'
'36083' = '10580'
'36085' = '35620'
'36087' = '35620'
'36089' = '36300'
'36091' = '10580'
'36093' = '10580'
'36095' = '10580'
'36099' = '42900'
'36101' = '18500'
'36103' = '35620'
'36107' = '13780'
'36109' = '27060'
'36111' = '28740'
'36113' = '24020'
'36115' = '24020'
'36117' = '40380'
'36119' = '35620'
'37001' = '15500'
'37003' = '25860'
'37007' = '16740'
'37013' = '47820'
'37019' = '48900'
'37021' = '11700'
'37023' = '25860'
'37025' = '16740'
'37027' = '25860'
'37029' = '21020'
'37031' = '33980'
'37035' = '25860'
'37037' = '20500'
'37045' = '43140'
'37049' = '35100'
'37051' = '22180'
'37053' = '47260'
'37055' = '28620'
'37057' = '45640'
'37059' = '49180'
'37063' = '20500'
'37065' = '40580'
'37067' = '49180'
'37069' = '39580'
'37071' = '16740'
'37079' = '24780'
'37081' = '24660'
'37083' = '40260'
'37085' = '20380'
'37087' = '11700'
'37089' = '11700'
'37093' = '22180'
'37097' = '44380'
'37101' = '39580'
'37103' = '35100'
'37105' = '41820'
'37107' = '28820'
'37109' = '30740'
'37115' = '11700'
'37119' = '16740'
'37125' = '43860'
'37127' = '40580'
'37129' = '48900'
'37131' = '40260'
'37133' = '27340'
'37135' = '20500'
'37137' = '35100'
'37139' = '21020'
'37141' = '48900'
'37143' = '21020'
'37145' = '20500'
'37147' = '24780'
'37151' = '24660'
'37153' = '40460'
'37155' = '31300'
'37157' = '24660'
'37159' = '41580'
'37161' = '22580'
'37165' = '29900'
'37167' = '10620'
'37169' = '49180'
'37171' = '34340'
'37175' = '14820'
'37179' = '16740'
'37181' = '25780'
'37183' = '39580'
'37189' = '14380'
'37191' = '24140'
'37193' = '35900'
'37195' = '48980'
'37197' = '49180'
'38007' = '19860'
'38015' = '13900'
'38017' = '22020'
'38035' = '24220'
'38049' = '33500'
'38059' = '13900'
'38075' = '33500'
'38077' = '47420'
'38089' = '19860'
'38093' = '27420'
'38101' = '33500'
'38105' = '48780'
'39003' = '30620'
'39005' = '11740'
'39007' = '11780'
'39009' = '11900'
'39011' = '47540'
'39013' = '48540'
'39015' = '17140'
'39017' = '17140'
'39019' = '15940'
'39021' = '46500'
'39023' = '44220'
'39025' = '17140'
'39027' = '48940'
'39029' = '20620'
'39031' = '18740'
'39033' = '15340'
'39035' = '17460'
'39037' = '24820'
'39039' = '19580'
'39041' = '18140'
'39043' = '41780'
'39045' = '18140'
'39047' = '47860'
'39049' = '18140'
'39051' = '45780'
'39053' = '38580'
'39055' = '17460'
'39057' = '19380'
'39059' = '15740'
'39061' = '17140'
'39063' = '22300'
'39077' = '35940'
'39081' = '48260'
'39083' = '34540'
'39085' = '17460'
'39087' = '26580'
'39089' = '18140'
'39091' = '13340'
'39093' = '17460'
'39095' = '45780'
'39097' = '18140'
'39099' = '49660'
'39101' = '32020'
'39103' = '17460'
'39107' = '16380'
'39109' = '19380'
'39113' = '19380'
'39117' = '18140'
'39119' = '49780'
'39123' = '45780'
'39129' = '18140'
'39133' = '10420'
'39135' = '19380'
'39139' = '31900'
'39141' = '17060'
'39143' = '23380'
'39145' = '39020'
'39147' = '45660'
'39149' = '43380'
'39151' = '15940'
'39153' = '10420'
'39155' = '49660'
'39157' = '35420'
'39159' = '18140'
'39161' = '46780'
'39165' = '17140'
'39167' = '37620'
'39169' = '49300'
'39173' = '45780'
'40009' = '21120'
'40013' = '20460'
'40017' = '36420'
'40019' = '11620'
'40021' = '45140'
'40027' = '36420'
'40031' = '30020'
'40037' = '46140'
'40047' = '21420'
'40051' = '36420'
'40065' = '11060'
'40071' = '38620'
'40079' = '22900'
'40081' = '36420'
'40083' = '36420'
'40085' = '11620'
'40087' = '36420'
'40101' = '34780'
'40109' = '36420'
'40111' = '46140'
'40113' = '46140'
'40115' = '33060'
'40117' = '46140'
'40119' = '44660'
'40121' = '32540'
'40123' = '10220'
'40125' = '43060'
'40131' = '46140'
'40135' = '22900'
'40137' = '20340'
'40139' = '25100'
'40143' = '46140'
'40145' = '46140'
'40147' = '12780'
'40153' = '49260'
'41003' = '18700'
'41005' = '38900'
'41007' = '11820'
'41009' = '38900'
'41011' = '18300'
'41013' = '39260'
'41015' = '15060'
'41017' = '13460'
'41019' = '40700'
'41027' = '26220'
'41029' = '32780'
'41033' = '24420'
'41035' = '28900'
'41039' = '21660'
'41043' = '10540'
'41045' = '36620'
'41047' = '41420'
'41049' = '37820'
'41051' = '38900'
'41053' = '41420'
'41059' = '37820'
'41061' = '29260'
'41065' = '17180'
'41067' = '38900'
'41071' = '38900'
'42001' = '23900'
'42003' = '38300'
'42005' = '38300'
'42007' = '38300'
'42011' = '39740'
'42013' = '11020'
'42015' = '42380'
'42017' = '37980'
'42019' = '38300'
'42021' = '27780'
'42025' = '10900'
'42027' = '44300'
'42029' = '37980'
'42033' = '20180'
'42035' = '30820'
'42037' = '14100'
'42039' = '32740'
'42041' = '25420'
'42043' = '25420'
'42045' = '37980'
'42047' = '41260'
'42049' = '21500'
'42051' = '38300'
'42055' = '16540'
'42061' = '26500'
'42063' = '26860'
'42069' = '42540'
'42071' = '29540'
'42073' = '35260'
'42075' = '30140'
'42077' = '10900'
'42079' = '42540'
'42081' = '48700'
'42083' = '14620'
'42085' = '49660'
'42087' = '30380'
'42089' = '20700'
'42091' = '37980'
'42093' = '14100'
'42095' = '10900'
'42097' = '44980'
'42099' = '25420'
'42101' = '37980'
'42103' = '35620'
'42107' = '39060'
'42109' = '42780'
'42111' = '43740'
'42119' = '30260'
'42121' = '36340'
'42123' = '47620'
'42125' = '38300'
'42129' = '38300'
'42131' = '42540'
'42133' = '49620'
'44001' = '39300'
'44003' = '39300'
'44005' = '39300'
'44007' = '39300'
'44009' = '39300'
'45003' = '12260'
'45007' = '11340'
'45013' = '25940'
'45015' = '16700'
'45017' = '17900'
'45019' = '16700'
'45021' = '23500'
'45023' = '16900'
'45029' = '47500'
'45031' = '22500'
'45033' = '19900'
'45035' = '16700'
'45037' = '12260'
'45039' = '17900'
'45041' = '22500'
'45043' = '23860'
'45045' = '24860'
'45047' = '24940'
'45051' = '34820'
'45053' = '25940'
'45055' = '17900'
'45057' = '29580'
'45059' = '24860'
'45063' = '17900'
'45069' = '13500'
'45071' = '35140'
'45073' = '42860'
'45075' = '36700'
'45077' = '24860'
'45079' = '17900'
'45081' = '17900'
'45083' = '43900'
'45085' = '44940'
'45087' = '46420'
'45091' = '16740'
'46005' = '26700'
'46011' = '15100'
'46013' = '10100'
'46027' = '46820'
'46029' = '47980'
'46035' = '33580'
'46045' = '10100'
'46057' = '47980'
'46061' = '33580'
'46065' = '38180'
'46081' = '43940'
'46083' = '43620'
'46087' = '43620'
'46093' = '39660'
'46099' = '43620'
'46103' = '39660'
'46117' = '38180'
'46125' = '43620'
'46127' = '43580'
'46135' = '49460'
'47001' = '28940'
'47003' = '43180'
'47009' = '28940'
'47011' = '17420'
'47013' = '29220'
'47015' = '34980'
'47019' = '27740'
'47021' = '34980'
'47023' = '27180'
'47029' = '35460'
'47031' = '46100'
'47035' = '18900'
'47037' = '34980'
'47043' = '34980'
'47045' = '20540'
'47047' = '32820'
'47051' = '46100'
'47053' = '26480'
'47057' = '34100'
'47059' = '24620'
'47063' = '34100'
'47065' = '16860'
'47073' = '28700'
'47075' = '15140'
'47079' = '37540'
'47081' = '34980'
'47087' = '18260'
'47089' = '34100'
'47093' = '28940'
'47099' = '29980'
'47105' = '28940'
'47107' = '11940'
'47111' = '34980'
'47113' = '27180'
'47115' = '16860'
'47117' = '30280'
'47119' = '17940'
'47125' = '17300'
'47127' = '46100'
'47131' = '46460'
'47133' = '18260'
'47139' = '17420'
'47141' = '18260'
'47145' = '25340'
'47147' = '34980'
'47149' = '34980'
'47153' = '16860'
'47155' = '42940'
'47157' = '32820'
'47159' = '34980'
'47161' = '17300'
'47163' = '28700'
'47165' = '34980'
'47167' = '32820'
'47169' = '34980'
'47171' = '27740'
'47173' = '28940'
'47177' = '32660'
'47179' = '27740'
'47183' = '32280'
'47187' = '34980'
'47189' = '34980'
'48001' = '37300'
'48003' = '11380'
'48005' = '31260'
'48007' = '18580'
'48009' = '48660'
'48011' = '11100'
'48013' = '41700'
'48015' = '26420'
'48019' = '41700'
'48021' = '12420'
'48025' = '13300'
'48027' = '28660'
'48029' = '41700'
'48037' = '45500'
'48039' = '26420'
'48041' = '17780'
'48049' = '15220'
'48051' = '17780'
'48055' = '12420'
'48057' = '47020'
'48059' = '10180'
'48061' = '15180'
'48065' = '11100'
'48071' = '26420'
'48073' = '27380'
'48077' = '48660'
'48085' = '19100'
'48091' = '41700'
'48097' = '23620'
'48099' = '28660'
'48107' = '31180'
'48113' = '19100'
'48115' = '29500'
'48117' = '25820'
'48119' = '19100'
'48121' = '19100'
'48135' = '36220'
'48139' = '19100'
'48141' = '21340'
'48143' = '44500'
'48147' = '14300'
'48157' = '26420'
'48167' = '26420'
'48175' = '47020'
'48179' = '37420'
'48181' = '43300'
'48183' = '30980'
'48187' = '41700'
'48189' = '38380'
'48199' = '13140'
'48201' = '26420'
'48203' = '32220'
'48209' = '12420'
'48213' = '11980'
'48215' = '32580'
'48219' = '30220'
'48221' = '24180'
'48223' = '44860'
'48227' = '13700'
'48231' = '19100'
'48233' = '14420'
'48235' = '41660'
'48245' = '13140'
'48249' = '10860'
'48251' = '19100'
'48253' = '10180'
'48257' = '19100'
'48259' = '41700'
'48261' = '28780'
'48265' = '28500'
'48273' = '28780'
'48277' = '37580'
'48281' = '28660'
'48291' = '26420'
'48303' = '31180'
'48309' = '47380'
'48321' = '13060'
'48323' = '20580'
'48325' = '41700'
'48329' = '33260'
'48339' = '26420'
'48341' = '20300'
'48347' = '34860'
'48349' = '18620'
'48353' = '45020'
'48355' = '18580'
'48361' = '13140'
'48363' = '33420'
'48367' = '19100'
'48375' = '11100'
'48381' = '11100'
'48389' = '37780'
'48393' = '37420'
'48395' = '17780'
'48397' = '19100'
'48401' = '30980'
'48407' = '26420'
'48409' = '18580'
'48415' = '43660'
'48423' = '46340'
'48425' = '24180'
'48427' = '40100'
'48439' = '19100'
'48441' = '10180'
'48449' = '34420'
'48451' = '41660'
'48453' = '12420'
'48459' = '30980'
'48463' = '46620'
'48465' = '19620'
'48469' = '47020'
'48471' = '26660'
'48473' = '26420'
'48477' = '14780'
'48479' = '29700'
'48481' = '20900'
'48485' = '48660'
'48487' = '46900'
'48489' = '39700'
'48491' = '12420'
'48493' = '41700'
'48497' = '19100'
'49003' = '14940'
'49005' = '30860'
'49007' = '39220'
'49011' = '36260'
'49021' = '16260'
'49023' = '39340'
'49029' = '36260'
'49035' = '41620'
'49043' = '41620'
'49045' = '41620'
'49047' = '46860'
'49049' = '39340'
'49051' = '25720'
'49053' = '41100'
'49057' = '36260'
'50003' = '13540'
'50007' = '15540'
'50009' = '13620'
'50011' = '15540'
'50013' = '15540'
'50017' = '30100'
'50021' = '40860'
'50023' = '12740'
'50027' = '30100'
'51003' = '16820'
'51007' = '40060'
'51009' = '31340'
'51011' = '31340'
'51013' = '47900'
'51015' = '44420'
'51019' = '31340'
'51023' = '40220'
'51031' = '31340'
'51033' = '40060'
'51036' = '40060'
'51041' = '40060'
'51043' = '47900'
'51045' = '40220'
'51047' = '19020'
'51049' = '40060'
'51053' = '40060'
'51059' = '47900'
'51061' = '47900'
'51065' = '16820'
'51067' = '40220'
'51069' = '49020'
'51071' = '13980'
'51073' = '47260'
'51075' = '40060'
'51079' = '16820'
'51085' = '40060'
'51087' = '40060'
'51089' = '32300'
'51093' = '47260'
'51095' = '47260'
'51097' = '40060'
'51101' = '40060'
'51107' = '47900'
'51109' = '40060'
'51115' = '47260'
'51121' = '13980'
'51125' = '16820'
'51127' = '40060'
'51143' = '19260'
'51145' = '40060'
'51149' = '40060'
'51153' = '47900'
'51155' = '13980'
'51161' = '40220'
'51165' = '25500'
'51169' = '28700'
'51177' = '47900'
'51179' = '47900'
'51181' = '47260'
'51183' = '40060'
'51185' = '14140'
'51187' = '47900'
'51191' = '28700'
'51199' = '47260'
'51510' = '47900'
'51515' = '31340'
'51520' = '28700'
'51540' = '16820'
'51550' = '47260'
'51570' = '40060'
'51590' = '19260'
'51600' = '47900'
'51610' = '47900'
'51630' = '47900'
'51650' = '47260'
'51660' = '25500'
'51670' = '40060'
'51680' = '31340'
'51683' = '47900'
'51685' = '47900'
'51690' = '32300'
'51700' = '47260'
'51710' = '47260'
'51730' = '40060'
'51735' = '47260'
'51740' = '47260'
'51750' = '13980'
'51760' = '40060'
'51770' = '40220'
'51775' = '40220'
'51790' = '44420'
'51800' = '47260'
'51810' = '47260'
'51820' = '44420'
'51830' = '47260'
'51840' = '49020'
'53003' = '30300'
'53005' = '28420'
'53007' = '48300'
'53009' = '38820'
'53011' = '38900'
'53015' = '31020'
'53017' = '48300'
'53021' = '28420'
'53025' = '34180'
'53027' = '10140'
'53029' = '36020'
'53033' = '42660'
'53035' = '14740'
'53037' = '21260'
'53041' = '16500'
'53045' = '43220'
'53053' = '42660'
'53057' = '34580'
'53059' = '38900'
'53061' = '42660'
'53063' = '44060'
'53067' = '36500'
'53071' = '47460'
'53073' = '13380'
'53075' = '39420'
'53077' = '49420'
'54003' = '25180'
'54005' = '16620'
'54009' = '48260'
'54011' = '26580'
'54015' = '16620'
'54017' = '17220'
'54019' = '36060'
'54027' = '49020'
'54029' = '48260'
'54033' = '17220'
'54037' = '47900'
'54039' = '16620'
'54043' = '16620'
'54049' = '21900'
'54051' = '48540'
'54053' = '38580'
'54055' = '14140'
'54057' = '19060'
'54061' = '34060'
'54065' = '25180'
'54069' = '48540'
'54073' = '37620'
'54077' = '34060'
'54079' = '16620'
'54081' = '13220'
'54091' = '17220'
'54099' = '26580'
'54105' = '37620'
'54107' = '37620'
'55009' = '24580'
'55015' = '11540'
'55017' = '20740'
'55021' = '31540'
'55025' = '31540'
'55027' = '13180'
'55031' = '20260'
'55033' = '32860'
'55035' = '20740'
'55037' = '27020'
'55039' = '22540'
'55043' = '38420'
'55045' = '33820'
'55049' = '31540'
'55055' = '48020'
'55059' = '16980'
'55061' = '24580'
'55063' = '29100'
'55069' = '32980'
'55071' = '31820'
'55073' = '48140'
'55075' = '31940'
'55079' = '33340'
'55083' = '24580'
'55087' = '11540'
'55089' = '33340'
'55093' = '33460'
'55097' = '44620'
'55101' = '39540'
'55105' = '27500'
'55109' = '33460'
'55111' = '12660'
'55117' = '43100'
'55127' = '48580'
'55131' = '33340'
'55133' = '33340'
'55139' = '36780'
'55141' = '49220'
'56001' = '29660'
'56005' = '23940'
'56013' = '40180'
'56021' = '16940'
'56025' = '16220'
'56033' = '43260'
'56037' = '40540'
'56039' = '27220'
'56041' = '21740'
;

 /* --------------------------------------------------------------- */
 /* ---   OPERATING ROOM PROCEDURE CODES                           - */
 /* --------------------------------------------------------------- */

VALUE $ORPROC
"0044" = "1" /* PROC-VESSEL BIFURCATION */
"0050" = "1" /* IMPL CRT PACEMAKER SYS */
"0051" = "1" /* IMPL CRT DEFIBRILLAT SYS */
"0052" = "1" /* IMP/REP LEAD LF VEN SYS */
"0053" = "1" /* IMP/REP CRT PACEMAKR GEN */
"0054" = "1" /* IMP/REP CRT DEFIB GENAT */
"0056" = "1" /* INS/REP IMPL SENSOR LEAD */
"0057" = "1" /* IMP/REP SUBCUE CARD DEV */
"0061" = "1" /* PERC ANGIO PRECEREB VESS */
"0062" = "1" /* PERC ANGIO INTRACRAN VES */
"0066" = "1" /* PTCA OR CORONARY ATHER */
"0070" = "1" /* REV HIP REPL-ACETAB/FEM */
"0071" = "1" /* REV HIP REPL-ACETAB COMP */
"0072" = "1" /* REV HIP REPL-FEM COMP */
"0073" = "1" /* REV HIP REPL-LINER/HEAD */
"0074" = "1" /* HIP REPL SURF-METAL/POLY */
"0075" = "1" /* HIP REP SURF-METAL/METAL */
"0076" = "1" /* HIP REP SURF-CERMC/CERMC */
"0077" = "1" /* HIP REPL SURF-CERMC/POLY */
"0080" = "1" /* REV KNEE REPLACEMT-TOTAL */
"0081" = "1" /* REV KNEE REPL-TIBIA COMP */
"0082" = "1" /* REV KNEE REPL-FEMUR COMP */
"0083" = "1" /* REV KNEE REPLACE-PATELLA */
"0084" = "1" /* REV KNEE REPL-TIBIA LIN */
"0085" = "1" /* RESRF HIPTOTAL-ACET/FEM */
"0086" = "1" /* RESRF HIPPART-FEM HEAD */
"0087" = "1" /* RESRF HIPPART-ACETABLUM */
"0112" = "1" /* OPEN CEREB MENINGES BX */
"0114" = "1" /* OPEN BRAIN BIOPSY */
"0115" = "1" /* SKULL BIOPSY */
"0118" = "1" /* OTHER BRAIN DX PROCEDURE */
"0119" = "1" /* OTHER SKULL DX PROCEDURE */
"0121" = "1" /* CRANIAL SINUS I & D */
"0122" = "1" /* REMOV INTRACRAN STIMULAT */
"0123" = "1" /* REOPEN CRANIOTOMY SITE */
"0124" = "1" /* OTHER CRANIOTOMY */
"0125" = "1" /* OTHER CRANIECTOMY */
"0126" = "1" /* INS CATH-CRANIAL CAVITY */
"0127" = "1" /* REM CATH-CRANIAL CAVITY */
"0128" = "1" /* INTRACEREB CTH-BURR HOLE */
"0131" = "1" /* INCISE CEREBRAL MENINGES */
"0132" = "1" /* LOBOTOMY & TRACTOTOMY */
"0139" = "1" /* OTHER BRAIN INCISION */
"0141" = "1" /* THALAMUS OPERATIONS */
"0142" = "1" /* GLOBUS PALLIDUS OPS */
"0151" = "1" /* EX CEREB MENINGEAL LES */
"0152" = "1" /* HEMISPHERECTOMY */
"0153" = "1" /* BRAIN LOBECTOMY */
"0159" = "1" /* OTHER BRAIN EXCISION */
"016 " = "1" /* EXCISE SKULL LESION */
"0201" = "1" /* LINEAR CRANIECTOMY */
"0202" = "1" /* ELEVATE SKULL FX FRAGMNT */
"0203" = "1" /* SKULL FLAP FORMATION */
"0204" = "1" /* BONE GRAFT TO SKULL */
"0205" = "1" /* SKULL PLATE INSERTION */
"0206" = "1" /* CRANIAL OSTEOPLASTY NEC */
"0207" = "1" /* SKULL PLATE REMOVAL */
"0211" = "1" /* SIMPLE SUTURE OF DURA */
"0212" = "1" /* BRAIN MENINGE REPAIR NEC */
"0213" = "1" /* MENINGE VESSEL LIGATION */
"0214" = "1" /* CHOROID PLEXECTOMY */
"022 " = "1" /* VENTRICULOSTOMY */
"0231" = "1" /* VENTRICL SHUNT-HEAD/NECK */
"0232" = "1" /* VENTRI SHUNT-CIRCULA SYS */
"0233" = "1" /* VENTRICL SHUNT-THORAX */
"0234" = "1" /* VENTRICL SHUNT-ABDOMEN */
"0235" = "1" /* VENTRI SHUNT-UNINARY SYS */
"0239" = "1" /* OTHER VENTRICULAR SHUNT */
"0242" = "1" /* REPLACE VENTRICLE SHUNT */
"0243" = "1" /* REMOVE VENTRICLE SHUNT */
"0291" = "1" /* LYSIS CORTICAL ADHESION */
"0292" = "1" /* BRAIN REPAIR */
"0293" = "1" /* IMPLANT BRAIN STIMULATOR */
"0294" = "1" /* INSERT/REPLAC SKULL TONG */
"0299" = "1" /* SKULL & BRAIN OP NEC */
"0301" = "1" /* REMOVAL FB SPINAL CANAL */
"0302" = "1" /* REOPEN LAMINECTOMY SITE */
"0309" = "1" /* SPINAL CANAL EXPLOR NEC */
"031 " = "1" /* INTRASPIN NERVE ROOT DIV */
"0321" = "1" /* PERCUTANEOUS CHORDOTOMY */
"0329" = "1" /* OTHER CHORDOTOMY */
"0332" = "1" /* SPINAL CORD/MENINGES BX */
"0339" = "1" /* OTHER SPINAL DX PROC */
"034 " = "1" /* EXCIS SPINAL CORD LESION */
"0351" = "1" /* SPINE MENINGOCELE REPAIR */
"0352" = "1" /* MYELOMENINGOCEL REPAIR */
"0353" = "1" /* VERTEBRAL FX REPAIR */
"0359" = "1" /* SPINAL STRUCT REPAIR NEC */
"036 " = "1" /* SPINAL CORD ADHESIOLYSIS */
"0371" = "1" /* SUBARACH-PERITON SHUNT */
"0372" = "1" /* SUBARACH-URETERAL SHUNT */
"0379" = "1" /* OTH SPINAL THECAL SHUNT */
"0393" = "1" /* INSERT SPINAL STIMULATOR */
"0394" = "1" /* REMOVE SPINAL STIMULATOR */
"0397" = "1" /* REVISE SPINE THECA SHUNT */
"0398" = "1" /* REMOVE SPINE THECA SHUNT */
"0399" = "1" /* SPINE CANAL STRUC OP NEC */
"0401" = "1" /* EXCISION ACOUSTC NEUROMA */
"0402" = "1" /* TRIGEMINAL NERV DIVISION */
"0403" = "1" /* PERIPH NERVE DIV NEC */
"0404" = "1" /* PERIPH NERVE INCIS NEC */
"0405" = "1" /* GASSERIAN GANGLIONECTOMY */
"0406" = "1" /* PERIPH GANGLIONECT NEC */
"0407" = "1" /* PERIPH NERV EXCISION NEC */
"0412" = "1" /* OPEN PERIPH NERVE BIOPSY */
"0419" = "1" /* PERIPH NERVE DX PROC NEC */
"043 " = "1" /* PERIPHERAL NERVE SUTURE */
"0441" = "1" /* DECOMPRESS TRIGEM ROOT */
"0442" = "1" /* CRAN NERV ROOT DECOM NEC */
"0443" = "1" /* CARPAL TUNNEL RELEASE */
"0444" = "1" /* TARSAL TUNNEL RELEASE */
"0449" = "1" /* PER NERVE ADHESIOLYS NEC */
"045 " = "1" /* PERIPHERAL NERVE GRAFT */
"046 " = "1" /* PERIPH NERVE TRANSPOSIT */
"0471" = "1" /* HYPOGLOSS-FACIAL ANASTOM */
"0472" = "1" /* ACCESSORY-FACIAL ANASTOM */
"0473" = "1" /* ACCESS-HYPOGLOSS ANASTOM */
"0474" = "1" /* PERIPH NERV ANASTOM NEC */
"0475" = "1" /* POSTOP REVIS PER NERV OP */
"0476" = "1" /* LATE REPAIR PER NERV INJ */
"0479" = "1" /* OTHER NEUROPLASTY */
"0491" = "1" /* NEURECTASIS */
"0492" = "1" /* IMPLANT PERIPH STIMULAT */
"0493" = "1" /* REMOVE PERIPH STIMULATOR */
"0499" = "1" /* PERIPHERAL NERVE OPS NEC */
"050 " = "1" /* SYMPATH NERVE DIVISION */
"0511" = "1" /* SYMPATHETIC NERVE BIOPSY */
"0519" = "1" /* SYMPATH NRV DX PROC NEC */
"0521" = "1" /* SPHENOPALATIN GANGLIONEC */
"0522" = "1" /* CERVICAL SYMPATHECTOMY */
"0523" = "1" /* LUMBAR SYMPATHECTOMY */
"0524" = "1" /* PRESACRAL SYMPATHECTOMY */
"0525" = "1" /* PERIART SYMPATHECTOMY */
"0529" = "1" /* OTHER SYMPATHECTOMY */
"0581" = "1" /* SYMPATHETIC NERVE REPAIR */
"0589" = "1" /* SYMPATHETIC NERVE OP NEC */
"059 " = "1" /* OTHER NERVOUS SYSTEM OPS */
"0602" = "1" /* REOPEN THYROID FIELD WND */
"0609" = "1" /* INCIS THYROID FIELD NEC */
"0612" = "1" /* OPEN THYROID GLAND BX */
"0613" = "1" /* PARATHYROID BIOPSY */
"0619" = "1" /* THYR/PARATHY DX PROC NEC */
"062 " = "1" /* UNILAT THYROID LOBECTOMY */
"0631" = "1" /* EXCISION THYROID LESION */
"0639" = "1" /* PART THYROIDECTOMY NEC */
"064 " = "1" /* COMPLETE THYROIDECTOMY */
"0650" = "1" /* SUBSTERN THYROIDECT NOS */
"0651" = "1" /* PART SUBSTERN THYROIDECT */
"0652" = "1" /* TOT SUBSTERN THYROIDECT */
"066 " = "1" /* LINGUAL THYROID EXCISION */
"067 " = "1" /* THYROGLOSS DUCT EXCISION */
"0681" = "1" /* TOTAL PARATHYROIDECTOMY */
"0689" = "1" /* OTHER PARATHYROIDECTOMY */
"0691" = "1" /* THYROID ISTHMUS DIVISION */
"0692" = "1" /* THYROID VESSEL LIGATION */
"0693" = "1" /* THYROID SUTURE */
"0694" = "1" /* THYROID REIMPLANTATION */
"0695" = "1" /* PARATHYROID REIMPLANT */
"0698" = "1" /* OTHER THYROID OPERATIONS */
"0699" = "1" /* OTHER PARATHYROID OPS */
"0700" = "1" /* ADRENAL EXPLORATION NOS */
"0701" = "1" /* UNILAT ADRENAL EXPLORAT */
"0702" = "1" /* BILAT ADRENAL EXPLORAT */
"0712" = "1" /* OPEN ADRENAL GLAND BX */
"0713" = "1" /* TRANSFRONT PITUITARY BX */
"0714" = "1" /* TRANSPHEN PITUITARY BX */
"0715" = "1" /* PITUITARY BIOPSY NOS */
"0716" = "1" /* THYMUS BIOPSY */
"0717" = "1" /* PINEAL BIOPSY */
"0719" = "1" /* ENDOCRINE DX PROC NEC */
"0721" = "1" /* ADRENAL LESION EXCISION */
"0722" = "1" /* UNILATERAL ADRENALECTOMY */
"0729" = "1" /* PART ADRENALECTOMY NEC */
"073 " = "1" /* BILATERAL ADRENALECTOMY */
"0741" = "1" /* ADRENAL INCISION */
"0742" = "1" /* ADRENAL NERVE DIVISION */
"0743" = "1" /* ADRENAL VESSEL LIGATION */
"0744" = "1" /* ADRENAL REPAIR */
"0745" = "1" /* ADRENAL REIMPLANTATION */
"0749" = "1" /* ADRENAL OPERATION NEC */
"0751" = "1" /* PINEAL FIELD EXPLORATION */
"0752" = "1" /* PINEAL GLAND INCISION */
"0753" = "1" /* PARTIAL PINEALECTOMY */
"0754" = "1" /* TOTAL PINEALECTOMY */
"0759" = "1" /* PINEAL OPERATION NEC */
"0761" = "1" /* EXC PITUIT LES-TRANSFRON */
"0762" = "1" /* EXC PITUIT LES-TRANSPHEN */
"0763" = "1" /* PART EXCIS PITUITARY NOS */
"0764" = "1" /* TOT EXC PITUIT-TRANSFRON */
"0765" = "1" /* TOT EXC PITUIT-TRANSPHEN */
"0768" = "1" /* TOTAL EXC PITUITARY NEC */
"0769" = "1" /* TOTAL EXC PITUITARY NOS */
"0771" = "1" /* PITUITARY FOSSA EXPLORAT */
"0772" = "1" /* PITUITARY GLAND INCISION */
"0779" = "1" /* PITUITARY OPERATION NEC */
"0780" = "1" /* THYMECTOMY NOS */
"0781" = "1" /* PART EXCISION OF THYMUS */
"0782" = "1" /* TOTAL EXCISION OF THYMUS */
"0791" = "1" /* THYMUS FIELD EXPLORATION */
"0792" = "1" /* INCISION OF THYMUS */
"0793" = "1" /* REPAIR OF THYMUS */
"0794" = "1" /* THYMUS TRANSPLANTATION */
"0799" = "1" /* THYMUS OPERATION NEC */
"0811" = "1" /* EYELID BIOPSY */
"0820" = "1" /* REMOVE EYELID LESION NOS */
"0821" = "1" /* CHALAZION EXCISION */
"0822" = "1" /* EXCISE MINOR LES LID NEC */
"0823" = "1" /* EXC MAJ LES LID PRT-THIC */
"0824" = "1" /* EXC MAJ LES LID FUL-THIC */
"0825" = "1" /* DESTRUCTION LID LESION */
"0831" = "1" /* PTOSIS REP-FRONT MUS SUT */
"0832" = "1" /* PTOSIS REP-FRON MUS SLNG */
"0833" = "1" /* PTOSIS REP-LEVAT MUS ADV */
"0834" = "1" /* PTOSIS REP-LEVAT MUS NEC */
"0835" = "1" /* PTOS REP-TARSAL TECHNIQ */
"0836" = "1" /* BLEPHAROPTOS REPAIR NEC */
"0837" = "1" /* REDUC OVERCORRECT PTOSIS */
"0838" = "1" /* CORRECT LID RETRACTION */
"0841" = "1" /* THERMOCAUT/ENTROPION REP */
"0842" = "1" /* SUTURE ENTROPION REPAIR */
"0843" = "1" /* WEDG RESEC ENTROPION REP */
"0844" = "1" /* LID RECONS ENTROPION REP */
"0849" = "1" /* ENTROPION/ECTROP REP NEC */
"0851" = "1" /* CANTHOTOMY */
"0852" = "1" /* BLEPHARORRHAPHY */
"0859" = "1" /* ADJUST LID POSITION NEC */
"0861" = "1" /* LID RECONST W SKIN GRAFT */
"0862" = "1" /* LID RECONST W MUC GRAFT */
"0863" = "1" /* LID RECONST W HAIR GRAFT */
"0864" = "1" /* LID RECON-TARSOCONJ FLAP */
"0869" = "1" /* LID RECONSTR W GRAFT NEC */
"0870" = "1" /* LID RECONSTRUCTION NOS */
"0871" = "1" /* LID MARG RECON-PART THIC */
"0872" = "1" /* LID RECONS-PART THIC NEC */
"0873" = "1" /* LID MARG RECONS FUL THIC */
"0874" = "1" /* LID RECONST-FUL THIC NEC */
"0891" = "1" /* ELECTROSURG LID EPILAT */
"0892" = "1" /* CRYOSURG LID EPILATION */
"0893" = "1" /* EYELID EPILATION NEC */
"0899" = "1" /* EYELID OPERATION NEC */
"090 " = "1" /* LACRIMAL GLAND INCISION */
"0911" = "1" /* LACRIMAL GLAND BIOPSY */
"0912" = "1" /* LACRIMAL SAC BIOPSY */
"0919" = "1" /* LACRIMAL SYS DX PROC NEC */
"0920" = "1" /* EXC LACRIMAL GLAND NOS */
"0921" = "1" /* EXCIS LES LACRIMAL GLAND */
"0922" = "1" /* PART DACRYOADENECT NEC */
"0923" = "1" /* TOTAL DACRYOADENECTOMY */
"093 " = "1" /* OTHER LACRIMAL GLAND OPS */
"0941" = "1" /* LACRIMAL PUNCTUM PROBE */
"0942" = "1" /* LAC CANALICULI PROBE */
"0943" = "1" /* NASOLACRIMAL DUCT PROBE */
"0944" = "1" /* NASOLAC DUCT INTUBAT */
"0949" = "1" /* LAC PASSAGE MANIP NEC */
"0951" = "1" /* LAC PUNCTUM INCISION */
"0952" = "1" /* LAC CANALICULI INCISION */
"0953" = "1" /* LACRIMAL SAC INCISION */
"0959" = "1" /* LACRIM PASSAGE INCIS NEC */
"096 " = "1" /* LACRIM SAC/PASSAGE EXCIS */
"0971" = "1" /* CORRECT EVERTED PUNCTUM */
"0972" = "1" /* PUNCTUM REPAIR NEC */
"0973" = "1" /* CANALICULUS REPAIR */
"0981" = "1" /* DACRYOCYSTORHINOSTOMY */
"0982" = "1" /* CONJUNCTIVOCYSTORHINOST */
"0983" = "1" /* CONJUNCTIVORHINOS W TUBE */
"0991" = "1" /* LAC PUNCTUM OBLITERATION */
"0999" = "1" /* LACRIMAL SYSTEM OP NEC */
"100 " = "1" /* INCISE/REMOV CONJUNCT FB */
"101 " = "1" /* CONJUNCTIVA INCISION NEC */
"1021" = "1" /* CONJUNCTIVAL BIOPSY */
"1029" = "1" /* CONJUNCTIVA DX PROC NEC */
"1031" = "1" /* EXCISE CONJUNCTIV LESION */
"1032" = "1" /* DESTRUCT CONJUNC LES NEC */
"1033" = "1" /* OTH CONJUNC DESTRUC PROC */
"1041" = "1" /* SYMBLEPH REP W FREE GRFT */
"1042" = "1" /* GRAFT CONJUNC CUL-DE-SAC */
"1043" = "1" /* CONJUN CUL-DE-SAC RX NEC */
"1044" = "1" /* CONJUNC FREE GRAFT NEC */
"1049" = "1" /* CONJUNCTIVOPLASTY NEC */
"105 " = "1" /* CONJUNC/LID ADHESIOLYSIS */
"106 " = "1" /* REPAIR CONJUNCT LACERAT */
"1091" = "1" /* SUBCONJUNCTIVAL INJECT */
"1099" = "1" /* CONJUNCTIVAL OP NEC */
"110 " = "1" /* MAGNET REMOVAL CORNEA FB */
"111 " = "1" /* CORNEAL INCISION */
"1121" = "1" /* CORNEAL SCRAPE FOR SMEAR */
"1122" = "1" /* CORNEAL BIOPSY */
"1129" = "1" /* CORNEAL DX PROC NEC */
"1131" = "1" /* PTERYGIUM TRANSPOSITION */
"1132" = "1" /* PTERYG EXC W CORNEA GRFT */
"1139" = "1" /* PTERYGIUM EXCISION NEC */
"1141" = "1" /* MECH REMOV CORNEA EPITH */
"1142" = "1" /* THERMOCAUT CORNEA LESION */
"1143" = "1" /* CRYOTHERAP CORNEA LESION */
"1149" = "1" /* DESTRUCT CORNEA LES NEC */
"1151" = "1" /* SUTURE CORNEA LACERATION */
"1152" = "1" /* REP CORNEA POSTOP DEHISC */
"1153" = "1" /* RX CORNEA LAC W CONJ FLP */
"1159" = "1" /* CORNEAL REPAIR NEC */
"1160" = "1" /* CORNEAL TRANSPLANT NOS */
"1161" = "1" /* LAM KERATPLAST W AUTGRFT */
"1162" = "1" /* LAMELLAR KERATOPLAST NEC */
"1163" = "1" /* PERF KERATOPL W AUTOGRFT */
"1164" = "1" /* PERFORAT KERATOPLAST NEC */
"1169" = "1" /* CORNEAL TRANSPLANT NEC */
"1171" = "1" /* KERATOMILEUSIS */
"1172" = "1" /* KERATOPHAKIA */
"1173" = "1" /* KERATOPROSTHESIS */
"1174" = "1" /* THERMOKERATOPLASTY */
"1175" = "1" /* RADIAL KERATOTOMY */
"1176" = "1" /* EPIKERATOPHAKIA */
"1179" = "1" /* CORNEA RECONSTRUCT NEC */
"1191" = "1" /* CORNEAL TATTOOING */
"1192" = "1" /* REMOVE CORNEAL IMPLANT */
"1199" = "1" /* CORNEAL OPERATION NEC */
"1200" = "1" /* REMOV ANT SEGMNT FB NOS */
"1201" = "1" /* MAGNET REMOV ANT SEG FB */
"1202" = "1" /* NONMAG REMOV ANT SEG FB */
"1211" = "1" /* IRIDOTOMY W TRANSFIXION */
"1212" = "1" /* IRIDOTOMY NEC */
"1213" = "1" /* PROLAPSED IRIS EXCISION */
"1214" = "1" /* IRIDECTOMY NEC */
"1221" = "1" /* DX ASPIRAT-ANT CHAMBER */
"1222" = "1" /* IRIS BIOPSY */
"1229" = "1" /* ANT SEGMENT DX PROC NEC */
"1231" = "1" /* GONIOSYNECHIAE LYSIS */
"1232" = "1" /* ANT SYNECHIA LYSIS NEC */
"1233" = "1" /* POST SYNECHIAE LYSIS */
"1234" = "1" /* CORNEOVITREAL ADHESIOLYS */
"1235" = "1" /* COREOPLASTY */
"1239" = "1" /* IRIDOPLASTY NEC */
"1240" = "1" /* REMOV ANT SEGMNT LES NOS */
"1241" = "1" /* NONEXC DESTRUC IRIS LES */
"1242" = "1" /* EXCISION OF IRIS LESION */
"1243" = "1" /* NONEXC DESTR CIL BOD LES */
"1244" = "1" /* EXCISE CILIARY BODY LES */
"1251" = "1" /* GONIOPUNCTURE */
"1252" = "1" /* GONIOTOMY */
"1253" = "1" /* GONIOTOMY W GONIOPUNCTUR */
"1254" = "1" /* TRABECULOTOMY AB EXTERNO */
"1255" = "1" /* CYCLODIALYSIS */
"1259" = "1" /* FACILIT INTRAOC CIRC NEC */
"1261" = "1" /* TREPHIN SCLERA W IRIDECT */
"1262" = "1" /* THERMCAUT SCLER W IRIDEC */
"1263" = "1" /* IRIDENCLEISIS/IRIDOTASIS */
"1264" = "1" /* TRABECULECTOM AB EXTERNO */
"1265" = "1" /* SCLER FISTULIZ W IRIDECT */
"1266" = "1" /* POSTOP REVIS SCL FISTUL */
"1269" = "1" /* SCLER FISTULIZING OP NEC */
"1271" = "1" /* CYCLODIATHERMY */
"1272" = "1" /* CYCLOCRYOTHERAPY */
"1273" = "1" /* CYCLOPHOTOCOAGULATION */
"1274" = "1" /* CIL BODY DIMINUTION NOS */
"1279" = "1" /* GLAUCOMA PROCEDURE NEC */
"1281" = "1" /* SUTURE SCLERAL LACER */
"1282" = "1" /* SCLERAL FISTULA REPAIR */
"1283" = "1" /* REVIS ANT SEG OP WND NEC */
"1284" = "1" /* DESTRUCT SCLERAL LESION */
"1285" = "1" /* REPAIR STAPHYLOM W GRAFT */
"1286" = "1" /* REP SCLER STAPHYLOMA NEC */
"1287" = "1" /* GRAFT REINFORCE SCLERA */
"1288" = "1" /* SCLERA REINFORCEMENT NEC */
"1289" = "1" /* SCLERAL OPERATION NEC */
"1291" = "1" /* THERAPEUT EVAC ANT CHAMB */
"1292" = "1" /* ANTERIOR CHAMBER INJECT */
"1293" = "1" /* REMOV EPITHEL DOWNGROWTH */
"1297" = "1" /* IRIS OPERATION NEC */
"1298" = "1" /* CILIARY BODY OP NEC */
"1299" = "1" /* ANTERIOR CHAMBER OP NEC */
"1300" = "1" /* REMOVE FB LENS NOS */
"1301" = "1" /* MAGNET REMOVE FB LENS */
"1302" = "1" /* NONMAGNET REMOVE FB LENS */
"1311" = "1" /* TEMP-INF INTRCAP LENS EX */
"1319" = "1" /* INTRACAPSUL LENS EXT NEC */
"132 " = "1" /* LINEAR EXTRACAP LENS EXT */
"133 " = "1" /* SIMPL ASPIR LENS EXTRACT */
"1341" = "1" /* CATARAC PHACOEMULS/ASPIR */
"1342" = "1" /* POST CATARAC FRAG/ASPIR */
"1343" = "1" /* CATARACT FRAG/ASPIR NEC */
"1351" = "1" /* TEMP-INF XTRACAP LENS EX */
"1359" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1361" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1362" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1363" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1364" = "1" /* AFTER-CATAR DISCISSION */
"1365" = "1" /* AFTER-CATARACT EXCISION */
"1366" = "1" /* AFTER CATAR FRAGMNTATION */
"1369" = "1" /* CATARACT EXTRACTION NEC */
"1370" = "1" /* INSERT PSEUDOPHAKOS NOS */
"1371" = "1" /* INSERT LENS AT CATAR EXT */
"1372" = "1" /* SECONDARY INSERT LENS */
"138 " = "1" /* IMPLANTED LENS REMOVAL */
"139 " = "1" /* OTHER OPERATIONS ON LENS */
"1390" = "1" /* OPERATION ON LENS NEC */
"1391" = "1" /* IMPL INTRAOC TELESC PROS */
"1400" = "1" /* REMOV POST SEGMNT FB NOS */
"1401" = "1" /* MAGNET REMOV POST SEG FB */
"1402" = "1" /* NONMAG REMOV POST SEG FB */
"1411" = "1" /* DIAGNOST VITREOUS ASPIR */
"1419" = "1" /* DX PROC POST SEG NEC */
"1421" = "1" /* CHORIORET LES DIATHERMY */
"1422" = "1" /* CHORIORETIN LES CRYOTHER */
"1426" = "1" /* CHORIORET LES RADIOTHER */
"1427" = "1" /* CHORIORET LES RAD IMPLAN */
"1429" = "1" /* CHORIORET LES DESTR NEC */
"1431" = "1" /* RETINAL TEAR DIATHERMY */
"1432" = "1" /* RETINAL TEAR CRYOTHERAPY */
"1439" = "1" /* RETINAL TEAR REPAIR NEC */
"1441" = "1" /* SCLERAL BUCKLE W IMPLANT */
"1449" = "1" /* SCLERAL BUCKLING NEC */
"1451" = "1" /* DETACH RETINA-DIATHERMY */
"1452" = "1" /* DETACH RETINA-CRYOTHERAP */
"1453" = "1" /* DETACH RETINA XENON COAG */
"1454" = "1" /* DETACH RETINA LASER COAG */
"1455" = "1" /* DETACH RET PHOTOCOAG NOS */
"1459" = "1" /* REPAIR RETINA DETACH NEC */
"146 " = "1" /* REMOV PROS MAT POST SEG */
"1471" = "1" /* ANTERIOR REMOV VITREOUS */
"1472" = "1" /* VITREOUS REMOVAL NEC */
"1473" = "1" /* ANTERIOR MECHAN VITRECT */
"1474" = "1" /* MECH VITRECTOMY NEC */
"1475" = "1" /* VITREOUS SUBSTITUT INJEC */
"1479" = "1" /* VITREOUS OPERATION NEC */
"149 " = "1" /* OTHER POST SEGMENT OPS */
"1501" = "1" /* EXTRAOC MUSC-TEND BIOPSY */
"1509" = "1" /* EXTRAOC MUSC DX PROC NEC */
"1511" = "1" /* ONE EXTRAOC MUS RECESS */
"1512" = "1" /* 1 EXTRAOC MUSCL ADVANCE */
"1513" = "1" /* 1 EXTRAOC MUSCL RESECT */
"1519" = "1" /* XTRAOC MUS OP/DETACH NEC */
"1521" = "1" /* LENGTHEN 1 EXTRAOC MUSC */
"1522" = "1" /* SHORTEN 1 EXTRAOC MUSC */
"1529" = "1" /* OP ON 1 EXTRAOC MUSC NEC */
"153 " = "1" /* TEMP DETACH >1 XTROC MUS */
"154 " = "1" /* OTH OP ON >L EXTRAOC MUS */
"155 " = "1" /* EXTRAOCUL MUS TRANSPOSIT */
"156 " = "1" /* REVIS EXTRAOC MUSC SURG */
"157 " = "1" /* EXTRAOC MUSC INJ REPAIR */
"159 " = "1" /* OTH EXTRAOC MUS-TEND OP */
"1601" = "1" /* ORBITOTOMY W BONE FLAP */
"1602" = "1" /* ORBITOTOMY W IMPLANT */
"1609" = "1" /* ORBITOTOMY NEC */
"161 " = "1" /* REMOVE PENETRAT FB EYE */
"1622" = "1" /* DIAGNOSTIC ASP OF ORBIT */
"1623" = "1" /* EYEBALL & ORBIT BIOPSY */
"1629" = "1" /* EYEBAL/ORBIT DX PROC NEC */
"1631" = "1" /* EYE EVISC W SYNCH IMPLAN */
"1639" = "1" /* EYEBALL EVISCERATION NEC */
"1641" = "1" /* EYE ENUC/IMPLAN/MUSC ATT */
"1642" = "1" /* EYE ENUC W IMPLANT NEC */
"1649" = "1" /* EYEBALL ENUCLEATION NEC */
"1651" = "1" /* RADICAL ORBITOMAXILLECT */
"1652" = "1" /* ORBIT EXENT W BONE REMOV */
"1659" = "1" /* ORBITAL EXENTERATION NEC */
"1661" = "1" /* 2NDRY OCULAR IMP INSERT */
"1662" = "1" /* REVIS/REINSERT OCUL IMP */
"1663" = "1" /* REVIS ENUC SOCKET W GRFT */
"1664" = "1" /* ENUC SOCKET REVIS NEC */
"1665" = "1" /* 2NDRY EXENT CAVITY GRAFT */
"1666" = "1" /* REVIS EXENTER CAVITY NEC */
"1669" = "1" /* 2ND OP POST EYE REM NEC */
"1671" = "1" /* REMOVE OCULAR IMPLANT */
"1672" = "1" /* REMOVE ORBITAL IMPLANT */
"1681" = "1" /* REPAIR OF ORBITAL WOUND */
"1682" = "1" /* REPAIR EYEBALL RUPTURE */
"1689" = "1" /* EYE/ORBIT INJ REPAIR NEC */
"1692" = "1" /* EXCISION ORBITAL LESION */
"1693" = "1" /* EXCISION EYE LESION NOS */
"1698" = "1" /* OPERATION ON ORBIT NEC */
"1699" = "1" /* OPERATION ON EYEBALL NEC */
"1821" = "1" /* PREAURICULAR SINUS EXCIS */
"1831" = "1" /* RAD EXCIS EXT EAR LES */
"1839" = "1" /* EXCIS EXTERNAL EAR NEC */
"185 " = "1" /* CORRECTION PROMINENT EAR */
"186 " = "1" /* EXT AUDIT CANAL RECONSTR */
"1871" = "1" /* CONSTRUCTION EAR AURICLE */
"1872" = "1" /* REATTACH AMPUTATED EAR */
"1879" = "1" /* PLASTIC REP EXT EAR NEC */
"189 " = "1" /* OTHER EXT EAR OPERATIONS */
"190 " = "1" /* STAPES MOBILIZATION */
"1911" = "1" /* STAPEDECT W REPLAC INCUS */
"1919" = "1" /* STAPEDECTOMY NEC */
"1921" = "1" /* REV STAPDEC W INCUS REPL */
"1929" = "1" /* STAPEDECTOMY REVIS NEC */
"193 " = "1" /* OSSICULAR CHAIN OP NEC */
"194 " = "1" /* MYRINGOPLASTY */
"1952" = "1" /* TYPE 2 TYMPANOPLASTY */
"1953" = "1" /* TYPE 3 TYMPANOPLASTY */
"1954" = "1" /* TYPE 4 TYMPANOPLASTY */
"1955" = "1" /* TYPE 5 TYMPANOPLASTY */
"196 " = "1" /* TYMPANOPLASTY REVISION */
"199 " = "1" /* MIDDLE EAR REPAIR NEC */
"2001" = "1" /* MYRINGOTOMY W INTUBATION */
"2021" = "1" /* MASTOID INCISION */
"2022" = "1" /* PETRUS PYRAM AIR CEL INC */
"2023" = "1" /* MIDDLE EAR INCISION */
"2032" = "1" /* MID & INNER EAR BIOPSY */
"2039" = "1" /* MID/IN EAR DX PROC NEC */
"2041" = "1" /* SIMPLE MASTOIDECTOMY */
"2042" = "1" /* RADICAL MASTOIDECTOMY */
"2049" = "1" /* MASTOIDECTOMY NEC */
"2051" = "1" /* EXCISE MIDDLE EAR LESION */
"2059" = "1" /* MIDDLE EAR EXCISION NEC */
"2061" = "1" /* INNER EAR FENESTRATION */
"2062" = "1" /* REVIS INNER EAR FENESTRA */
"2071" = "1" /* ENDOLYMPHATIC SHUNT */
"2072" = "1" /* INNER EAR INJECTION */
"2079" = "1" /* INC/EXC/DESTR IN EAR NEC */
"2091" = "1" /* TYMPANOSYMPATHECTOMY */
"2092" = "1" /* MASTOIDECTOMY REVISION */
"2093" = "1" /* REPAIR OVAL/ROUND WINDOW */
"2095" = "1" /* ELECMAG HEAR DEV IMPLANT */
"2096" = "1" /* IMPLT COCHLEAR PROST NOS */
"2097" = "1" /* IMP/REP SCHAN COCH PROS */
"2098" = "1" /* IMP/REP MCHAN COCHL PROS */
"2099" = "1" /* MID-INNER EAR OPS NEC */
"2104" = "1" /* ETHMOID ART LIGAT-EPIST */
"2105" = "1" /* MAX ART LIG FOR EPISTAX */
"2106" = "1" /* EXT CAROT ART LIG-EPIST */
"2107" = "1" /* NASAL SEPT GRFT-EPISTAX */
"2109" = "1" /* EPISTAXIS CONTROL NEC */
"214 " = "1" /* RESECTION OF NOSE */
"215 " = "1" /* SUBMUC NASAL SEPT RESECT */
"2161" = "1" /* DIATHER/CRYO TURBINECTOM */
"2162" = "1" /* TURBINATE FRACTURE */
"2169" = "1" /* TURBINECTOMY NEC */
"2172" = "1" /* OPEN REDUCTION NASAL FX */
"2182" = "1" /* NASAL FISTULA CLOSURE */
"2183" = "1" /* TOT NASAL RECONSTRUCTION */
"2184" = "1" /* REVISION RHINOPLASTY */
"2185" = "1" /* AUGMENTATION RHINOPLASTY */
"2186" = "1" /* LIMITED RHINOPLASTY */
"2187" = "1" /* RHINOPLASTY NEC */
"2188" = "1" /* SEPTOPLASTY NEC */
"2189" = "1" /* NASAL REPAIR NEC */
"2199" = "1" /* NASAL OPERATION NEC */
"2212" = "1" /* OPEN BIOPSY NASAL SINUS */
"2231" = "1" /* RADICAL MAXILLARY ANTROT */
"2239" = "1" /* EXT MAXILLARY ANTROT NEC */
"2241" = "1" /* FRONTAL SINUSOTOMY */
"2242" = "1" /* FRONTAL SINUSECTOMY */
"2250" = "1" /* SINUSOTOMY NOS */
"2251" = "1" /* ETHMOIDOTOMY */
"2252" = "1" /* SPHENOIDOTOMY */
"2253" = "1" /* MULTIPLE SINUS INCISION */
"2260" = "1" /* SINUSECTOMY NOS */
"2261" = "1" /* C-LUC EXC MAX SINUS LES */
"2262" = "1" /* EXC MAX SINUS LESION NEC */
"2263" = "1" /* ETHMOIDECTOMY */
"2264" = "1" /* SPHENOIDECTOMY */
"2271" = "1" /* NASAL SINUS FISTULA CLOS */
"2279" = "1" /* NASAL SINUS REPAIR NEC */
"229 " = "1" /* OTHER NASAL SINUS OPS */
"242 " = "1" /* GINGIVOPLASTY */
"244 " = "1" /* EXC OF DENTAL LES OF JAW */
"245 " = "1" /* ALVEOLOPLASTY */
"2502" = "1" /* OPEN BIOPSY OF TONGUE */
"251 " = "1" /* DESTRUCTION TONGUE LES */
"252 " = "1" /* PARTIAL GLOSSECTOMY */
"253 " = "1" /* COMPLETE GLOSSECTOMY */
"254 " = "1" /* RADICAL GLOSSECTOMY */
"2559" = "1" /* REPAIR OF TONGUE NEC */
"2594" = "1" /* OTHER GLOSSOTOMY */
"2599" = "1" /* TONGUE OPERATION NEC */
"2612" = "1" /* OPEN BX SALIV GLAND/DUCT */
"2621" = "1" /* SALIVARY CYST MARSUPIAL */
"2629" = "1" /* SALIV LESION EXCIS NEC */
"2630" = "1" /* SIALOADENECTOMY NOS */
"2631" = "1" /* PARTIAL SIALOADENECTOMY */
"2632" = "1" /* COMPLETE SIALOADENECTOMY */
"2641" = "1" /* SUTURE OF SALIV GLND LAC */
"2642" = "1" /* SALIVARY FISTULA CLOSURE */
"2649" = "1" /* SALIVARY REPAIR NEC */
"2699" = "1" /* SALIVARY OPERATION NEC */
"270 " = "1" /* DRAIN FACE & MOUTH FLOOR */
"271 " = "1" /* INCISION OF PALATE */
"2721" = "1" /* BONY PALATE BIOPSY */
"2722" = "1" /* UVULA AND SOFT PALATE BX */
"2731" = "1" /* LOC EXC BONY PALATE LES */
"2732" = "1" /* WIDE EXC BONY PALATE LES */
"2742" = "1" /* WIDE EXCISION OF LIP LES */
"2743" = "1" /* EXCISION OF LIP LES NEC */
"2749" = "1" /* EXCISION OF MOUTH NEC */
"2753" = "1" /* CLOSURE OF MOUTH FISTULA */
"2754" = "1" /* REPAIR OF CLEFT LIP */
"2755" = "1" /* FULL-THICK GRFT TO MOUTH */
"2756" = "1" /* SKIN GRAFT TO MOUTH NEC */
"2757" = "1" /* PEDICLE ATTACH TO MOUTH */
"2759" = "1" /* MOUTH REPAIR NEC */
"2761" = "1" /* SUTURE OF PALATE LACERAT */
"2762" = "1" /* CLEFT PALATE CORRECTION */
"2763" = "1" /* REVIS CLEFT PALAT REPAIR */
"2769" = "1" /* OTH PLASTIC REPAIR PALAT */
"2771" = "1" /* INCISION OF UVULA */
"2772" = "1" /* EXCISION OF UVULA */
"2773" = "1" /* REPAIR OF UVULA */
"2779" = "1" /* OTHER UVULA OPERATIONS */
"2792" = "1" /* MOUTH INCISION NOS */
"2799" = "1" /* ORAL CAVITY OPS NEC */
"280 " = "1" /* PERITONSILLAR I & D */
"2811" = "1" /* TONSIL&ADENOID BIOPSY */
"2819" = "1" /* TONSIL&ADENOID DX OP NEC */
"282 " = "1" /* TONSILLECTOMY */
"283 " = "1" /* TONSILLECTOMY/ADENOIDEC */
"284 " = "1" /* EXCISION OF TONSIL TAG */
"285 " = "1" /* EXCISION LINGUAL TONSIL */
"286 " = "1" /* ADENOIDECTOMY */
"287 " = "1" /* HEMORR CONTRL POST T & A */
"2891" = "1" /* INCIS TO REMOV TONSIL FB */
"2892" = "1" /* EXCIS TONSIL/ADENOID LES */
"2899" = "1" /* TONSIL/ADENOID OPS NEC */
"290 " = "1" /* PHARYNGOTOMY */
"292 " = "1" /* EXC BRANCHIAL CLEFT CYST */
"293 " = "1" /* EXC BRANCHIAL CLEFT CYST */
"2931" = "1" /* CRICOPHARYNGEAL MYOTOMY */
"2932" = "1" /* PHARYNGEAL DIVERTICULEC */
"2933" = "1" /* PHARYNGECTOMY */
"2939" = "1" /* EXCIS/DESTR LES PHAR NEC */
"294 " = "1" /* PLASTIC OP ON PHARYNX */
"2951" = "1" /* SUTURE OF PHARYNGEAL LAC */
"2952" = "1" /* CLOS BRANCH CLEFT FISTUL */
"2953" = "1" /* CLOS PHARYNX FISTULA NEC */
"2954" = "1" /* LYSIS PHARYNGEAL ADHES */
"2959" = "1" /* PHARYNGEAL REPAIR NEC */
"2992" = "1" /* DIVIS GLOSSOPHARYNG NERV */
"2999" = "1" /* PHARYNGEAL OPERATION NEC */
"3001" = "1" /* LARYNX CYST MARSUPIALIZ */
"3009" = "1" /* DESTRUCT LARYNX LES NEC */
"301 " = "1" /* HEMILARYNGECTOMY */
"3021" = "1" /* EPIGLOTTIDECTOMY */
"3022" = "1" /* VOCAL CORDECTOMY */
"3029" = "1" /* OTHER PART LARYNGECTOMY */
"303 " = "1" /* COMPLETE LARYNGECTOMY */
"304 " = "1" /* RADICAL LARYNGECTOMY */
"3121" = "1" /* MEDIASTINAL TRACHEOSTOMY */
"3129" = "1" /* OTHER PERM TRACHEOSTOMY */
"313 " = "1" /* INCIS LARYNX TRACHEA NEC */
"3145" = "1" /* OPN BX LARYNX OR TRACHEA */
"315 " = "1" /* LOCAL DESTRUC TRACH LES */
"3161" = "1" /* SUTURE OF LARYNGEAL LAC */
"3162" = "1" /* LARYNGEAL FISTULA CLOS */
"3163" = "1" /* LARYNGOSTOMY REVISION */
"3164" = "1" /* LARYNGEAL FX REPAIR */
"3169" = "1" /* OTHER LARYNGEAL REPAIR */
"3171" = "1" /* SUTURE OF TRACHEAL LACER */
"3172" = "1" /* CLOSURE OF TRACHEOSTOMY */
"3173" = "1" /* TRACHEA FISTULA CLOS NEC */
"3174" = "1" /* REVISION OF TRACHEOSTOMY */
"3175" = "1" /* TRACHEAL RECONSTRUCTION */
"3179" = "1" /* OTHER TRACHEAL REPAIR */
"3191" = "1" /* LARYNGEAL NERV DIVISION */
"3192" = "1" /* LYSIS TRACH/LARYNX ADHES */
"3198" = "1" /* OTH LARYNGEAL OPERATION */
"3199" = "1" /* OTHER TRACHEAL OPERATION */
"320 " = "1" /* OTHER TRACHEAL OPERATION */
"3209" = "1" /* OTHER DESTRUC BRONC LES */
"321 " = "1" /* OTHER BRONCHIAL EXCISION */
"3221" = "1" /* EMPHYSEMA BLEB PLICATION */
"3222" = "1" /* LUNG VOL REDUCTION SURG */
"3223" = "1" /* OPEN ABLTN LUNG LES/TISS */
"3224" = "1" /* PERC ABLTN LUNG LES/TISS */
"3225" = "1" /* THOR ABLTN LUNG LES/TISS */
"3226" = "1" /* ABLTN LUNG TISS NEC/NOS */
"3229" = "1" /* DESTROY LOC LUNG LES NEC */
"323 " = "1" /* SEGMENTAL LUNG RESECTION */
"324 " = "1" /* LOBECTOMY OF LUNG */
"325 " = "1" /* COMPLETE PNEUMONECTOMY */
"326 " = "1" /* RAD DISSEC THORAC STRUCT */
"329 " = "1" /* OTHER EXCISION OF LUNG */
"330 " = "1" /* INCISION OF BRONCHUS */
"331 " = "1" /* INCISION OF LUNG */
"3325" = "1" /* OPEN BRONCHIAL BIOPSY */
"3327" = "1" /* CLOS ENDOSCOPIC LUNG BX */
"3328" = "1" /* OPEN LUNG BIOPSY */
"3329" = "1" /* BRONCH/LUNG DX PROC NEC */
"3334" = "1" /* THORACOPLASTY */
"3339" = "1" /* SURG COLLAPS OF LUNG NEC */
"3341" = "1" /* BRONCHIAL LACERAT SUTURE */
"3342" = "1" /* BRONCHIAL FISTULA CLOS */
"3343" = "1" /* LUNG LACERATION CLOSURE */
"3348" = "1" /* BRONCHIAL REPAIR NEC */
"3349" = "1" /* LUNG REPAIR NEC */
"335 " = "1" /* LUNG REPAIR NEC */
"3350" = "1" /* LUNG TRANSPLANT NOS */
"3351" = "1" /* UNILAT LUNG TRANSPLANT */
"3352" = "1" /* BILAT LUNG TRANSPLANT */
"336 " = "1" /* COMB HEART/LUNG TRANSPLA */
"3392" = "1" /* BRONCHIAL LIGATION */
"3393" = "1" /* PUNCTURE OF LUNG */
"3398" = "1" /* BRONCHIAL OPERATION NEC */
"3399" = "1" /* LUNG OPERATION NEC */
"3402" = "1" /* EXPLORATORY THORACOTOMY */
"3403" = "1" /* REOPEN THORACOTOMY SITE */
"341 " = "1" /* INCISION OF MEDIASTINUM */
"3421" = "1" /* TRANSPLEURA THORACOSCOPY */
"3422" = "1" /* MEDIASTINOSCOPY */
"3426" = "1" /* OPEN MEDIASTINAL BIOPSY */
"3427" = "1" /* BIOPSY OF DIAPHRAGM */
"3428" = "1" /* DX PROCEDURE THORAX NEC */
"3429" = "1" /* DX PROC MEDIASTINUM NEC */
"343 " = "1" /* DESTRUCT MEDIASTIN LES */
"344 " = "1" /* DESTRUCT CHEST WALL LES */
"3451" = "1" /* DECORTICATION OF LUNG */
"3459" = "1" /* OTHER PLEURAL EXCISION */
"346 " = "1" /* SCARIFICATION OF PLEURA */
"3473" = "1" /* CLOS THORACIC FISTUL NEC */
"3474" = "1" /* PECTUS DEFORMITY REPAIR */
"3479" = "1" /* OTHER CHEST WALL REPAIR */
"3481" = "1" /* EXCISE DIAPHRAGM LESION */
"3482" = "1" /* SUTURE DIAPHRAGM LACERAT */
"3483" = "1" /* CLOSE DIAPHRAGM FISTULA */
"3484" = "1" /* OTHER DIAPHRAGM REPAIR */
"3485" = "1" /* IMPLANT DIAPHRA PACEMAKE */
"3489" = "1" /* DIAPHRAGM OPERATION NEC */
"3493" = "1" /* REPAIR OF PLEURA */
"3499" = "1" /* THORACIC OPERATION NEC */
"3500" = "1" /* CLOSED VALVOTOMY NOS */
"3501" = "1" /* CLOSED AORTIC VALVOTOMY */
"3502" = "1" /* CLOSED MITRAL VALVOTOMY */
"3503" = "1" /* CLOSED PULMON VALVOTOMY */
"3504" = "1" /* CLOSED TRICUSP VALVOTOMY */
"3510" = "1" /* OPEN VALVULOPLASTY NOS */
"3511" = "1" /* OPN AORTIC VALVULOPLASTY */
"3512" = "1" /* OPN MITRAL VALVULOPLASTY */
"3513" = "1" /* OPN PULMON VALVULOPLASTY */
"3514" = "1" /* OPN TRICUS VALVULOPLASTY */
"3520" = "1" /* REPLACE HEART VALVE NOS */
"3521" = "1" /* REPLACE AORT VALV-TISSUE */
"3522" = "1" /* REPLACE AORTIC VALVE NEC */
"3523" = "1" /* REPLACE MITR VALV-TISSUE */
"3524" = "1" /* REPLACE MITRAL VALVE NEC */
"3525" = "1" /* REPLACE PULM VALV-TISSUE */
"3526" = "1" /* REPLACE PULMON VALVE NEC */
"3527" = "1" /* REPLACE TRIC VALV-TISSUE */
"3528" = "1" /* REPLACE TRICUSP VALV NEC */
"3531" = "1" /* PAPILLARY MUSCLE OPS */
"3532" = "1" /* CHORDAE TENDINEAE OPS */
"3533" = "1" /* ANNULOPLASTY */
"3534" = "1" /* INFUNDIBULECTOMY */
"3535" = "1" /* TRABECUL CARNEAE CORD OP */
"3539" = "1" /* TISS ADJ TO VALV OPS NEC */
"3542" = "1" /* CREATE SEPTAL DEFECT */
"3550" = "1" /* PROSTH REP HRT SEPTA NOS */
"3551" = "1" /* PROS REP ATRIAL DEF-OPN */
"3552" = "1" /* PROS REPAIR ATRIA DEF-CL */
"3553" = "1" /* PROST REPAIR VENTRIC DEF */
"3554" = "1" /* PROS REP ENDOCAR CUSHION */
"3555" = "1" /* PROS REP VENTRC DEF-CLOS */
"3560" = "1" /* GRFT REPAIR HRT SEPT NOS */
"3561" = "1" /* GRAFT REPAIR ATRIAL DEF */
"3562" = "1" /* GRAFT REPAIR VENTRIC DEF */
"3563" = "1" /* GRFT REP ENDOCAR CUSHION */
"3570" = "1" /* HEART SEPTA REPAIR NOS */
"3571" = "1" /* ATRIA SEPTA DEF REP NEC */
"3572" = "1" /* VENTR SEPTA DEF REP NEC */
"3573" = "1" /* ENDOCAR CUSHION REP NEC */
"3581" = "1" /* TOT REPAIR TETRAL FALLOT */
"3582" = "1" /* TOTAL REPAIR OF TAPVC */
"3583" = "1" /* TOT REP TRUNCUS ARTERIOS */
"3584" = "1" /* TOT COR TRANSPOS GRT VES */
"3591" = "1" /* INTERAT VEN RETRN TRANSP */
"3592" = "1" /* CONDUIT RT VENT-PUL ART */
"3593" = "1" /* CONDUIT LEFT VENTR-AORTA */
"3594" = "1" /* CONDUIT ARTIUM-PULM ART */
"3595" = "1" /* HEART REPAIR REVISION */
"3596" = "1" /* PERC HEART VALVULOPLASTY */
"3598" = "1" /* OTHER HEART SEPTA OPS */
"3599" = "1" /* OTHER HEART VALVE OPS */
"3600" = "1" /* OTHER HEART VALVE OPS */
"3601" = "1" /* PTCA-1 VES/ATH W/O AGENT */
"3602" = "1" /* PTCA-1 VES/ATH W AGENT */
"3603" = "1" /* OPEN CORONRY ANGIOPLASTY */
"3605" = "1" /* PTCA-MULTIPLE VESSEL/ATH */
"3609" = "1" /* REM OF COR ART OBSTR NEC */
"3610" = "1" /* AORTOCORONARY BYPASS NOS */
"3611" = "1" /* AORTOCOR BYPAS-1 COR ART */
"3612" = "1" /* AORTOCOR BYPAS-2 COR ART */
"3613" = "1" /* AORTOCOR BYPAS-3 COR ART */
"3614" = "1" /* AORTCOR BYPAS-4+ COR ART */
"3615" = "1" /* 1 INT MAM-COR ART BYPASS */
"3616" = "1" /* 2 INT MAM-COR ART BYPASS */
"3617" = "1" /* ABD-CORON ARTERY BYPASS */
"3619" = "1" /* HRT REVAS BYPS ANAS NEC */
"362 " = "1" /* ARTERIAL IMPLANT REVASC */
"363 " = "1" /* ARTERIAL IMPLANT REVASC */
"3631" = "1" /* OPEN CHEST TRANS REVASC */
"3632" = "1" /* OTH TRANSMYO REVASCULAR */
"3633" = "1" /* ENDO TRANSMYO REVASCULAR */
"3634" = "1" /* PERC TRANSMYO REVASCULAR */
"3639" = "1" /* OTH HEART REVASCULAR */
"3691" = "1" /* CORON VESS ANEURYSM REP */
"3699" = "1" /* HEART VESSEL OP NEC */
"3710" = "1" /* INCISION OF HEART NOS */
"3711" = "1" /* CARDIOTOMY */
"3712" = "1" /* PERICARDIOTOMY */
"3724" = "1" /* PERICARDIAL BIOPSY */
"3731" = "1" /* PERICARDIECTOMY */
"3732" = "1" /* HEART ANEURYSM EXCISION */
"3733" = "1" /* EXC/DEST HRT LESION OPEN */
"3734" = "1" /* EXC/DEST HRT LES OTHER */
"3735" = "1" /* PARTIAL VENTRICULECTOMY */
"374 " = "1" /* HEART & PERICARD REPAIR */
"3741" = "1" /* IMPL CARDIAC SUPPORT DEV */
"3749" = "1" /* HEART/PERICARD REPR NEC */
"375 " = "1" /* HEART & PERICARD REPAIR */
"3751" = "1" /* HEART TRANSPLANTATION */
"3752" = "1" /* IMPLANT TOT REP HRT SYS */
"3753" = "1" /* REPL/REP THORAC UNIT HRT */
"3754" = "1" /* REPL/REP OTH TOT HRT SYS */
"3761" = "1" /* PULSATION BALLOON IMPLAN */
"3762" = "1" /* IMPLANT HRT ASST SYS NEC */
"3763" = "1" /* REPLACE HRT ASSIST SYST */
"3764" = "1" /* REMOVE HEART ASSIST SYS */
"3765" = "1" /* IMP EXT PUL HRT ASST SYS */
"3766" = "1" /* IMP IMP PUL HRT ASST SYS */
"3767" = "1" /* IMP CARDIOMYOSTIMUL SYS */
"3774" = "1" /* INT OR REPL LEAD EPICAR */
"3775" = "1" /* REVISION OF LEAD */
"3776" = "1" /* REPL TV ATRI-VENT LEAD */
"3777" = "1" /* REMOVAL OF LEAD W/O REPL */
"3779" = "1" /* REVIS OR RELOCATE POCKET */
"3780" = "1" /* INT OR REPL PERM PACEMKR */
"3785" = "1" /* REPL PACEM W 1-CHAM, NON */
"3786" = "1" /* REPL PACEM 1-CHAM, RATE */
"3787" = "1" /* REPL PACEM W DUAL-CHAM */
"3789" = "1" /* REVISE OR REMOVE PACEMAK */
"3790" = "1" /* INS LEFT ATR APPEND DEV */
"3791" = "1" /* OPN CHEST CARDIAC MASSAG */
"3794" = "1" /* IMPLT/REPL CARDDEFIB TOT */
"3795" = "1" /* IMPLT CARDIODEFIB LEADS */
"3796" = "1" /* IMPLT CARDIODEFIB GENATR */
"3797" = "1" /* REPL CARDIODEFIB LEADS */
"3798" = "1" /* REPL CARDIODEFIB GENRATR */
"3799" = "1" /* OTHER HEART/PERICARD OPS */
"3800" = "1" /* INCISION OF VESSEL NOS */
"3801" = "1" /* INTRACRAN VESSEL INCIS */
"3802" = "1" /* HEAD/NECK VES INCIS NEC */
"3803" = "1" /* UPPER LIMB VESSEL INCIS */
"3804" = "1" /* INCISION OF AORTA */
"3805" = "1" /* THORACIC VESSEL INC NEC */
"3806" = "1" /* ABDOMEN ARTERY INCISION */
"3807" = "1" /* ABDOMINAL VEIN INCISION */
"3808" = "1" /* LOWER LIMB ARTERY INCIS */
"3809" = "1" /* LOWER LIMB VEIN INCISION */
"3810" = "1" /* ENDARTERECTOMY NOS */
"3811" = "1" /* INTRACRAN ENDARTERECTOMY */
"3812" = "1" /* HEAD & NECK ENDARTER NEC */
"3813" = "1" /* UPPER LIMB ENDARTERECTOM */
"3814" = "1" /* ENDARTERECTOMY OF AORTA */
"3815" = "1" /* THORACIC ENDARTERECTOMY */
"3816" = "1" /* ABDOMINAL ENDARTERECTOMY */
"3818" = "1" /* LOWER LIMB ENDARTERECT */
"3821" = "1" /* BLOOD VESSEL BIOPSY */
"3829" = "1" /* BLOOD VESSEL DX PROC NEC */
"3830" = "1" /* VESSEL RESECT/ANAST NOS */
"3831" = "1" /* INTRACRAN VES RESEC-ANAS */
"3832" = "1" /* HEAD/NECK VES RESEC-ANAS */
"3833" = "1" /* ARM VESSEL RESECT/ANAST */
"3834" = "1" /* AORTA RESECTION & ANAST */
"3835" = "1" /* THOR VESSEL RESECT/ANAST */
"3836" = "1" /* ABD VESSEL RESECT/ANAST */
"3837" = "1" /* ABD VEIN RESECT & ANAST */
"3838" = "1" /* LEG ARTERY RESECT/ANAST */
"3839" = "1" /* LEG VEIN RESECT/ANASTOM */
"3840" = "1" /* VESSEL RESECT/REPLAC NOS */
"3841" = "1" /* INTRACRAN VES RESEC-REPL */
"3842" = "1" /* HEAD/NECK VES RESEC-REPL */
"3843" = "1" /* ARM VES RESECT W REPLACE */
"3844" = "1" /* RESECT ABDM AORTA W REPL */
"3845" = "1" /* RESECT THORAC VES W REPL */
"3846" = "1" /* ABD ARTERY RESEC W REPLA */
"3847" = "1" /* ABD VEIN RESECT W REPLAC */
"3848" = "1" /* LEG ARTERY RESEC W REPLA */
"3849" = "1" /* LEG VEIN RESECT W REPLAC */
"3850" = "1" /* VARICOSE V LIG-STRIP NOS */
"3851" = "1" /* INTCRAN VAR V LIG-STRIP */
"3852" = "1" /* HEAD/NECK VAR V LIG-STR */
"3853" = "1" /* ARM VARICOSE V LIG-STRIP */
"3855" = "1" /* THORAC VAR V LIG-STRIP */
"3857" = "1" /* ABD VARICOS V LIGA-STRIP */
"3859" = "1" /* LEG VARICOS V LIGA-STRIP */
"3860" = "1" /* EXCISION OF VESSEL NOS */
"3861" = "1" /* INTRACRAN VESSEL EXCIS */
"3862" = "1" /* HEAD/NECK VESSEL EXCIS */
"3863" = "1" /* ARM VESSEL EXCISION */
"3864" = "1" /* EXCISION OF AORTA */
"3865" = "1" /* THORACIC VESSEL EXCISION */
"3866" = "1" /* ABDOMINAL ARTERY EXCIS */
"3867" = "1" /* ABDOMINAL VEIN EXCISION */
"3868" = "1" /* LEG ARTERY EXCISION */
"3869" = "1" /* LEG VEIN EXCISION */
"387 " = "1" /* INTERRUPTION VENA CAVA */
"3880" = "1" /* SURG VESSEL OCCLUS NEC */
"3881" = "1" /* OCCLUS INTRACRAN VES NEC */
"3882" = "1" /* OCCLUS HEAD/NECK VES NEC */
"3883" = "1" /* OCCLUDE ARM VESSEL NEC */
"3884" = "1" /* OCCLUDE AORTA NEC */
"3885" = "1" /* OCCLUDE THORACIC VES NEC */
"3886" = "1" /* OCCLUDE ABD ARTERY NEC */
"3887" = "1" /* OCCLUDE ABD VEIN NEC */
"3888" = "1" /* OCCLUDE LEG ARTERY NEC */
"3889" = "1" /* OCCLUDE LEG VEIN NEC */
"390 " = "1" /* SYSTEMIC-PULM ART SHUNT */
"391 " = "1" /* INTRA-ABD VENOUS SHUNT */
"3921" = "1" /* CAVAL-PULMON ART ANASTOM */
"3922" = "1" /* AORTA-SUBCLV-CAROT BYPAS */
"3923" = "1" /* INTRATHORACIC SHUNT NEC */
"3924" = "1" /* AORTA-RENAL BYPASS */
"3925" = "1" /* AORTA-ILIAC-FEMOR BYPASS */
"3926" = "1" /* INTRA-ABDOMIN SHUNT NEC */
"3927" = "1" /* DIALYSIS ARTERIOVENOSTOM */
"3928" = "1" /* EXTRACRAN-INTRACR BYPASS */
"3929" = "1" /* VASC SHUNT & BYPASS NEC */
"3930" = "1" /* SUTURE OF VESSEL NOS */
"3931" = "1" /* SUTURE OF ARTERY */
"3932" = "1" /* SUTURE OF VEIN */
"3941" = "1" /* POSTOP VASC OP HEM CONTR */
"3942" = "1" /* REVIS REN DIALYSIS SHUNT */
"3943" = "1" /* REMOV REN DIALYSIS SHUNT */
"3949" = "1" /* VASC PROC REVISION NEC */
"3950" = "1" /* ANGIO/ATH NON-CORO VES */
"3951" = "1" /* CLIPPING OF ANEURYSM */
"3952" = "1" /* ANEURYSM REPAIR NEC */
"3953" = "1" /* ARTERIOVEN FISTULA REP */
"3954" = "1" /* RE-ENTRY OPERATION */
"3955" = "1" /* REIMPLAN ABERR RENAL VES */
"3956" = "1" /* REPAIR VESS W TIS PATCH */
"3957" = "1" /* REP VESS W SYNTH PATCH */
"3958" = "1" /* REPAIR VESS W PATCH NOS */
"3959" = "1" /* REPAIR OF VESSEL NEC */
"397 " = "1" /* PER CARDIOPULMON BYPASS */
"3971" = "1" /* ENDO IMPL GRFT ABD AORTA */
"3972" = "1" /* ENDOVASC REPAIR HEAD VES */
"3973" = "1" /* ENDO IMP GRFT THOR AORTA */
"3974" = "1" /* ENDO REM OBS HD/NECK VES */
"3979" = "1" /* ENDO REPAIR OTHER VESSEL */
"398 " = "1" /* VASCULAR BODY OPERATIONS */
"3991" = "1" /* FREEING OF VESSEL */
"3992" = "1" /* VEIN INJECT-SCLEROS AGNT */
"3993" = "1" /* INSERT VES-TO-VES CANNUL */
"3994" = "1" /* REPLAC VES-TO-VES CANNUL */
"3998" = "1" /* HEMORRHAGE CONTROL NOS */
"3999" = "1" /* VESSEL OPERATION NEC */
"400 " = "1" /* INCIS LYMPHATIC STRUCTUR */
"4011" = "1" /* LYMPHATIC STRUCT BIOPSY */
"4019" = "1" /* LYMPHATIC DIAG PROC NEC */
"4021" = "1" /* EXCIS DEEP CERVICAL NODE */
"4022" = "1" /* EXCISE INT MAMMARY NODE */
"4023" = "1" /* EXCISE AXILLARY NODE */
"4024" = "1" /* EXCISE INGUINAL NODE */
"4029" = "1" /* SIMP EXC LYMPH STRUC NEC */
"403 " = "1" /* REGIONAL LYMPH NODE EXC */
"4040" = "1" /* RAD NECK DISSECTION NOS */
"4041" = "1" /* UNILAT RAD NECK DISSECT */
"4042" = "1" /* BILAT RAD NECK DISSECT */
"4050" = "1" /* RAD NODE DISSECTION NOS */
"4051" = "1" /* RAD DISSEC AXILLARY NODE */
"4052" = "1" /* RAD DISSEC PERIAORT NODE */
"4053" = "1" /* RAD DISSECT ILIAC NODES */
"4054" = "1" /* RADICAL GROIN DISSECTION */
"4059" = "1" /* RAD NODE DISSECTION NEC */
"4061" = "1" /* THORAC DUCT CANNULATION */
"4062" = "1" /* THORACIC DUCT FISTULIZAT */
"4063" = "1" /* CLOSE THORACIC DUCT FIST */
"4064" = "1" /* LIGATE THORACIC DUCT */
"4069" = "1" /* THORACIC DUCT OP NEC */
"409 " = "1" /* LYMPH STRUCTURE OP NEC */
"412 " = "1" /* SPLENOTOMY */
"4133" = "1" /* OPEN SPLEEN BIOPSY */
"4141" = "1" /* SPLENIC CYST MARSUPIAL */
"4142" = "1" /* EXC SPLENIC LESION/TISS */
"4143" = "1" /* PARTIAL SPLENECTOMY */
"415 " = "1" /* TOTAL SPLENECTOMY */
"4193" = "1" /* EXC OF ACCESSORY SPLEEN */
"4194" = "1" /* SPLEEN TRANSPLANTATION */
"4195" = "1" /* REPAIR OF SPLEEN */
"4199" = "1" /* SPLEEN OPERATION NEC */
"4201" = "1" /* ESOPHAGEAL WEB INCISION */
"4209" = "1" /* ESOPHAGEAL INCISION NEC */
"4210" = "1" /* ESOPHAGOSTOMY NOS */
"4211" = "1" /* CERVICAL ESOPHAGOSTOMY */
"4212" = "1" /* ESOPH POUCH EXTERIORIZAT */
"4219" = "1" /* EXT FISTULIZAT ESOPH NEC */
"4221" = "1" /* ESOPHAGOSCOPY BY INCIS */
"4225" = "1" /* OPEN BIOPSY OF ESOPHAGUS */
"4231" = "1" /* LOC EXCIS ESOPH DIVERTIC */
"4232" = "1" /* LOCAL EXCIS ESOPHAG NEC */
"4239" = "1" /* DESTRUCT ESOPHAG LES NEC */
"4240" = "1" /* ESOPHAGECTOMY NOS */
"4241" = "1" /* PARTIAL ESOPHAGECTOMY */
"4242" = "1" /* TOTAL ESOPHAGECTOMY */
"4251" = "1" /* THORAC ESOPHAGOESOPHAGOS */
"4252" = "1" /* THORAC ESOPHAGOGASTROST */
"4253" = "1" /* THORAC SM BOWEL INTERPOS */
"4254" = "1" /* THORAC ESOPHAGOENTER NEC */
"4255" = "1" /* THORAC LG BOWEL INTERPOS */
"4256" = "1" /* THORAC ESOPHAGOCOLOS NEC */
"4258" = "1" /* THORAC INTERPOSITION NEC */
"4259" = "1" /* THORAC ESOPHAG ANAST NEC */
"4261" = "1" /* STERN ESOPHAGOESOPHAGOST */
"4262" = "1" /* STERN ESOPHAGOGASTROSTOM */
"4263" = "1" /* STERN SM BOWEL INTERPOS */
"4264" = "1" /* STERN ESOPHAGOENTER NEC */
"4265" = "1" /* STERN LG BOWEL INTERPOS */
"4266" = "1" /* STERN ESOPHAGOCOLOS NEC */
"4268" = "1" /* STERN INTERPOSITION NEC */
"4269" = "1" /* STERN ESOPHAG ANAST NEC */
"427 " = "1" /* ESOPHAGOMYOTOMY */
"4282" = "1" /* SUTURE ESOPHAGEAL LACER */
"4283" = "1" /* ESOPHAGOSTOMY CLOSURE */
"4284" = "1" /* ESOPH FISTULA REPAIR NEC */
"4285" = "1" /* ESOPHAG STRICTURE REPAIR */
"4286" = "1" /* PROD SUBQ TUNNEL NO ANAS */
"4287" = "1" /* ESOPHAGEAL GRAFT NEC */
"4289" = "1" /* ESOPHAGEAL REPAIR NEC */
"4291" = "1" /* LIGATION ESOPH VARIX */
"430 " = "1" /* GASTROTOMY */
"431 " = "1" /* GASTROTOMY */
"432 " = "1" /* OTHER GASTROSTOMY */
"433 " = "1" /* PYLOROMYOTOMY */
"4342" = "1" /* LOCAL GASTR EXCISION NEC */
"4349" = "1" /* LOCAL GASTR DESTRUCT NEC */
"435 " = "1" /* PROXIMAL GASTRECTOMY */
"436 " = "1" /* DISTAL GASTRECTOMY */
"437 " = "1" /* PART GASTREC W JEJ ANAST */
"4381" = "1" /* PART GAST W JEJ TRANSPOS */
"4389" = "1" /* PARTIAL GASTRECTOMY NEC */
"4391" = "1" /* TOT GAST W INTES INTERPO */
"4399" = "1" /* TOTAL GASTRECTOMY NEC */
"4400" = "1" /* VAGOTOMY NOS */
"4401" = "1" /* TRUNCAL VAGOTOMY */
"4402" = "1" /* HIGHLY SELECT VAGOTOMY */
"4403" = "1" /* SELECTIVE VAGOTOMY NEC */
"4411" = "1" /* TRANSABDOMIN GASTROSCOPY */
"4415" = "1" /* OPEN GASTRIC BIOPSY */
"442 " = "1" /* GASTRIC DIAGNOS PROC NEC */
"4421" = "1" /* DILATE PYLORUS, INCISION */
"4429" = "1" /* OTHER PYLOROPLASTY */
"4431" = "1" /* HIGH GASTRIC BYPASS */
"4432" = "1" /* PERCU GASTROJEJUNOSTOMY */
"4438" = "1" /* LAP GASTROENTEROSTOMY */
"4439" = "1" /* GASTROENTEROSTOMY NEC */
"4440" = "1" /* SUTURE PEPTIC ULCER NOS */
"4441" = "1" /* SUT GASTRIC ULCER SITE */
"4442" = "1" /* SUTURE DUODEN ULCER SITE */
"445 " = "1" /* REVISION GASTRIC ANASTOM */
"4461" = "1" /* SUTURE GASTRIC LACERAT */
"4463" = "1" /* CLOSE GASTRIC FISTUL NEC */
"4464" = "1" /* GASTROPEXY */
"4465" = "1" /* ESOPHAGOGASTROPLASTY */
"4466" = "1" /* CREAT ESOPHAGASTR SPHINC */
"4467" = "1" /* LAP CREAT ESOPH SPHINCT */
"4468" = "1" /* LAPAROSCOP GASTROPLASTY */
"4469" = "1" /* GASTRIC REPAIR NEC */
"4491" = "1" /* LIGATE GASTRIC VARICES */
"4492" = "1" /* INTRAOP GASTRIC MANIPUL */
"4495" = "1" /* LAP GASTRIC RESTRIC PROC */
"4496" = "1" /* LAP REV GAST RESTRI PROC */
"4497" = "1" /* LAP REM GAST RESTRIC DEV */
"4498" = "1" /* ADJUST GAST RESTRICT DEV */
"4499" = "1" /* GASTRIC OPERATION NEC */
"4500" = "1" /* INTESTINAL INCISION NOS */
"4501" = "1" /* DUODENAL INCISION */
"4502" = "1" /* SMALL BOWEL INCISION NEC */
"4503" = "1" /* LARGE BOWEL INCISION */
"4511" = "1" /* TRANSAB SM BOWEL ENDOSC */
"4515" = "1" /* OPEN SMALL BOWEL BIOPSY */
"4521" = "1" /* TRANSAB LG BOWEL ENDOSC */
"4526" = "1" /* OPEN LARGE BOWEL BIOPSY */
"4531" = "1" /* OTH EXCISE DUODENUM LES */
"4532" = "1" /* DESTRUCT DUODEN LES NEC */
"4533" = "1" /* LOCAL EXCIS SM BOWEL NEC */
"4534" = "1" /* DESTR SM BOWEL LES NEC */
"4541" = "1" /* EXCISE LG INTESTINE LES */
"4549" = "1" /* DESTRUC LG BOWEL LES NEC */
"4550" = "1" /* INTEST SEG ISOLAT NOS */
"4551" = "1" /* SM BOWEL SEGMENT ISOLAT */
"4552" = "1" /* LG BOWEL SEGMENT ISOLAT */
"4561" = "1" /* MULT SEG SM BOWEL EXCIS */
"4562" = "1" /* PART SM BOWEL RESECT NEC */
"4563" = "1" /* TOTAL REMOVAL SM BOWEL */
"4571" = "1" /* MULT SEG LG BOWEL EXCIS */
"4572" = "1" /* CECECTOMY */
"4573" = "1" /* RIGHT HEMICOLECTOMY */
"4574" = "1" /* TRANSVERSE COLON RESECT */
"4575" = "1" /* LEFT HEMICOLECTOMY */
"4576" = "1" /* SIGMOIDECTOMY */
"4579" = "1" /* PART LG BOWEL EXCIS NEC */
"458 " = "1" /* TOT INTRA-ABD COLECTOMY */
"4590" = "1" /* INTESTINAL ANASTOM NOS */
"4591" = "1" /* SM-TO-SM BOWEL ANASTOM */
"4592" = "1" /* SM BOWEL-RECT STUMP ANAS */
"4593" = "1" /* SMALL-TO-LARGE BOWEL NEC */
"4594" = "1" /* LG-TO-LG BOWEL ANASTOM */
"4595" = "1" /* ANAL ANASTOMOSIS */
"4601" = "1" /* SM BOWEL EXTERIORIZATION */
"4602" = "1" /* RESECT EXT SEG SM BOWEL */
"4603" = "1" /* LG BOWEL EXTERIORIZATION */
"4604" = "1" /* RESECT EXT SEG LG BOWEL */
"4610" = "1" /* COLOSTOMY NOS */
"4611" = "1" /* TEMPORARY COLOSTOMY */
"4612" = "1" /* TEMPORARY COLOSTOMY */
"4613" = "1" /* PERMANENT COLOSTOMY */
"4620" = "1" /* ILEOSTOMY NOS */
"4621" = "1" /* TEMPORARY ILEOSTOMY */
"4622" = "1" /* CONTINENT ILEOSTOMY */
"4623" = "1" /* PERMANENT ILEOSTOMY NEC */
"4640" = "1" /* INTEST STOMA REVIS NOS */
"4641" = "1" /* SM BOWEL STOMA REVISION */
"4642" = "1" /* PERICOLOST HERNIA REPAIR */
"4643" = "1" /* LG BOWEL STOMA REVIS NEC */
"4650" = "1" /* INTEST STOMA CLOSURE NOS */
"4651" = "1" /* SM BOWEL STOMA CLOSURE */
"4652" = "1" /* LG BOWEL STOMA CLOSURE */
"4660" = "1" /* INTESTINAL FIXATION NOS */
"4661" = "1" /* SM BOWEL-ABD WALL FIXAT */
"4662" = "1" /* SMALL BOWEL FIXATION NEC */
"4663" = "1" /* LG BOWEL-ABD WALL FIXAT */
"4664" = "1" /* LARGE BOWEL FIXATION NEC */
"4671" = "1" /* DUODENAL LACERAT SUTURE */
"4672" = "1" /* DUODENAL FISTULA CLOSURE */
"4673" = "1" /* SMALL BOWEL SUTURE NEC */
"4674" = "1" /* CLOSE SM BOWEL FIST NEC */
"4675" = "1" /* SUTURE LG BOWEL LACERAT */
"4676" = "1" /* CLOSE LG BOWEL FISTULA */
"4679" = "1" /* REPAIR OF INTESTINE NEC */
"4680" = "1" /* INTRA-AB BOWEL MANIP NOS */
"4681" = "1" /* INTRA-ABD SM BOWEL MANIP */
"4682" = "1" /* INTRA-ABD LG BOWEL MANIP */
"4691" = "1" /* MYOTOMY OF SIGMOID COLON */
"4692" = "1" /* MYOTOMY OF COLON NEC */
"4693" = "1" /* REVISE SM BOWEL ANASTOM */
"4694" = "1" /* REVISE LG BOWEL ANASTOM */
"4697" = "1" /* TRANSPLANT OF INTESTINE */
"4699" = "1" /* INTESTINAL OP NEC */
"470 " = "1" /* INTESTINAL OP NEC */
"4701" = "1" /* LAP APPENDECTOMY */
"4709" = "1" /* OTHER APPENDECTOMY */
"471 " = "1" /* OTHER APPENDECTOMY */
"4711" = "1" /* LAP INCID APPENDECTOMY */
"4719" = "1" /* OTHER INCID APPENDECTOMY */
"472 " = "1" /* DRAIN APPENDICEAL ABSC */
"4791" = "1" /* APPENDICOSTOMY */
"4792" = "1" /* CLOSE APPENDICEAL FISTUL */
"4799" = "1" /* APPENDICEAL OPS NEC */
"480 " = "1" /* PROCTOTOMY */
"481 " = "1" /* PROCTOSTOMY */
"4821" = "1" /* TRANSAB PROCTOSIGMOIDOSC */
"4825" = "1" /* OPEN RECTAL BIOPSY */
"4835" = "1" /* LOCAL EXCIS RECTAL LES */
"4841" = "1" /* SOAVE SUBMUC RECT RESECT */
"4849" = "1" /* PULL-THRU RECT RESEC NEC */
"485 " = "1" /* ABD-PERINEAL RECT RESECT */
"4861" = "1" /* TRANSSAC RECTOSIGMOIDECT */
"4862" = "1" /* ANT RECT RESECT W COLOST */
"4863" = "1" /* ANTERIOR RECT RESECT NEC */
"4864" = "1" /* POSTERIOR RECT RESECTION */
"4865" = "1" /* DUHAMEL RECTAL RESECTION */
"4866" = "1" /* DUHAMEL RECTAL RESECTION */
"4869" = "1" /* RECTAL RESECTION NEC */
"4871" = "1" /* SUTURE OF RECTAL LACER */
"4872" = "1" /* CLOSURE OF PROCTOSTOMY */
"4873" = "1" /* CLOSE RECTAL FIST NEC */
"4874" = "1" /* RECTORECTOSTOMY */
"4875" = "1" /* ABDOMINAL PROCTOPEXY */
"4876" = "1" /* PROCTOPEXY NEC */
"4879" = "1" /* REPAIR OF RECTUM NEC */
"4881" = "1" /* PERIRECTAL INCISION */
"4882" = "1" /* PERIRECTAL EXCISION */
"4891" = "1" /* INCIS RECTAL STRICTURE */
"4892" = "1" /* ANORECTAL MYOMECTOMY */
"4893" = "1" /* REPAIR PERIRECT FISTULA */
"4899" = "1" /* RECTAL PERIRECT OP NEC */
"4901" = "1" /* INCIS PERIANAL ABSCESS */
"4902" = "1" /* PERIANAL INCISION NEC */
"4904" = "1" /* PERIANAL EXCISION NEC */
"4911" = "1" /* ANAL FISTULOTOMY */
"4912" = "1" /* ANAL FISTULECTOMY */
"493 " = "1" /* ANAL/PERIAN DX PROC NEC */
"4939" = "1" /* OTHER DESTRUC ANUS LES */
"4944" = "1" /* HEMORRHOID CRYOTHERAPY */
"4945" = "1" /* HEMORRHOID LIGATION */
"4946" = "1" /* HEMORRHOIDECTOMY */
"4949" = "1" /* HEMORRHOID PROCEDURE NEC */
"4951" = "1" /* LEFT LAT SPHINCTEROTOMY */
"4952" = "1" /* POST SPHINCTEROTOMY */
"4959" = "1" /* ANAL SPHINCTEROTOMY NEC */
"496 " = "1" /* EXCISION OF ANUS */
"4971" = "1" /* SUTURE ANAL LACERATION */
"4972" = "1" /* ANAL CERCLAGE */
"4973" = "1" /* CLOSURE OF ANAL FISTULA */
"4974" = "1" /* GRACILIS MUSC TRANSPLAN */
"4975" = "1" /* IMPL OR REV ART ANAL SPH */
"4976" = "1" /* REMOV ART ANAL SPHINCTER */
"4979" = "1" /* ANAL SPHINCT REPAIR NEC */
"4991" = "1" /* INCISION OF ANAL SEPTUM */
"4992" = "1" /* INSERT SUBQ ANAL STIMUL */
"4993" = "1" /* ANAL INCISION NEC */
"4994" = "1" /* REDUCTION ANAL PROLAPSE */
"4995" = "1" /* CONTROL ANAL HEMORRHAGE */
"4999" = "1" /* ANAL OPERATION NEC */
"500 " = "1" /* HEPATOTOMY */
"5012" = "1" /* OPEN LIVER BIOPSY */
"5019" = "1" /* HEPATIC DX PROC NEC */
"5021" = "1" /* MARSUPIALIZAT LIVER LES */
"5022" = "1" /* PARTIAL HEPATECTOMY */
"5023" = "1" /* OPN ABLTN LIVER LES/TISS */
"5024" = "1" /* PERC ABLTN LIVER LES/TIS */
"5025" = "1" /* LAP ABLTN LIVER LES/TISS */
"5026" = "1" /* ABLTN LIVER LES/TISS NEC */
"5029" = "1" /* DESTRUC HEPATIC LES NEC */
"503 " = "1" /* HEPATIC LOBECTOMY */
"504 " = "1" /* TOTAL HEPATECTOMY */
"5051" = "1" /* AUXILIARY LIVER TRANSPL */
"5059" = "1" /* LIVER TRANSPLANT NEC */
"5061" = "1" /* CLOSURE LIVER LACERAT */
"5069" = "1" /* LIVER REPAIR NEC */
"5102" = "1" /* TROCAR CHOLECYSTOSTOMY */
"5103" = "1" /* CHOLECYSTOSTOMY NEC */
"5104" = "1" /* CHOLECYSTOTOMY NEC */
"5113" = "1" /* OPEN BILIARY TRACT BX */
"5119" = "1" /* BILIARY TR DX PROC NEC */
"5121" = "1" /* OTH PART CHOLECYSTECTOMY */
"5122" = "1" /* CHOLECYSTECTOMY */
"5123" = "1" /* LAPAROSCOPIC CHOLECYSTEC */
"5124" = "1" /* LAP PART CHOLECYSTECTOMY */
"5131" = "1" /* GB-TO-HEPAT DUCT ANAST */
"5132" = "1" /* GB-TO-INTESTINE ANASTOM */
"5133" = "1" /* GB-TO-PANCREAS ANASTOM */
"5134" = "1" /* GB-TO-STOMACH ANASTOMOS */
"5135" = "1" /* GALLBLADDER ANASTOM NEC */
"5136" = "1" /* CHOLEDOCHOENTEROSTOMY */
"5137" = "1" /* HEPATIC DUCT-GI ANASTOM */
"5139" = "1" /* BILE DUCT ANASTOMOS NEC */
"5141" = "1" /* CDE FOR CALCULUS REMOV */
"5142" = "1" /* CDE FOR OBSTRUCTION NEC */
"5143" = "1" /* CHOLEDOCHOHEPAT INTUBAT */
"5149" = "1" /* INCIS OBSTR BILE DUC NEC */
"5151" = "1" /* COMMON DUCT EXPLORATION */
"5159" = "1" /* BILE DUCT INCISION NEC */
"5161" = "1" /* EXCIS CYST DUCT REMNANT */
"5162" = "1" /* EXCIS AMPULLA OF VATER */
"5163" = "1" /* COMMON DUCT EXCIS NEC */
"5169" = "1" /* BILE DUCT EXCISION NEC */
"5171" = "1" /* SIMPLE SUT-COMMON DUCT */
"5172" = "1" /* CHOLEDOCHOPLASTY */
"5179" = "1" /* BILE DUCT REPAIR NEC */
"5181" = "1" /* SPHINCTER OF ODDI DILAT */
"5182" = "1" /* PANCREAT SPHINCTEROTOM */
"5183" = "1" /* PANCREAT SPHINCTEROPLAS */
"5189" = "1" /* SPHINCT OF ODDI OP NEC */
"5191" = "1" /* REPAIR GB LACERATION */
"5192" = "1" /* CLOSURE CHOLECYSTOSTOMY */
"5193" = "1" /* CLOS BILIARY FISTUL NEC */
"5194" = "1" /* REVIS BILE TRACT ANASTOM */
"5195" = "1" /* REMOVE BILE DUCT PROSTH */
"5199" = "1" /* BILIARY TRACT OP NEC */
"5201" = "1" /* CATH DRAIN-PANCREAT CYST */
"5209" = "1" /* PANCREATOTOMY NEC */
"5212" = "1" /* OPEN PANCREATIC BIOPSY */
"5219" = "1" /* PANCREATIC DX PROC NEC */
"522 " = "1" /* PANCREATIC DX PROC NEC */
"5222" = "1" /* OTHER DESTRU PANCREA LES */
"523 " = "1" /* PANCREAT CYST MARSUPIALI */
"524 " = "1" /* INT DRAIN PANCREAT CYST */
"5251" = "1" /* PROXIMAL PANCREATECTOMY */
"5252" = "1" /* DISTAL PANCREATECTOMY */
"5253" = "1" /* RAD SUBTOT PANCREATECTOM */
"5259" = "1" /* PARTIAL PANCREATECT NEC */
"526 " = "1" /* TOTAL PANCREATECTOMY */
"527 " = "1" /* RAD PANCREATICODUODENECT */
"5280" = "1" /* PANCREAT TRANSPLANT NOS */
"5281" = "1" /* REIMPLANT PANCREATIC TIS */
"5282" = "1" /* PANCREATIC HOMOTRANSPLAN */
"5283" = "1" /* PANCREATIC HETEROTRANSPL */
"5291" = "1" /* TRNSPLNT ISLETS LANG NOS */
"5292" = "1" /* CANNULATION PANCREA DUC */
"5295" = "1" /* PANCREATIC REPAIR NEC */
"5296" = "1" /* PANCREATIC ANASTOMOSIS */
"5299" = "1" /* PANCREATIC OPERATION NEC */
"5300" = "1" /* UNILAT ING HERN REP NOS */
"5301" = "1" /* REPAIR DIRECT ING HERNIA */
"5302" = "1" /* REPAIR INDIR ING HERNIA */
"5303" = "1" /* DIR ING HERNIA REP-GRAFT */
"5304" = "1" /* IND ING HERNIA REP-GRAFT */
"5305" = "1" /* ING HERNIA REP-GRAFT NOS */
"5310" = "1" /* BILAT ING HERNIA REP NOS */
"5311" = "1" /* BILAT DIR ING HERN REP */
"5312" = "1" /* BILAT IND ING HERN REP */
"5313" = "1" /* BIL DIR/IND ING HRN REP */
"5314" = "1" /* BIL DIR ING HRN REP-GRFT */
"5315" = "1" /* BIL IND ING HRN REP-GRFT */
"5316" = "1" /* BIL DIR/IND ING HERN-PRO */
"5317" = "1" /* BIL ING HRN REP-GRFT NOS */
"5321" = "1" /* UNIL FEMOR HRN REP-GRFT */
"5329" = "1" /* UNIL FEMOR HERN REP NEC */
"5331" = "1" /* BIL FEM HERN REPAIR-GRFT */
"5339" = "1" /* BIL FEM HERN REPAIR NEC */
"5341" = "1" /* UMBIL HERNIA REPAIR-GRFT */
"5349" = "1" /* UMBIL HERNIA REPAIR NEC */
"5351" = "1" /* INCISIONAL HERNIA REPAIR */
"5359" = "1" /* ABD WALL HERN REPAIR NEC */
"5361" = "1" /* INCIS HERNIA REPAIR-GRFT */
"5369" = "1" /* ABD HERN REPAIR-GRFT NEC */
"537 " = "1" /* ABD REPAIR-DIAPHR HERNIA */
"5380" = "1" /* THOR REP-DIAPH HERN NOS */
"5381" = "1" /* DIAPHRAGMATIC PLICATION */
"5382" = "1" /* PARASTERN HERNIA REPAIR */
"539 " = "1" /* OTHER HERNIA REPAIR */
"540 " = "1" /* ABDOMINAL WALL INCISION */
"5411" = "1" /* EXPLORATORY LAPAROTOMY */
"5412" = "1" /* REOPEN RECENT LAP SITE */
"5419" = "1" /* LAPAROTOMY NEC */
"5421" = "1" /* LAPAROSCOPY */
"5422" = "1" /* ABDOMINAL WALL BIOPSY */
"5423" = "1" /* PERITONEAL BIOPSY */
"5429" = "1" /* ABD REGION DX PROC NEC */
"543 " = "1" /* DESTRUCT ABD WALL LESION */
"544 " = "1" /* DESTRUCT PERITONEAL TISS */
"545 " = "1" /* DESTRUCT PERITONEAL TISS */
"5451" = "1" /* LAP PERITON ADHESIOLYSIS */
"5459" = "1" /* OTH PERITON ADHESIOLYSIS */
"5461" = "1" /* RECLOSE POST OP DISRUPT */
"5462" = "1" /* DELAYED CLOS ABD WOUND */
"5463" = "1" /* ABD WALL SUTURE NEC */
"5464" = "1" /* PERITONEAL SUTURE */
"5471" = "1" /* REPAIR OF GASTROSCHISIS */
"5472" = "1" /* ABDOMEN WALL REPAIR NEC */
"5473" = "1" /* PERITONEAL REPAIR NEC */
"5474" = "1" /* OMENTAL REPAIR NEC */
"5475" = "1" /* MESENTERIC REPAIR NEC */
"5492" = "1" /* REMOVE FB FROM PERITON */
"5493" = "1" /* CREATE CUTANPERITON FIST */
"5494" = "1" /* CREAT PERITONEOVAS SHUNT */
"5495" = "1" /* PERITONEAL INCISION */
"5501" = "1" /* NEPHROTOMY */
"5502" = "1" /* NEPHROSTOMY */
"5503" = "1" /* PERCU NEPHROSTM W/O FRAG */
"5504" = "1" /* PERCU NEPHROSTMY W FRAG */
"5511" = "1" /* PYELOTOMY */
"5512" = "1" /* PYELOSTOMY */
"5524" = "1" /* OPEN RENAL BIOPSY */
"5529" = "1" /* RENAL DIAGNOST PROC NEC */
"5531" = "1" /* RENAL LES MARSUPIALIZAT */
"5532" = "1" /* OPN ABLTN RENAL LES/TISS */
"5533" = "1" /* PERC ABLTN RENL LES/TISS */
"5534" = "1" /* LAP ABLTN RENAL LES/TISS */
"5535" = "1" /* ABLTN RENAL LES/TISS NEC */
"5539" = "1" /* LOC DESTR RENAL LES NEC */
"554 " = "1" /* PARTIAL NEPHRECTOMY */
"5551" = "1" /* NEPHROURETERECTOMY */
"5552" = "1" /* SOLITARY KIDNEY NEPHRECT */
"5553" = "1" /* REJECTED KIDNEY NEPHRECT */
"5554" = "1" /* BILATERAL NEPHRECTOMY */
"5561" = "1" /* RENAL AUTOTRANSPLANT */
"5569" = "1" /* KIDNEY TRANSPLANT NEC */
"557 " = "1" /* NEPHROPEXY */
"5581" = "1" /* SUTURE KIDNEY LACERATION */
"5582" = "1" /* CLOSE NEPHROST & PYELOST */
"5583" = "1" /* CLOSE RENAL FISTULA NEC */
"5584" = "1" /* REDUCE RENAL PEDICL TORS */
"5585" = "1" /* SYMPHYSIOTOMY */
"5586" = "1" /* RENAL ANASTOMOSIS */
"5587" = "1" /* CORRECT URETEROPELV JUNC */
"5589" = "1" /* RENAL REPAIR NEC */
"5591" = "1" /* RENAL DECAPSULATION */
"5597" = "1" /* IMPLANT MECHANIC KIDNEY */
"5598" = "1" /* REMOV MECHANICAL KIDNEY */
"5599" = "1" /* RENAL OPERATION NEC */
"560 " = "1" /* TU REMOV URETER OBSTRUCT */
"561 " = "1" /* URETERAL MEATOTOMY */
"562 " = "1" /* URETEROTOMY */
"5634" = "1" /* OPEN URETERAL BIOPSY */
"5639" = "1" /* URETERAL DX PROCEDUR NEC */
"5640" = "1" /* URETERECTOMY NOS */
"5641" = "1" /* PARTIAL URETERECTOMY */
"5642" = "1" /* TOTAL URETERECTOMY */
"5651" = "1" /* FORM CUTAN ILEOURETEROST */
"5652" = "1" /* REVIS CUTAN ILEOURETEROS */
"5661" = "1" /* FORM CUTAN URETEROSTOMY */
"5662" = "1" /* REVIS CUTAN URETEROS NEC */
"5671" = "1" /* URIN DIVERSION TO BOWEL */
"5672" = "1" /* REVIS URETEROENTEROSTOMY */
"5673" = "1" /* NEPHROCYSTANASTOMOSI NOS */
"5674" = "1" /* URETERONEOCYSTOSTOMY */
"5675" = "1" /* TRANSURETEROURETEROSTOMY */
"5679" = "1" /* URETERAL ANASTOMOSIS NEC */
"5681" = "1" /* INTRALUM URETE ADHESIOLY */
"5682" = "1" /* SUTURE URETERAL LACERAT */
"5683" = "1" /* URETEROSTOMY CLOSURE */
"5684" = "1" /* CLOSE URETER FISTULA NEC */
"5685" = "1" /* URETEROPEXY */
"5686" = "1" /* REMOVE URETERAL LIGATURE */
"5689" = "1" /* REPAIR OF URETER NEC */
"5692" = "1" /* IMPLANT URETERAL STIMUL */
"5693" = "1" /* REPLACE URETERAL STIMUL */
"5694" = "1" /* REMOVE URETERAL STIMULAT */
"5695" = "1" /* LIGATION OF URETER */
"5699" = "1" /* URETERAL OPERATION NEC */
"5712" = "1" /* CYSTOTOMY & ADHESIOLYSIS */
"5718" = "1" /* OTHER SUPRAPU CYSTOSTOMY */
"5719" = "1" /* CYSTOTOMY NEC */
"5721" = "1" /* VESICOSTOMY */
"5722" = "1" /* REVISE CLO VESICOSTOMY */
"5733" = "1" /* CLOS TRANSURETH BLADD BX */
"5734" = "1" /* OPEN BLADDER BIOPSY */
"5739" = "1" /* BLADDER DIAGNOS PROC NEC */
"5741" = "1" /* TU ADHESIOLYSIS BLADDER */
"5749" = "1" /* TU DESTRUC BLADD LES NEC */
"5751" = "1" /* EXCISION OF URACHUS */
"5759" = "1" /* BLADDER LES DESTRUCT NEC */
"576 " = "1" /* PARTIAL CYSTECTOMY */
"5771" = "1" /* RADICAL CYSTECTOMY */
"5779" = "1" /* TOTAL CYSTECTOMY NEC */
"5781" = "1" /* SUTURE BLADDER LACERAT */
"5782" = "1" /* CYSTOSTOMY CLOSURE */
"5783" = "1" /* ENTEROVESICO FIST REPAIR */
"5784" = "1" /* VESIC FISTULA REPAIR NEC */
"5785" = "1" /* CYSTOURETHROPLASTY */
"5786" = "1" /* BLADDER EXSTROPHY REPAIR */
"5787" = "1" /* BLADDER RECONSTRUCTION */
"5788" = "1" /* BLADDER ANASTOMOSIS NEC */
"5789" = "1" /* BLADDER REPAIR NEC */
"5791" = "1" /* BLADDER SPHINCTEROTOMY */
"5793" = "1" /* CONTROL BLADD HEMORRHAGE */
"5796" = "1" /* IMPLANT BLADDER STIMULAT */
"5797" = "1" /* REPLACE BLADDER STIMULAT */
"5798" = "1" /* REMOVE BLADDER STIMULAT */
"5799" = "1" /* BLADDER OPERATION NEC */
"580 " = "1" /* URETHROTOMY */
"581 " = "1" /* URETHRAL MEATOTOMY */
"5841" = "1" /* SUTURE URETHRAL LACERAT */
"5842" = "1" /* URETHROSTOMY CLOSURE */
"5843" = "1" /* CLOSE URETH FISTULA NEC */
"5844" = "1" /* URETHRAL REANASTOMOSIS */
"5845" = "1" /* HYPO-EPISPADIUS REPAIR */
"5846" = "1" /* URETH RECONSTRUCTION NEC */
"5847" = "1" /* URETHRAL MEATOPLASTY */
"5849" = "1" /* URETHRAL REPAIR NEC */
"585 " = "1" /* URETH STRICTURE RELEASE */
"5891" = "1" /* PERIURETHRAL INCISION */
"5892" = "1" /* PERIURETHRAL EXCISION */
"5893" = "1" /* IMPLT ARTF URIN SPHINCT */
"5899" = "1" /* URETH/PERIURETH OP NEC */
"5900" = "1" /* RETROPERIT DISSECT NOS */
"5901" = "1" /* RETROPERIT DISSECT NOS */
"5902" = "1" /* PERIREN ADHESIOLYS NEC */
"5903" = "1" /* LAP LYS PERIREN/URET ADH */
"5909" = "1" /* PERIREN/URETER INCIS NEC */
"5911" = "1" /* OTH LYS PERIVES ADHESIO */
"5912" = "1" /* LAP LYS PERIVESURETH ADH */
"5919" = "1" /* PERIVESICAL INCISION NEC */
"5921" = "1" /* PERIREN/URETERAL BIOPSY */
"5929" = "1" /* PERIREN/URET DX PROC NEC */
"593 " = "1" /* URETHROVES JUNCT PLICAT */
"594 " = "1" /* SUPRAPUBIC SLING OP */
"595 " = "1" /* RETROPUBIC URETH SUSPENS */
"596 " = "1" /* PARAURETHRAL SUSPENSION */
"5971" = "1" /* LEVATOR MUSC SUSPENSION */
"5979" = "1" /* URIN INCONTIN REPAIR NEC */
"5991" = "1" /* PERIREN/VESICLE EXCISION */
"5992" = "1" /* PERIREN/VESICLE OP NEC */
"600 " = "1" /* INCISION OF PROSTATE */
"6012" = "1" /* OPEN PROSTATIC BIOPSY */
"6014" = "1" /* OPEN SEMINAL VESICLES BX */
"6015" = "1" /* PERIPROSTATIC BIOPSY */
"6018" = "1" /* PROSTATIC DX PROCED NEC */
"6019" = "1" /* SEMIN VES DX PROCED NEC */
"602 " = "1" /* SEMIN VES DX PROCED NEC */
"6021" = "1" /* TRANSURETH PROSTATECTOMY */
"6029" = "1" /* OTH TRANSURETH PROSTATEC */
"603 " = "1" /* SUPRAPUBIC PROSTATECTOMY */
"604 " = "1" /* RETROPUBIC PROSTATECTOMY */
"605 " = "1" /* RADICAL PROSTATECTOMY */
"6061" = "1" /* LOS EXCIS PROSTATIC LES */
"6062" = "1" /* PERINEAL PROSTATECTOMY */
"6069" = "1" /* PROSTATECTOMY NEC */
"6072" = "1" /* SEMINAL VESICLE INCISION */
"6073" = "1" /* SEMINAL VESICLE EXCISION */
"6079" = "1" /* SEMINAL VESICLE OP NEC */
"6081" = "1" /* PERIPROSTATIC INCISION */
"6082" = "1" /* PERIPROSTATIC EXCISION */
"6093" = "1" /* REPAIR OF PROSTATE */
"6094" = "1" /* CONTROL PROSTATE HEMORR */
"6095" = "1" /* TRANS BAL DIL PROS URETH */
"6096" = "1" /* TU DESTR PROSTATE BY MT */
"6097" = "1" /* OTH TU DESTR PROS - RT */
"6099" = "1" /* PROSTATIC OPERATION NEC */
"612 " = "1" /* EXCISION OF HYDROCELE */
"6142" = "1" /* SCROTAL FISTULA REPAIR */
"6149" = "1" /* SCROTUM/TUNIC REPAIR NEC */
"6192" = "1" /* EXCISION TUNICA LES NEC */
"6199" = "1" /* SCROTUM & TUNICA OP NEC */
"620 " = "1" /* INCISION OF TESTES */
"6212" = "1" /* OPEN TESTICULAR BIOPSY */
"6219" = "1" /* TESTES DX PROCEDURE NEC */
"622 " = "1" /* TESTICULAR LES DESTRUCT */
"623 " = "1" /* UNILATERAL ORCHIECTOMY */
"6241" = "1" /* REMOVE BOTH TESTES */
"6242" = "1" /* REMOVE SOLITARY TESTIS */
"625 " = "1" /* ORCHIOPEXY */
"6261" = "1" /* SUTURE TESTICULAR LACER */
"6269" = "1" /* TESTICULAR REPAIR NEC */
"627 " = "1" /* INSERT TESTICULAR PROSTH */
"6299" = "1" /* TESTICULAR OPERATION NEC */
"6309" = "1" /* SPERMAT CORD/VAS DX NEC */
"631 " = "1" /* EXC SPERMATIC VARICOCELE */
"632 " = "1" /* EXCISE EPIDIDYMIS CYST */
"633 " = "1" /* EXCISE CORD/EPID LES NEC */
"634 " = "1" /* EPIDIDYMECTOMY */
"6351" = "1" /* SUTURE CORD & EPID LACER */
"6353" = "1" /* TRANSPLANT SPERMAT CORD */
"6359" = "1" /* CORD & EPIDID REPAIR NEC */
"6381" = "1" /* SUTURE VAS & EPIDID LAC */
"6382" = "1" /* POSTOP VAS RECONSTRUCT */
"6383" = "1" /* EPIDIDYMOVASOSTOMY */
"6385" = "1" /* REMOV VAS DEFERENS VALVE */
"6389" = "1" /* VAS & EPIDIDY REPAIR NEC */
"6392" = "1" /* EPIDIDYMOTOMY */
"6393" = "1" /* SPERMATIC CORD INCISION */
"6394" = "1" /* SPERM CORD ADHESIOLYSIS */
"6395" = "1" /* INSERT VALVE IN VAS DEF */
"6399" = "1" /* CORD/EPID/VAS OPS NEC */
"6411" = "1" /* PENILE BIOPSY */
"642 " = "1" /* LOCAL EXCIS PENILE LES */
"643 " = "1" /* AMPUTATION OF PENIS */
"6441" = "1" /* SUTURE PENILE LACERATION */
"6442" = "1" /* RELEASE OF CHORDEE */
"6443" = "1" /* CONSTRUCTION OF PENIS */
"6444" = "1" /* RECONSTRUCTION OF PENIS */
"6445" = "1" /* REPLANTATION OF PENIS */
"6449" = "1" /* PENILE REPAIR NEC */
"645 " = "1" /* SEX TRANSFORMAT OP NEC */
"6492" = "1" /* INCISION OF PENIS */
"6493" = "1" /* DIVISION OF PENILE ADHES */
"6495" = "1" /* INS NONINFL PENIS PROSTH */
"6496" = "1" /* REMOVE INT PENILE PROSTH */
"6497" = "1" /* INS INFLATE PENIS PROSTH */
"6498" = "1" /* PENILE OPERATION NEC */
"6499" = "1" /* MALE GENITAL OP NEC */
"650 " = "1" /* MALE GENITAL OP NEC */
"6501" = "1" /* LAPAROSCOPIC OOPHOROTOMY */
"6509" = "1" /* OTHER OOPHOROTOMY */
"6511" = "1" /* OVARIAN ASPIRAT BIOPSY */
"6512" = "1" /* OVARIAN BIOPSY NEC */
"6513" = "1" /* LAP BIOPSY OF OVARY */
"6514" = "1" /* OTH LAP DX PROC OVARIES */
"6519" = "1" /* OVARIAN DX PROCEDURE NEC */
"6521" = "1" /* OVARIAN CYST MARSUPIALIZ */
"6522" = "1" /* OVARIAN WEDGE RESECTION */
"6523" = "1" /* LAP MARSUP OVARIAN CYST */
"6524" = "1" /* LAP WEDGE RESECT OVARY */
"6525" = "1" /* OTH LAP LOC EXC DEST OVA */
"6529" = "1" /* LOCAL DESTR OVA LES NEC */
"653 " = "1" /* LOCAL DESTR OVA LES NEC */
"6531" = "1" /* LAP UNILAT OOPHORECTOMY */
"6539" = "1" /* OTH UNILAT OOPHORECTOMY */
"654 " = "1" /* OTH UNILAT OOPHORECTOMY */
"6541" = "1" /* LAP UNI SALPINGO-OOPHOR */
"6549" = "1" /* OTH UNI SALPINGO-OOPHOR */
"6551" = "1" /* OTH REMOVE BOTH OVARIES */
"6552" = "1" /* OTH REMOVE REMAIN OVARY */
"6553" = "1" /* LAP REMOVE BOTH OVARIES */
"6554" = "1" /* LAP REMOVE REMAIN OVARY */
"6561" = "1" /* OTH REMOVE OVARIES/TUBES */
"6562" = "1" /* OTH REMOVE REM OVA/TUBE */
"6563" = "1" /* LAP REMOVE OVARIES/TUBES */
"6564" = "1" /* LAP REMOVE REM OVA/TUBE */
"6571" = "1" /* OTH SIMPLE SUTURE OVARY */
"6572" = "1" /* OTH REIMPLANT OF OVARY */
"6573" = "1" /* OTH SALPINGO-OOPHOROPLAS */
"6574" = "1" /* LAP SIMPLE SUTURE OVARY */
"6575" = "1" /* LAP REIMPLANT OF OVARY */
"6576" = "1" /* LAP SALPINGO-OOPHOROPLAS */
"6579" = "1" /* REPAIR OF OVARY NEC */
"658 " = "1" /* REPAIR OF OVARY NEC */
"6581" = "1" /* LAP ADHESIOLYS OVA/TUBE */
"6589" = "1" /* ADHESIOLYSIS OVARY/TUBE */
"6591" = "1" /* ASPIRATION OF OVARY */
"6592" = "1" /* TRANSPLANTATION OF OVARY */
"6593" = "1" /* MANUAL RUPT OVARIAN CYST */
"6594" = "1" /* OVARIAN DENERVATION */
"6595" = "1" /* OVARIAN TORSION RELEASE */
"6599" = "1" /* OVARIAN OPERATION NEC */
"660 " = "1" /* OVARIAN OPERATION NEC */
"6601" = "1" /* SALPINGOTOMY */
"6602" = "1" /* SALPINGOSTOMY */
"6611" = "1" /* FALLOPIAN TUBE BIOPSY */
"6619" = "1" /* FALLOP TUBE DX PROC NEC */
"6621" = "1" /* BILAT ENDOSC CRUSH TUBE */
"6622" = "1" /* BILAT ENDOSC DIVIS TUBE */
"6629" = "1" /* BILAT ENDOS OCC TUBE NEC */
"6631" = "1" /* BILAT TUBAL CRUSHING NEC */
"6632" = "1" /* BILAT TUBAL DIVISION NEC */
"6639" = "1" /* BILAT TUBAL DESTRUCT NEC */
"664 " = "1" /* TOTAL UNILAT SALPINGECT */
"6651" = "1" /* REMOVE BOTH FALLOP TUBES */
"6652" = "1" /* REMOVE SOLITARY FAL TUBE */
"6661" = "1" /* DESTROY FALLOP TUBE LES */
"6662" = "1" /* REMOV TUBE & ECTOP PREG */
"6663" = "1" /* BILAT PART SALPINGEC NOS */
"6669" = "1" /* PARTIAL SALPINGECTOM NEC */
"6671" = "1" /* SIMPL SUTURE FALLOP TUBE */
"6672" = "1" /* SALPINGO-OOPHOROSTOMY */
"6673" = "1" /* SALPINGO-SALPINGOSTOMY */
"6674" = "1" /* SALPINGO-UTEROSTOMY */
"6679" = "1" /* FALLOP TUBE REPAIR NEC */
"6692" = "1" /* UNILAT FALLOP TUBE DESTR */
"6693" = "1" /* IMPL FALLOP TUBE PROSTH */
"6694" = "1" /* REMOV FALLOP TUBE PROSTH */
"6695" = "1" /* BLOW THERAPEUT INTO TUBE */
"6696" = "1" /* FALLOPIAN TUBE DILATION */
"6697" = "1" /* BURY FIMBRIAE IN UTERUS */
"6699" = "1" /* FALLOPIAN TUBE OP NEC */
"6711" = "1" /* ENDOCERVICAL BIOPSY */
"6712" = "1" /* CERVICAL BIOPSY NEC */
"6719" = "1" /* CERVICAL DX PROCEDUR NEC */
"672 " = "1" /* CONIZATION OF CERVIX */
"6731" = "1" /* CERVICAL CYST MARSUPIAL */
"6732" = "1" /* CERVICAL LES CAUTERIZAT */
"6733" = "1" /* CERVICAL LES CRYOTHERAPY */
"6739" = "1" /* CERVICAL LES DESTRUC NEC */
"674 " = "1" /* AMPUTATION OF CERVIX */
"675 " = "1" /* AMPUTATION OF CERVIX */
"6751" = "1" /* TRANSAB CERCLAGE CERVIX */
"6759" = "1" /* OTH REP INT CERVICAL OS */
"6761" = "1" /* SUTURE CERVICAL LACERAT */
"6762" = "1" /* CERVICAL FISTULA REPAIR */
"6769" = "1" /* CERVICAL REPAIR NEC */
"680 " = "1" /* HYSTEROTOMY */
"6813" = "1" /* OPEN UTERINE BIOPSY */
"6814" = "1" /* OPEN UTERINE LIGAMENT BX */
"6815" = "1" /* CLOS UTERINE LIGAMENT BX */
"6816" = "1" /* CLOSED UTERINE BIOPSY */
"6819" = "1" /* UTERUS/ADNEX DX PROC NEC */
"6821" = "1" /* ENDOMET SYNECHIAE DIVIS */
"6822" = "1" /* INCISION UTERINE SEPTUM */
"6823" = "1" /* ENDOMETRIAL ABLATION */
"6829" = "1" /* UTERINE LES DESTRUCT NEC */
"683 " = "1" /* UTERINE LES DESTRUCT NEC */
"6831" = "1" /* LAP SCERVIC HYSTERECTOMY */
"6839" = "1" /* OTH SUBTOT ABD HYSTERECT */
"684 " = "1" /* TOTAL ABD HYSTERECTOMY */
"6841" = "1" /* LAP TOTAL ABDOMINAL HYST */
"6849" = "1" /* TOTAL ABD HYST NEC/NOS */
"685 " = "1" /* TOTAL ABD HYSTERECTOMY */
"6851" = "1" /* LAP AST VAG HYSTERECTOMY */
"6859" = "1" /* OTHER VAG HYSTERECTOMY */
"686 " = "1" /* RADICAL ABD HYSTERECTOMY */
"6861" = "1" /* LAP RADICAL ABDOMNL HYST */
"6869" = "1" /* RADICAL ABD HYST NEC/NOS */
"687 " = "1" /* RADICAL VAG HYSTERECTOMY */
"6871" = "1" /* LAP RADICAL VAGINAL HYST */
"6879" = "1" /* RADICAL VAG HYST NEC/NOS */
"688 " = "1" /* PELVIC EVISCERATION */
"689 " = "1" /* HYSTERECTOMY NEC/NOS */
"6901" = "1" /* D & C FOR PREG TERMINAT */
"6902" = "1" /* D & C POST DELIVERY */
"6909" = "1" /* D & C NEC */
"6911" = "1" /* D & C NEC */
"6919" = "1" /* DESTRUC UTER SUPPORT NEC */
"6921" = "1" /* INTERPOSIT OP UTERIN LIG */
"6922" = "1" /* UTERINE SUSPENSION NEC */
"6923" = "1" /* VAG REPAIR INVERS UTERUS */
"6929" = "1" /* UTERUS/ADNEXA REPAIR NEC */
"693 " = "1" /* PARACERV UTERINE DENERV */
"6941" = "1" /* SUTURE UTERINE LACERAT */
"6942" = "1" /* CLOSURE UTERINE FISTULA */
"6949" = "1" /* UTERINE REPAIR NEC */
"6951" = "1" /* ASPIRAT CURET-PREG TERMI */
"6952" = "1" /* ASPIRAT CURET-POST DELIV */
"6995" = "1" /* INCISION OF CERVIX */
"6997" = "1" /* REMOVE PENETRAT CERV FB */
"6998" = "1" /* UTERINE SUPPORT OP NEC */
"6999" = "1" /* UTERINE OPERATION NEC */
"7012" = "1" /* CULDOTOMY */
"7013" = "1" /* INTRALUM VAG ADHESIOLYS */
"7014" = "1" /* VAGINOTOMY NEC */
"7023" = "1" /* CUL-DE-SAC BIOPSY */
"7024" = "1" /* VAGINAL BIOPSY */
"7029" = "1" /* VAGIN/CUL-DE-SAC DX NEC */
"7031" = "1" /* HYMENECTOMY */
"7032" = "1" /* EXCIS CUL-DE-SAC LESION */
"7033" = "1" /* EXCISION VAGINAL LESION */
"704 " = "1" /* VAGINAL OBLITERATION */
"7050" = "1" /* CYSTOCEL/RECTOCEL REPAIR */
"7051" = "1" /* CYSTOCELE REPAIR */
"7052" = "1" /* RECTOCELE REPAIR */
"7061" = "1" /* VAGINAL CONSTRUCTION */
"7062" = "1" /* VAGINAL RECONSTRUCTION */
"7071" = "1" /* SUTURE VAGINA LACERATION */
"7072" = "1" /* REPAIR COLOVAGIN FISTULA */
"7073" = "1" /* REPAIR RECTOVAG FISTULA */
"7074" = "1" /* REP VAGINOENT FISTUL NEC */
"7075" = "1" /* REPAIR VAG FISTULA NEC */
"7076" = "1" /* HYMENORRHAPHY */
"7077" = "1" /* VAGINAL SUSPENS & FIXAT */
"7079" = "1" /* VAGINAL REPAIR NEC */
"708 " = "1" /* VAGINAL VAULT OBLITERAT */
"7091" = "1" /* VAGINAL OPERATION NEC */
"7092" = "1" /* CUL-DE-SAC OPERATION NEC */
"7101" = "1" /* VULVAR ADHESIOLYSIS */
"7109" = "1" /* INCIS VULVA/PERINEUM NEC */
"7111" = "1" /* VULVAR BIOPSY */
"7119" = "1" /* VULVAR DIAGNOS PROC NEC */
"7122" = "1" /* INCISE BARTHOLIN"S GLAND */
"7123" = "1" /* BARTHOLIN GLAND MARSUP */
"7124" = "1" /* DESTRUC BARTHOLIN GLAND */
"7129" = "1" /* BARTHOLIN"S GLAND OP NEC */
"713 " = "1" /* LOCAL VULVAR EXCIS NEC */
"714 " = "1" /* OPERATIONS ON CLITORIS */
"715 " = "1" /* RADICAL VULVECTOMY */
"7161" = "1" /* UNILATERAL VULVECTOMY */
"7162" = "1" /* BILATERAL VULVECTOMY */
"7171" = "1" /* SUTURE VULVAR LACERATION */
"7172" = "1" /* REPAIR VULVAR FISTULA */
"7179" = "1" /* VULVAR/PERIN REPAIR NEC */
"718 " = "1" /* OTHER VULVAR OPERATIONS */
"719 " = "1" /* OTHER FEMALE GENITAL OPS */
"7394" = "1" /* PUBIOTOMY TO ASSIST DEL */
"7399" = "1" /* OPS ASSISTING DELIV NEC */
"740 " = "1" /* CLASSICAL C-SECTION */
"741 " = "1" /* LOW CERVICAL C-SECTION */
"742 " = "1" /* EXTRAPERITONEAL C-SECT */
"743 " = "1" /* REM EXTRATUB ECTOP PREG */
"744 " = "1" /* CESAREAN SECTION NEC */
"7491" = "1" /* HYSTEROTOMY TO TERMIN PG */
"7499" = "1" /* CESAREAN SECTION NOS */
"7536" = "1" /* CORRECTION FETAL DEFECT */
"7550" = "1" /* REPAIR OB LAC UTERUS NOS */
"7551" = "1" /* REPAIR OB LACERAT CERVIX */
"7552" = "1" /* REPAIR OB LAC CORP UTERI */
"7561" = "1" /* REPAIR OB LAC BLAD/URETH */
"7593" = "1" /* SURG CORR INVERT UTERUS */
"7599" = "1" /* OBSTETRIC OPERATION NEC */
"7601" = "1" /* FACIAL BONE SEQUESTRECT */
"7609" = "1" /* FACIAL BONE INCISION NEC */
"7611" = "1" /* FACIAL BONE BIOPSY */
"7619" = "1" /* FACIAL BONE DX PROC NEC */
"762 " = "1" /* DESTRUCT FACIAL BONE LES */
"7631" = "1" /* PARTIAL MANDIBULECTOMY */
"7639" = "1" /* PART FACIAL OSTECTOM NEC */
"7641" = "1" /* TOT MANDIBULEC W RECONST */
"7642" = "1" /* TOTAL MANDIBULECTOMY NEC */
"7643" = "1" /* MANDIBULAR RECONST NEC */
"7644" = "1" /* TOT FACE OSTECT W RECONS */
"7645" = "1" /* TOT FACE BONE OSTECT NEC */
"7646" = "1" /* FACIAL BONE RECONSTR NEC */
"765 " = "1" /* TEMPOROMAND ARTHROPLASTY */
"7661" = "1" /* CL OSTEOPLASTY MAND RAMI */
"7662" = "1" /* OPEN OSTEOPLAS MAND RAMI */
"7663" = "1" /* OSTEOPLASTY MANDIBLE BDY */
"7664" = "1" /* MAND ORTHOGNATHIC OP NEC */
"7665" = "1" /* SEG OSTEOPLASTY MAXILLA */
"7666" = "1" /* TOT OSTEOPLASTY MAXILLA */
"7667" = "1" /* REDUCTION GENIOPLASTY */
"7668" = "1" /* AUGMENTATION GENIOPLASTY */
"7669" = "1" /* FACIAL BONE REPAIR NEC */
"7670" = "1" /* REDUCTION FACIAL FX NOS */
"7672" = "1" /* OPN REDUCT MALAR/ZYGO FX */
"7674" = "1" /* OPEN REDUCT MAXILLARY FX */
"7676" = "1" /* OPEN REDUCT MANDIBLE FX */
"7677" = "1" /* OPEN REDUCT ALVEOLAR FX */
"7679" = "1" /* OPEN REDUCT FACE FX NEC */
"7691" = "1" /* BONE GRAFT TO FACE BONE */
"7692" = "1" /* SYN IMPLANT TO FACE BONE */
"7694" = "1" /* OPEN REDUCT TM DISLOCAT */
"7697" = "1" /* REMOVE INT FIX FACE BONE */
"7699" = "1" /* FACIAL BONE/JNT OP NEC */
"7700" = "1" /* SEQUESTRECTOMY NOS */
"7701" = "1" /* CHEST CAGE SEQUESTREC */
"7702" = "1" /* HUMERUS SEQUESTRECTOMY */
"7703" = "1" /* RADIUS & ULNA SEQUESTREC */
"7704" = "1" /* METACARP/CARP SEQUESTREC */
"7705" = "1" /* FEMORAL SEQUESTRECTOMY */
"7706" = "1" /* PATELLAR SEQUESTRECTOMY */
"7707" = "1" /* TIBIA/FIBULA SEQUESTREC */
"7708" = "1" /* METATAR/TAR SEQUESTREC */
"7709" = "1" /* SEQUESTRECTOMY NEC */
"7710" = "1" /* OTHER BONE INCISION NOS */
"7711" = "1" /* OTHER CHEST CAGE INCIS */
"7712" = "1" /* OTHER HUMERUS INCISION */
"7713" = "1" /* OTHER RADIUS/ULNA INCIS */
"7714" = "1" /* OTH METACARP/CARP INCIS */
"7715" = "1" /* OTHER FEMORAL INCISION */
"7716" = "1" /* OTHER PATELLAR INCISION */
"7717" = "1" /* OTHER TIBIA/FIBULA INCIS */
"7718" = "1" /* OTH METATARS/TARS INCIS */
"7719" = "1" /* BONE INCIS W/O DIV NEC */
"7720" = "1" /* WEDGE OSTEOTOMY NOS */
"7721" = "1" /* CHEST CAGE WEDG OSTEOTOM */
"7722" = "1" /* HUMERUS WEDGE OSTEOTOMY */
"7723" = "1" /* RADIUS/ULNA WEDG OSTEOTO */
"7724" = "1" /* METACAR/CAR WEDG OSTEOTO */
"7725" = "1" /* FEMORAL WEDGE OSTEOTOMY */
"7726" = "1" /* PATELLAR WEDGE OSTEOTOMY */
"7727" = "1" /* TIBIA/FIBUL WEDG OSTEOT */
"7728" = "1" /* METATAR/TAR WEDG OSTEOT */
"7729" = "1" /* WEDGE OSTEOTOMY NEC */
"7730" = "1" /* OTHER BONE DIVISION NOS */
"7731" = "1" /* CHEST CAGE BONE DIV NEC */
"7732" = "1" /* HUMERUS DIVISION NEC */
"7733" = "1" /* RADIUS/ULNA DIVISION NEC */
"7734" = "1" /* METACAR/CAR DIVISION NEC */
"7735" = "1" /* FEMORAL DIVISION NEC */
"7736" = "1" /* PATELLAR DIVISION NEC */
"7737" = "1" /* TIBIA/FIBULA DIV NEC */
"7738" = "1" /* METATAR/TAR DIVISION NEC */
"7739" = "1" /* BONE DIVISION NEC */
"7740" = "1" /* BONE BIOPSY NOS */
"7741" = "1" /* CHEST CAGE BONE BIOPSY */
"7742" = "1" /* HUMERUS BIOPSY */
"7743" = "1" /* RADIUS & ULNA BIOPSY */
"7744" = "1" /* METACARPAL/CARPAL BIOPSY */
"7745" = "1" /* FEMORAL BIOPSY */
"7746" = "1" /* PATELLAR BIOPSY */
"7747" = "1" /* TIBIA & FIBULA BIOPSY */
"7748" = "1" /* METATARSAL/TARSAL BIOPSY */
"7749" = "1" /* BONE BIOPSY NEC */
"7751" = "1" /* BUNIONECT/SFT/OSTEOTOMY */
"7752" = "1" /* BUNIONECT/SFT/ARTHRODES */
"7753" = "1" /* OTH BUNIONECT W SFT CORR */
"7754" = "1" /* EXC CORRECT BUNIONETTE */
"7756" = "1" /* REPAIR OF HAMMER TOE */
"7757" = "1" /* REPAIR OF CLAW TOE */
"7758" = "1" /* OTH EXC, FUS, REPAIR TOE */
"7759" = "1" /* BUNIONECTOMY NEC */
"7760" = "1" /* LOC EXC BONE LESION NOS */
"7761" = "1" /* EXC CHEST CAGE BONE LES */
"7762" = "1" /* LOC EXC BONE LES HUMERUS */
"7763" = "1" /* LOC EXC LES RADIUS/ULNA */
"7764" = "1" /* LOC EXC LES METACAR/CAR */
"7765" = "1" /* LOC EXC BONE LES FEMUR */
"7766" = "1" /* LOC EXC BONE LES PATELLA */
"7767" = "1" /* LOC EXC LES TIBIA/FIBULA */
"7768" = "1" /* LOC EXC LES METATAR/TAR */
"7769" = "1" /* LOC EXC BONE LESION NEC */
"7770" = "1" /* EXCISE BONE FOR GRFT NOS */
"7771" = "1" /* EX CHEST CAGE BONE-GFT */
"7772" = "1" /* EXCISE HUMERUS FOR GRAFT */
"7773" = "1" /* EXCIS RADIUS/ULNA-GRAFT */
"7774" = "1" /* EXCIS METACAR/CAR-GRAFT */
"7775" = "1" /* EXCISE FEMUR FOR GRAFT */
"7776" = "1" /* EXCISE PATELLA FOR GRAFT */
"7777" = "1" /* EXCISE TIB/FIB FOR GRAFT */
"7778" = "1" /* EXCIS METATAR/TAR-GRAFT */
"7779" = "1" /* EXCISE BONE FOR GFT NEC */
"7780" = "1" /* OTH PART OSTECTOMY NOS */
"7781" = "1" /* OTH CHEST CAGE OSTECTOMY */
"7782" = "1" /* PARTIAL HUMERECTOMY NEC */
"7783" = "1" /* PART OSTECT-RADIUS/ULNA */
"7784" = "1" /* PART OSTECT-METACAR/CAR */
"7785" = "1" /* PART OSTECTOMY-FEMUR */
"7786" = "1" /* PARTIAL PATELLECTOMY */
"7787" = "1" /* PART OSTECT-TIBIA/FIBULA */
"7788" = "1" /* PART OSTECT-METATAR/TAR */
"7789" = "1" /* PARTIAL OSTECTOMY NEC */
"7790" = "1" /* TOTAL OSTECTOMY NOS */
"7791" = "1" /* TOT CHEST CAGE OSTECTOMY */
"7792" = "1" /* TOTAL OSTECTOMY-HUMERUS */
"7793" = "1" /* TOT OSTECT-RADIUS/ULNA */
"7794" = "1" /* TOT OSTECT-METACARP/CARP */
"7795" = "1" /* TOT OSTECTOMY-FEMUR */
"7796" = "1" /* TOTAL PATELLECTOMY */
"7797" = "1" /* TOT OSTECT-TIBIA/FIBULA */
"7798" = "1" /* TOT OSTECT-METATARS/TARS */
"7799" = "1" /* TOTAL OSTECTOMY NEC */
"7800" = "1" /* BONE GRAFT NOS */
"7801" = "1" /* BONE GRAFT TO CHEST CAGE */
"7802" = "1" /* BONE GRAFT TO HUMERUS */
"7803" = "1" /* BONE GRAFT-RADIUS/ULNA */
"7804" = "1" /* BONE GRFT TO METACAR/CAR */
"7805" = "1" /* BONE GRAFT TO FEMUR */
"7806" = "1" /* BONE GRAFT TO PATELLA */
"7807" = "1" /* BONE GRAFT-TIBIA/FIBULA */
"7808" = "1" /* BONE GRAFT-METATAR/TAR */
"7809" = "1" /* BONE GRAFT NEC */
"7810" = "1" /* APPLIC EXT FIX DEV NOS */
"7811" = "1" /* APPL EXT FIX-CHEST CAGE */
"7812" = "1" /* APPLIC EXT FIX-HUMERUS */
"7813" = "1" /* APPL EXT FIX-RADIUS/ULNA */
"7814" = "1" /* APPL EXT FIX-METACAR/CAR */
"7815" = "1" /* APPLIC EXT FIX DEV-FEMUR */
"7816" = "1" /* APPL EXT FIX DEV-PATELLA */
"7817" = "1" /* APPL EXT FIX-TIB/FIBULA */
"7818" = "1" /* APPL EXT FIX-METATAR/TAR */
"7819" = "1" /* APPLIC EXT FIX DEV NEC */
"7820" = "1" /* LIMB SHORTEN PROC NOS */
"7822" = "1" /* LIMB SHORT PROC-HUMERUS */
"7823" = "1" /* LIMB SHORTEN-RADIUS/ULNA */
"7824" = "1" /* LIMB SHORTEN-METACAR/CAR */
"7825" = "1" /* LIMB SHORT PROC-FEMUR */
"7827" = "1" /* LIMB SHORTEN-TIB/FIBULA */
"7828" = "1" /* LIMB SHORTEN-METATAR/TAR */
"7829" = "1" /* LIMB SHORTEN PROC NEC */
"7830" = "1" /* LIMB LENGTHEN PROC NOS */
"7831" = "1" /* LIMB LENGTHEN PROC NOS */
"7832" = "1" /* LIMB LENGTH PROC-HUMERUS */
"7833" = "1" /* LIMB LENGTH-RADIUS/ULNA */
"7834" = "1" /* LIMB LENGTH-METACAR/CAR */
"7835" = "1" /* LIMB LENGTH PROC-FEMUR */
"7837" = "1" /* LIMB LENGTHEN-TIB/FIBULA */
"7838" = "1" /* LIMB LENGTHN-METATAR/TAR */
"7839" = "1" /* LIMB LENGTHEN PROC NEC */
"7840" = "1" /* OTH BONE REPAIR/PLAST OP */
"7841" = "1" /* OTH CHEST CAGE REP/PLAST */
"7842" = "1" /* OTH HUMERUS REPAIR/PLAST */
"7843" = "1" /* OTH RAD/ULN REPAIR/PLAST */
"7844" = "1" /* OTH METAC/CARP REP/PLAST */
"7845" = "1" /* OTH FEMUR REPAIR/PLASTIC */
"7846" = "1" /* OTH PATELLA REPAIR/PLAST */
"7847" = "1" /* OTH TIB/FIB REPAIR/PLAST */
"7848" = "1" /* OTH META/TAR REPA/PLAST */
"7849" = "1" /* OTH BONE REPA/PLAST NEC */
"7850" = "1" /* INT FIX W/O FX REDUC NOS */
"7851" = "1" /* INT FIXATION-CHEST CAGE */
"7852" = "1" /* INT FIXATION-HUMERUS */
"7853" = "1" /* INT FIXATION-RADIUS/ULNA */
"7854" = "1" /* INT FIXATION-METACAR/CAR */
"7855" = "1" /* INTERNAL FIXATION-FEMUR */
"7856" = "1" /* INTERNAL FIX-PATELLA */
"7857" = "1" /* INT FIXATION-TIBIA/FIBUL */
"7858" = "1" /* INT FIXATION-METATAR/TAR */
"7859" = "1" /* INT FIX-NO FX REDUCT NEC */
"7860" = "1" /* REMOVE IMP DEVICE NOS */
"7861" = "1" /* REMOV IMP DEV-CHEST CAGE */
"7862" = "1" /* REMOVE IMPL DEV-HUMERUS */
"7863" = "1" /* REMOV IMP DEV-RADIUS/ULN */
"7864" = "1" /* REMOV IMP DEV-METAC/CARP */
"7865" = "1" /* REMOVE IMP DEVICE-FEMUR */
"7866" = "1" /* REMOV IMP DEVICE-PATELLA */
"7867" = "1" /* REMOV IMP DEV-TIB/FIBULA */
"7868" = "1" /* REMOVE IMP DEV-METAT/TAR */
"7869" = "1" /* REMOVE IMPL DEVICE NEC */
"7870" = "1" /* OSTEOCLASIS NOS */
"7871" = "1" /* OSTEOCLASIS-CHEST CAGE */
"7872" = "1" /* OSTEOCLASIS-HUMERUS */
"7873" = "1" /* OSTEOCLASIS-RADIUS/ULNA */
"7874" = "1" /* OSTEOCLASIS-METACAR/CAR */
"7875" = "1" /* OSTEOCLASIS-FEMUR */
"7876" = "1" /* OSTEOCLASIS-PATELLA */
"7877" = "1" /* OSTEOCLASIS-TIBIA/FIBULA */
"7878" = "1" /* OSTEOCLASIS-METATAR/TAR */
"7879" = "1" /* OSTEOCLASIS NEC */
"7880" = "1" /* OTHER BONE DX PROC NOS */
"7881" = "1" /* OTH DX PROCED-CHEST CAGE */
"7882" = "1" /* OTH DX PROCED-HUMERUS */
"7883" = "1" /* OTH DX PROC-RADIUS/ULNA */
"7884" = "1" /* OTH DX PROC-METACAR/CAR */
"7885" = "1" /* OTH DX PROCED-FEMUR */
"7886" = "1" /* OTH DX PROCED-PATELLA */
"7887" = "1" /* OTH DX PROC-TIBIA/FIBULA */
"7888" = "1" /* OTH DX PROC-METATAR/TAR */
"7889" = "1" /* OTHER BONE DX PROC NEC */
"7890" = "1" /* INSERT BONE STIMUL NOS */
"7891" = "1" /* INSERT BONE STIMUL-CHEST */
"7892" = "1" /* INSERT BONE STIM-HUMERUS */
"7893" = "1" /* INSER BONE STIM-RAD/ULNA */
"7894" = "1" /* INSER BONE STIM-META/CAR */
"7895" = "1" /* INSERT BONE STIM-FEMUR */
"7896" = "1" /* INSERT BONE STIM-PATELLA */
"7897" = "1" /* INSER BONE STIM-TIB/FIB */
"7898" = "1" /* INSER BONE STIM-META/TAR */
"7899" = "1" /* INSERT BONE STIMUL NEC */
"7910" = "1" /* CL FX REDUC-INT FIX NOS */
"7911" = "1" /* CLOS RED-INT FIX HUMERUS */
"7912" = "1" /* CL RED-INT FIX RAD/ULNA */
"7913" = "1" /* CL RED-INT FIX METAC/CAR */
"7914" = "1" /* CLOSE RED-INT FIX FINGER */
"7915" = "1" /* CLOSED RED-INT FIX FEMUR */
"7916" = "1" /* CL RED-INT FIX TIB/FIBU */
"7917" = "1" /* CL RED-INT FIX METAT/TAR */
"7918" = "1" /* CLOSE RED-INT FIX TOE FX */
"7919" = "1" /* CL FX REDUC-INT FIX NEC */
"7920" = "1" /* OPEN FX REDUCTION NOS */
"7921" = "1" /* OPEN REDUC-HUMERUS FX */
"7922" = "1" /* OPEN REDUC-RADIUS/ULN FX */
"7923" = "1" /* OPEN REDUC-METAC/CAR FX */
"7924" = "1" /* OPEN REDUCTION-FINGER FX */
"7925" = "1" /* OPEN REDUCTION-FEMUR FX */
"7926" = "1" /* OPEN REDUC-TIBIA/FIB FX */
"7927" = "1" /* OPEN REDUC-METAT/TARS FX */
"7928" = "1" /* OPEN REDUCTION-TOE FX */
"7929" = "1" /* OPEN FX REDUCTION NEC */
"7930" = "1" /* OPN FX RED W INT FIX NOS */
"7931" = "1" /* OPEN RED-INT FIX HUMERUS */
"7932" = "1" /* OP RED-INT FIX RAD/ULNA */
"7933" = "1" /* OP RED-INT FIX METAC/CAR */
"7934" = "1" /* OPEN RED-INT FIX FINGER */
"7935" = "1" /* OPEN REDUC-INT FIX FEMUR */
"7936" = "1" /* OP RED-INT FIX TIB/FIBUL */
"7937" = "1" /* OP RED-INT FIX METAT/TAR */
"7938" = "1" /* OPEN REDUCT-INT FIX TOE */
"7939" = "1" /* OPN FX RED W INT FIX NEC */
"7940" = "1" /* CLS REDUC-SEP EPIPHY NOS */
"7941" = "1" /* CLOSE RED-HUMERUS EPIPHY */
"7942" = "1" /* CLS RED-RADIUS/UL EPIPHY */
"7945" = "1" /* CLOSE REDUC-FEMUR EPIPHY */
"7946" = "1" /* CLS RED-TIBIA/FIB EPIPHY */
"7949" = "1" /* CLS REDUC-SEP EPIPHY NEC */
"7950" = "1" /* OPEN RED-SEP EPIPHY NOS */
"7951" = "1" /* OPN RED-SEP EPIPHY-HUMER */
"7952" = "1" /* OP RED-RADIUS/ULN EPIPHY */
"7955" = "1" /* OPN RED-SEP EPIPHY-FEMUR */
"7956" = "1" /* OP RED-TIBIA/FIB EPIPHYS */
"7959" = "1" /* OPEN RED-SEP EPIPHY NEC */
"7960" = "1" /* OPEN FX SITE DEBRIDE NOS */
"7961" = "1" /* DEBRID OPEN FX-HUMERUS */
"7962" = "1" /* DEBRID OPN FX-RADIUS/ULN */
"7963" = "1" /* DEBRID OPN FX-METAC/CAR */
"7964" = "1" /* DEBRID OPN FX-FINGER */
"7965" = "1" /* DEBRID OPN FX-FEMUR */
"7966" = "1" /* DEBRID OPN FX-TIBIA/FIB */
"7967" = "1" /* DEBRID OPN FX-METAT/TAR */
"7968" = "1" /* DEBRID OPN FX-TOE */
"7969" = "1" /* OPEN FX SITE DEBRIDE NEC */
"7980" = "1" /* OPEN REDUC-DISLOCAT NOS */
"7981" = "1" /* OPN REDUC DISLOC-SHOULDR */
"7982" = "1" /* OPEN REDUC-ELBOW DISLOC */
"7983" = "1" /* OPEN REDUC-WRIST DISLOC */
"7984" = "1" /* OPN REDUC DISLOC-HAND */
"7985" = "1" /* OPEN REDUC-HIP DISLOCAT */
"7986" = "1" /* OPEN REDUC-KNEE DISLOCAT */
"7987" = "1" /* OPEN REDUC-ANKLE DISLOC */
"7988" = "1" /* OPN REDUC DISLOC-FT/TOE */
"7989" = "1" /* OPEN REDUC-DISLOCAT NEC */
"7990" = "1" /* UNSPEC OP BONE INJ NOS */
"7991" = "1" /* HUMERUS INJURY OP NOS */
"7992" = "1" /* RADIUS/ULNA INJ OP NOS */
"7993" = "1" /* METACARP/CARP INJ OP NOS */
"7994" = "1" /* FINGER INJURY OP NOS */
"7995" = "1" /* FEMUR INJURY OP NOS */
"7996" = "1" /* TIBIA/FIBULA INJ OP NOS */
"7997" = "1" /* METATARS/TARS INJ OP NOS */
"7998" = "1" /* TOE INJURY OPERATION NOS */
"7999" = "1" /* UNSPEC OP-BONE INJ NEC */
"8000" = "1" /* ARTHROT & PROS REMOV NOS */
"8001" = "1" /* ARTHROT/PROS REMOV-SHLDR */
"8002" = "1" /* ARTHROT/PROS REMOV-ELBOW */
"8003" = "1" /* ARTHROT/PROS REMOV-WRIST */
"8004" = "1" /* ARTHROT/PROS REMOV-HAND */
"8005" = "1" /* ARTHROT/PROS REMOV-HIP */
"8006" = "1" /* ARTHROT/PROS REMOV-KNEE */
"8007" = "1" /* ARTHROT/PROS REMOV-ANKLE */
"8008" = "1" /* ARTHROT/PROS REMOV-FOOT */
"8009" = "1" /* ARTHROT & PROS REMOV NEC */
"8010" = "1" /* OTHER ARTHROTOMY NOS */
"8011" = "1" /* OTH ARTHROTOMY-SHOULDER */
"8012" = "1" /* OTH ARTHROTOMY-ELBOW */
"8013" = "1" /* OTH ARTHROTOMY-WRIST */
"8014" = "1" /* OTH ARTHROTOMY-HAND/FNGR */
"8015" = "1" /* OTH ARTHROTOMY-HIP */
"8016" = "1" /* OTH ARTHROTOMY-KNEE */
"8017" = "1" /* OTH ARTHROTOMY-ANKLE */
"8018" = "1" /* OTH ARTHROTOMY-FOOT/TOE */
"8019" = "1" /* OTHER ARTHROTOMY NEC */
"8020" = "1" /* ARTHROSCOPY NOS */
"8021" = "1" /* SHOULDER ARTHROSCOPY */
"8022" = "1" /* ELBOW ARTHROSCOPY */
"8023" = "1" /* WRIST ARTHROSCOPY */
"8024" = "1" /* HAND & FINGER ARTHROSCOP */
"8025" = "1" /* HIP ARTHROSCOPY */
"8026" = "1" /* KNEE ARTHROSCOPY */
"8027" = "1" /* ANKLE ARTHROSCOPY */
"8028" = "1" /* FOOT & TOE ARTHROSCOPY */
"8029" = "1" /* ARTHROSCOPY NEC */
"8040" = "1" /* JT STRUCTUR DIVISION NOS */
"8041" = "1" /* SHOULDER STRUCT DIVISION */
"8042" = "1" /* ELBOW STRUCTURE DIVISION */
"8043" = "1" /* WRIST STRUCTURE DIVISION */
"8044" = "1" /* HAND JOINT STRUCT DIVIS */
"8045" = "1" /* HIP STRUCTURE DIVISION */
"8046" = "1" /* KNEE STRUCTURE DIVISION */
"8047" = "1" /* ANKLE STRUCTURE DIVISION */
"8048" = "1" /* FOOT JOINT STRUCT DIVIS */
"8049" = "1" /* JT STRUCTUR DIVISION NEC */
"805 " = "1" /* JT STRUCTUR DIVISION NEC */
"8050" = "1" /* EXC/DEST INTVRT DISC NOS */
"8051" = "1" /* EXCISION INTERVERT DISC */
"8059" = "1" /* OTH EXC/DEST INTVRT DISC */
"806 " = "1" /* EXCIS KNEE SEMILUN CARTL */
"8070" = "1" /* SYNOVECTOMY-SITE NOS */
"8071" = "1" /* SHOULDER SYNOVECTOMY */
"8072" = "1" /* ELBOW SYNOVECTOMY */
"8073" = "1" /* WRIST SYNOVECTOMY */
"8074" = "1" /* HAND SYNOVECTOMY */
"8075" = "1" /* HIP SYNOVECTOMY */
"8076" = "1" /* KNEE SYNOVECTOMY */
"8077" = "1" /* ANKLE SYNOVECTOMY */
"8078" = "1" /* FOOT SYNOVECTOMY */
"8079" = "1" /* SYNOVECTOMY-SITE NEC */
"8080" = "1" /* DESTRUCT JOINT LES NOS */
"8081" = "1" /* DESTRUC-SHOULDER LES NEC */
"8082" = "1" /* DESTRUC-ELBOW LESION NEC */
"8083" = "1" /* DESTRUC-WRIST LESION NEC */
"8084" = "1" /* DESTRUC-HAND JT LES NEC */
"8085" = "1" /* DESTRUCT-HIP LESION NEC */
"8086" = "1" /* DESTRUCT-KNEE LESION NEC */
"8087" = "1" /* DESTRUC-ANKLE LESION NEC */
"8088" = "1" /* DESTRUC-FOOT JT LES NEC */
"8089" = "1" /* DESTRUCT JOINT LES NEC */
"8090" = "1" /* EXCISION OF JOINT NOS */
"8091" = "1" /* EXCISION OF SHOULDER NEC */
"8092" = "1" /* EXCISION OF ELBOW NEC */
"8093" = "1" /* EXCISION OF WRIST NEC */
"8094" = "1" /* EXCISION HAND JOINT NEC */
"8095" = "1" /* EXCISION OF HIP NEC */
"8096" = "1" /* EXCISION OF KNEE NEC */
"8097" = "1" /* EXCISION OF ANKLE NEC */
"8098" = "1" /* EXCISION FOOT JOINT NEC */
"8099" = "1" /* EXCISION OF JOINT NEC */
"8100" = "1" /* SPINAL FUSION NOS */
"8101" = "1" /* ATLAS-AXIS FUSION */
"8102" = "1" /* OTHER CERVICAL FUS ANT */
"8103" = "1" /* OTHER CERVICAL FUS POST */
"8104" = "1" /* DORSAL/DORSOLUM FUS ANT */
"8105" = "1" /* DORSAL/DORSOLUM FUS POST */
"8106" = "1" /* LUMBAR/LUMBOSAC FUS ANT */
"8107" = "1" /* LUMBAR/LUMBOSAC FUS LAT */
"8108" = "1" /* LUMBAR/LUMBOSAC FUS POST */
"8109" = "1" /* LUMBAR/LUMBOSAC FUS POST */
"8111" = "1" /* ANKLE FUSION */
"8112" = "1" /* TRIPLE ARTHRODESIS */
"8113" = "1" /* SUBTALAR FUSION */
"8114" = "1" /* MIDTARSAL FUSION */
"8115" = "1" /* TARSOMETATARSAL FUSION */
"8116" = "1" /* METATARSOPHALANGEAL FUS */
"8117" = "1" /* OTHER FUSION OF FOOT */
"8118" = "1" /* OTHER FUSION OF FOOT */
"8120" = "1" /* ARTHRODESIS NOS */
"8121" = "1" /* ARTHRODESIS OF HIP */
"8122" = "1" /* ARTHRODESIS OF KNEE */
"8123" = "1" /* ARTHRODESIS OF SHOULDER */
"8124" = "1" /* ARTHRODESIS OF ELBOW */
"8125" = "1" /* CARPORADIAL FUSION */
"8126" = "1" /* METACARPOCARPAL FUSION */
"8127" = "1" /* METACARPOPHALANGEAL FUS */
"8128" = "1" /* INTERPHALANGEAL FUSION */
"8129" = "1" /* ARTHRODESIS NEC */
"8130" = "1" /* SPINAL REFUSION NOS */
"8131" = "1" /* REFUSION OF ATLAS-AXIS */
"8132" = "1" /* REFUSION OF OTH CERV ANT */
"8133" = "1" /* REFUS OF OTH CERV POST */
"8134" = "1" /* REFUSION OF DORSAL ANT */
"8135" = "1" /* REFUSION OF DORSAL POST */
"8136" = "1" /* REFUSION OF LUMBAR ANT */
"8137" = "1" /* REFUSION OF LUMBAR LAT */
"8138" = "1" /* REFUSION OF LUMBAR POST */
"8139" = "1" /* REFUSION OF SPINE NEC */
"8140" = "1" /* REPAIR OF HIP, NEC */
"8141" = "1" /* REPAIR OF HIP, NEC */
"8142" = "1" /* FIVE-IN-ONE KNEE REPAIR */
"8143" = "1" /* TRIAD KNEE REPAIR */
"8144" = "1" /* PATELLAR STABILIZATION */
"8145" = "1" /* CRUCIATE LIG REPAIR NEC */
"8146" = "1" /* COLLATERL LIG REPAIR NEC */
"8147" = "1" /* OTHER REPAIR OF KNEE */
"8148" = "1" /* OTHER REPAIR OF KNEE */
"8149" = "1" /* OTHER REPAIR OF ANKLE */
"8151" = "1" /* TOTAL HIP REPLACEMENT */
"8152" = "1" /* PARTIAL HIP REPLACEMENT */
"8153" = "1" /* REVISE HIP REPLACEMENT */
"8154" = "1" /* TOTAL KNEE REPLACEMENT */
"8155" = "1" /* REVISE KNEE REPLACEMENT */
"8156" = "1" /* TOTAL ANKLE REPLACEMENT */
"8157" = "1" /* REPL JOINT OF FOOT, TOE */
"8159" = "1" /* REV JT REPL LOW EXT NEC */
"8161" = "1" /* 360 SPINAL FUSION */
"8162" = "1" /* FUS/REFUS 2-3 VERTEBRAE */
"8163" = "1" /* FUS/REFUS 4-8 VERTEBRAE */
"8164" = "1" /* FUS/REFUS 9 VERTEBRAE */
"8165" = "1" /* VERTEBROPLASTY */
"8166" = "1" /* KYPHOPLASTY */
"8169" = "1" /* OTH HIP REPAIR  JAN80--SEP89 */
"8171" = "1" /* ARTHROPLAS METACARP WIT */
"8172" = "1" /* ARTHROPLASTY METACAR W/O */
"8173" = "1" /* TOTAL WRIST REPLACEMENT */
"8174" = "1" /* ARTHROPLASTY CARPAL WIT */
"8175" = "1" /* ARTHROPLASTY CARPAL W/O */
"8179" = "1" /* OTH REPAIR HAN/FIN/WRIS */
"8180" = "1" /* TOTAL SHOULDER REPLACE */
"8181" = "1" /* PARTIAL SHOULDER REPLACE */
"8182" = "1" /* REP RECUR SHLDER DISLOC */
"8183" = "1" /* SHOULDER ARTHROPLAST NEC */
"8184" = "1" /* TOTAL ELBOW REPLACEMENT */
"8185" = "1" /* ELBOW ARTHROPLASTY NEC */
"8186" = "1" /* ELBOW ARTHROPLASTY NEC */
"8187" = "1" /* ELBOW ARTHROPLASTY NEC */
"8193" = "1" /* SUTUR CAPSUL/LIGAMEN ARM */
"8194" = "1" /* SUTURE CAPSUL/LIG ANK/FT */
"8195" = "1" /* SUTUR CAPSUL/LIG LEG NEC */
"8196" = "1" /* OTHER REPAIR OF JOINT */
"8197" = "1" /* REV JT REPL UPPER EXTREM */
"8198" = "1" /* OTHER JOINT DX PROCEDURE */
"8199" = "1" /* JOINT STRUCTURE OP NEC */
"8201" = "1" /* EXPLOR TEND SHEATH-HAND */
"8202" = "1" /* MYOTOMY OF HAND */
"8203" = "1" /* BURSOTOMY OF HAND */
"8209" = "1" /* INC SOFT TISSUE HAND NEC */
"8211" = "1" /* TENOTOMY OF HAND */
"8212" = "1" /* FASCIOTOMY OF HAND */
"8219" = "1" /* DIV SOFT TISSUE HAND NEC */
"8221" = "1" /* EXC LES TEND SHEATH HAND */
"8222" = "1" /* EXCISION HAND MUSCLE LES */
"8229" = "1" /* EXC LES SFT TISS HND NEC */
"8231" = "1" /* BURSECTOMY OF HAND */
"8232" = "1" /* EXCIS HAND TEND FOR GRFT */
"8233" = "1" /* HAND TENONECTOMY NEC */
"8234" = "1" /* EXC HND MUS/FAS FOR GRFT */
"8235" = "1" /* HAND FASCIECTOMY NEC */
"8236" = "1" /* OTHER MYECTOMY OF HAND */
"8239" = "1" /* HAND SOFT TISSUE EXC NEC */
"8241" = "1" /* SUTURE TENDN SHEATH HAND */
"8242" = "1" /* DELAY SUT FLEX TEND HAND */
"8243" = "1" /* DELAY SUT HAND TEND NEC */
"8244" = "1" /* SUTUR FLEX TEND HAND NEC */
"8245" = "1" /* SUTURE HAND TENDON NEC */
"8246" = "1" /* SUTURE HAND MUSCLE/FASC */
"8251" = "1" /* HAND TENDON ADVANCEMENT */
"8252" = "1" /* HAND TENDON RECESSION */
"8253" = "1" /* HAND TENDON REATTACHMENT */
"8254" = "1" /* HAND MUSCLE REATTACHMENT */
"8255" = "1" /* CHNG HND MUS/TEN LNG NEC */
"8256" = "1" /* TRANSPLANT HAND TEND NEC */
"8257" = "1" /* TRANSPOSIT HAND TEND NEC */
"8258" = "1" /* TRANSPLANT HAND MUSC NEC */
"8259" = "1" /* TRANSPOSIT HAND MUSC NEC */
"8261" = "1" /* POLLICIZATION OPERATION */
"8269" = "1" /* THUMB RECONSTRUCTION NEC */
"8271" = "1" /* HAND TEND PULLEY RECONST */
"8272" = "1" /* PLAST OP HND-MUS/FAS GRF */
"8279" = "1" /* PLAST OP HAND W GRFT NEC */
"8281" = "1" /* TRANSFER OF FINGER */
"8282" = "1" /* REPAIR OF CLEFT HAND */
"8283" = "1" /* REPAIR OF MACRODACTYLY */
"8284" = "1" /* REPAIR OF MALLET FINGER */
"8285" = "1" /* OTHER TENODESIS OF HAND */
"8286" = "1" /* OTHER TENOPLASTY OF HAND */
"8289" = "1" /* HAND PLASTIC OP NEC */
"8291" = "1" /* LYSIS OF HAND ADHESIONS */
"8299" = "1" /* HAND MUS/TEN/FAS/OPS NEC */
"8301" = "1" /* TENDON SHEATH EXPLORAT */
"8302" = "1" /* MYOTOMY */
"8303" = "1" /* BURSOTOMY */
"8309" = "1" /* SOFT TISSUE INCISION NEC */
"8311" = "1" /* ACHILLOTENOTOMY */
"8312" = "1" /* ADDUCTOR TENOTOMY OF HIP */
"8313" = "1" /* OTHER TENOTOMY */
"8314" = "1" /* FASCIOTOMY */
"8319" = "1" /* SOFT TISSUE DIVISION NEC */
"8321" = "1" /* SOFT TISSUE BIOPSY */
"8329" = "1" /* SOFT TISSUE DX PROC NEC */
"8331" = "1" /* EXCIS LES TENDON SHEATH */
"8332" = "1" /* EXCIS LESION OF MUSCLE */
"8339" = "1" /* EXC LES SOFT TISSUE NEC */
"8341" = "1" /* TENDON EXCISION FOR GRFT */
"8342" = "1" /* OTHER TENONECTOMY */
"8343" = "1" /* MUSC/FASC EXCIS FOR GRFT */
"8344" = "1" /* OTHER FASCIECTOMY */
"8345" = "1" /* OTHER MYECTOMY */
"8349" = "1" /* OTHER SOFT TISSUE EXCIS */
"835 " = "1" /* BURSECTOMY */
"8361" = "1" /* TENDON SHEATH SUTURE */
"8362" = "1" /* DELAYED TENDON SUTURE */
"8363" = "1" /* ROTATOR CUFF REPAIR */
"8364" = "1" /* OTHER SUTURE OF TENDON */
"8365" = "1" /* OTHER MUSCLE/FASC SUTURE */
"8371" = "1" /* TENDON ADVANCEMENT */
"8372" = "1" /* TENDON RECESSION */
"8373" = "1" /* TENDON REATTACHMENT */
"8374" = "1" /* MUSCLE REATTACHMENT */
"8375" = "1" /* TENDON TRNSFR/TRANSPLANT */
"8376" = "1" /* OTHER TENDON TRANSPOSIT */
"8377" = "1" /* MUSCLE TRNSFR/TRANSPLANT */
"8379" = "1" /* OTHER MUSCLE TRANSPOSIT */
"8381" = "1" /* TENDON GRAFT */
"8382" = "1" /* MUSCLE OR FASCIA GRAFT */
"8383" = "1" /* TENDON PULLEY RECONSTRUC */
"8384" = "1" /* CLUBFOOT RELEASE NEC */
"8385" = "1" /* MUSC/TEND LNG CHANGE NEC */
"8386" = "1" /* QUADRICEPSPLASTY */
"8387" = "1" /* OTHER PLASTIC OPS MUSCLE */
"8388" = "1" /* OTHER PLASTIC OPS TENDON */
"8389" = "1" /* OTHER PLASTIC OPS FASCIA */
"8391" = "1" /* ADHESIOLYSIS MUS/TEN/FAS */
"8392" = "1" /* INSERT SKEL MUSC STIMULA */
"8393" = "1" /* REMOV SKEL MUSC STIMULAT */
"8399" = "1" /* MUS/TEN/FAS/BUR OP NEC */
"8400" = "1" /* UPPER LIMB AMPUTAT NOS */
"8401" = "1" /* FINGER AMPUTATION */
"8402" = "1" /* THUMB AMPUTATION */
"8403" = "1" /* AMPUTATION THROUGH HAND */
"8404" = "1" /* DISARTICULATION OF WRIST */
"8405" = "1" /* AMPUTATION THRU FOREARM */
"8406" = "1" /* DISARTICULATION OF ELBOW */
"8407" = "1" /* AMPUTATION THRU HUMERUS */
"8408" = "1" /* SHOULDER DISARTICULATION */
"8409" = "1" /* FOREQUARTER AMPUTATION */
"8410" = "1" /* LOWER LIMB AMPUTAT NOS */
"8411" = "1" /* TOE AMPUTATION */
"8412" = "1" /* AMPUTATION THROUGH FOOT */
"8413" = "1" /* DISARTICULATION OF ANKLE */
"8414" = "1" /* AMPUTAT THROUGH MALLEOLI */
"8415" = "1" /* BELOW KNEE AMPUTAT NEC */
"8416" = "1" /* DISARTICULATION OF KNEE */
"8417" = "1" /* ABOVE KNEE AMPUTATION */
"8418" = "1" /* DISARTICULATION OF HIP */
"8419" = "1" /* HINDQUARTER AMPUTATION */
"8421" = "1" /* THUMB REATTACHMENT */
"8422" = "1" /* FINGER REATTACHMENT */
"8423" = "1" /* FOREARM/WRIST/HAND REATT */
"8424" = "1" /* UPPER ARM REATTACHMENT */
"8425" = "1" /* TOE REATTACHMENT */
"8426" = "1" /* FOOT REATTACHMENT */
"8427" = "1" /* LOWER LEG/ANKLE REATTACH */
"8428" = "1" /* THIGH REATTACHMENT */
"8429" = "1" /* REATTACHMENT NEC */
"843 " = "1" /* AMPUTATION STUMP REVIS */
"8440" = "1" /* IMPLNT/FIT PROS LIMB NOS */
"8444" = "1" /* IMPLANT ARM PROSTHESIS */
"8448" = "1" /* IMPLANT LEG PROSTHESIS */
"8458" = "1" /* IMP INTRSPINE DECOMP DEV */
"8459" = "1" /* INSERT OTHR SPIN DEVICE */
"8460" = "1" /* INSERT DISC PROS NOS */
"8461" = "1" /* INS PART DISC PROS CERV */
"8462" = "1" /* INS TOT DISC PROST CERV */
"8463" = "1" /* INS SPIN DISC PROS THOR */
"8464" = "1" /* INS PART DISC PROS LUMB */
"8465" = "1" /* INS TOTL DISC PROS LUMB */
"8466" = "1" /* REVISE DISC PROST CERV */
"8467" = "1" /* REVISE DISC PROST THORA */
"8468" = "1" /* REVISE DISC PROSTH LUMB */
"8469" = "1" /* REVISE DISC PROSTH NOS */
"8472" = "1" /* APP EXT FIX DEV-RING SYS */
"8473" = "1" /* APP HYBRID EXT FIX DEV */
"8491" = "1" /* AMPUTATION NOS */
"8492" = "1" /* SEPARAT EQUAL JOIN TWIN */
"8493" = "1" /* SEPARAT UNEQUL JOIN TWIN */
"8499" = "1" /* MUSCULOSKELETAL OP NEC */
"8512" = "1" /* OPEN BREAST BIOPSY */
"8520" = "1" /* BREAST TISSU DESTRUC NOS */
"8521" = "1" /* LOCAL EXCIS BREAST LES */
"8522" = "1" /* QUADRANT RESECT BREAST */
"8523" = "1" /* SUBTOTAL MASTECTOMY */
"8524" = "1" /* EXC ECTOPIC BREAST TISSU */
"8525" = "1" /* EXCISION OF NIPPLE */
"8531" = "1" /* UNILAT REDUCT MAMMOPLAST */
"8532" = "1" /* BILAT REDUCT MAMMOPLASTY */
"8533" = "1" /* UNIL SUBQ MAMMECT-IMPLNT */
"8534" = "1" /* UNILAT SUBQ MAMMECT NEC */
"8535" = "1" /* BIL SUBQ MAMMECT-IMPLANT */
"8536" = "1" /* BILAT SUBQ MAMMECTOM NEC */
"8541" = "1" /* UNILAT SIMPLE MASTECTOMY */
"8542" = "1" /* BILAT SIMPLE MASTECTOMY */
"8543" = "1" /* UNILAT EXTEN SIMP MASTEC */
"8544" = "1" /* BILAT EXTEND SIMP MASTEC */
"8545" = "1" /* UNILAT RADICAL MASTECTOM */
"8546" = "1" /* BILAT RADICAL MASTECTOMY */
"8547" = "1" /* UNIL EXT RAD MASTECTOMY */
"8548" = "1" /* BIL EXTEN RAD MASTECTOMY */
"8550" = "1" /* AUGMENT MAMMOPLASTY NOS */
"8553" = "1" /* UNILAT BREAST IMPLANT */
"8554" = "1" /* BILATERAL BREAST IMPLANT */
"856 " = "1" /* MASTOPEXY */
"857 " = "1" /* TOTAL BREAST RECONSTRUCT */
"8582" = "1" /* BREAST SPLIT-THICK GRAFT */
"8583" = "1" /* BREAST FULL-THICK GRAFT */
"8584" = "1" /* BREAST PEDICLE GRAFT */
"8585" = "1" /* BREAST MUSCLE FLAP GRAFT */
"8586" = "1" /* TRANSPOSITION OF NIPPLE */
"8587" = "1" /* NIPPLE REPAIR NEC */
"8589" = "1" /* MAMMOPLASTY NEC */
"8593" = "1" /* BREAST IMPLANT REVISION */
"8594" = "1" /* BREAST IMPLANT REMOVAL */
"8595" = "1" /* INSER BREAST TISSU EXPAN */
"8596" = "1" /* REMOV BREAST TISSU EXPAN */
"8599" = "1" /* BREAST OPERATION NEC */
"8606" = "1" /* INSERT INFUSION PUMP */
"8621" = "1" /* EXCISION OF PILONID CYST */
"8622" = "1" /* EXC WOUND DEBRIDEMENT */
"8625" = "1" /* DERMABRASION */
"864 " = "1" /* RADICAL EXCIS SKIN LES */
"8660" = "1" /* FREE SKIN GRAFT NOS */
"8661" = "1" /* FULL-THICK HAND SKIN GRF */
"8662" = "1" /* HAND SKIN GRAFT NEC */
"8663" = "1" /* FULL-THICK SKIN GRFT NEC */
"8665" = "1" /* HETEROGRAFT TO SKIN */
"8666" = "1" /* HOMOGRAFT TO SKIN */
"8667" = "1" /* DERMAL REGENER GRAFT */
"8669" = "1" /* FREE SKIN GRAFT NEC */
"8670" = "1" /* PEDICLE GRAFT/FLAP NOS */
"8671" = "1" /* CUT & PREP PEDICLE GRAFT */
"8672" = "1" /* PEDICLE GRAFT ADVANCEMEN */
"8673" = "1" /* ATTACH PEDICLE TO HAND */
"8674" = "1" /* ATTACH PEDICLE GRAFT NEC */
"8675" = "1" /* REVISION OF PEDICLE GRFT */
"8681" = "1" /* REPAIR FACIAL WEAKNESS */
"8682" = "1" /* FACIAL RHYTIDECTOMY */
"8683" = "1" /* SIZE REDUCT PLASTIC OP */
"8684" = "1" /* RELAXATION OF SCAR */
"8685" = "1" /* SYNDACTYLY CORRECTION */
"8686" = "1" /* ONYCHOPLASTY */
"8689" = "1" /* SKIN REPAIR & PLASTY NEC */
"8691" = "1" /* SKIN EXCISION FOR GRAFT */
"8693" = "1" /* INSERT TISSUE EXPANDER */
"8694" = "1" /* INS/REPL SINGLE PUL GEN */
"8695" = "1" /* INS/REPL DUAL PULSE GEN */
"8696" = "1" /* INSERT/REPL OTH NEUROST */
"8697" = "1" /* INS/REP 1 PUL GEN */
"8698" = "1" /* INS/REP 2 PUL GEN */
"8753" = "1" /* INTRAOPER CHOLANGIOGRAM */
"9504" = "1" /* ANESTHETIZED EYE EXAM */
OTHER  = "0" ;

VALUE $PRCLASS
'0001' = 2
'0002' = 2
'0003' = 2
'0009' = 2
'0010' = 2
'0011' = 2
'0012' = 2
'0013' = 2
'0014' = 2
'0015' = 2
'0016' = 2
'0017' = 2
'0018' = 2
'0021' = 1
'0022' = 1
'0023' = 1
'0024' = 1
'0025' = 1
'0028' = 1
'0029' = 1
'0031' = 1
'0032' = 1
'0033' = 1
'0034' = 1
'0035' = 1
'0039' = 1
'0040' = 2
'0041' = 2
'0042' = 2
'0043' = 2
'0044' = 4
'0045' = 2
'0046' = 2
'0047' = 2
'0048' = 2
'0050' = 4
'0051' = 4
'0052' = 4
'0053' = 4
'0054' = 4
'0055' = 2
'0056' = 4
'0057' = 4
'0061' = 4
'0062' = 4
'0063' = 2
'0064' = 2
'0065' = 2
'0066' = 4
'0070' = 4
'0071' = 4
'0072' = 4
'0073' = 4
'0074' = 4
'0075' = 4
'0076' = 4
'0077' = 4
'0080' = 4
'0081' = 4
'0082' = 4
'0083' = 4
'0084' = 4
'0085' = 4
'0086' = 4
'0087' = 4
'0091' = 2
'0092' = 2
'0093' = 2
'0101' = 2
'0102' = 2
'0109' = 2
'0111' = 1
'0112' = 3
'0113' = 1
'0114' = 3
'0115' = 3
'0118' = 3
'0119' = 3
'0121' = 4
'0122' = 4
'0123' = 4
'0124' = 4
'0125' = 4
'0126' = 4
'0127' = 4
'0128' = 4
'0131' = 4
'0132' = 4
'0139' = 4
'0141' = 4
'0142' = 4
'0151' = 4
'0152' = 4
'0153' = 4
'0159' = 4
'016' = 4
'0201' = 4
'0202' = 4
'0203' = 4
'0204' = 4
'0205' = 4
'0206' = 4
'0207' = 4
'0211' = 4
'0212' = 4
'0213' = 4
'0214' = 4
'022' = 4
'0231' = 4
'0232' = 4
'0233' = 4
'0234' = 4
'0235' = 4
'0239' = 4
'0241' = 2
'0242' = 4
'0243' = 4
'0291' = 4
'0292' = 4
'0293' = 4
'0294' = 4
'0295' = 2
'0296' = 2
'0299' = 4
'0301' = 4
'0302' = 4
'0309' = 4
'031' = 4
'0321' = 4
'0329' = 4
'0331' = 1
'0332' = 3
'0339' = 3
'034' = 4
'0351' = 4
'0352' = 4
'0353' = 4
'0359' = 4
'036' = 4
'0371' = 4
'0372' = 4
'0379' = 4
'038' = 2
'0390' = 2
'0391' = 2
'0392' = 2
'0393' = 4
'0394' = 4
'0395' = 2
'0396' = 2
'0397' = 4
'0398' = 4
'0399' = 4
'0401' = 4
'0402' = 4
'0403' = 4
'0404' = 4
'0405' = 4
'0406' = 4
'0407' = 4
'0411' = 1
'0412' = 3
'0419' = 3
'042' = 2
'043' = 4
'0441' = 4
'0442' = 4
'0443' = 4
'0444' = 4
'0449' = 4
'045' = 4
'046' = 4
'0471' = 4
'0472' = 4
'0473' = 4
'0474' = 4
'0475' = 4
'0476' = 4
'0479' = 4
'0480' = 2
'0481' = 2
'0489' = 2
'0491' = 4
'0492' = 4
'0493' = 4
'0499' = 4
'050' = 4
'0511' = 3
'0519' = 3
'0521' = 4
'0522' = 4
'0523' = 4
'0524' = 4
'0525' = 4
'0529' = 4
'0531' = 2
'0532' = 2
'0539' = 2
'0581' = 4
'0589' = 4
'059' = 4
'0601' = 2
'0602' = 4
'0609' = 4
'0611' = 1
'0612' = 3
'0613' = 3
'0619' = 3
'062' = 4
'0631' = 4
'0639' = 4
'064' = 4
'0650' = 4
'0651' = 4
'0652' = 4
'066' = 4
'067' = 4
'0681' = 4
'0689' = 4
'0691' = 4
'0692' = 4
'0693' = 4
'0694' = 4
'0695' = 4
'0698' = 4
'0699' = 4
'0700' = 4
'0701' = 4
'0702' = 4
'0711' = 1
'0712' = 3
'0713' = 3
'0714' = 3
'0715' = 3
'0716' = 3
'0717' = 3
'0719' = 3
'0721' = 4
'0722' = 4
'0729' = 4
'073' = 4
'0741' = 4
'0742' = 4
'0743' = 4
'0744' = 4
'0745' = 4
'0749' = 4
'0751' = 4
'0752' = 4
'0753' = 4
'0754' = 4
'0759' = 4
'0761' = 4
'0762' = 4
'0763' = 4
'0764' = 4
'0765' = 4
'0768' = 4
'0769' = 4
'0771' = 4
'0772' = 4
'0779' = 4
'0780' = 4
'0781' = 4
'0782' = 4
'0791' = 4
'0792' = 4
'0793' = 4
'0794' = 4
'0799' = 4
'0801' = 2
'0802' = 2
'0809' = 2
'0811' = 3
'0819' = 1
'0820' = 4
'0821' = 4
'0822' = 4
'0823' = 4
'0824' = 4
'0825' = 4
'0831' = 4
'0832' = 4
'0833' = 4
'0834' = 4
'0835' = 4
'0836' = 4
'0837' = 4
'0838' = 4
'0841' = 4
'0842' = 4
'0843' = 4
'0844' = 4
'0849' = 4
'0851' = 4
'0852' = 4
'0859' = 4
'0861' = 4
'0862' = 4
'0863' = 4
'0864' = 4
'0869' = 4
'0870' = 4
'0871' = 4
'0872' = 4
'0873' = 4
'0874' = 4
'0881' = 2
'0882' = 2
'0883' = 2
'0884' = 2
'0885' = 2
'0886' = 2
'0887' = 2
'0889' = 2
'0891' = 4
'0892' = 4
'0893' = 4
'0899' = 4
'090' = 4
'0911' = 3
'0912' = 3
'0919' = 3
'0920' = 4
'0921' = 4
'0922' = 4
'0923' = 4
'093' = 4
'0941' = 4
'0942' = 4
'0943' = 4
'0944' = 4
'0949' = 4
'0951' = 4
'0952' = 4
'0953' = 4
'0959' = 4
'096' = 4
'0971' = 4
'0972' = 4
'0973' = 4
'0981' = 4
'0982' = 4
'0983' = 4
'0991' = 4
'0999' = 4
'100' = 4
'101' = 4
'1021' = 3
'1029' = 3
'1031' = 4
'1032' = 4
'1033' = 4
'1041' = 4
'1042' = 4
'1043' = 4
'1044' = 4
'1049' = 4
'105' = 4
'106' = 4
'1091' = 4
'1099' = 4
'110' = 4
'111' = 4
'1121' = 3
'1122' = 3
'1129' = 3
'1131' = 4
'1132' = 4
'1139' = 4
'1141' = 4
'1142' = 4
'1143' = 4
'1149' = 4
'1151' = 4
'1152' = 4
'1153' = 4
'1159' = 4
'1160' = 4
'1161' = 4
'1162' = 4
'1163' = 4
'1164' = 4
'1169' = 4
'1171' = 4
'1172' = 4
'1173' = 4
'1174' = 4
'1175' = 4
'1176' = 4
'1179' = 4
'1191' = 4
'1192' = 4
'1199' = 4
'1200' = 4
'1201' = 4
'1202' = 4
'1211' = 4
'1212' = 4
'1213' = 4
'1214' = 4
'1221' = 3
'1222' = 3
'1229' = 3
'1231' = 4
'1232' = 4
'1233' = 4
'1234' = 4
'1235' = 4
'1239' = 4
'1240' = 4
'1241' = 4
'1242' = 4
'1243' = 4
'1244' = 4
'1251' = 4
'1252' = 4
'1253' = 4
'1254' = 4
'1255' = 4
'1259' = 4
'1261' = 4
'1262' = 4
'1263' = 4
'1264' = 4
'1265' = 4
'1266' = 4
'1269' = 4
'1271' = 4
'1272' = 4
'1273' = 4
'1274' = 4
'1279' = 4
'1281' = 4
'1282' = 4
'1283' = 4
'1284' = 4
'1285' = 4
'1286' = 4
'1287' = 4
'1288' = 4
'1289' = 4
'1291' = 4
'1292' = 4
'1293' = 4
'1297' = 4
'1298' = 4
'1299' = 4
'1300' = 4
'1301' = 4
'1302' = 4
'1311' = 4
'1319' = 4
'132' = 4
'133' = 4
'1341' = 4
'1342' = 4
'1343' = 4
'1351' = 4
'1359' = 4
'1361' = 4
'1362' = 4
'1363' = 4
'1364' = 4
'1365' = 4
'1366' = 4
'1369' = 4
'1370' = 4
'1371' = 4
'1372' = 4
'138' = 4
'139' = 4
'1390' = 4
'1391' = 4
'1400' = 4
'1401' = 4
'1402' = 4
'1411' = 3
'1419' = 3
'1421' = 4
'1422' = 4
'1423' = 2
'1424' = 2
'1425' = 2
'1426' = 4
'1427' = 4
'1429' = 4
'1431' = 4
'1432' = 4
'1433' = 2
'1434' = 2
'1435' = 2
'1439' = 4
'1441' = 4
'1449' = 4
'1451' = 4
'1452' = 4
'1453' = 4
'1454' = 4
'1455' = 4
'1459' = 4
'146' = 4
'1471' = 4
'1472' = 4
'1473' = 4
'1474' = 4
'1475' = 4
'1479' = 4
'149' = 4
'1501' = 3
'1509' = 3
'1511' = 4
'1512' = 4
'1513' = 4
'1519' = 4
'1521' = 4
'1522' = 4
'1529' = 4
'153' = 4
'154' = 4
'155' = 4
'156' = 4
'157' = 4
'159' = 4
'1601' = 4
'1602' = 4
'1609' = 4
'161' = 4
'1621' = 1
'1622' = 3
'1623' = 3
'1629' = 3
'1631' = 4
'1639' = 4
'1641' = 4
'1642' = 4
'1649' = 4
'1651' = 4
'1652' = 4
'1659' = 4
'1661' = 4
'1662' = 4
'1663' = 4
'1664' = 4
'1665' = 4
'1666' = 4
'1669' = 4
'1671' = 4
'1672' = 4
'1681' = 4
'1682' = 4
'1689' = 4
'1691' = 2
'1692' = 4
'1693' = 4
'1698' = 4
'1699' = 4
'1801' = 2
'1802' = 2
'1809' = 2
'1811' = 1
'1812' = 1
'1819' = 1
'1821' = 4
'1829' = 2
'1831' = 4
'1839' = 4
'184' = 2
'185' = 4
'186' = 4
'1871' = 4
'1872' = 4
'1879' = 4
'189' = 4
'190' = 4
'1911' = 4
'1919' = 4
'1921' = 4
'1929' = 4
'193' = 4
'194' = 4
'1952' = 4
'1953' = 4
'1954' = 4
'1955' = 4
'196' = 4
'199' = 4
'2001' = 4
'2009' = 2
'201' = 2
'2021' = 4
'2022' = 4
'2023' = 4
'2031' = 1
'2032' = 3
'2039' = 3
'2041' = 4
'2042' = 4
'2049' = 4
'2051' = 4
'2059' = 4
'2061' = 4
'2062' = 4
'2071' = 4
'2072' = 4
'2079' = 4
'208' = 2
'2091' = 4
'2092' = 4
'2093' = 4
'2094' = 2
'2095' = 4
'2096' = 4
'2097' = 4
'2098' = 4
'2099' = 4
'2100' = 2
'2101' = 2
'2102' = 2
'2103' = 2
'2104' = 4
'2105' = 4
'2106' = 4
'2107' = 4
'2109' = 4
'211' = 2
'2121' = 1
'2122' = 1
'2129' = 1
'2130' = 2
'2131' = 2
'2132' = 2
'214' = 4
'215' = 4
'2161' = 4
'2162' = 4
'2169' = 4
'2171' = 2
'2172' = 4
'2181' = 2
'2182' = 4
'2183' = 4
'2184' = 4
'2185' = 4
'2186' = 4
'2187' = 4
'2188' = 4
'2189' = 4
'2191' = 2
'2199' = 4
'2200' = 2
'2201' = 2
'2202' = 2
'2211' = 1
'2212' = 3
'2219' = 1
'222' = 2
'2231' = 4
'2239' = 4
'2241' = 4
'2242' = 4
'2250' = 4
'2251' = 4
'2252' = 4
'2253' = 4
'2260' = 4
'2261' = 4
'2262' = 4
'2263' = 4
'2264' = 4
'2271' = 4
'2279' = 4
'229' = 4
'2301' = 2
'2309' = 2
'2311' = 2
'2319' = 2
'232' = 2
'233' = 2
'2341' = 2
'2342' = 2
'2343' = 2
'2349' = 2
'235' = 2
'236' = 2
'2370' = 2
'2371' = 2
'2372' = 2
'2373' = 2
'240' = 2
'2411' = 1
'2412' = 1
'2419' = 1
'242' = 4
'2431' = 2
'2432' = 2
'2439' = 2
'244' = 4
'245' = 4
'246' = 2
'247' = 2
'248' = 2
'2491' = 2
'2499' = 2
'2501' = 1
'2502' = 3
'2509' = 1
'251' = 4
'252' = 4
'253' = 4
'254' = 4
'2551' = 2
'2559' = 4
'2591' = 2
'2592' = 2
'2593' = 2
'2594' = 4
'2599' = 4
'260' = 2
'2611' = 1
'2612' = 3
'2619' = 1
'2621' = 4
'2629' = 4
'2630' = 4
'2631' = 4
'2632' = 4
'2641' = 4
'2642' = 4
'2649' = 4
'2691' = 2
'2699' = 4
'270' = 4
'271' = 4
'2721' = 3
'2722' = 3
'2723' = 1
'2724' = 1
'2729' = 1
'2731' = 4
'2732' = 4
'2741' = 2
'2742' = 4
'2743' = 4
'2749' = 4
'2751' = 2
'2752' = 2
'2753' = 4
'2754' = 4
'2755' = 4
'2756' = 4
'2757' = 4
'2759' = 4
'2761' = 4
'2762' = 4
'2763' = 4
'2764' = 2
'2769' = 4
'2771' = 4
'2772' = 4
'2773' = 4
'2779' = 4
'2791' = 2
'2792' = 4
'2799' = 4
'280' = 4
'2811' = 3
'2819' = 3
'282' = 4
'283' = 4
'284' = 4
'285' = 4
'286' = 4
'287' = 4
'2891' = 4
'2892' = 4
'2899' = 4
'290' = 4
'2911' = 1
'2912' = 1
'2919' = 1
'292' = 4
'293' = 4
'2931' = 4
'2932' = 4
'2933' = 4
'2939' = 4
'294' = 4
'2951' = 4
'2952' = 4
'2953' = 4
'2954' = 4
'2959' = 4
'2991' = 2
'2992' = 4
'2999' = 4
'3001' = 4
'3009' = 4
'301' = 4
'3021' = 4
'3022' = 4
'3029' = 4
'303' = 4
'304' = 4
'310' = 2
'311' = 2
'3121' = 4
'3129' = 4
'313' = 4
'3141' = 1
'3142' = 1
'3143' = 1
'3144' = 1
'3145' = 3
'3148' = 1
'3149' = 1
'315' = 4
'3161' = 4
'3162' = 4
'3163' = 4
'3164' = 4
'3169' = 4
'3171' = 4
'3172' = 4
'3173' = 4
'3174' = 4
'3175' = 4
'3179' = 4
'3191' = 4
'3192' = 4
'3193' = 2
'3194' = 2
'3195' = 2
'3198' = 4
'3199' = 4
'320' = 4
'3201' = 2
'3209' = 4
'321' = 4
'3221' = 4
'3222' = 4
'3223' = 4
'3224' = 4
'3225' = 4
'3226' = 4
'3228' = 2
'3229' = 4
'323' = 4
'324' = 4
'325' = 4
'326' = 4
'329' = 4
'330' = 4
'331' = 4
'3321' = 1
'3322' = 1
'3323' = 1
'3324' = 1
'3325' = 3
'3326' = 1
'3327' = 3
'3328' = 3
'3329' = 3
'3331' = 2
'3332' = 2
'3333' = 2
'3334' = 4
'3339' = 4
'3341' = 4
'3342' = 4
'3343' = 4
'3348' = 4
'3349' = 4
'335' = 4
'3350' = 4
'3351' = 4
'3352' = 4
'336' = 4
'3371' = 2
'3378' = 2
'3379' = 2
'3391' = 2
'3392' = 4
'3393' = 4
'3398' = 4
'3399' = 4
'3401' = 2
'3402' = 4
'3403' = 4
'3404' = 2
'3405' = 2
'3409' = 2
'341' = 4
'3421' = 3
'3422' = 3
'3423' = 1
'3424' = 1
'3425' = 1
'3426' = 3
'3427' = 3
'3428' = 3
'3429' = 3
'343' = 4
'344' = 4
'3451' = 4
'3459' = 4
'346' = 4
'3471' = 2
'3472' = 2
'3473' = 4
'3474' = 4
'3479' = 4
'3481' = 4
'3482' = 4
'3483' = 4
'3484' = 4
'3485' = 4
'3489' = 4
'3491' = 2
'3492' = 2
'3493' = 4
'3499' = 4
'3500' = 4
'3501' = 4
'3502' = 4
'3503' = 4
'3504' = 4
'3510' = 4
'3511' = 4
'3512' = 4
'3513' = 4
'3514' = 4
'3520' = 4
'3521' = 4
'3522' = 4
'3523' = 4
'3524' = 4
'3525' = 4
'3526' = 4
'3527' = 4
'3528' = 4
'3531' = 4
'3532' = 4
'3533' = 4
'3534' = 4
'3535' = 4
'3539' = 4
'3541' = 2
'3542' = 4
'3550' = 4
'3551' = 4
'3552' = 4
'3553' = 4
'3554' = 4
'3555' = 4
'3560' = 4
'3561' = 4
'3562' = 4
'3563' = 4
'3570' = 4
'3571' = 4
'3572' = 4
'3573' = 4
'3581' = 4
'3582' = 4
'3583' = 4
'3584' = 4
'3591' = 4
'3592' = 4
'3593' = 4
'3594' = 4
'3595' = 4
'3596' = 4
'3598' = 4
'3599' = 4
'3600' = 4
'3601' = 4
'3602' = 4
'3603' = 4
'3604' = 2
'3605' = 4
'3606' = 2
'3607' = 2
'3609' = 4
'3610' = 4
'3611' = 4
'3612' = 4
'3613' = 4
'3614' = 4
'3615' = 4
'3616' = 4
'3617' = 4
'3619' = 4
'362' = 4
'363' = 4
'3631' = 4
'3632' = 4
'3633' = 4
'3634' = 4
'3639' = 4
'3691' = 4
'3699' = 4
'370' = 2
'3710' = 4
'3711' = 4
'3712' = 4
'3720' = 1
'3721' = 1
'3722' = 1
'3723' = 1
'3724' = 3
'3725' = 1
'3726' = 1
'3727' = 1
'3728' = 1
'3729' = 1
'3731' = 4
'3732' = 4
'3733' = 4
'3734' = 4
'3735' = 4
'374' = 4
'3741' = 4
'3749' = 4
'375' = 4
'3751' = 4
'3752' = 4
'3753' = 4
'3754' = 4
'3761' = 4
'3762' = 4
'3763' = 4
'3764' = 4
'3765' = 4
'3766' = 4
'3767' = 4
'3768' = 2
'3770' = 2
'3771' = 2
'3772' = 2
'3773' = 2
'3774' = 4
'3775' = 4
'3776' = 4
'3777' = 4
'3778' = 2
'3779' = 4
'3780' = 4
'3781' = 2
'3782' = 2
'3783' = 2
'3785' = 4
'3786' = 4
'3787' = 4
'3789' = 4
'3790' = 4
'3791' = 4
'3792' = 2
'3793' = 2
'3794' = 4
'3795' = 4
'3796' = 4
'3797' = 4
'3798' = 4
'3799' = 4
'3800' = 4
'3801' = 4
'3802' = 4
'3803' = 4
'3804' = 4
'3805' = 4
'3806' = 4
'3807' = 4
'3808' = 4
'3809' = 4
'3810' = 4
'3811' = 4
'3812' = 4
'3813' = 4
'3814' = 4
'3815' = 4
'3816' = 4
'3818' = 4
'3821' = 3
'3822' = 1
'3829' = 3
'3830' = 4
'3831' = 4
'3832' = 4
'3833' = 4
'3834' = 4
'3835' = 4
'3836' = 4
'3837' = 4
'3838' = 4
'3839' = 4
'3840' = 4
'3841' = 4
'3842' = 4
'3843' = 4
'3844' = 4
'3845' = 4
'3846' = 4
'3847' = 4
'3848' = 4
'3849' = 4
'3850' = 4
'3851' = 4
'3852' = 4
'3853' = 4
'3855' = 4
'3857' = 4
'3859' = 4
'3860' = 4
'3861' = 4
'3862' = 4
'3863' = 4
'3864' = 4
'3865' = 4
'3866' = 4
'3867' = 4
'3868' = 4
'3869' = 4
'387' = 4
'3880' = 4
'3881' = 4
'3882' = 4
'3883' = 4
'3884' = 4
'3885' = 4
'3886' = 4
'3887' = 4
'3888' = 4
'3889' = 4
'3891' = 2
'3892' = 2
'3893' = 2
'3894' = 2
'3895' = 2
'3898' = 2
'3899' = 2
'390' = 4
'391' = 4
'3921' = 4
'3922' = 4
'3923' = 4
'3924' = 4
'3925' = 4
'3926' = 4
'3927' = 4
'3928' = 4
'3929' = 4
'3930' = 4
'3931' = 4
'3932' = 4
'3941' = 4
'3942' = 4
'3943' = 4
'3949' = 4
'3950' = 4
'3951' = 4
'3952' = 4
'3953' = 4
'3954' = 4
'3955' = 4
'3956' = 4
'3957' = 4
'3958' = 4
'3959' = 4
'3961' = 2
'3962' = 2
'3963' = 2
'3964' = 2
'3965' = 2
'3966' = 2
'397' = 4
'3971' = 4
'3972' = 4
'3973' = 4
'3974' = 4
'3979' = 4
'398' = 4
'3990' = 2
'3991' = 4
'3992' = 4
'3993' = 4
'3994' = 4
'3995' = 2
'3996' = 2
'3997' = 2
'3998' = 4
'3999' = 4
'400' = 4
'4011' = 3
'4019' = 3
'4021' = 4
'4022' = 4
'4023' = 4
'4024' = 4
'4029' = 4
'403' = 4
'4040' = 4
'4041' = 4
'4042' = 4
'4050' = 4
'4051' = 4
'4052' = 4
'4053' = 4
'4054' = 4
'4059' = 4
'4061' = 4
'4062' = 4
'4063' = 4
'4064' = 4
'4069' = 4
'409' = 4
'410' = 2  /* CHANGED FROM 4 TO 2 */
'4100' = 2 /* CHANGED FROM 4 TO 2 */
'4101' = 2 /* CHANGED FROM 4 TO 2 */
'4102' = 2 /* CHANGED FROM 4 TO 2 */
'4103' = 2 /* CHANGED FROM 4 TO 2 */
'4104' = 2 /* CHANGED FROM 4 TO 2 */
'4105' = 2 /* CHANGED FROM 4 TO 2 */
'4106' = 2 /* CHANGED FROM 4 TO 2 */
'4107' = 2 /* CHANGED FROM 4 TO 2 */
'4108' = 2 /* CHANGED FROM 4 TO 2 */
'4109' = 2 /* CHANGED FROM 4 TO 2 */
'411' = 2
'412' = 4
'4131' = 1
'4132' = 1
'4133' = 3
'4138' = 1
'4139' = 1
'4141' = 4
'4142' = 4
'4143' = 4
'415' = 4
'4191' = 2
'4192' = 2
'4193' = 4
'4194' = 4
'4195' = 4
'4198' = 2
'4199' = 4
'4201' = 4
'4209' = 4
'4210' = 4
'4211' = 4
'4212' = 4
'4219' = 4
'4221' = 3
'4222' = 1
'4223' = 1
'4224' = 1
'4225' = 3
'4229' = 1
'4231' = 4
'4232' = 4
'4233' = 2
'4239' = 4
'4240' = 4
'4241' = 4
'4242' = 4
'4251' = 4
'4252' = 4
'4253' = 4
'4254' = 4
'4255' = 4
'4256' = 4
'4258' = 4
'4259' = 4
'4261' = 4
'4262' = 4
'4263' = 4
'4264' = 4
'4265' = 4
'4266' = 4
'4268' = 4
'4269' = 4
'427' = 4
'4281' = 2
'4282' = 4
'4283' = 4
'4284' = 4
'4285' = 4
'4286' = 4
'4287' = 4
'4289' = 4
'4291' = 4
'4292' = 2
'4299' = 2
'430' = 4
'431' = 4
'4311' = 2
'4319' = 2
'432' = 4
'433' = 4
'4341' = 2
'4342' = 4
'4349' = 4
'435' = 4
'436' = 4
'437' = 4
'4381' = 4
'4389' = 4
'4391' = 4
'4399' = 4
'4400' = 4
'4401' = 4
'4402' = 4
'4403' = 4
'4411' = 3
'4412' = 1
'4413' = 1
'4414' = 1
'4415' = 3
'4419' = 1
'442' = 4
'4421' = 4
'4422' = 2
'4429' = 4
'4431' = 4
'4432' = 4
'4438' = 4
'4439' = 4
'4440' = 4
'4441' = 4
'4442' = 4
'4443' = 2
'4444' = 2
'4449' = 2
'445' = 4
'4461' = 4
'4462' = 2
'4463' = 4
'4464' = 4
'4465' = 4
'4466' = 4
'4467' = 4
'4468' = 4
'4469' = 4
'4491' = 4
'4492' = 4
'4493' = 2
'4494' = 2
'4495' = 4
'4496' = 4
'4497' = 4
'4498' = 4
'4499' = 4
'4500' = 4
'4501' = 4
'4502' = 4
'4503' = 4
'4511' = 3
'4512' = 1
'4513' = 1
'4514' = 1
'4515' = 3
'4516' = 1
'4519' = 1
'4521' = 3
'4522' = 1
'4523' = 1
'4524' = 1
'4525' = 1
'4526' = 3
'4527' = 1
'4528' = 1
'4529' = 1
'4530' = 2
'4531' = 4
'4532' = 4
'4533' = 4
'4534' = 4
'4541' = 4
'4542' = 2
'4543' = 2
'4549' = 4
'4550' = 4
'4551' = 4
'4552' = 4
'4561' = 4
'4562' = 4
'4563' = 4
'4571' = 4
'4572' = 4
'4573' = 4
'4574' = 4
'4575' = 4
'4576' = 4
'4579' = 4
'458' = 4
'4590' = 4
'4591' = 4
'4592' = 4
'4593' = 4
'4594' = 4
'4595' = 4
'4601' = 4
'4602' = 4
'4603' = 4
'4604' = 4
'4610' = 4
'4611' = 4
'4612' = 4
'4613' = 4
'4614' = 2
'4620' = 4
'4621' = 4
'4622' = 4
'4623' = 4
'4624' = 2
'4631' = 2
'4632' = 2
'4639' = 2
'4640' = 4
'4641' = 4
'4642' = 4
'4643' = 4
'4650' = 4
'4651' = 4
'4652' = 4
'4660' = 4
'4661' = 4
'4662' = 4
'4663' = 4
'4664' = 4
'4671' = 4
'4672' = 4
'4673' = 4
'4674' = 4
'4675' = 4
'4676' = 4
'4679' = 4
'4680' = 4
'4681' = 4
'4682' = 4
'4685' = 2
'4691' = 4
'4692' = 4
'4693' = 4
'4694' = 4
'4695' = 2
'4696' = 2
'4697' = 4
'4699' = 4
'470' = 4
'4701' = 4
'4709' = 4
'471' = 4
'4711' = 4
'4719' = 4
'472' = 4
'4791' = 4
'4792' = 4
'4799' = 4
'480' = 4
'481' = 4
'4821' = 3
'4822' = 1
'4823' = 1
'4824' = 1
'4825' = 3
'4826' = 1
'4829' = 1
'4831' = 2
'4832' = 2
'4833' = 2
'4834' = 2
'4835' = 4
'4836' = 2
'4841' = 4
'4849' = 4
'485' = 4
'4861' = 4
'4862' = 4
'4863' = 4
'4864' = 4
'4865' = 4
'4866' = 4
'4869' = 4
'4871' = 4
'4872' = 4
'4873' = 4
'4874' = 4
'4875' = 4
'4876' = 4
'4879' = 4
'4881' = 4
'4882' = 4
'4891' = 4
'4892' = 4
'4893' = 4
'4899' = 4
'4901' = 4
'4902' = 4
'4903' = 2
'4904' = 4
'4911' = 4
'4912' = 4
'4921' = 1
'4922' = 1
'4923' = 1
'4929' = 1
'493' = 4
'4931' = 2
'4939' = 4
'4941' = 2
'4942' = 2
'4943' = 2
'4944' = 4
'4945' = 4
'4946' = 4
'4947' = 2
'4949' = 4
'4951' = 4
'4952' = 4
'4959' = 4
'496' = 4
'4971' = 4
'4972' = 4
'4973' = 4
'4974' = 4
'4975' = 4
'4976' = 4
'4979' = 4
'4991' = 4
'4992' = 4
'4993' = 4
'4994' = 4
'4995' = 4
'4999' = 4
'500' = 4
'5011' = 1
'5012' = 3
'5019' = 3
'5021' = 4
'5022' = 4
'5023' = 4
'5024' = 4
'5025' = 4
'5026' = 4
'5029' = 4
'503' = 4
'504' = 4
'5051' = 4
'5059' = 4
'5061' = 4
'5069' = 4
'5091' = 2
'5092' = 2
'5093' = 2
'5094' = 2
'5099' = 2
'5101' = 2
'5102' = 4
'5103' = 4
'5104' = 4
'5110' = 1
'5111' = 1
'5112' = 1
'5113' = 3
'5114' = 1
'5115' = 1
'5119' = 3
'5121' = 4
'5122' = 4
'5123' = 4
'5124' = 4
'5131' = 4
'5132' = 4
'5133' = 4
'5134' = 4
'5135' = 4
'5136' = 4
'5137' = 4
'5139' = 4
'5141' = 4
'5142' = 4
'5143' = 4
'5149' = 4
'5151' = 4
'5159' = 4
'5161' = 4
'5162' = 4
'5163' = 4
'5164' = 2
'5169' = 4
'5171' = 4
'5172' = 4
'5179' = 4
'5181' = 4
'5182' = 4
'5183' = 4
'5184' = 2
'5185' = 2
'5186' = 2
'5187' = 2
'5188' = 2
'5189' = 4
'5191' = 4
'5192' = 4
'5193' = 4
'5194' = 4
'5195' = 4
'5196' = 2
'5197' = 2
'5198' = 2
'5199' = 4
'5201' = 4
'5209' = 4
'5211' = 1
'5212' = 3
'5213' = 1
'5214' = 1
'5219' = 3
'522' = 4
'5221' = 2
'5222' = 4
'523' = 4
'524' = 4
'5251' = 4
'5252' = 4
'5253' = 4
'5259' = 4
'526' = 4
'527' = 4
'5280' = 4
'5281' = 4
'5282' = 4
'5283' = 4
'5284' = 2
'5285' = 2
'5286' = 2
'5291' = 4
'5292' = 4
'5293' = 2
'5294' = 2
'5295' = 4
'5296' = 4
'5297' = 2
'5298' = 2
'5299' = 4
'5300' = 4
'5301' = 4
'5302' = 4
'5303' = 4
'5304' = 4
'5305' = 4
'5310' = 4
'5311' = 4
'5312' = 4
'5313' = 4
'5314' = 4
'5315' = 4
'5316' = 4
'5317' = 4
'5321' = 4
'5329' = 4
'5331' = 4
'5339' = 4
'5341' = 4
'5349' = 4
'5351' = 4
'5359' = 4
'5361' = 4
'5369' = 4
'537' = 4
'5380' = 4
'5381' = 4
'5382' = 4
'539' = 4
'540' = 4
'5411' = 4
'5412' = 4
'5419' = 4
'5421' = 3
'5422' = 3
'5423' = 3
'5424' = 1
'5425' = 1
'5429' = 3
'543' = 4
'544' = 4
'545' = 4
'5451' = 4
'5459' = 4
'5461' = 4
'5462' = 4
'5463' = 4
'5464' = 4
'5471' = 4
'5472' = 4
'5473' = 4
'5474' = 4
'5475' = 4
'5491' = 2
'5492' = 4
'5493' = 4
'5494' = 4
'5495' = 4
'5496' = 2
'5497' = 2
'5498' = 2
'5499' = 2
'5501' = 4
'5502' = 4
'5503' = 4
'5504' = 4
'5511' = 4
'5512' = 4
'5521' = 1
'5522' = 1
'5523' = 1
'5524' = 3
'5529' = 3
'5531' = 4
'5532' = 4
'5533' = 4
'5534' = 4
'5535' = 4
'5539' = 4
'554' = 4
'5551' = 4
'5552' = 4
'5553' = 4
'5554' = 4
'5561' = 4
'5569' = 4
'557' = 4
'5581' = 4
'5582' = 4
'5583' = 4
'5584' = 4
'5585' = 4
'5586' = 4
'5587' = 4
'5589' = 4
'5591' = 4
'5592' = 2
'5593' = 2
'5594' = 2
'5595' = 2
'5596' = 2
'5597' = 4
'5598' = 4
'5599' = 4
'560' = 4
'561' = 4
'562' = 4
'5631' = 1
'5632' = 1
'5633' = 1
'5634' = 3
'5635' = 1
'5639' = 3
'5640' = 4
'5641' = 4
'5642' = 4
'5651' = 4
'5652' = 4
'5661' = 4
'5662' = 4
'5671' = 4
'5672' = 4
'5673' = 4
'5674' = 4
'5675' = 4
'5679' = 4
'5681' = 4
'5682' = 4
'5683' = 4
'5684' = 4
'5685' = 4
'5686' = 4
'5689' = 4
'5691' = 2
'5692' = 4
'5693' = 4
'5694' = 4
'5695' = 4
'5699' = 4
'570' = 2
'5711' = 2
'5712' = 4
'5717' = 2
'5718' = 4
'5719' = 4
'5721' = 4
'5722' = 4
'5731' = 1
'5732' = 1
'5733' = 3
'5734' = 3
'5739' = 3
'5741' = 4
'5749' = 4
'5751' = 4
'5759' = 4
'576' = 4
'5771' = 4
'5779' = 4
'5781' = 4
'5782' = 4
'5783' = 4
'5784' = 4
'5785' = 4
'5786' = 4
'5787' = 4
'5788' = 4
'5789' = 4
'5791' = 4
'5792' = 2
'5793' = 4
'5794' = 2
'5795' = 2
'5796' = 4
'5797' = 4
'5798' = 4
'5799' = 4
'580' = 4
'581' = 4
'5821' = 1
'5822' = 1
'5823' = 1
'5824' = 1
'5829' = 1
'583' = 2
'5831' = 2
'5839' = 2
'5841' = 4
'5842' = 4
'5843' = 4
'5844' = 4
'5845' = 4
'5846' = 4
'5847' = 4
'5849' = 4
'585' = 4
'586' = 2
'5891' = 4
'5892' = 4
'5893' = 4
'5899' = 4
'5900' = 4
'5901' = 4
'5902' = 4
'5903' = 4
'5909' = 4
'5911' = 4
'5912' = 4
'5919' = 4
'5921' = 3
'5929' = 3
'593' = 4
'594' = 4
'595' = 4
'596' = 4
'5971' = 4
'5972' = 2
'5979' = 4
'598' = 2
'5991' = 4
'5992' = 4
'5993' = 2
'5994' = 2
'5995' = 2
'5996' = 2
'5999' = 2
'600' = 4
'6011' = 1
'6012' = 3
'6013' = 1
'6014' = 3
'6015' = 3
'6018' = 3
'6019' = 3
'602' = 4
'6021' = 4
'6029' = 4
'603' = 4
'604' = 4
'605' = 4
'6061' = 4
'6062' = 4
'6069' = 4
'6071' = 2
'6072' = 4
'6073' = 4
'6079' = 4
'6081' = 4
'6082' = 4
'6091' = 2
'6092' = 2
'6093' = 4
'6094' = 4
'6095' = 4
'6096' = 4
'6097' = 4
'6099' = 4
'610' = 2
'6111' = 1
'6119' = 1
'612' = 4
'613' = 2
'6141' = 2
'6142' = 4
'6149' = 4
'6191' = 2
'6192' = 4
'6199' = 4
'620' = 4
'6211' = 1
'6212' = 3
'6219' = 3
'622' = 4
'623' = 4
'6241' = 4
'6242' = 4
'625' = 4
'6261' = 4
'6269' = 4
'627' = 4
'6291' = 2
'6292' = 2
'6299' = 4
'6301' = 1
'6309' = 3
'631' = 4
'632' = 4
'633' = 4
'634' = 4
'6351' = 4
'6352' = 2
'6353' = 4
'6359' = 4
'636' = 2
'6370' = 2
'6371' = 2
'6372' = 2
'6373' = 2
'6381' = 4
'6382' = 4
'6383' = 4
'6384' = 2
'6385' = 4
'6389' = 4
'6391' = 2
'6392' = 4
'6393' = 4
'6394' = 4
'6395' = 4
'6399' = 4
'640' = 4
'6411' = 3
'6419' = 1
'642' = 4
'643' = 4
'6441' = 4
'6442' = 4
'6443' = 4
'6444' = 4
'6445' = 4
'6449' = 4
'645' = 4
'6491' = 2
'6492' = 4
'6493' = 4
'6494' = 2
'6495' = 4
'6496' = 4
'6497' = 4
'6498' = 4
'6499' = 4
'650' = 4
'6501' = 4
'6509' = 4
'6511' = 3
'6512' = 3
'6513' = 3
'6514' = 3
'6519' = 3
'6521' = 4
'6522' = 4
'6523' = 4
'6524' = 4
'6525' = 4
'6529' = 4
'653' = 4
'6531' = 4
'6539' = 4
'654' = 4
'6541' = 4
'6549' = 4
'6551' = 4
'6552' = 4
'6553' = 4
'6554' = 4
'6561' = 4
'6562' = 4
'6563' = 4
'6564' = 4
'6571' = 4
'6572' = 4
'6573' = 4
'6574' = 4
'6575' = 4
'6576' = 4
'6579' = 4
'658' = 4
'6581' = 4
'6589' = 4
'6591' = 4
'6592' = 4
'6593' = 4
'6594' = 4
'6595' = 4
'6599' = 4
'660' = 4
'6601' = 4
'6602' = 4
'6611' = 3
'6619' = 3
'6621' = 4
'6622' = 4
'6629' = 4
'6631' = 4
'6632' = 4
'6639' = 4
'664' = 4
'6651' = 4
'6652' = 4
'6661' = 4
'6662' = 4
'6663' = 4
'6669' = 4
'6671' = 4
'6672' = 4
'6673' = 4
'6674' = 4
'6679' = 4
'668' = 2
'6691' = 2
'6692' = 4
'6693' = 4
'6694' = 4
'6695' = 4
'6696' = 4
'6697' = 4
'6699' = 4
'670' = 2
'6711' = 3
'6712' = 3
'6719' = 3
'672' = 4
'6731' = 4
'6732' = 4
'6733' = 4
'6739' = 4
'674' = 4
'675' = 4
'6751' = 4
'6759' = 4
'6761' = 4
'6762' = 4
'6769' = 4
'680' = 4
'6811' = 1
'6812' = 1
'6813' = 3
'6814' = 3
'6815' = 3
'6816' = 3
'6819' = 3
'6821' = 4
'6822' = 4
'6823' = 4
'6829' = 4
'683' = 4
'6831' = 4
'6839' = 4
'684' = 4
'6841' = 4
'6849' = 4
'685' = 4
'6851' = 4
'6859' = 4
'686' = 4
'6861' = 4
'6869' = 4
'687' = 4
'6871' = 4
'6879' = 4
'688' = 4
'689' = 4
'6901' = 4
'6902' = 4
'6909' = 3
'6911' = 4
'6919' = 4
'6921' = 4
'6922' = 4
'6923' = 4
'6929' = 4
'693' = 4
'6941' = 4
'6942' = 4
'6949' = 4
'6951' = 4
'6952' = 4
'6959' = 2
'696' = 2
'697' = 2
'6991' = 2
'6992' = 2
'6993' = 2
'6994' = 2
'6995' = 4
'6996' = 2
'6997' = 4
'6998' = 4
'6999' = 4
'700' = 2
'7011' = 2
'7012' = 4
'7013' = 4
'7014' = 4
'7021' = 1
'7022' = 1
'7023' = 3
'7024' = 3
'7029' = 3
'7031' = 4
'7032' = 4
'7033' = 4
'704' = 4
'7050' = 4
'7051' = 4
'7052' = 4
'7061' = 4
'7062' = 4
'7071' = 4
'7072' = 4
'7073' = 4
'7074' = 4
'7075' = 4
'7076' = 4
'7077' = 4
'7079' = 4
'708' = 4
'7091' = 4
'7092' = 4
'7101' = 4
'7109' = 4
'7111' = 3
'7119' = 3
'7121' = 2
'7122' = 4
'7123' = 4
'7124' = 4
'7129' = 4
'713' = 4
'714' = 4
'715' = 4
'7161' = 4
'7162' = 4
'7171' = 4
'7172' = 4
'7179' = 4
'718' = 4
'719' = 4
'720' = 2
'721' = 2
'7221' = 2
'7229' = 2
'7231' = 2
'7239' = 2
'724' = 2
'7251' = 2
'7252' = 2
'7253' = 2
'7254' = 2
'726' = 2
'7271' = 2
'7279' = 2
'728' = 2
'729' = 2
'7301' = 2
'7309' = 2
'731' = 2
'7321' = 2
'7322' = 2
'733' = 2
'734' = 2
'7351' = 2
'7359' = 2
'736' = 2
'738' = 2
'7391' = 2
'7392' = 2
'7393' = 2
'7394' = 4
'7399' = 4
'740' = 4
'741' = 4
'742' = 4
'743' = 4
'744' = 4
'7491' = 4
'7499' = 4
'750' = 2
'751' = 1
'752' = 2
'7531' = 1
'7532' = 1
'7533' = 1
'7534' = 1
'7535' = 1
'7536' = 4
'7537' = 2
'7538' = 1
'754' = 2
'7550' = 4
'7551' = 4
'7552' = 4
'7561' = 4
'7562' = 2
'7569' = 2
'757' = 2
'758' = 2
'7591' = 2
'7592' = 2
'7593' = 4
'7594' = 2
'7599' = 4
'7601' = 4
'7609' = 4
'7611' = 3
'7619' = 3
'762' = 4
'7631' = 4
'7639' = 4
'7641' = 4
'7642' = 4
'7643' = 4
'7644' = 4
'7645' = 4
'7646' = 4
'765' = 4
'7661' = 4
'7662' = 4
'7663' = 4
'7664' = 4
'7665' = 4
'7666' = 4
'7667' = 4
'7668' = 4
'7669' = 4
'7670' = 4
'7671' = 2
'7672' = 4
'7673' = 2
'7674' = 4
'7675' = 2
'7676' = 4
'7677' = 4
'7678' = 2
'7679' = 4
'7691' = 4
'7692' = 4
'7693' = 2
'7694' = 4
'7695' = 2
'7696' = 2
'7697' = 4
'7699' = 4
'7700' = 4
'7701' = 4
'7702' = 4
'7703' = 4
'7704' = 4
'7705' = 4
'7706' = 4
'7707' = 4
'7708' = 4
'7709' = 4
'7710' = 4
'7711' = 4
'7712' = 4
'7713' = 4
'7714' = 4
'7715' = 4
'7716' = 4
'7717' = 4
'7718' = 4
'7719' = 4
'7720' = 4
'7721' = 4
'7722' = 4
'7723' = 4
'7724' = 4
'7725' = 4
'7726' = 4
'7727' = 4
'7728' = 4
'7729' = 4
'7730' = 4
'7731' = 4
'7732' = 4
'7733' = 4
'7734' = 4
'7735' = 4
'7736' = 4
'7737' = 4
'7738' = 4
'7739' = 4
'7740' = 3
'7741' = 3
'7742' = 3
'7743' = 3
'7744' = 3
'7745' = 3
'7746' = 3
'7747' = 3
'7748' = 3
'7749' = 3
'7751' = 4
'7752' = 4
'7753' = 4
'7754' = 4
'7756' = 4
'7757' = 4
'7758' = 4
'7759' = 4
'7760' = 4
'7761' = 4
'7762' = 4
'7763' = 4
'7764' = 4
'7765' = 4
'7766' = 4
'7767' = 4
'7768' = 4
'7769' = 4
'7770' = 4
'7771' = 4
'7772' = 4
'7773' = 4
'7774' = 4
'7775' = 4
'7776' = 4
'7777' = 4
'7778' = 4
'7779' = 4
'7780' = 4
'7781' = 4
'7782' = 4
'7783' = 4
'7784' = 4
'7785' = 4
'7786' = 4
'7787' = 4
'7788' = 4
'7789' = 4
'7790' = 4
'7791' = 4
'7792' = 4
'7793' = 4
'7794' = 4
'7795' = 4
'7796' = 4
'7797' = 4
'7798' = 4
'7799' = 4
'7800' = 4
'7801' = 4
'7802' = 4
'7803' = 4
'7804' = 4
'7805' = 4
'7806' = 4
'7807' = 4
'7808' = 4
'7809' = 4
'7810' = 4
'7811' = 4
'7812' = 4
'7813' = 4
'7814' = 4
'7815' = 4
'7816' = 4
'7817' = 4
'7818' = 4
'7819' = 4
'7820' = 4
'7822' = 4
'7823' = 4
'7824' = 4
'7825' = 4
'7827' = 4
'7828' = 4
'7829' = 4
'7830' = 4
'7831' = 4
'7832' = 4
'7833' = 4
'7834' = 4
'7835' = 4
'7837' = 4
'7838' = 4
'7839' = 4
'7840' = 4
'7841' = 4
'7842' = 4
'7843' = 4
'7844' = 4
'7845' = 4
'7846' = 4
'7847' = 4
'7848' = 4
'7849' = 4
'7850' = 4
'7851' = 4
'7852' = 4
'7853' = 4
'7854' = 4
'7855' = 4
'7856' = 4
'7857' = 4
'7858' = 4
'7859' = 4
'7860' = 4
'7861' = 4
'7862' = 4
'7863' = 4
'7864' = 4
'7865' = 4
'7866' = 4
'7867' = 4
'7868' = 4
'7869' = 4
'7870' = 4
'7871' = 4
'7872' = 4
'7873' = 4
'7874' = 4
'7875' = 4
'7876' = 4
'7877' = 4
'7878' = 4
'7879' = 4
'7880' = 3
'7881' = 3
'7882' = 3
'7883' = 3
'7884' = 3
'7885' = 3
'7886' = 3
'7887' = 3
'7888' = 3
'7889' = 3
'7890' = 4
'7891' = 4
'7892' = 4
'7893' = 4
'7894' = 4
'7895' = 4
'7896' = 4
'7897' = 4
'7898' = 4
'7899' = 4
'7900' = 2
'7901' = 2
'7902' = 2
'7903' = 2
'7904' = 2
'7905' = 2
'7906' = 2
'7907' = 2
'7908' = 2
'7909' = 2
'7910' = 4
'7911' = 4
'7912' = 4
'7913' = 4
'7914' = 4
'7915' = 4
'7916' = 4
'7917' = 4
'7918' = 4
'7919' = 4
'7920' = 4
'7921' = 4
'7922' = 4
'7923' = 4
'7924' = 4
'7925' = 4
'7926' = 4
'7927' = 4
'7928' = 4
'7929' = 4
'7930' = 4
'7931' = 4
'7932' = 4
'7933' = 4
'7934' = 4
'7935' = 4
'7936' = 4
'7937' = 4
'7938' = 4
'7939' = 4
'7940' = 4
'7941' = 4
'7942' = 4
'7945' = 4
'7946' = 4
'7949' = 4
'7950' = 4
'7951' = 4
'7952' = 4
'7955' = 4
'7956' = 4
'7959' = 4
'7960' = 4
'7961' = 4
'7962' = 4
'7963' = 4
'7964' = 4
'7965' = 4
'7966' = 4
'7967' = 4
'7968' = 4
'7969' = 4
'7970' = 2
'7971' = 2
'7972' = 2
'7973' = 2
'7974' = 2
'7975' = 2
'7976' = 2
'7977' = 2
'7978' = 2
'7979' = 2
'7980' = 4
'7981' = 4
'7982' = 4
'7983' = 4
'7984' = 4
'7985' = 4
'7986' = 4
'7987' = 4
'7988' = 4
'7989' = 4
'7990' = 4
'7991' = 4
'7992' = 4
'7993' = 4
'7994' = 4
'7995' = 4
'7996' = 4
'7997' = 4
'7998' = 4
'7999' = 4
'8000' = 4
'8001' = 4
'8002' = 4
'8003' = 4
'8004' = 4
'8005' = 4
'8006' = 4
'8007' = 4
'8008' = 4
'8009' = 4
'8010' = 4
'8011' = 4
'8012' = 4
'8013' = 4
'8014' = 4
'8015' = 4
'8016' = 4
'8017' = 4
'8018' = 4
'8019' = 4
'8020' = 3
'8021' = 3
'8022' = 3
'8023' = 3
'8024' = 3
'8025' = 3
'8026' = 3
'8027' = 3
'8028' = 3
'8029' = 3
'8030' = 1
'8031' = 1
'8032' = 1
'8033' = 1
'8034' = 1
'8035' = 1
'8036' = 1
'8037' = 1
'8038' = 1
'8039' = 1
'8040' = 4
'8041' = 4
'8042' = 4
'8043' = 4
'8044' = 4
'8045' = 4
'8046' = 4
'8047' = 4
'8048' = 4
'8049' = 4
'805' = 4
'8050' = 4
'8051' = 4
'8052' = 2
'8059' = 4
'806' = 4
'8070' = 4
'8071' = 4
'8072' = 4
'8073' = 4
'8074' = 4
'8075' = 4
'8076' = 4
'8077' = 4
'8078' = 4
'8079' = 4
'8080' = 4
'8081' = 4
'8082' = 4
'8083' = 4
'8084' = 4
'8085' = 4
'8086' = 4
'8087' = 4
'8088' = 4
'8089' = 4
'8090' = 4
'8091' = 4
'8092' = 4
'8093' = 4
'8094' = 4
'8095' = 4
'8096' = 4
'8097' = 4
'8098' = 4
'8099' = 4
'8100' = 4
'8101' = 4
'8102' = 4
'8103' = 4
'8104' = 4
'8105' = 4
'8106' = 4
'8107' = 4
'8108' = 4
'8109' = 4
'8111' = 4
'8112' = 4
'8113' = 4
'8114' = 4
'8115' = 4
'8116' = 4
'8117' = 4
'8118' = 4
'8120' = 4
'8121' = 4
'8122' = 4
'8123' = 4
'8124' = 4
'8125' = 4
'8126' = 4
'8127' = 4
'8128' = 4
'8129' = 4
'8130' = 4
'8131' = 4
'8132' = 4
'8133' = 4
'8134' = 4
'8135' = 4
'8136' = 4
'8137' = 4
'8138' = 4
'8139' = 4
'8140' = 4
'8141' = 4
'8142' = 4
'8143' = 4
'8144' = 4
'8145' = 4
'8146' = 4
'8147' = 4
'8148' = 4
'8149' = 4
'8151' = 4
'8152' = 4
'8153' = 4
'8154' = 4
'8155' = 4
'8156' = 4
'8157' = 4
'8159' = 4
'8161' = 4
'8162' = 4
'8163' = 4
'8164' = 4
'8165' = 4
'8166' = 4
'8169' = 4
'8171' = 4
'8172' = 4
'8173' = 4
'8174' = 4
'8175' = 4
'8179' = 4
'8180' = 4
'8181' = 4
'8182' = 4
'8183' = 4
'8184' = 4
'8185' = 4
'8186' = 4
'8187' = 4
'8191' = 2
'8192' = 2
'8193' = 4
'8194' = 4
'8195' = 4
'8196' = 4
'8197' = 4
'8198' = 3
'8199' = 4
'8201' = 4
'8202' = 4
'8203' = 4
'8204' = 2
'8209' = 4
'8211' = 4
'8212' = 4
'8219' = 4
'8221' = 4
'8222' = 4
'8229' = 4
'8231' = 4
'8232' = 4
'8233' = 4
'8234' = 4
'8235' = 4
'8236' = 4
'8239' = 4
'8241' = 4
'8242' = 4
'8243' = 4
'8244' = 4
'8245' = 4
'8246' = 4
'8251' = 4
'8252' = 4
'8253' = 4
'8254' = 4
'8255' = 4
'8256' = 4
'8257' = 4
'8258' = 4
'8259' = 4
'8261' = 4
'8269' = 4
'8271' = 4
'8272' = 4
'8279' = 4
'8281' = 4
'8282' = 4
'8283' = 4
'8284' = 4
'8285' = 4
'8286' = 4
'8289' = 4
'8291' = 4
'8292' = 2
'8293' = 2
'8294' = 2
'8295' = 2
'8296' = 2
'8299' = 4
'8301' = 4
'8302' = 4
'8303' = 4
'8309' = 4
'8311' = 4
'8312' = 4
'8313' = 4
'8314' = 4
'8319' = 4
'8321' = 3
'8329' = 3
'8331' = 4
'8332' = 4
'8339' = 4
'8341' = 4
'8342' = 4
'8343' = 4
'8344' = 4
'8345' = 4
'8349' = 4
'835' = 4
'8361' = 4
'8362' = 4
'8363' = 4
'8364' = 4
'8365' = 4
'8371' = 4
'8372' = 4
'8373' = 4
'8374' = 4
'8375' = 4
'8376' = 4
'8377' = 4
'8379' = 4
'8381' = 4
'8382' = 4
'8383' = 4
'8384' = 4
'8385' = 4
'8386' = 4
'8387' = 4
'8388' = 4
'8389' = 4
'8391' = 4
'8392' = 4
'8393' = 4
'8394' = 2
'8395' = 2
'8396' = 2
'8397' = 2
'8398' = 2
'8399' = 4
'8400' = 4
'8401' = 4
'8402' = 4
'8403' = 4
'8404' = 4
'8405' = 4
'8406' = 4
'8407' = 4
'8408' = 4
'8409' = 4
'8410' = 4
'8411' = 4
'8412' = 4
'8413' = 4
'8414' = 4
'8415' = 4
'8416' = 4
'8417' = 4
'8418' = 4
'8419' = 4
'8421' = 4
'8422' = 4
'8423' = 4
'8424' = 4
'8425' = 4
'8426' = 4
'8427' = 4
'8428' = 4
'8429' = 4
'843' = 4
'8440' = 4
'8441' = 2
'8442' = 2
'8443' = 2
'8444' = 4
'8445' = 2
'8446' = 2
'8447' = 2
'8448' = 4
'8451' = 2
'8452' = 2
'8453' = 2
'8454' = 2
'8455' = 2
'8456' = 2
'8457' = 2
'8458' = 4
'8459' = 4
'8460' = 4
'8461' = 4
'8462' = 4
'8463' = 4
'8464' = 4
'8465' = 4
'8466' = 4
'8467' = 4
'8468' = 4
'8469' = 4
'8471' = 2
'8472' = 4
'8473' = 4
'8491' = 4
'8492' = 4
'8493' = 4
'8499' = 4
'850' = 2
'8511' = 1
'8512' = 3
'8519' = 1
'8520' = 4
'8521' = 4
'8522' = 4
'8523' = 4
'8524' = 4
'8525' = 4
'8531' = 4
'8532' = 4
'8533' = 4
'8534' = 4
'8535' = 4
'8536' = 4
'8541' = 4
'8542' = 4
'8543' = 4
'8544' = 4
'8545' = 4
'8546' = 4
'8547' = 4
'8548' = 4
'8550' = 4
'8551' = 2
'8552' = 2
'8553' = 4
'8554' = 4
'856' = 4
'857' = 4
'8581' = 2
'8582' = 4
'8583' = 4
'8584' = 4
'8585' = 4
'8586' = 4
'8587' = 4
'8589' = 4
'8591' = 2
'8592' = 2
'8593' = 4
'8594' = 4
'8595' = 4
'8596' = 4
'8599' = 4
'8601' = 2
'8602' = 2
'8603' = 2
'8604' = 2
'8605' = 2
'8606' = 4
'8607' = 2
'8609' = 2
'8611' = 1
'8619' = 1
'8621' = 4
'8622' = 4
'8623' = 2
'8624' = 2
'8625' = 4
'8626' = 2
'8627' = 2
'8628' = 2
'863' = 2
'864' = 4
'8651' = 2
'8659' = 2
'8660' = 4
'8661' = 4
'8662' = 4
'8663' = 4
'8664' = 2
'8665' = 4
'8666' = 4
'8667' = 4
'8669' = 4
'8670' = 4
'8671' = 4
'8672' = 4
'8673' = 4
'8674' = 4
'8675' = 4
'8681' = 4
'8682' = 4
'8683' = 4
'8684' = 4
'8685' = 4
'8686' = 4
'8689' = 4
'8691' = 4
'8692' = 2
'8693' = 4
'8694' = 4
'8695' = 4
'8696' = 4
'8697' = 4
'8698' = 4
'8699' = 2
'8701' = 1
'8702' = 1
'8703' = 1
'8704' = 1
'8705' = 1
'8706' = 1
'8707' = 1
'8708' = 1
'8709' = 1
'8711' = 1
'8712' = 1
'8713' = 1
'8714' = 1
'8715' = 1
'8716' = 1
'8717' = 1
'8721' = 1
'8722' = 1
'8723' = 1
'8724' = 1
'8729' = 1
'8731' = 1
'8732' = 1
'8733' = 1
'8734' = 1
'8735' = 1
'8736' = 1
'8737' = 1
'8738' = 1
'8739' = 1
'8741' = 1
'8742' = 1
'8743' = 1
'8744' = 1
'8749' = 1
'8751' = 1
'8752' = 1
'8753' = 3
'8754' = 1
'8759' = 1
'8761' = 1
'8762' = 1
'8763' = 1
'8764' = 1
'8765' = 1
'8766' = 1
'8769' = 1
'8771' = 1
'8772' = 1
'8773' = 1
'8774' = 1
'8775' = 1
'8776' = 1
'8777' = 1
'8778' = 1
'8779' = 1
'8781' = 1
'8782' = 1
'8783' = 1
'8784' = 1
'8785' = 1
'8789' = 1
'8791' = 1
'8792' = 1
'8793' = 1
'8794' = 1
'8795' = 1
'8799' = 1
'8801' = 1
'8802' = 1
'8803' = 1
'8804' = 1
'8809' = 1
'8811' = 1
'8812' = 1
'8813' = 1
'8814' = 1
'8815' = 1
'8816' = 1
'8819' = 1
'8821' = 1
'8822' = 1
'8823' = 1
'8824' = 1
'8825' = 1
'8826' = 1
'8827' = 1
'8828' = 1
'8829' = 1
'8831' = 1
'8832' = 1
'8833' = 1
'8834' = 1
'8835' = 1
'8836' = 1
'8837' = 1
'8838' = 1
'8839' = 1
'8840' = 1
'8841' = 1
'8842' = 1
'8843' = 1
'8844' = 1
'8845' = 1
'8846' = 1
'8847' = 1
'8848' = 1
'8849' = 1
'8850' = 1
'8851' = 1
'8852' = 1
'8853' = 1
'8854' = 1
'8855' = 1
'8856' = 1
'8857' = 1
'8858' = 1
'8860' = 1
'8861' = 1
'8862' = 1
'8863' = 1
'8864' = 1
'8865' = 1
'8866' = 1
'8867' = 1
'8868' = 1
'8871' = 1
'8872' = 1
'8873' = 1
'8874' = 1
'8875' = 1
'8876' = 1
'8877' = 1
'8878' = 1
'8879' = 1
'8881' = 1
'8882' = 1
'8883' = 1
'8884' = 1
'8885' = 1
'8886' = 1
'8889' = 1
'8890' = 1
'8891' = 1
'8892' = 1
'8893' = 1
'8894' = 1
'8895' = 1
'8896' = 1
'8897' = 1
'8898' = 1
'8899' = 1
'8901' = 1
'8902' = 1
'8903' = 1
'8904' = 1
'8905' = 1
'8906' = 1
'8907' = 1
'8908' = 1
'8909' = 1
'8910' = 1
'8911' = 1
'8912' = 1
'8913' = 1
'8914' = 1
'8915' = 1
'8916' = 1
'8917' = 1
'8918' = 1
'8919' = 1
'8921' = 1
'8922' = 1
'8923' = 1
'8924' = 1
'8925' = 1
'8926' = 1
'8929' = 1
'8931' = 1
'8932' = 1
'8933' = 1
'8934' = 1
'8935' = 1
'8936' = 1
'8937' = 1
'8938' = 1
'8939' = 1
'8941' = 1
'8942' = 1
'8943' = 1
'8944' = 1
'8945' = 1
'8946' = 1
'8947' = 1
'8948' = 1
'8949' = 1
'8950' = 1
'8951' = 1
'8952' = 1
'8953' = 1
'8954' = 1
'8955' = 1
'8956' = 1
'8957' = 1
'8958' = 1
'8959' = 1
'8960' = 1
'8961' = 1
'8962' = 1
'8963' = 1
'8964' = 1
'8965' = 1
'8966' = 1
'8967' = 1
'8968' = 1
'8969' = 1
'897' = 1
'898' = 1
'9001' = 1
'9002' = 1
'9003' = 1
'9004' = 1
'9005' = 1
'9006' = 1
'9009' = 1
'9011' = 1
'9012' = 1
'9013' = 1
'9014' = 1
'9015' = 1
'9016' = 1
'9019' = 1
'9021' = 1
'9022' = 1
'9023' = 1
'9024' = 1
'9025' = 1
'9026' = 1
'9029' = 1
'9031' = 1
'9032' = 1
'9033' = 1
'9034' = 1
'9035' = 1
'9036' = 1
'9039' = 1
'9041' = 1
'9042' = 1
'9043' = 1
'9044' = 1
'9045' = 1
'9046' = 1
'9049' = 1
'9051' = 1
'9052' = 1
'9053' = 1
'9054' = 1
'9055' = 1
'9056' = 1
'9059' = 1
'9061' = 1
'9062' = 1
'9063' = 1
'9064' = 1
'9065' = 1
'9066' = 1
'9069' = 1
'9071' = 1
'9072' = 1
'9073' = 1
'9074' = 1
'9075' = 1
'9076' = 1
'9079' = 1
'9081' = 1
'9082' = 1
'9083' = 1
'9084' = 1
'9085' = 1
'9086' = 1
'9089' = 1
'9091' = 1
'9092' = 1
'9093' = 1
'9094' = 1
'9095' = 1
'9096' = 1
'9099' = 1
'9101' = 1
'9102' = 1
'9103' = 1
'9104' = 1
'9105' = 1
'9106' = 1
'9109' = 1
'9111' = 1
'9112' = 1
'9113' = 1
'9114' = 1
'9115' = 1
'9116' = 1
'9119' = 1
'9121' = 1
'9122' = 1
'9123' = 1
'9124' = 1
'9125' = 1
'9126' = 1
'9129' = 1
'9131' = 1
'9132' = 1
'9133' = 1
'9134' = 1
'9135' = 1
'9136' = 1
'9139' = 1
'9141' = 1
'9142' = 1
'9143' = 1
'9144' = 1
'9145' = 1
'9146' = 1
'9149' = 1
'9151' = 1
'9152' = 1
'9153' = 1
'9154' = 1
'9155' = 1
'9156' = 1
'9159' = 1
'9161' = 1
'9162' = 1
'9163' = 1
'9164' = 1
'9165' = 1
'9166' = 1
'9169' = 1
'9171' = 1
'9172' = 1
'9173' = 1
'9174' = 1
'9175' = 1
'9176' = 1
'9179' = 1
'9181' = 1
'9182' = 1
'9183' = 1
'9184' = 1
'9185' = 1
'9186' = 1
'9189' = 1
'9191' = 1
'9192' = 1
'9193' = 1
'9194' = 1
'9195' = 1
'9196' = 1
'9199' = 1
'9201' = 1
'9202' = 1
'9203' = 1
'9204' = 1
'9205' = 1
'9209' = 1
'9211' = 1
'9212' = 1
'9213' = 1
'9214' = 1
'9215' = 1
'9216' = 1
'9217' = 1
'9218' = 1
'9219' = 1
'9220' = 2
'9221' = 2
'9222' = 2
'9223' = 2
'9224' = 2
'9225' = 2
'9226' = 2
'9227' = 2
'9228' = 2
'9229' = 2
'923' = 2
'9230' = 2
'9231' = 2
'9232' = 2
'9233' = 2
'9239' = 2
'9301' = 1
'9302' = 1
'9303' = 1
'9304' = 1
'9305' = 1
'9306' = 1
'9307' = 1
'9308' = 1
'9309' = 1
'9311' = 2
'9312' = 2
'9313' = 2
'9314' = 2
'9315' = 2
'9316' = 2
'9317' = 2
'9318' = 2
'9319' = 2
'9321' = 2
'9322' = 2
'9323' = 2
'9324' = 2
'9325' = 2
'9326' = 2
'9327' = 2
'9328' = 2
'9329' = 2
'9331' = 2
'9332' = 2
'9333' = 2
'9334' = 2
'9335' = 2
'9336' = 2
'9337' = 2
'9338' = 2
'9339' = 2
'9341' = 2
'9342' = 2
'9343' = 2
'9344' = 2
'9345' = 2
'9346' = 2
'9351' = 2
'9352' = 2
'9353' = 2
'9354' = 2
'9355' = 2
'9356' = 2
'9357' = 2
'9358' = 2
'9359' = 2
'9361' = 2
'9362' = 2
'9363' = 2
'9364' = 2
'9365' = 2
'9366' = 2
'9367' = 2
'9371' = 2
'9372' = 2
'9373' = 2
'9374' = 2
'9375' = 2
'9376' = 2
'9377' = 2
'9378' = 2
'9381' = 2
'9382' = 2
'9383' = 2
'9384' = 2
'9385' = 2
'9389' = 2
'9390' = 2
'9391' = 2
'9392' = 2
'9393' = 2
'9394' = 2
'9395' = 2
'9396' = 2
'9397' = 2
'9398' = 2
'9399' = 2
'9401' = 1
'9402' = 1
'9403' = 1
'9408' = 1
'9409' = 1
'9411' = 1
'9412' = 1
'9413' = 1
'9419' = 1
'9421' = 2
'9422' = 2
'9423' = 2
'9424' = 2
'9425' = 2
'9426' = 2
'9427' = 2
'9429' = 2
'9431' = 2
'9432' = 2
'9433' = 2
'9434' = 2
'9435' = 2
'9436' = 2
'9437' = 2
'9438' = 2
'9439' = 2
'9441' = 2
'9442' = 2
'9443' = 2
'9444' = 2
'9445' = 2
'9446' = 2
'9449' = 2
'9451' = 2
'9452' = 2
'9453' = 2
'9454' = 2
'9455' = 2
'9459' = 2
'9461' = 2
'9462' = 2
'9463' = 2
'9464' = 2
'9465' = 2
'9466' = 2
'9467' = 2
'9468' = 2
'9469' = 2
'9501' = 1
'9502' = 1
'9503' = 1
'9504' = 3
'9505' = 1
'9506' = 1
'9507' = 1
'9509' = 1
'9511' = 1
'9512' = 1
'9513' = 1
'9514' = 1
'9515' = 1
'9516' = 1
'9521' = 1
'9522' = 1
'9523' = 1
'9524' = 1
'9525' = 1
'9526' = 1
'9531' = 2
'9532' = 2
'9533' = 2
'9534' = 2
'9535' = 2
'9536' = 2
'9541' = 1
'9542' = 1
'9543' = 1
'9544' = 1
'9545' = 1
'9546' = 1
'9547' = 1
'9548' = 2
'9549' = 2
'9601' = 2
'9602' = 2
'9603' = 2
'9604' = 2
'9605' = 2
'9606' = 2
'9607' = 2
'9608' = 2
'9609' = 2
'9611' = 2
'9614' = 2
'9615' = 2
'9616' = 2
'9617' = 2
'9618' = 2
'9619' = 2
'9621' = 2
'9622' = 2
'9623' = 2
'9624' = 2
'9625' = 2
'9626' = 2
'9627' = 2
'9628' = 2
'9629' = 2
'9631' = 2
'9632' = 2
'9633' = 2
'9634' = 2
'9635' = 2
'9636' = 2
'9637' = 2
'9638' = 2
'9639' = 2
'9641' = 2
'9642' = 2
'9643' = 2
'9644' = 2
'9645' = 2
'9646' = 2
'9647' = 2
'9648' = 2
'9649' = 2
'9651' = 2
'9652' = 2
'9653' = 2
'9654' = 2
'9655' = 2
'9656' = 2
'9657' = 2
'9658' = 2
'9659' = 2
'966' = 2
'9670' = 2
'9671' = 2
'9672' = 2
'9701' = 2
'9702' = 2
'9703' = 2
'9704' = 2
'9705' = 2
'9711' = 2
'9712' = 2
'9713' = 2
'9714' = 2
'9715' = 2
'9716' = 2
'9721' = 2
'9722' = 2
'9723' = 2
'9724' = 2
'9725' = 2
'9726' = 2
'9729' = 2
'9731' = 2
'9732' = 2
'9733' = 2
'9734' = 2
'9735' = 2
'9736' = 2
'9737' = 2
'9738' = 2
'9739' = 2
'9741' = 2
'9742' = 2
'9743' = 2
'9744' = 2
'9749' = 2
'9751' = 2
'9752' = 2
'9753' = 2
'9754' = 2
'9755' = 2
'9756' = 2
'9759' = 2
'9761' = 2
'9762' = 2
'9763' = 2
'9764' = 2
'9765' = 2
'9769' = 2
'9771' = 2
'9772' = 2
'9773' = 2
'9774' = 2
'9775' = 2
'9779' = 2
'9781' = 2
'9782' = 2
'9783' = 2
'9784' = 2
'9785' = 2
'9786' = 2
'9787' = 2
'9788' = 2
'9789' = 2
'9801' = 2
'9802' = 2
'9803' = 2
'9804' = 2
'9805' = 2
'9811' = 2
'9812' = 2
'9813' = 2
'9814' = 2
'9815' = 2
'9816' = 2
'9817' = 2
'9818' = 2
'9819' = 2
'9820' = 2
'9821' = 2
'9822' = 2
'9823' = 2
'9824' = 2
'9825' = 2
'9826' = 2
'9827' = 2
'9828' = 2
'9829' = 2
'9851' = 2
'9852' = 2
'9859' = 2
'9900' = 2
'9901' = 2
'9902' = 2
'9903' = 2
'9904' = 2
'9905' = 2
'9906' = 2
'9907' = 2
'9908' = 2
'9909' = 2
'9910' = 2
'9911' = 2
'9912' = 2
'9913' = 2
'9914' = 2
'9915' = 2
'9916' = 2
'9917' = 2
'9918' = 2
'9919' = 2
'9920' = 2
'9921' = 2
'9922' = 2
'9923' = 2
'9924' = 2
'9925' = 2
'9926' = 2
'9927' = 2
'9928' = 2
'9929' = 2
'9931' = 2
'9932' = 2
'9933' = 2
'9934' = 2
'9935' = 2
'9936' = 2
'9937' = 2
'9938' = 2
'9939' = 2
'9941' = 2
'9942' = 2
'9943' = 2
'9944' = 2
'9945' = 2
'9946' = 2
'9947' = 2
'9948' = 2
'9951' = 2
'9952' = 2
'9953' = 2
'9954' = 2
'9955' = 2
'9956' = 2
'9957' = 2
'9958' = 2
'9959' = 2
'9960' = 2
'9961' = 2
'9962' = 2
'9963' = 2
'9964' = 2
'9969' = 2
'9971' = 2
'9972' = 2
'9973' = 2
'9974' = 2
'9975' = 2
'9976' = 2
'9977' = 2
'9978' = 2
'9979' = 2
'9981' = 2
'9982' = 2
'9983' = 2
'9984' = 2
'9985' = 2
'9986' = 2
'9988' = 2
'9991' = 2
'9992' = 2
'9993' = 2
'9994' = 2
'9995' = 2
'9996' = 2
'9997' = 2
'9998' = 2
'9999' = 2
OTHER  = 0;

 /* -------------------------------------------------------------- */
 /* ---   FORMAT FOR AGE STRATIFIERS                           --- */
 /* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR AGE CATEGORIES     --- */
 /* -------------------------------------------------------------- */

VALUE AGEFMT
low - 4 = 1
 5 -  9 = 2
10 - 14 = 3
15 - 17 = 4
18 - 24 = 5
25 - 29 = 6
30 - 34 = 7
35 - 39 = 8
40 - 44 = 9
45 - 49 = 10
50 - 54 = 11
55 - 59 = 12
60 - 64 = 13
65 - 69 = 14
70 - 74 = 15
75 - 79 = 16
80 - 84 = 17
85 - high = 18;

VALUE $CCS
'0700 ' = 6 /* HEPATITIS A WITH COMA */
'0701 ' = 6 /* HEPATITIS A W/O COMA */
'0702 ' = 6 /* HEPATITIS B WITH COMA  J80  S91 */
'07020' = 6 /* VRL HEPAT B CM W/O DELTA OCT91 */
'07021' = 6 /* VRL HEPAT B CM W DELTA OCT91 */
'07022' = 6 /* CHR HEPAT COMA W/O DELTA OCT94 */
'07023' = 6 /* CHR HEPAT COMA W/ DELTA  OCT94 */
'0703 ' = 6 /* HEPATITIS B W/O COMA   J80  S91 */
'07030' = 6 /* VRL HPT B W/O CM W/O DLT OCT91 */
'07031' = 6 /* VRL HPT B W/O CM W DELTA OCT91 */
'07032' = 6 /* CHR HEPAT W/O COMA W/O DELTA OCT94 */
'07033' = 6 /* CHR HEPAT W/O COMA W/ DELTA  OCT94 */
'0704 ' = 6 /* VIRAL HEPAT NEC W COMA J80  S91 */
'07041' = 6 /* SPF VRL HPT CM HPT C   OCT91 */
'07042' = 6 /* SPF VRL HPT CM DLT W/O B OCT91 */
'07043' = 6 /* SPF VRL HPT CM HPT E   OCT91 */
'07044' = 6 /* CHR HEPAT C W/ COMA OCT94 */
'07049' = 6 /* SPF VRL HPT CM     OCT91 */
'0705 ' = 6 /* VIRAL HEPAT NEC W/O COMA  J80  S91 */
'07051' = 6 /* VRL HPT W/O CM HEPAT C OCT91 */
'07052' = 6 /* VRL HPT W/O CM DLT W/O B OCT91 */
'07053' = 6 /* VRL HPT W/O CM HEPAT E OCT91 */
'07054' = 6 /* CHR HEPAT C W/O COMA OCT94 */
'07059' = 6 /* VRL HPT W/O CM     OCT91 */
'0706 ' = 6 /* VIRAL HEPAT NOS W COMA */
'07070' = 6 /* HPT C W/O HEPAT COMA NOS */
'07071' = 6 /* HPT C W HEPATIC COMA NOS */
'0709 ' = 6 /* VIRAL HEPAT NOS W/O COMA */
'1100 ' = 4 /* DERMATOPHYT SCALP/BEARD */
'1101 ' = 4 /* DERMATOPHYTOSIS OF NAIL */
'1102 ' = 4 /* DERMATOPHYTOSIS OF HAND */
'1103 ' = 4 /* DERMATOPHYTOSIS OF GROIN */
'1104 ' = 4 /* DERMATOPHYTOSIS OF FOOT */
'1105 ' = 4 /* DERMATOPHYTOSIS OF BODY */
'1106 ' = 4 /* DEEP DERMATOPHYTOSIS */
'1108 ' = 4 /* DERMATOPHYTOSIS SITE NEC */
'1109 ' = 4 /* DERMATOPHYTOSIS SITE NOS */
'1110 ' = 4 /* PITYRIASIS VERSICOLOR */
'1111 ' = 4 /* TINEA NIGRA */
'1112 ' = 4 /* TINEA BLANCA */
'1113 ' = 4 /* BLACK PIEDRA */
'1118 ' = 4 /* DERMATOMYCOSES NEC */
'1119 ' = 4 /* DERMATOMYCOSIS NOS */
'1120 ' = 4 /* THRUSH */
'1121 ' = 4 /* CANDIDAL VULVOVAGINITIS */
'1122 ' = 4 /* CANDIDIAS UROGENITAL NEC */
'1123 ' = 4 /* CUTANEOUS CANDIDIASIS */
'1125 ' = 4 /* DISSEMINATED CANDIDIASIS */
'11282' = 4 /* CANDIDAL OTITIS EXTERNA */
'11284' = 4 /* CANDIDAL ESOPHAGITIS   OCT92 */
'11285' = 4 /* CANDIDAL ENTERITIS   OCT92 */
'11289' = 4 /* CANDIDIASIS SITE NEC */
'1129 ' = 4 /* CANDIDIASIS SITE NOS */
'1141 ' = 4 /* PRIM CUTAN COCCIDIOID */
'1143 ' = 4 /* PROGRESS COCCIDIOID NEC */
'1149 ' = 4 /* COCCIDIOIDOMYCOSIS NOS */
'11500' = 4 /* HISTOPLASMA CAPSULAT NOS */
'11509' = 4 /* HISTOPLASMA CAPSULAT NEC */
'11510' = 4 /* HISTOPLASMA DUBOISII NOS */
'11519' = 4 /* HISTOPLASMA DUBOISII NEC */
'11590' = 4 /* HISTOPLASMOSIS NOS */
'11599' = 4 /* HISTOPLASMOSIS NEC */
'1160 ' = 4 /* BLASTOMYCOSIS */
'1161 ' = 4 /* PARACOCCIDIOIDOMYCOSIS */
'1162 ' = 4 /* LOBOMYCOSIS */
'1170 ' = 4 /* RHINOSPORIDIOSIS */
'1171 ' = 4 /* SPOROTRICHOSIS */
'1172 ' = 4 /* CHROMOBLASTOMYCOSIS */
'1173 ' = 4 /* ASPERGILLOSIS */
'1174 ' = 4 /* MYCOTIC MYCETOMAS */
'1175 ' = 4 /* CRYPTOCOCCOSIS */
'1176 ' = 4 /* ALLESCHERIOSIS */
'1177 ' = 4 /* ZYGOMYCOSIS */
'1178 ' = 4 /* DEMATIACIOUS FUNGI INF */
'1179 ' = 4 /* MYCOSES NEC & NOS */
'118  ' = 4 /* OPPORTUNISTIC MYCOSES */
'1640 ' = 41 /* MALIGNANT NEOPL THYMUS */
'1641 ' = 41 /* MALIGNANT NEOPL HEART */
'1642 ' = 41 /* MAL NEO ANT MEDIASTINUM */
'1643 ' = 41 /* MAL NEO POST MEDIASTINUM */
'1648 ' = 41 /* MAL NEO MEDIASTINUM NEC */
'1649 ' = 41 /* MAL NEO MEDIASTINUM NOS */
'1700 ' = 21 /* MAL NEO SKULL/FACE BONE */
'1701 ' = 21 /* MALIGNANT NEO MANDIBLE */
'1702 ' = 21 /* MALIG NEO VERTEBRAE */
'1703 ' = 21 /* MAL NEO RIBS/STERN/CLAV */
'1704 ' = 21 /* MAL NEO LONG BONES ARM */
'1705 ' = 21 /* MAL NEO BONES WRIST/HAND */
'1706 ' = 21 /* MAL NEO PELVIC GIRDLE */
'1707 ' = 21 /* MAL NEO LONG BONES LEG */
'1708 ' = 21 /* MAL NEO BONES ANKLE/FOOT */
'1709 ' = 21 /* MALIG NEOPL BONE NOS */
'1710 ' = 21 /* MAL NEO SOFT TISSUE HEAD */
'1712 ' = 21 /* MAL NEO SOFT TISSUE ARM */
'1713 ' = 21 /* MAL NEO SOFT TISSUE LEG */
'1714 ' = 21 /* MAL NEO SOFT TIS THORAX */
'1715 ' = 21 /* MAL NEO SOFT TIS ABDOMEN */
'1716 ' = 21 /* MAL NEO SOFT TIS PELVIS */
'1717 ' = 21 /* MAL NEOPL TRUNK NOS */
'1718 ' = 21 /* MAL NEO SOFT TISSUE NEC */
'1719 ' = 21 /* MAL NEO SOFT TISSUE NOS */
'1760 ' = 41 /* SKIN - KAPOSI-s SARCOMA  OCT91 */
'1761 ' = 41 /* SFT TISUE - KPSI-s SRCMA OCT91 */
'1762 ' = 41 /* PALATE - KPSI-s SARCOMA  OCT91 */
'1763 ' = 41 /* GI SITES - KPSI-s SRCOMA OCT91 */
'1764 ' = 41 /* LUNG - KAPOSI-s SARCOMA  OCT91 */
'1765 ' = 41 /* LYM NDS - KPSI-s SARCOMA OCT91 */
'1768 ' = 41 /* SPF STS - KPSI-s SARCOMA OCT91 */
'1769 ' = 41 /* KAPOSI-s SARCOMA NOS   OCT91 */
'1890 ' = 33 /* MALIG NEOPL KIDNEY */
'1891 ' = 33 /* MALIG NEO RENAL PELVIS */
'1900 ' = 41 /* MALIGN NEOPL EYEBALL */
'1901 ' = 41 /* MALIGN NEOPL ORBIT */
'1902 ' = 41 /* MAL NEO LACRIMAL GLAND */
'1903 ' = 41 /* MAL NEO CONJUNCTIVA */
'1904 ' = 41 /* MALIGN NEOPL CORNEA */
'1905 ' = 41 /* MALIGN NEOPL RETINA */
'1906 ' = 41 /* MALIGN NEOPL CHOROID */
'1907 ' = 41 /* MAL NEO LACRIMAL DUCT */
'1908 ' = 41 /* MALIGN NEOPL EYE NEC */
'1909 ' = 41 /* MALIGN NEOPL EYE NOS */
'1910 ' = 35 /* MALIGN NEOPL CEREBRUM */
'1911 ' = 35 /* MALIG NEO FRONTAL LOBE */
'1912 ' = 35 /* MAL NEO TEMPORAL LOBE */
'1913 ' = 35 /* MAL NEO PARIETAL LOBE */
'1914 ' = 35 /* MAL NEO OCCIPITAL LOBE */
'1915 ' = 35 /* MAL NEO CEREB VENTRICLE */
'1916 ' = 35 /* MAL NEO CEREBELLUM NOS */
'1917 ' = 35 /* MAL NEO BRAIN STEM */
'1918 ' = 35 /* MALIG NEO BRAIN NEC */
'1919 ' = 35 /* MALIG NEO BRAIN NOS */
'1920 ' = 35 /* MAL NEO CRANIAL NERVES */
'1921 ' = 35 /* MAL NEO CEREBRAL MENING */
'1922 ' = 35 /* MAL NEO SPINAL CORD */
'1923 ' = 35 /* MAL NEO SPINAL MENINGES */
'1928 ' = 35 /* MAL NEO NERVOUS SYST NEC */
'1929 ' = 35 /* MAL NEO NERVOUS SYST NOS */
'1940 ' = 41 /* MALIGN NEOPL ADRENAL */
'1941 ' = 41 /* MALIG NEO PARATHYROID */
'1943 ' = 41 /* MALIG NEO PITUITARY */
'1944 ' = 41 /* MALIGN NEO PINEAL GLAND */
'1945 ' = 41 /* MAL NEO CAROTID BODY */
'1946 ' = 41 /* MAL NEO PARAGANGLIA NEC */
'1948 ' = 41 /* MAL NEO ENDOCRINE NEC */
'1949 ' = 41 /* MAL NEO ENDOCRINE NOS */
'1951 ' = 41 /* MALIGN NEOPL THORAX */
'1952 ' = 41 /* MALIG NEO ABDOMEN */
'1953 ' = 41 /* MALIGN NEOPL PELVIS */
'1954 ' = 41 /* MALIGN NEOPL ARM */
'1955 ' = 41 /* MALIGN NEOPL LEG */
'1958 ' = 41 /* MALIG NEO SITE NEC */
'1960 ' = 42 /* MAL NEO LYMPH-HEAD/NECK */
'1961 ' = 42 /* MAL NEO LYMPH-INTRATHOR */
'1962 ' = 42 /* MAL NEO LYMPH INTRA-ABD */
'1963 ' = 42 /* MAL NEO LYMPH-AXILLA/ARM */
'1965 ' = 42 /* MAL NEO LYMPH-INGUIN/LEG */
'1966 ' = 42 /* MAL NEO LYMPH-INTRAPELV */
'1968 ' = 42 /* MAL NEO LYMPH NODE-MULT */
'1969 ' = 42 /* MAL NEO LYMPH NODE NOS */
'1970 ' = 42 /* SECONDARY MALIG NEO LUNG */
'1971 ' = 42 /* SEC MAL NEO MEDIASTINUM */
'1972 ' = 42 /* SECOND MALIG NEO PLEURA */
'1973 ' = 42 /* SEC MALIG NEO RESP NEC */
'1974 ' = 42 /* SEC MALIG NEO SM BOWEL */
'1975 ' = 42 /* SEC MALIG NEO LG BOWEL */
'1976 ' = 42 /* SEC MAL NEO PERITONEUM */
'1977 ' = 42 /* SECOND MALIG NEO LIVER */
'1978 ' = 42 /* SEC MAL NEO GI NEC */
'1980 ' = 42 /* SECOND MALIG NEO KIDNEY */
'1981 ' = 42 /* SEC MALIG NEO URIN NEC */
'1982 ' = 42 /* SECONDARY MALIG NEO SKIN */
'1983 ' = 42 /* SEC MAL NEO BRAIN/SPINE */
'1984 ' = 42 /* SEC MALIG NEO NERVE NEC */
'1985 ' = 42 /* SECONDARY MALIG NEO BONE */
'1986 ' = 42 /* SECOND MALIG NEO OVARY */
'1987 ' = 42 /* SECOND MALIG NEO ADRENAL */
'19881' = 42 /* SECOND MALIG NEO BREAST */
'19882' = 42 /* SECOND MALIG NEO GENITAL */
'19889' = 42 /* SECONDARY MALIG NEO NEC */
'20000' = 38 /* RETICULOSARCOMA UNSPEC */
'20001' = 38 /* RETICULOSARCOMA HEAD */
'20002' = 38 /* RETICULOSARCOMA THORAX */
'20003' = 38 /* RETICULOSARCOMA ABDOM */
'20004' = 38 /* RETICULOSARCOMA AXILLA */
'20005' = 38 /* RETICULOSARCOMA INGUIN */
'20006' = 38 /* RETICULOSARCOMA PELVIC */
'20007' = 38 /* RETICULOSARCOMA SPLEEN */
'20008' = 38 /* RETICULOSARCOMA MULT */
'20010' = 38 /* LYMPHOSARCOMA UNSPEC */
'20011' = 38 /* LYMPHOSARCOMA HEAD */
'20012' = 38 /* LYMPHOSARCOMA THORAX */
'20013' = 38 /* LYMPHOSARCOMA ABDOM */
'20014' = 38 /* LYMPHOSARCOMA AXILLA */
'20015' = 38 /* LYMPHOSARCOMA INGUIN */
'20016' = 38 /* LYMPHOSARCOMA PELVIC */
'20017' = 38 /* LYMPHOSARCOMA SPLEEN */
'20018' = 38 /* LYMPHOSARCOMA MULT */
'20020' = 38 /* BURKITT-s TUMOR UNSPEC */
'20021' = 38 /* BURKITT-s TUMOR HEAD */
'20022' = 38 /* BURKITT-s TUMOR THORAX */
'20023' = 38 /* BURKITT-s TUMOR ABDOM */
'20024' = 38 /* BURKITT-s TUMOR AXILLA */
'20025' = 38 /* BURKITT-s TUMOR INGUIN */
'20026' = 38 /* BURKITT-s TUMOR PELVIC */
'20027' = 38 /* BURKITT-s TUMOR SPLEEN */
'20028' = 38 /* BURKITT-s TUMOR MULT */
'20080' = 38 /* MIXED LYMPHOSARC UNSPEC */
'20081' = 38 /* MIXED LYMPHOSARC HEAD */
'20082' = 38 /* MIXED LYMPHOSARC THORAX */
'20083' = 38 /* MIXED LYMPHOSARC ABDOM */
'20084' = 38 /* MIXED LYMPHOSARC AXILLA */
'20085' = 38 /* MIXED LYMPHOSARC INGUIN */
'20086' = 38 /* MIXED LYMPHOSARC PELVIC */
'20087' = 38 /* MIXED LYMPHOSARC SPLEEN */
'20088' = 38 /* MIXED LYMPHOSARC MULT */
'20200' = 38 /* NODULAR LYMPHOMA UNSPEC */
'20201' = 38 /* NODULAR LYMPHOMA HEAD */
'20202' = 38 /* NODULAR LYMPHOMA THORAX */
'20203' = 38 /* NODULAR LYMPHOMA ABDOM */
'20204' = 38 /* NODULAR LYMPHOMA AXILLA */
'20205' = 38 /* NODULAR LYMPHOMA INGUIN */
'20206' = 38 /* NODULAR LYMPHOMA PELVIC */
'20207' = 38 /* NODULAR LYMPHOMA SPLEEN */
'20208' = 38 /* NODULAR LYMPHOMA MULT */
'20210' = 38 /* MYCOSIS FUNGOIDES UNSPEC */
'20211' = 38 /* MYCOSIS FUNGOIDES HEAD */
'20212' = 38 /* MYCOSIS FUNGOIDES THORAX */
'20213' = 38 /* MYCOSIS FUNGOIDES ABDOM */
'20214' = 38 /* MYCOSIS FUNGOIDES AXILLA */
'20215' = 38 /* MYCOSIS FUNGOIDES INGUIN */
'20216' = 38 /* MYCOSIS FUNGOIDES PELVIC */
'20217' = 38 /* MYCOSIS FUNGOIDES SPLEEN */
'20218' = 38 /* MYCOSIS FUNGOIDES MULT */
'20220' = 38 /* SEZARY-s DISEASE UNSPEC */
'20221' = 38 /* SEZARY-s DISEASE HEAD */
'20222' = 38 /* SEZARY-s DISEASE THORAX */
'20223' = 38 /* SEZARY-s DISEASE ABDOM */
'20224' = 38 /* SEZARY-s DISEASE AXILLA */
'20225' = 38 /* SEZARY-s DISEASE INGUIN */
'20226' = 38 /* SEZARY-s DISEASE PELVIC */
'20227' = 38 /* SEZARY-s DISEASE SPLEEN */
'20228' = 38 /* SEZARY-s DISEASE MULT */
'20230' = 41 /* MAL HISTIOCYTOSIS UNSPEC */
'20231' = 41 /* MAL HISTIOCYTOSIS HEAD */
'20232' = 41 /* MAL HISTIOCYTOSIS THORAX */
'20233' = 41 /* MAL HISTIOCYTOSIS ABDOM */
'20234' = 41 /* MAL HISTIOCYTOSIS AXILLA */
'20235' = 41 /* MAL HISTIOCYTOSIS INGUIN */
'20236' = 41 /* MAL HISTIOCYTOSIS PELVIC */
'20237' = 41 /* MAL HISTIOCYTOSIS SPLEEN */
'20238' = 41 /* MAL HISTIOCYTOSIS MULT */
'20240' = 39 /* HAIRY-CELL LEUKEM UNSPEC */
'20241' = 39 /* HAIRY-CELL LEUKEM HEAD */
'20242' = 39 /* HAIRY-CELL LEUKEM THORAX */
'20243' = 39 /* HAIRY-CELL LEUKEM ABDOM */
'20244' = 39 /* HAIRY-CELL LEUKEM AXILLA */
'20245' = 39 /* HAIRY-CELL LEUKEM INGUIN */
'20246' = 39 /* HAIRY-CELL LEUKEM PELVIC */
'20247' = 39 /* HAIRY-CELL LEUKEM SPLEEN */
'20248' = 39 /* HAIRY-CELL LEUKEM MULT */
'20250' = 41 /* LETTERER-SIWE DIS UNSPEC */
'20251' = 41 /* LETTERER-SIWE DIS HEAD */
'20252' = 41 /* LETTERER-SIWE DIS THORAX */
'20253' = 41 /* LETTERER-SIWE DIS ABDOM */
'20254' = 41 /* LETTERER-SIWE DIS AXILLA */
'20255' = 41 /* LETTERER-SIWE DIS INGUIN */
'20256' = 41 /* LETTERER-SIWE DIS PELVIC */
'20257' = 41 /* LETTERER-SIWE DIS SPLEEN */
'20258' = 41 /* LETTERER-SIWE DIS MULT */
'20260' = 41 /* MAL MASTOCYTOSIS UNSPEC */
'20261' = 41 /* MAL MASTOCYTOSIS HEAD */
'20262' = 41 /* MAL MASTOCYTOSIS THORAX */
'20263' = 41 /* MAL MASTOCYTOSIS ABDOM */
'20264' = 41 /* MAL MASTOCYTOSIS AXILLA */
'20265' = 41 /* MAL MASTOCYTOSIS INGUIN */
'20266' = 41 /* MAL MASTOCYTOSIS PELVIC */
'20267' = 41 /* MAL MASTOCYTOSIS SPLEEN */
'20268' = 41 /* MAL MASTOCYTOSIS MULT */
'20280' = 38 /* LYMPHOMA NEC UNSPEC SITE */
'20281' = 38 /* LYMPHOMAS NEC HEAD */
'20282' = 38 /* LYMPHOMAS NEC THORAX */
'20283' = 38 /* LYMPHOMAS NEC ABDOM */
'20284' = 38 /* LYMPHOMAS NEC AXILLA */
'20285' = 38 /* LYMPHOMAS NEC INGUIN */
'20286' = 38 /* LYMPHOMAS NEC PELVIC */
'20287' = 38 /* LYMPHOMAS NEC SPLEEN */
'20288' = 38 /* LYMPHOMAS NEC MULT */
'20290' = 38 /* LYMPHOID MAL NEC UNSPEC */
'20291' = 38 /* LYMPHOID MAL NEC HEAD */
'20292' = 38 /* LYMPHOID MAL NEC THORAX */
'20293' = 38 /* LYMPHOID MAL NEC ABDOM */
'20294' = 38 /* LYMPHOID MAL NEC AXILLA */
'20295' = 38 /* LYMPHOID MAL NEC INGUIN */
'20296' = 38 /* LYMPHOID MAL NEC PELVIC */
'20297' = 38 /* LYMPHOID MAL NEC SPLEEN */
'20298' = 38 /* LYMPHOID MAL NEC MULT */
'2031 ' = 39 /* PLASMA CELL LEUKEMIA   J80  S91 */
'20310' = 39 /* PLSM CELL LEUK W/O RMSON OCT91 */
'20311' = 39 /* PLSM CELL LEUK W RMSON OCT91 */
'2040 ' = 39 /* ACUTE LYMPHOID LEUKEMIA  J80  S91 */
'20400' = 39 /* ACT LYM LEUK W/O RMSION  OCT91 */
'20401' = 39 /* ACT LYM LEUK W RMSION  OCT91 */
'2041 ' = 39 /* CHR LYMPHOID LEUKEMIA  J80  S91 */
'20410' = 39 /* CHR LYM LEUK W/O RMSION  OCT91 */
'20411' = 39 /* CHR LYM LEUK W RMSION  OCT91 */
'2042 ' = 39 /* SUBAC LYMPHOID LEUKEMIA  J80  S91 */
'20420' = 39 /* SBAC LYM LEUK W/O RMSION OCT91 */
'20421' = 39 /* SBAC LYM LEUK W RMSION OCT91 */
'2048 ' = 39 /* LYMPHOID LEUKEMIA NEC  J80  S91 */
'20480' = 39 /* OTH LYM LEUK W/O RMSION  OCT91 */
'20481' = 39 /* OTH LYM LEUK W RMSION  OCT91 */
'2049 ' = 39 /* LYMPHOID LEUKEMIA NOS  J80  S91 */
'20490' = 39 /* UNS LYM LEUK W/O RMSION  OCT91 */
'20491' = 39 /* UNS LYM LEUK W RMSION  OCT91 */
'2050 ' = 39 /* ACUTE MYELOID LEUKEMIA J80  S91 */
'20500' = 39 /* ACT MYL LEUK W/O RMSION  OCT91 */
'20501' = 39 /* ACT MYL LEUK W RMSION  OCT91 */
'2051 ' = 39 /* CHRONIC MYELOID LEUKEMIA  J80  S91 */
'20510' = 39 /* CHR MYL LEUK W/O RMSION  OCT91 */
'20511' = 39 /* CHR MYL LEUK W RMSION  OCT91 */
'2052 ' = 39 /* SUBACUT MYELOID LEUKEMIA  J80  S91 */
'20520' = 39 /* SBAC MYL LEUK W/O RMSION OCT91 */
'20521' = 39 /* SBAC MYL LEUK W RMSION OCT91 */
'2053 ' = 39 /* MYELOID SARCOMA    J80  S91 */
'20530' = 39 /* MYL SRCOMA W/O RMSION  OCT91 */
'20531' = 39 /* MYL SRCOMA W RMSION  OCT91 */
'2058 ' = 39 /* MYELOID LEUKEMIA NEC   J80  S91 */
'20580' = 39 /* OTH MYL LEUK W/O RMSION  OCT91 */
'20581' = 39 /* OTH MYL LEUK W RMSION  OCT91 */
'2059 ' = 39 /* MYELOID LEUKEMIA NOS   J80  S91 */
'20590' = 39 /* UNS MYL LEUK W/O RMSION  OCT91 */
'20591' = 39 /* UNS MYL LEUK W RMSION  OCT91 */
'2060 ' = 39 /* ACUTE MONOCYTIC LEUKEMIA  J80  S91 */
'20600' = 39 /* ACT MONO LEUK W/O RMSION OCT91 */
'20601' = 39 /* ACT MONO LEUK W RMSION OCT91 */
'2061 ' = 39 /* CHR MONOCYTIC LEUKEMIA  J80  S91 */
'20610' = 39 /* CHR MONO LEUK W/O RMSION OCT91 */
'20611' = 39 /* CHR MONO LEUK W RMSION OCT91 */
'2062 ' = 39 /* SUBAC MONOCYTIC LEUKEMIA  J80  S91 */
'20620' = 39 /* SBAC MONO LEUK W/O RMSON OCT91 */
'20621' = 39 /* SBAC MONO LEUK W RMSION  OCT91 */
'2068 ' = 39 /* MONOCYTIC LEUKEMIA NEC  J80  S91 */
'20680' = 39 /* OTH MONO LEUK W/O RMSION OCT91 */
'20681' = 39 /* OTH MONO LEUK W RMSION OCT91 */
'2069 ' = 39 /* MONOCYTIC LEUKEMIA NOS  J80  S91 */
'20690' = 39 /* UNS MONO LEUK W/O RMSION OCT91 */
'20691' = 39 /* UNS MONO LEUK W RMSION OCT91 */
'2070 ' = 39 /* ACUTE ERYTHREMIA   J80  S91 */
'20700' = 39 /* ACT ERTH/ERYLK W/O RMSON OCT91 */
'20701' = 39 /* ACT ERTH/ERYLK W RMSON OCT91 */
'2071 ' = 39 /* CHRONIC ERYTHREMIA   J80  S91 */
'20710' = 39 /* CHR ERYTHRM W/O REMISION OCT91 */
'20711' = 39 /* CHR ERYTHRM W REMISION OCT91 */
'2072 ' = 39 /* MEGAKARYOCYTIC LEUKEMIA  J80  S91 */
'20720' = 39 /* MGKRYCYT LEUK W/O RMSION OCT91 */
'20721' = 39 /* MGKRYCYT LEUK W RMSION OCT91 */
'2078 ' = 39 /* SPECIFIED LEUKEMIA NEC  J80  S91 */
'20780' = 39 /* OTH SPF LEUK W/O REMSION OCT91 */
'20781' = 39 /* OTH SPF LEUK W REMSION OCT91 */
'2080 ' = 39 /* ACT LEUK UNS CL W/O RMSN  J80  S91 */
'20800' = 39 /* ACT LEUK UNS CL W/O RMSN OCT91 */
'20801' = 39 /* ACT LEUK UNS CL W RMSON  OCT91 */
'2081 ' = 39 /* CHRONIC LEUKEMIA NOS   J80  S91 */
'20810' = 39 /* CHR LEUK UNS CL W/O RMSN OCT91 */
'20811' = 39 /* CHR LEUK UNS CL W RMSON  OCT91 */
'2082 ' = 39 /* SUBACUTE LEUKEMIA NOS  J80  S91 */
'20820' = 39 /* SBAC LEUK UNS CL W/O RMS OCT91 */
'20821' = 39 /* SBAC LEUK UNS CL W RMSON OCT91 */
'2088 ' = 39 /* LEUKEMIA-UNSPEC CELL NEC  J80  S91 */
'20880' = 39 /* OTH LEUK UNS CL W/O RMSN OCT91 */
'20881' = 39 /* OTH LEUK UNS CL W RMSON  OCT91 */
'2089 ' = 39 /* LEUKEMIA-UNSPEC CELL NOS  J80  S91 */
'20890' = 39 /* LEUKEMIA NOS W/O REMSION OCT91 */
'20891' = 39 /* LEUKEMIA NOS W REMISSION OCT91 */
'2340 ' = 41 /* CA IN SITU EYE */
'2348 ' = 41 /* CA IN SITU NEC */
'2349 ' = 41 /* CA IN SITU NOS */
'2375 ' = 35 /* UNC BEH NEO BRAIN/SPINAL */
'2396 ' = 35 /* BRAIN NEOPLASM NOS */
'2400 ' = 48 /* SIMPLE GOITER */
'2409 ' = 48 /* GOITER NOS */
'2410 ' = 48 /* NONTOX UNINODULAR GOITER */
'2411 ' = 48 /* NONTOX MULTINODUL GOITER */
'2419 ' = 48 /* NONTOX NODUL GOITER NOS */
'24200' = 48 /* TOX DIF GOITER NO CRISIS */
'24201' = 48 /* TOX DIF GOITER W CRISIS */
'24210' = 48 /* TOX UNINOD GOIT NO CRIS */
'24211' = 48 /* TOX UNINOD GOIT W CRISIS */
'24220' = 48 /* TOX MULTNOD GOIT NO CRIS */
'24221' = 48 /* TOX MULTNOD GOIT W CRIS */
'24230' = 48 /* TOX NOD GOITER NO CRISIS */
'24231' = 48 /* TOX NOD GOITER W CRISIS */
'24240' = 48 /* THYROTOX-ECT NOD NO CRIS */
'24241' = 48 /* THYROTOX-ECT NOD W CRIS */
'24280' = 48 /* THYRTOX ORIG NEC NO CRIS */
'24281' = 48 /* THYROTOX ORIG NEC W CRIS */
'24290' = 48 /* THYROTOX NOS NO CRISIS */
'24291' = 48 /* THYROTOX NOS W CRISIS */
'243  ' = 48 /* CONGENITAL HYPOTHYROIDSM */
'2440 ' = 48 /* POSTSURGICAL HYPOTHYROID */
'2441 ' = 48 /* POSTABLAT HYPOTHYR NEC */
'2442 ' = 48 /* IODINE HYPOTHYROIDISM */
'2443 ' = 48 /* IATROGEN HYPOTHYROID NEC */
'2448 ' = 48 /* ACQUIRED HYPOTHYROID NEC */
'2449 ' = 48 /* HYPOTHYROIDISM NOS */
'2450 ' = 48 /* ACUTE THYROIDITIS */
'2451 ' = 48 /* SUBACUTE THYROIDITIS */
'2452 ' = 48 /* CHR LYMPHOCYT THYROIDIT */
'2453 ' = 48 /* CHR FIBROUS THYROIDITIS */
'2454 ' = 48 /* IATROGENIC THYROIDITIS */
'2458 ' = 48 /* CHR THYROIDITIS NEC/NOS */
'2459 ' = 48 /* THYROIDITIS NOS */
'2460 ' = 48 /* DIS THYROCALCITON SECRET */
'2461 ' = 48 /* DYSHORMONOGENIC GOITER */
'2462 ' = 48 /* CYST OF THYROID */
'2463 ' = 48 /* HEMORR/INFARC THYROID */
'2468 ' = 48 /* DISORDERS OF THYROID NEC */
'2469 ' = 48 /* DISORDER OF THYROID NOS */
'2510 ' = 51 /* HYPOGLYCEMIC COMA  OCT93 */
'2511 ' = 51 /* HYPERINSULINISM NEC */
'2512 ' = 51 /* HYPOGLYCEMIA NOS */
'2513 ' = 51 /* POSTSURG HYPOINSULINEMIA */
'2514 ' = 51 /* ABN SECRETION GLUCAGON */
'2515 ' = 51 /* ABNORM SECRETION GASTRIN */
'2518 ' = 51 /* PANCREATIC DISORDER NEC */
'2519 ' = 51 /* PANCREATIC DISORDER NOS */
'2520 ' = 51 /* HYPERPARATHYROIDISM */
'25200' = 51 /* HYPERPARATHYROIDISM NOS */
'25201' = 51 /* PRIMARY HYPERPARATHYROID */
'25202' = 51 /* SEC HYPRPRTHYRD NONRENAL */
'25208' = 51 /* HYPERPARATHYROIDISM NEC */
'2521 ' = 51 /* HYPOPARATHYROIDISM */
'2528 ' = 51 /* PARATHYROID DISORDER NEC */
'2529 ' = 51 /* PARATHYROID DISORDER NOS */
'2530 ' = 51 /* ACROMEGALY AND GIGANTISM */
'2531 ' = 51 /* ANT PITUIT HYPERFUNC NEC */
'2532 ' = 51 /* PANHYPOPITUITARISM */
'2533 ' = 51 /* PITUITARY DWARFISM */
'2534 ' = 51 /* ANTER PITUITARY DIS NEC */
'2535 ' = 51 /* DIABETES INSIPIDUS */
'2536 ' = 51 /* NEUROHYPOPHYSIS DIS NEC */
'2537 ' = 51 /* IATROGENIC PITUITARY DIS */
'2538 ' = 51 /* PITUITARY DISORDER NEC */
'2539 ' = 51 /* PITUITARY DISORDER NOS */
'2540 ' = 51 /* PERSIST HYPERPLAS THYMUS */
'2541 ' = 51 /* ABSCESS OF THYMUS */
'2548 ' = 51 /* DISEASES OF THYMUS NEC */
'2549 ' = 51 /* DISEASE OF THYMUS NOS */
'2550 ' = 51 /* CUSHING-s SYNDROME */
'2551 ' = 51 /* HYPERALDOSTERONISM */
'25510' = 51 /* Primary aldosteronism */
'25511' = 51 /* Glucocorticoid-remediable aldosteronism */
'25512' = 51 /* Conns syndrome */
'25513' = 51 /* Bartters syndrome */
'25514' = 51 /* Other secondary aldosteronism */
'2552 ' = 51 /* ADRENOGENITAL DISORDERS */
'2553 ' = 51 /* CORTICOADREN OVERACT NEC */
'2554 ' = 51 /* CORTICOADRENAL INSUFFIC */
'2555 ' = 51 /* ADRENAL HYPOFUNCTION NEC */
'2556 ' = 51 /* MEDULLOADRENAL HYPERFUNC */
'2558 ' = 51 /* ADRENAL DISORDER NEC */
'2559 ' = 51 /* ADRENAL DISORDER NOS */
'2560 ' = 51 /* HYPERESTROGENISM */
'2561 ' = 51 /* OVARIAN HYPERFUNC NEC */
'2562 ' = 51 /* POSTABLATIV OVARIAN FAIL */
'2563 ' = 51 /* OVARIAN FAILURE NEC */
'2564 ' = 51 /* POLYCYSTIC OVARIES */
'2568 ' = 51 /* OVARIAN DYSFUNCTION NEC */
'2569 ' = 51 /* OVARIAN DYSFUNCTION NOS */
'2570 ' = 51 /* TESTICULAR HYPERFUNCTION */
'2571 ' = 51 /* POSTABLAT TESTIC HYPOFUN */
'2572 ' = 51 /* TESTICULAR HYPOFUNC NEC */
'2578 ' = 51 /* TESTICULAR DYSFUNCT NEC */
'2579 ' = 51 /* TESTICULAR DYSFUNCT NOS */
'2580 ' = 51 /* WERMER-s SYNDROME */
'2581 ' = 51 /* COMB ENDOCR DYSFUNCT NEC */
'2588 ' = 51 /* POLYGLANDUL DYSFUNC NEC */
'2589 ' = 51 /* POLYGLANDUL DYSFUNC NOS */
'2590 ' = 51 /* DELAY SEXUAL DEVELOP NEC */
'2591 ' = 51 /* SEXUAL PRECOCITY NEC */
'2592 ' = 51 /* CARCINOID SYNDROME */
'2593 ' = 51 /* ECTOPIC HORMONE SECR NEC */
'2594 ' = 51 /* DWARFISM NEC */
'2595 ' = 51 /* ANDROGEN INSENSITVTY SYN */
'2598 ' = 51 /* ENDOCRINE DISORDERS NEC */
'2599 ' = 51 /* ENDOCRINE DISORDER NOS */
'260  ' = 52 /* KWASHIORKOR */
'261  ' = 52 /* NUTRITIONAL MARASMUS */
'262  ' = 52 /* OTH SEVERE MALNUTRITION */
'2630 ' = 52 /* MALNUTRITION MOD DEGREE */
'2631 ' = 52 /* MALNUTRITION MILD DEGREE */
'2632 ' = 52 /* ARREST DEVEL D/T MALNUTR */
'2638 ' = 52 /* PROTEIN-CAL MALNUTR NEC */
'2639 ' = 52 /* PROTEIN-CAL MALNUTR NOS */
'2640 ' = 52 /* VIT A CONJUNCTIV XEROSIS */
'2641 ' = 52 /* VIT A BITOT-s SPOT */
'2642 ' = 52 /* VIT A CORNEAL XEROSIS */
'2643 ' = 52 /* VIT A CORNEA ULCER/XEROS */
'2644 ' = 52 /* VIT A KERATOMALACIA */
'2645 ' = 52 /* VIT A NIGHT BLINDNESS */
'2646 ' = 52 /* VIT A DEF W CORNEAL SCAR */
'2647 ' = 52 /* VIT A OCULAR DEFIC NEC */
'2648 ' = 52 /* VITAMIN A DEFICIENCY NEC */
'2649 ' = 52 /* VITAMIN A DEFICIENCY NOS */
'2650 ' = 52 /* BERIBERI */
'2651 ' = 52 /* THIAMINE DEFIC NEC/NOS */
'2652 ' = 52 /* PELLAGRA */
'2660 ' = 52 /* ARIBOFLAVINOSIS */
'2661 ' = 52 /* VITAMIN B6 DEFICIENCY */
'2662 ' = 52 /* B-COMPLEX DEFIC NEC */
'2669 ' = 52 /* VITAMIN B DEFICIENCY NOS */
'267  ' = 52 /* ASCORBIC ACID DEFICIENCY */
'2680 ' = 52 /* RICKETS- ACTIVE */
'2681 ' = 52 /* RICKETS- LATE EFFECT */
'2682 ' = 52 /* OSTEOMALACIA NOS */
'2689 ' = 52 /* VITAMIN D DEFICIENCY NOS */
'2690 ' = 52 /* DEFICIENCY OF VITAMIN K */
'2691 ' = 52 /* VITAMIN DEFICIENCY NEC */
'2692 ' = 52 /* VITAMIN DEFICIENCY NOS */
'2693 ' = 52 /* MINERAL DEFICIENCY NEC */
'2698 ' = 52 /* NUTRITION DEFICIENCY NEC */
'2699 ' = 52 /* NUTRITION DEFICIENCY NOS */
'2700 ' = 58 /* AMINO-ACID TRANSPORT DIS */
'2701 ' = 58 /* PHENYLKETONURIA - PKU */
'2702 ' = 58 /* AROM AMIN-ACID METAB NEC */
'2703 ' = 58 /* BRAN-CHAIN AMIN-ACID DIS */
'2704 ' = 58 /* SULPH AMINO-ACID MET DIS */
'2705 ' = 58 /* DIS HISTIDINE METABOLISM */
'2706 ' = 58 /* DIS UREA CYCLE METABOL */
'2707 ' = 58 /* STRAIG AMIN-ACID MET NEC */
'2708 ' = 58 /* DIS AMINO-ACID METAB NEC */
'2709 ' = 58 /* DIS AMINO-ACID METAB NOS */
'2710 ' = 58 /* GLYCOGENOSIS */
'2711 ' = 58 /* GALACTOSEMIA */
'2712 ' = 58 /* HERED FRUCTOSE INTOLERAN */
'2713 ' = 58 /* DISACCHARIDASE DEF/MALAB */
'2714 ' = 58 /* RENAL GLYCOSURIA */
'2718 ' = 58 /* DIS CARBOHYDR METAB NEC */
'2719 ' = 58 /* DIS CARBOHYDR METAB NOS */
'2725 ' = 58 /* LIPOPROTEIN DEFICIENCIES */
'2726 ' = 58 /* LIPODYSTROPHY */
'2727 ' = 58 /* LIPIDOSES */
'2728 ' = 58 /* LIPOID METABOL DIS NEC */
'2729 ' = 58 /* LIPOID METABOL DIS NOS */
'2730 ' = 58 /* POLYCLON HYPERGAMMAGLOBU */
'2731 ' = 58 /* MONOCLON PARAPROTEINEMIA */
'2732 ' = 58 /* PARAPROTEINEMIA NEC */
'2733 ' = 58 /* MACROGLOBULINEMIA */
'2734 ' = 58 /* ALPHA-1-ANTITRYPSIN DEF */
'2738 ' = 58 /* DIS PLAS PROTEIN MET NEC */
'2739 ' = 58 /* DIS PLAS PROTEIN MET NOS */
'2750 ' = 58 /* DIS IRON METABOLISM */
'2751 ' = 58 /* DIS COPPER METABOLISM */
'2752 ' = 58 /* DIS MAGNESIUM METABOLISM */
'2753 ' = 58 /* DIS PHOSPHORUS METABOL */
'2754 ' = 58 /* DIS CALCIUM METABOLISM */
'27540' = 58 /* UNSPEC DISORDER CALCIUM METAB OCT97 */
'27541' = 58 /* HYPOCALCEMIA OCT97 */
'27542' = 58 /* HYPERCALCEMIA OCT97 */
'27549' = 58 /* OT DISORDER OF CALCIUM METAB OCT97 */
'2758 ' = 58 /* DIS MINERAL METABOL NEC */
'2759 ' = 58 /* DIS MINERAL METABOL NOS */
'27700' = 56 /* CYSTIC FIBROS W/O ILEUS */
'27701' = 56 /* CYSTIC FIBROSIS W ILEUS- */
'27702' = 56 /* CYSTIC FIBROSIS W PULM MANFSTATNS OCT02 */
'27703' = 56 /* CYSTIC FIBROSIS W GASTRO MANFSTATNS OCT02 */
'27709' = 56 /* CYSTIC FIBROSIS W OTHER MANFSTATNS  OCT02 */
'2771 ' = 58 /* DIS PORPHYRIN METABOLISM */
'2772 ' = 58 /* PURINE/PYRIMID DIS NEC */
'2773 ' = 58 /* AMYLOIDOSIS */
'27730' = 58 /* AMYLOIDOSIS NOS */
'27731' = 58 /* FAM MEDITERRANEAN FEVER */
'27739' = 58 /* AMYLOIDOSIS NEC */
'2774 ' = 58 /* DIS BILIRUBIN EXCRETION */
'2775 ' = 58 /* MUCOPOLYSACCHARIDOSIS */
'2776 ' = 58 /* DEFIC CIRCUL ENZYME NEC */
'2777 ' = 58 /* DYSMETABOLIC SYNDROME X OCT01 */
'2778 ' = 58 /* METABOLISM DISORDER NEC */
'27781' = 58 /* Primary carnitine deficiency */
'27782' = 58 /* Carnitine deficiency due to inborn errors of */
'27784' = 58 /* Other secondary carnitine deficiency */
'27785' = 58 /* DISORDERS ACID OXIDATION */
'27786' = 58 /* PEROXISOMAL DISORDERS */
'27787' = 58 /* DIS MITOCHONDRIAL METAB */
'27789' = 58 /* Other specified disorders of metabolism */
'2779 ' = 58 /* METABOLISM DISORDER NOS */
'2780 ' = 58 /* OBESITY */
'27800' = 58 /* OBESITY UNSPECIFIED OCT95 */
'27801' = 58 /* MORBID OBESITY OCT95 */
'27802' = 58 /* OVERWEIGHT */
'2781 ' = 58 /* LOCALIZED ADIPOSITY */
'2782 ' = 58 /* HYPERVITAMINOSIS A */
'2783 ' = 58 /* HYPERCAROTINEMIA */
'2784 ' = 58 /* HYPERVITAMINOSIS D */
'2788 ' = 58 /* OTHER HYPERALIMENTATION */
'27900' = 57 /* HYPOGAMMAGLOBULINEM NOS */
'27901' = 57 /* SELECTIVE IGA IMMUNODEF */
'27902' = 57 /* SELECTIVE IGM IMMUNODEF */
'27903' = 57 /* SELECTIVE IG DEFIC NEC */
'27904' = 57 /* CONG HYPOGAMMAGLOBULINEM */
'27905' = 57 /* IMMUNODEFIC W HYPER-IGM */
'27906' = 57 /* COMMON VARIABL IMMUNODEF */
'27909' = 57 /* HUMORAL IMMUNITY DEF NEC */
'27911' = 57 /* DIGEORGE-s SYNDROME */
'27912' = 57 /* WISKOTT-ALDRICH SYNDROME */
'27913' = 57 /* NEZELOF-s SYNDROME */
'2792 ' = 57 /* COMBINED IMMUNITY DEFIC */
'2793 ' = 57 /* IMMUNITY DEFICIENCY NOS */
'2794 ' = 57 /* AUTOIMMUNE DISEASE NEC */
'2798 ' = 57 /* IMMUNE MECHANISM DIS NEC */
'2799 ' = 57 /* IMMUNE MECHANISM DIS NOS */
'2860 ' = 62 /* CONG FACTOR VIII DIORD */
'2861 ' = 62 /* CONG FACTOR IX DISORDER */
'2862 ' = 62 /* CONG FACTOR XI DISORDER */
'2863 ' = 62 /* CONG DEF CLOT FACTOR NEC */
'2864 ' = 62 /* VON WILLEBRAND-S DISEASE */
'2869 ' = 62 /* COAGULAT DEFECT NEC/NOS */
'2870 ' = 62 /* ALLERGIC PURPURA */
'2871 ' = 62 /* THROMBOCYTOPATHY */
'2872 ' = 62 /* PURPURA NOS */
'2873 ' = 62 /* PRIMARY THROMBOCYTOPENIA */
'28730' = 62 /* PRIM THROMBOCYTOPEN NOS */
'28731' = 62 /* IMMUNE THROMBOCYT PURPRA */
'28732' = 62 /* EVANS SYNDROME */
'28733' = 62 /* CONG-HERID THROMB PURPRA */
'28739' = 62 /* PRIM THROMBOCYTOPEN NEC */
'2875 ' = 62 /* THROMBOCYTOPENIA NOS */
'2878 ' = 62 /* HEMORRHAGIC COND NEC */
'2879 ' = 62 /* HEMORRHAGIC COND NOS */
'2880 ' = 63 /* AGRANULOCYTOSIS */
'28800' = 63 /* NEUTROPENIA NOS */
'28801' = 63 /* CONGENITAL NEUTROPENIA */
'28802' = 63 /* CYCLIC NEUTROPENIA */
'28803' = 63 /* DRUG INDUCED NEUTROPENIA */
'28804' = 63 /* NEUTROPENIA D/T INFECTN */
'28809' = 63 /* NEUTROPENIA NEC */
'2881 ' = 63 /* FUNCTION DIS NEUTROPHILS */
'2882 ' = 63 /* GENETIC ANOMALY LEUKOCYT */
'2883 ' = 63 /* EOSINOPHILIA */
'2884 ' = 63 /* HEMOPHAGOCYTIC SYNDROMES */
'28850' = 63 /* LEUKOCYTOPENIA NOS */
'28851' = 63 /* LYMPHOCYTOPENIA */
'28859' = 63 /* DECREASED WBC COUNT NEC */
'28860' = 63 /* LEUKOCYTOSIS NOS */
'28861' = 63 /* LYMPHOCYTOSIS-SYMPTOMATC */
'28862' = 63 /* LEUKEMOID REACTION */
'28863' = 63 /* MONOCYTOSIS-SYMPTOMATIC */
'28864' = 63 /* PLASMACYTOSIS */
'28865' = 63 /* BASOPHILIA */
'28869' = 63 /* ELEVATED WBC COUNT NEC */
'2888 ' = 63 /* WBC DISEASE NEC */
'2889 ' = 63 /* WBC DISEASE NOS */
'28953' = 63 /* NEUTROPENIC SPLENOMEGALY */
'28981' = 62 /* PRIMARY HYPERCOAGULABLE STATE */
'2920 ' = 67 /* DRUG WITHDRAWAL SYNDROME */
'29211' = 67 /* DRUG PARANOID STATE */
'29212' = 67 /* DRUG HALLUCINOSIS */
'2922 ' = 67 /* PATHOLOGIC DRUG INTOX */
'29281' = 67 /* DRUG-INDUCED DELIRIUM */
'29282' = 67 /* DRUG-INDUCED DEMENTIA */
'29283' = 67 /* DRUG AMNESTIC SYNDROME */
'29284' = 67 /* DRUG DEPRESSIVE SYNDROME */
'29285' = 67 /* DRUG INDUCED SLEEP DISOR */
'29289' = 67 /* DRUG MENTAL DISORDER NEC */
'2929 ' = 67 /* DRUG MENTAL DISORDER NOS */
'30400' = 67 /* OPIOID DEPENDENCE-UNSPEC */
'30401' = 67 /* OPIOID DEPENDENCE-CONTIN */
'30402' = 67 /* OPIOID DEPENDENCE-EPISOD */
'30403' = 67 /* OPIOID DEPENDENCE-REMISS */
'30410' = 67 /* BARBITURAT DEPEND-UNSPEC */
'30411' = 67 /* BARBITURAT DEPEND-CONTIN */
'30412' = 67 /* BARBITURAT DEPEND-EPISOD */
'30413' = 67 /* BARBITURAT DEPEND-REMISS */
'30420' = 67 /* COCAINE DEPEND-UNSPEC */
'30421' = 67 /* COCAINE DEPEND-CONTIN */
'30422' = 67 /* COCAINE DEPEND-EPISODIC */
'30423' = 67 /* COCAINE DEPEND-REMISS */
'30430' = 67 /* CANNABIS DEPEND-UNSPEC */
'30431' = 67 /* CANNABIS DEPEND-CONTIN */
'30432' = 67 /* CANNABIS DEPEND-EPISODIC */
'30433' = 67 /* CANNABIS DEPEND-REMISS */
'30440' = 67 /* AMPHETAMIN DEPEND-UNSPEC */
'30441' = 67 /* AMPHETAMIN DEPEND-CONTIN */
'30442' = 67 /* AMPHETAMIN DEPEND-EPISOD */
'30443' = 67 /* AMPHETAMIN DEPEND-REMISS */
'30450' = 67 /* HALLUCINOGEN DEP-UNSPEC */
'30451' = 67 /* HALLUCINOGEN DEP-CONTIN */
'30452' = 67 /* HALLUCINOGEN DEP-EPISOD */
'30453' = 67 /* HALLUCINOGEN DEP-REMISS */
'30460' = 67 /* DRUG DEPEND NEC-UNSPEC */
'30461' = 67 /* DRUG DEPEND NEC-CONTIN */
'30462' = 67 /* DRUG DEPEND NEC-EPISODIC */
'30463' = 67 /* DRUG DEPEND NEC-IN REM */
'30470' = 67 /* OPIOID/OTHER DEP-UNSPEC */
'30471' = 67 /* OPIOID/OTHER DEP-CONTIN */
'30472' = 67 /* OPIOID/OTHER DEP-EPISOD */
'30473' = 67 /* OPIOID/OTHER DEP-REMISS */
'30480' = 67 /* COMB DRUG DEP NEC-UNSPEC */
'30481' = 67 /* COMB DRUG DEP NEC-CONTIN */
'30482' = 67 /* COMB DRUG DEP NEC-EPISOD */
'30483' = 67 /* COMB DRUG DEP NEC-REMISS */
'30490' = 67 /* DRUG DEPEND NOS-UNSPEC */
'30491' = 67 /* DRUG DEPEND NOS-CONTIN */
'30492' = 67 /* DRUG DEPEND NOS-EPISODIC */
'30493' = 67 /* DRUG DEPEND NOS-REMISS */
'3051 ' = 67 /* TOBACCO USE DISORDER  OCT94 */
'30510' = 67 /* TOBACCO ABUSE-UNSPEC */
'30511' = 67 /* TOBACCO ABUSE-CONTINUOUS */
'30512' = 67 /* TOBACCO ABUSE-EPISODIC */
'30513' = 67 /* TOBACCO ABUSE-IN REMISS */
'30520' = 67 /* CANNABIS ABUSE-UNSPEC */
'30521' = 67 /* CANNABIS ABUSE-CONTIN */
'30522' = 67 /* CANNABIS ABUSE-EPISODIC */
'30523' = 67 /* CANNABIS ABUSE-IN REMISS */
'30530' = 67 /* HALLUCINOG ABUSE-UNSPEC */
'30531' = 67 /* HALLUCINOG ABUSE-CONTIN */
'30532' = 67 /* HALLUCINOG ABUSE-EPISOD */
'30533' = 67 /* HALLUCINOG ABUSE-REMISS */
'30540' = 67 /* BARBITURATE ABUSE-UNSPEC */
'30541' = 67 /* BARBITURATE ABUSE-CONTIN */
'30542' = 67 /* BARBITURATE ABUSE-EPISOD */
'30543' = 67 /* BARBITURATE ABUSE-REMISS */
'30550' = 67 /* OPIOID ABUSE-UNSPEC */
'30551' = 67 /* OPIOID ABUSE-CONTINUOUS */
'30552' = 67 /* OPIOID ABUSE-EPISODIC */
'30553' = 67 /* OPIOID ABUSE-IN REMISS */
'30560' = 67 /* COCAINE ABUSE-UNSPEC */
'30561' = 67 /* COCAINE ABUSE-CONTINUOUS */
'30562' = 67 /* COCAINE ABUSE-EPISODIC */
'30563' = 67 /* COCAINE ABUSE-IN REMISS */
'30570' = 67 /* AMPHETAMINE ABUSE-UNSPEC */
'30571' = 67 /* AMPHETAMINE ABUSE-CONTIN */
'30572' = 67 /* AMPHETAMINE ABUSE-EPISOD */
'30573' = 67 /* AMPHETAMINE ABUSE-REMISS */
'30580' = 67 /* ANTIDEPRESS ABUSE-UNSPEC */
'30581' = 67 /* ANTIDEPRESS ABUSE-CONTIN */
'30582' = 67 /* ANTIDEPRESS ABUSE-EPISOD */
'30583' = 67 /* ANTIDEPRESS ABUSE-REMISS */
'30590' = 67 /* DRUG ABUSE NEC-UNSPEC */
'30591' = 67 /* DRUG ABUSE NEC-CONTIN */
'30592' = 67 /* DRUG ABUSE NEC-EPISODIC */
'30593' = 67 /* DRUG ABUSE NEC-IN REMISS */
'3158 ' = 65 /* DEVELOPMENT DELAYS NEC */
'3159 ' = 65 /* DEVELOPMENT DELAY NOS */
'317  ' = 65 /* MILD MENTAL RETARDATION */
'3180 ' = 65 /* MOD MENTAL RETARDATION */
'3181 ' = 65 /* SEVERE MENTAL RETARDAT */
'3182 ' = 65 /* PROFOUND MENTAL RETARDAT */
'319  ' = 65 /* MENTAL RETARDATION NOS- */
'325  ' = 95 /* PHLEBITIS INTRCRAN SINUS */
'32752' = 211 /* SLEEP RELATED LEG CRAMPS */
'3300 ' = 81 /* LEUKODYSTROPHY */
'3301 ' = 81 /* CEREBRAL LIPIDOSES */
'3302 ' = 81 /* CEREB DEGEN IN LIPIDOSIS */
'3303 ' = 81 /* CERB DEG CHLD IN OTH DIS */
'3308 ' = 81 /* CEREB DEGEN IN CHILD NEC */
'3309 ' = 81 /* CEREB DEGEN IN CHILD NOS */
'3313 ' = 81 /* COMMUNICAT HYDROCEPHALUS */
'3314 ' = 81 /* OBSTRUCTIV HYDROCEPHALUS */
'3317 ' = 81 /* CEREB DEGEN IN OTH DIS */
'33181' = 81 /* REYE-S SYNDROME */
'33189' = 81 /* CEREB DEGENERATION NEC */
'3319 ' = 81 /* CEREB DEGENERATION NOS */
'3321 ' = 95 /* SECONDARY PARKINSONISM */
'3330 ' = 81 /* DEGEN BASAL GANGLIA NEC */
'3331 ' = 81 /* TREMOR NEC */
'3332 ' = 81 /* MYOCLONUS */
'3333 ' = 81 /* TICS OF ORGANIC ORIGIN */
'3334 ' = 81 /* HUNTINGTON-S CHOREA */
'3335 ' = 81 /* CHOREA NEC */
'3336 ' = 81 /* IDIOPAT TORSION DYSTONIA */
'3337 ' = 81 /* SYMPTOM TORSION DYSTONIA */
'33371' = 81 /* ATHETOID CEREBRAL PALSY */
'33372' = 81 /* ACUTE DYSTONIA D/T DRUGS */
'33379' = 81 /* ACQ TORSION DYSTONIA NEC */
'33381' = 81 /* BLEPHAROSPASM */
'33382' = 81 /* OROFACIAL DYSKINESIA */
'33383' = 81 /* SPASMODIC TORTICOLLIS */
'33384' = 81 /* ORGANIC WRITERS CRAMP */
'33385' = 81 /* SUBAC DYSKINESA D/T DRUG */
'33389' = 81 /* FRAGM TORSION DYSTON NEC */
'33390' = 81 /* EXTRAPYRAMIDAL DIS NOS */
'33391' = 81 /* STIFF-MAN SYNDROME */
'33392' = 81 /* NEUROLEPTIC MALIGNANT SYND OCT94 */
'33393' = 81 /* BENIGN SHUDDERING ATTACKS OCT94 */
'33394' = 81 /* RESTLESS LEGS SYNDROME */
'33399' = 81 /* EXTRAPYRAMIDAL DIS NEC */
'3340 ' = 81 /* FRIEDREICH-S ATAXIA */
'3341 ' = 81 /* HERED SPASTIC PARAPLEGIA */
'3342 ' = 81 /* PRIMARY CEREBELLAR DEGEN */
'3343 ' = 81 /* CEREBELLAR ATAXIA NEC */
'3344 ' = 81 /* CEREBEL ATAX IN OTH DIS */
'3348 ' = 81 /* SPINOCEREBELLAR DIS NEC */
'3349 ' = 81 /* SPINOCEREBELLAR DIS NOS */
'3350 ' = 81 /* WERDNIG-HOFFMANN DISEASE */
'33510' = 81 /* SPINAL MUSCL ATROPHY NOS */
'33511' = 81 /* KUGELBERG-WELANDER DIS */
'33519' = 81 /* SPINAL MUSCL ATROPHY NEC */
'33520' = 81 /* AMYOTROPHIC SCLEROSIS */
'33521' = 81 /* PROG MUSCULAR ATROPHY */
'33522' = 81 /* PROGRESSIVE BULBAR PALSY */
'33523' = 81 /* PSEUDOBULBAR PALSY */
'33524' = 81 /* PRIM LATERAL SCLEROSIS */
'33529' = 81 /* MOTOR NEURON DISEASE NEC */
'3358 ' = 81 /* ANT HORN CELL DIS NEC */
'3359 ' = 81 /* ANT HORN CELL DIS NOS */
'3360 ' = 81 /* SYRINGOMYELIA */
'3361 ' = 81 /* VASCULAR MYELOPATHIES */
'3362 ' = 81 /* COMB DEG CORD IN OTH DIS */
'3363 ' = 81 /* MYELOPATHY IN OTH DIS */
'3368 ' = 81 /* MYELOPATHY NEC */
'3369 ' = 81 /* SPINAL CORD DISEASE NOS */
'3370 ' = 81 /* IDIOPATH AUTO NEUROPATHY */
'3371 ' = 81 /* AUT NEUROPTHY IN OTH DIS */
'33720' = 95 /* REFLEX SYMPATH DYSTROPHY UNSPEC OCT93 */
'33721' = 95 /* REFLEX SYMPATH DYSTROPHY UP LIMB OCT93 */
'33722' = 95 /* REFLEX SYMPATH DYSTROPHY LO LIMB OCT93 */
'33729' = 95 /* REFLEX SYMPATH DYSTR OTH SPEC SITE OCT93 */
'3373 ' = 81 /* AUTONOMIC DYSREFLEXIA OCT98 */
'3379 ' = 81 /* AUTONOMIC NERVE DIS NEC */
'3380 ' = 95 /* CENTRAL PAIN SYNDROME */
'33811' = 95 /* ACUTE PAIN DUE TO TRAUMA */
'33812' = 95 /* ACUTE POST-THORACOT PAIN */
'33818' = 95 /* ACUTE POSTOP PAIN NEC */
'33819' = 95 /* ACUTE PAIN NEC */
'33821' = 95 /* CHRONC PAIN D/T TRAUMA */
'33822' = 95 /* CHRON POST-THORACOT PAIN */
'33828' = 95 /* CHRONIC POSTOP PAIN NEC */
'33829' = 95 /* CHRONIC PAIN NEC */
'3383 ' = 95 /* NEOPLASM RELATED PAIN */
'3384 ' = 95 /* CHRONIC PAIN SYNDROME */
'3410 ' = 95 /* NEUROMYELITIS OPTICA */
'3411 ' = 95 /* SCHILDER-s DISEASE */
'3418 ' = 95 /* CNS DEMYELINATION NEC */
'3419 ' = 95 /* CNS DEMYELINATION NOS */
'3420 ' = 82 /* FLACCID HEMIPLEGIA */
'34200' = 82 /* FLACCID HEMIPLEG- UNSPEC SIDE OCT94 */
'34201' = 82 /* FLACCID HEMIPLEG- DOMINANT SIDE OCT94 */
'34202' = 82 /* FLACCID HEMIPLEG- NONDOMINANT SIDE OCT94 */
'3421 ' = 82 /* SPASTIC HEMIPLEGIA */
'34210' = 82 /* SPASTIC HEMIPLEG- UNSPEC SIDE OCT94 */
'34211' = 82 /* SPASTIC HEMIPLEG- DOMINANT SIDE OCT94 */
'34212' = 82 /* SPASTIC HEMIPLEG- NONDOMINANT SIDE OCT94 */
'34280' = 82 /* OTH SPEC HEMIPLEGIA- UNSPEC SIDE OCT94 */
'34281' = 82 /* OTH SPEC HEMIPLEGIA- DOMINANT SIDE OCT94 */
'34282' = 82 /* OTH SPEC HEMIPLEGIA- NONDOMINANT SIDE OCT94 */
'3429 ' = 82 /* HEMIPLEGIA NOS */
'34290' = 82 /* UNSPEC HEMIPLEGIA- UNSPEC SIDE OCT94 */
'34291' = 82 /* UNSPEC HEMIPLEGIA- DOMINANT SIDE OCT94 */
'34292' = 82 /* UNSPEC HEMIPLEGIA- NONDOMINANT SIDE OCT94 */
'3430 ' = 82 /* CONGENITAL DIPLEGIA */
'3431 ' = 82 /* CONGENITAL HEMIPLEGIA */
'3432 ' = 82 /* CONGENITAL QUADRIPLEGIA */
'3433 ' = 82 /* CONGENITAL MONOPLEGIA */
'3434 ' = 82 /* INFANTILE HEMIPLEGIA */
'3438 ' = 82 /* CEREBRAL PALSY NEC */
'3439 ' = 82 /* CEREBRAL PALSY NOS */
'3440 ' = 82 /* QUADRIPLEGIA NOS */
'34400' = 82 /* QUADRIPLEGIA- NOS OCT94 */
'34401' = 82 /* QUADRIPLEGIA- C1-C4 COMPLETE OCT94 */
'34402' = 82 /* QUADRIPLEGIA- C1-C4 INCOMPLETE OCT94 */
'34403' = 82 /* QUADRIPLEGIA- C5-C7 COMPLETE OCT94 */
'34404' = 82 /* QUADRIPLEGIA- C5-C7 INCOMPLETE OCT94 */
'34409' = 82 /* QUADRIPLEGIA- OTHER OCT94 */
'3441 ' = 82 /* PARAPLEGIA NOS */
'3442 ' = 82 /* DIPLEGIA OF UPPER LIMBS */
'3443 ' = 82 /* MONOPLEGIA OF LOWER LIMB */
'34430' = 82 /* MONOPLEGIA LEG NOS OCT94 */
'34431' = 82 /* MONOPLEGIA LEG AFFECT DOM SIDE OCT94 */
'34432' = 82 /* MONOPLEGIA LEG AFFECT NONDOM SIDE OCT94 */
'3444 ' = 82 /* MONOPLEGIA OF UPPER LIMB */
'34440' = 82 /* MONOPLEGIA ARM NOS OCT94 */
'34441' = 82 /* MONOPLEGIA ARM AFFECT DOM SIDE OCT94 */
'34442' = 82 /* MONOPLEGIA ARM AFFECT NONDOM SIDE OCT94 */
'3445 ' = 82 /* MONOPLEGIA NOS */
'34460' = 82 /* CAUDA EQUINA SYND NOS */
'34461' = 95 /* NEUROGENIC BLADDER */
'3448 ' = 82 /* PARALYTIC SYNDROMES NEC */
'34481' = 82 /* LOCKED-IN STATE OCT93 */
'34489' = 82 /* OTH SPEC PARALYTIC SYNDROMES OCT93 */
'3449 ' = 82 /* PARALYSIS NOS */
'3450 ' = 83 /* GEN NONCONVULS EPILEPSY J80  S89 */
'34500' = 83 /* GEN NONCV EP W/O INTR EP  OCT89 */
'34501' = 83 /* GEN NONCONV EP W INTR EP  OCT89 */
'3451 ' = 83 /* GEN CONVULSIVE EPILEPSY J80  S89 */
'34510' = 83 /* GEN CNV EPIL W/O INTR EP  OCT89 */
'34511' = 83 /* GEN CNV EPIL W INTR EPIL  OCT89 */
'3452 ' = 83 /* PETIT MAL STATUS */
'3453 ' = 83 /* GRAND MAL STATUS */
'3454 ' = 83 /* PSYCHOMOTOR EPILEPSY   J80  S89 */
'34540' = 83 /* PSYMOTR EPIL W/O INT EPI OCT89 */
'34541' = 83 /* PSYMOTR EPIL W INTR EPIL OCT89 */
'3455 ' = 83 /* PARTIAL EPILEPSY NEC   J80  S89 */
'34550' = 83 /* PART EPIL W/O INTR EPIL  OCT89 */
'34551' = 83 /* PART EPIL W INTR EPIL  OCT89 */
'3456 ' = 83 /* INFANTILE SPASMS   J80  S89 */
'34560' = 83 /* INF SPASM W/O INTR EPIL  OCT89 */
'34561' = 83 /* INF SPASM W INTRACT EPIL OCT89 */
'3457 ' = 83 /* EPILEPS PARTIAL CONTINUA  J80  S89 */
'34570' = 83 /* EPIL PAR CONT W/O INT EP OCT89 */
'34571' = 83 /* EPIL PAR CONT W INTR EPI OCT89 */
'3458 ' = 83 /* EPILEPSY NEC     J80  S89 */
'34580' = 83 /* EPILEP NEC W/O INTR EPIL OCT89 */
'34581' = 83 /* EPILEPSY NEC W INTR EPIL OCT89 */
'3459 ' = 83 /* EPILEPSY NOS     J80  S89 */
'34590' = 83 /* EPILEP NOS W/O INTR EPIL OCT89 */
'34591' = 83 /* EPILEPSY NOS W INTR EPIL OCT89 */
'347  ' = 95 /* CATAPLEXY AND NARCOLEPSY */
'34700' = 95 /* NARCOLEPSY W/O CATAPLEXY */
'34701' = 95 /* NARCOLEPSY W CATAPLEXY */
'34710' = 95 /* NARCLPSY W/O CAT OTH DIS */
'34711' = 95 /* NARCOLEPSY W CAT OTH DIS */
'3480 ' = 95 /* CEREBRAL CYSTS */
'3481 ' = 85 /* ANOXIC BRAIN DAMAGE */
'3482 ' = 95 /* PSEUDOTUMOR CEREBRI */
'3483 ' = 95 /* ENCEPHALOPATHY NOS */
'34830' = 95 /* Encephalopathy- unspecified */
'34831' = 95 /* Metabolic encephalopathy */
'34839' = 95 /* Other encephalopathy */
'3484 ' = 95 /* COMPRESSION OF BRAIN */
'3485 ' = 95 /* CEREBRAL EDEMA */
'3488 ' = 95 /* BRAIN CONDITIONS NEC */
'3489 ' = 95 /* BRAIN CONDITION NOS */
'3492 ' = 95 /* DISORDER OF MENINGES NEC */
'34981' = 95 /* CEREBROSPINAL RHINORRHEA */
'34982' = 95 /* TOXIC ENCEPHALOPATHY */
'34989' = 95 /* CNS DISORDER NEC */
'3499 ' = 95 /* CNS DISORDER NOS */
'3501 ' = 95 /* TRIGEMINAL NEURALGIA */
'3502 ' = 95 /* ATYPICAL FACE PAIN */
'3508 ' = 95 /* TRIGEMINAL NERVE DIS NEC */
'3509 ' = 95 /* TRIGEMINAL NERVE DIS NOS */
'3510 ' = 95 /* BELL-s PALSY */
'3511 ' = 95 /* GENICULATE GANGLIONITIS */
'3518 ' = 95 /* FACIAL NERVE DIS NEC */
'3519 ' = 95 /* FACIAL NERVE DIS NOS */
'3520 ' = 95 /* OLFACTORY NERVE DISORDER */
'3521 ' = 95 /* GLOSSOPHARYNG NEURALGIA */
'3522 ' = 95 /* GLOSSOPHAR NERVE DIS NEC */
'3523 ' = 95 /* PNEUMOGASTRIC NERVE DIS */
'3524 ' = 95 /* ACCESSORY NERVE DISORDER */
'3525 ' = 95 /* HYPOGLOSSAL NERVE DIS */
'3526 ' = 95 /* MULT CRANIAL NERVE PALSY */
'3529 ' = 95 /* CRANIAL NERVE DIS NOS */
'3530 ' = 95 /* BRACHIAL PLEXUS LESIONS */
'3531 ' = 95 /* LUMBOSACRAL PLEX LESION */
'3532 ' = 95 /* CERVICAL ROOT LESION NEC */
'3533 ' = 95 /* THORACIC ROOT LESION NEC */
'3534 ' = 95 /* LUMBSACRAL ROOT LES NEC */
'3535 ' = 95 /* NEURALGIC AMYOTROPHY */
'3536 ' = 95 /* PHANTOM LIMB (SYNDROME) */
'3538 ' = 95 /* NERV ROOT/PLEXUS DIS NEC */
'3539 ' = 95 /* NERV ROOT/PLEXUS DIS NOS */
'3540 ' = 95 /* CARPAL TUNNEL SYNDROME */
'3541 ' = 95 /* MEDIAN NERVE LESION NEC */
'3542 ' = 95 /* ULNAR NERVE LESION */
'3543 ' = 95 /* RADIAL NERVE LESION */
'3544 ' = 95 /* CAUSALGIA */
'3545 ' = 95 /* MONONEURITIS MULTIPLEX */
'3548 ' = 95 /* MONONEURITIS ARM NEC */
'3549 ' = 95 /* MONONEURITIS ARM NOS */
'3550 ' = 95 /* SCIATIC NERVE LESION */
'3551 ' = 95 /* MERALGIA PARESTHETICA */
'3552 ' = 95 /* FEMORAL NERVE LESION NEC */
'3553 ' = 95 /* LAT POPLITEAL NERVE LES */
'3554 ' = 95 /* MED POPLITEAL NERVE LES */
'3555 ' = 95 /* TARSAL TUNNEL SYNDROME */
'3556 ' = 95 /* PLANTAR NERVE LESION */
'3557 ' = 95 /* MONONEURITIS LEG NEC */
'35571' = 95 /* CAUSALGIA OF LOWER LIMB OCT93 */
'35579' = 95 /* OTH MONONEURITIS OF LOWER LIMB OCT93 */
'3558 ' = 95 /* MONONEURITIS LEG NOS */
'3559 ' = 95 /* MONONEURITIS NOS */
'3560 ' = 95 /* HERED PERIPH NEUROPATHY */
'3561 ' = 95 /* PERONEAL MUSCLE ATROPHY */
'3562 ' = 95 /* HERED SENSORY NEUROPATHY */
'3563 ' = 95 /* REFSUM-s DISEASE */
'3564 ' = 95 /* IDIO PROG POLYNEUROPATHY */
'3568 ' = 95 /* IDIO PERIPH NEURPTHY NEC */
'3569 ' = 95 /* IDIO PERIPH NEURPTHY NOS */
'3570 ' = 95 /* AC INFECT POLYNEURITIS */
'3571 ' = 95 /* NEURPTHY IN COL VASC DIS */
'3572 ' = 95 /* NEUROPATHY IN DIABETES */
'3573 ' = 95 /* NEUROPATHY IN MALIG DIS */
'3574 ' = 95 /* NEUROPATHY IN OTHER DIS */
'3575 ' = 95 /* ALCOHOLIC POLYNEUROPATHY */
'3576 ' = 95 /* NEUROPATHY DUE TO DRUGS */
'3577 ' = 95 /* NEURPTHY TOXIC AGENT NEC */
'3578 ' = 95 /* INFLAM/TOX NEUROPTHY NEC */
'35781' = 95 /* CHRONIC INFLAMM DEMYELINATING PLYNEUR OCT02 */
'35782' = 95 /* CRITICAL ILLNESS POLYNEUROPATHY   OCT02 */
'35789' = 95 /* OTHER INFLAMMATORY AND TOX NEUROPATHY OCT02 */
'3579 ' = 95 /* INFLAM/TOX NEUROPTHY NOS */
'3580 ' = 95 /* MYASTHENIA GRAVIS */
'35800' = 95 /* Myasthenia gravis without (acute) exacerbatio */
'35801' = 95 /* Myasthenia gravis with (acute) exacerbation */
'3581 ' = 95 /* MYASTHENIA IN OTH DIS */
'3582 ' = 95 /* TOXIC MYONEURAL DISORDER */
'3588 ' = 95 /* MYONEURAL DISORDERS NEC */
'3589 ' = 95 /* MYONEURAL DISORDERS NOS */
'3590 ' = 95 /* CONG HERED MUSC DYSTRPHY */
'3591 ' = 95 /* HERED PROG MUSC DYSTRPHY */
'3592 ' = 95 /* MYOTONIC DISORDERS */
'3593 ' = 95 /* FAMIL PERIODIC PARALYSIS */
'3594 ' = 95 /* TOXIC MYOPATHY */
'3595 ' = 95 /* MYOPATHY IN ENDOCRIN DIS */
'3596 ' = 95 /* INFL MYOPATHY IN OTH DIS */
'3598 ' = 95 /* MYOPATHY NEC */
'35981' = 95 /* CRITICAL ILLNESS MYOPATHY    OCT02 */
'35989' = 95 /* OTHER MYOPATHIES       OCT02 */
'3599 ' = 95 /* MYOPATHY NOS */
'3940 ' = 96 /* MITRAL STENOSIS */
'3941 ' = 96 /* RHEUMATIC MITRAL INSUFF */
'3942 ' = 96 /* MITRAL STENOSIS W INSUFF */
'3949 ' = 96 /* MITRAL VALVE DIS NEC/NOS */
'3950 ' = 96 /* RHEUMAT AORTIC STENOSIS */
'3951 ' = 96 /* RHEUMATIC AORTIC INSUFF */
'3952 ' = 96 /* RHEUM AORTIC STEN/INSUFF */
'3959 ' = 96 /* RHEUM AORTIC DIS NEC/NOS */
'3960 ' = 96 /* MITRAL/AORTIC STENOSIS */
'3961 ' = 96 /* MITRAL STENOS/AORT INSUF */
'3962 ' = 96 /* MITRAL INSUF/AORT STENOS */
'3963 ' = 96 /* MITRAL/AORTIC VAL INSUFF */
'3968 ' = 96 /* MITR/AORTIC MULT INVOLV */
'3969 ' = 96 /* MITRAL/AORTIC V DIS NOS */
'3970 ' = 96 /* TRICUSPID VALVE DISEASE */
'3971 ' = 96 /* RHEUM PULMON VALVE DIS */
'3979 ' = 96 /* RHEUM ENDOCARDITIS NOS */
'39891' = 108 /* RHEUMATIC HEART FAILURE */
'4011 ' = 98 /* BENIGN HYPERTENSION */
'4019 ' = 98 /* HYPERTENSION NOS */
'4150 ' = 103 /* ACUTE COR PULMONALE */
'4151 ' = 103 /* PULMON EMBOLISM/INFARCT */
'41519' = 103 /* OTHER PULMON EMBOL INFARCT OCT95 */
'4160 ' = 103 /* PRIM PULM HYPERTENSION */
'4161 ' = 103 /* KYPHOSCOLIOTIC HEART DIS */
'4168 ' = 103 /* CHR PULMON HEART DIS NEC */
'4169 ' = 103 /* CHR PULMON HEART DIS NOS */
'4170 ' = 103 /* ARTERIOVEN FISTU PUL VES */
'4171 ' = 103 /* PULMON ARTERY ANEURYSM */
'4178 ' = 103 /* PULMON CIRCULAT DIS NEC */
'4179 ' = 103 /* PULMON CIRCULAT DIS NOS */
'4240 ' = 96 /* MITRAL VALVE DISORDER */
'4241 ' = 96 /* AORTIC VALVE DISORDER */
'4242 ' = 96 /* NONRHEUM TRICUSP VAL DIS */
'4243 ' = 96 /* PULMONARY VALVE DISORDER */
'42490' = 96 /* ENDOCARDITIS NOS */
'42491' = 96 /* ENDOCARDITIS IN OTH DIS */
'42499' = 96 /* ENDOCARDITIS NEC */
'4254 ' = 108 /* PRIM CARDIOMYOPATHY NEC */
'4260 ' = 105 /* ATRIOVENT BLOCK COMPLETE */
'42610' = 105 /* ATRIOVENT BLOCK NOS */
'42611' = 105 /* ATRIOVENT BLOCK-1ST DEGR */
'42612' = 105 /* ATRIOVEN BLOCK-MOBITZ II */
'42613' = 105 /* AV BLOCK-2ND DEGREE NEC */
'4262 ' = 105 /* LEFT BB HEMIBLOCK */
'4263 ' = 105 /* LEFT BB BLOCK NEC */
'4264 ' = 105 /* RT BUNDLE BRANCH BLOCK */
'42650' = 105 /* BUNDLE BRANCH BLOCK NOS */
'42651' = 105 /* RT BBB/LFT POST FASC BLK */
'42652' = 105 /* RT BBB/LFT ANT FASC BLK */
'42653' = 105 /* BILAT BB BLOCK NEC */
'42654' = 105 /* TRIFASCICULAR BLOCK */
'4266 ' = 105 /* OTHER HEART BLOCK */
'4267 ' = 105 /* ANOMALOUS AV EXCITATION */
'42681' = 105 /* LOWN-GANONG-LEVINE SYND */
'42689' = 105 /* CONDUCTION DISORDER NEC */
'4269 ' = 105 /* CONDUCTION DISORDER NOS */
'4270 ' = 106 /* PAROX ATRIAL TACHYCARDIA */
'4271 ' = 106 /* PAROX VENTRIC TACHYCARD */
'4272 ' = 106 /* PAROX TACHYCARDIA NOS */
'42731' = 106 /* ATRIAL FIBRILLATION */
'42732' = 106 /* ATRIAL FLUTTER */
'42760' = 106 /* PREMATURE BEATS NOS */
'42761' = 106 /* ATRIAL PREMATURE BEATS */
'42769' = 106 /* PREMATURE BEATS NEC */
'42781' = 106 /* SINOATRIAL NODE DYSFUNCT */
'42789' = 106 /* CARDIAC DYSRHYTHMIAS NEC */
'4279 ' = 106 /* CARDIAC DYSRHYTHMIA NOS */
'4280 ' = 108 /* CONGESTIVE HEART FAILURE */
'4281 ' = 108 /* LEFT HEART FAILURE */
'42820' = 108 /* UNSPECIFIED SYSTOLIC HEART FAILURE OCT02 */
'42821' = 108 /* ACUTE SYSTOLIC HEART FAILURE OCT02 */
'42822' = 108 /* CHRONIC SYSTOLIC HEART FAILURE   OCT02 */
'42823' = 108 /* ACUTE ON CHRONIC SYSTOLIC HEART FAILR OCT02 */
'42830' = 108 /* UNSPECIFIED DIASTOLIC HEART FAILURE  OCT02 */
'42831' = 108 /* ACUTE DIASTOLIC HEART FAILURE    OCT02 */
'42832' = 108 /* CHRONIC DIASTOLIC HEART FAILURE  OCT02 */
'42833' = 108 /* ACUTE ON CHRONIC DIASTOLIC HEART FAILR OCT0 */
'42840' = 108 /* UNSPEC CMBINED SYST & DIAS HEART FAILR OCT0 */
'42841' = 108 /* ACUTE CMBINED SYST & DIAS HEART FAILR  OCT0 */
'42842' = 108 /* CHRON CMBINED SYST & DIAS HEART FAILR  OCT0 */
'42843' = 108 /* ACU CHRO COMBI SYST & DIAS HRT FAILR OCT0 */
'4289 ' = 108 /* HEART FAILURE NOS */
'4561 ' = 138 /* ESOPH VARICES W/O BLEED */
'45621' = 138 /* ESOPH VARICE OTH DIS NOS */
'5131 ' = 133 /* ABSCESS OF MEDIASTINUM */
'514  ' = 133 /* PULM CONGEST/HYPOSTASIS */
'515  ' = 133 /* POSTINFLAM PULM FIBROSIS */
'5160 ' = 133 /* PUL ALVEOLAR PROTEINOSIS */
'5161 ' = 133 /* IDIO PULM HEMOSIDEROSIS */
'5162 ' = 133 /* PULM ALVEOLAR MICROLITH */
'5163 ' = 133 /* IDIO FIBROS ALVEOLITIS */
'5168 ' = 133 /* ALVEOL PNEUMONOPATHY NEC */
'5169 ' = 133 /* ALVEOL PNEUMONOPATHY NOS */
'5172 ' = 133 /* SYST SCLEROSIS LUNG DIS */
'5178 ' = 133 /* LUNG INVOLV IN OTH DIS */
'5183 ' = 133 /* PULMONARY EOSINOPHILIA */
'5184 ' = 133 /* ACUTE LUNG EDEMA NOS */
'51889' = 133 /* OTHER LUNG DISEASE NEC */
'5194 ' = 133 /* DISORDERS OF DIAPHRAGM */
'5198 ' = 133 /* RESP SYSTEM DISEASE NEC */
'5199 ' = 133 /* RESP SYSTEM DISEASE NOS */
'5300 ' = 138 /* ACHALASIA & CARDIOSPASM */
'5301 ' = 138 /* ESOPHAGITIS */
'53010' = 138 /* ESOPHAGITIS UNSPEC OCT93 */
'53011' = 138 /* REFLUX ESOPHAGITIS OCT93 */
'53012' = 138 /* ACUTE ESOPHAGITIS OCT01 */
'53019' = 138 /* OTH ESOPHAGITIS OCT93 */
'5302 ' = 138 /* ULCER OF ESOPHAGUS */
'53020' = 138 /* Ulcer of esophagus without bleeding */
'53021' = 138 /* Ulcer of esophagus with bleeding */
'5303 ' = 138 /* ESOPHAGEAL STRICTURE */
'5304 ' = 138 /* PERFORATION OF ESOPHAGUS */
'5305 ' = 138 /* DYSKINESIA OF ESOPHAGUS */
'5306 ' = 138 /* ACQ ESOPHAG DIVERTICULUM */
'5308 ' = 138 /* ESOPHAGEAL DISORDER NEC */
'53081' = 138 /* ESOPHAGEAL REFLUX OCT93 */
'53083' = 138 /* ESOPHAGEAL LEUKOPLAKIA OCT93 */
'53084' = 138 /* TRACHEOESOPHAGEAL FISTULA OCT93 */
'53085' = 138 /* Barretts esophagus */
'53089' = 138 /* OTH SPEC DISORDER ESOPHAGUS OCT93 */
'5309 ' = 138 /* ESOPHAGEAL DISORDER NOS */
'56731' = 211 /* PSOAS MUSCLE ABSCESS */
'570  ' = 151 /* ACUTE NECROSIS OF LIVER */
'57140' = 6 /* CHRONIC HEPATITIS NOS */
'57141' = 6 /* CHR PERSISTENT HEPATITIS */
'57149' = 6 /* CHRONIC HEPATITIS NEC */
'5715 ' = 151 /* CIRRHOSIS OF LIVER NOS */
'5716 ' = 151 /* BILIARY CIRRHOSIS */
'5718 ' = 151 /* CHRONIC LIVER DIS NEC */
'5719 ' = 151 /* CHRONIC LIVER DIS NOS */
'5720 ' = 151 /* ABSCESS OF LIVER */
'5721 ' = 151 /* PORTAL PYEMIA */
'5722 ' = 151 /* HEPATIC COMA */
'5723 ' = 151 /* PORTAL HYPERTENSION */
'5724 ' = 151 /* HEPATORENAL SYNDROME */
'5728 ' = 151 /* OTH SEQUELA- CHR LIV DIS */
'5730 ' = 151 /* CHR PASSIV CONGEST LIVER */
'5731 ' = 6 /* HEPATITIS IN VIRAL DIS */
'5732 ' = 6 /* HEPATITIS IN OTH INF DIS */
'5733 ' = 6 /* HEPATITIS NOS */
'5734 ' = 151 /* HEPATIC INFARCTION */
'5738 ' = 151 /* LIVER DISORDERS NEC */
'5739 ' = 151 /* LIVER DISORDER NOS */
'585  ' = 158 /* CHRONIC RENAL FAILURE */
'5851 ' = 161 /* CHRO KIDNEY DIS STAGE I */
'5852 ' = 161 /* CHRO KIDNEY DIS STAGE II */
'5853 ' = 158 /* CHR KIDNEY DIS STAGE III */
'5854 ' = 158 /* CHR KIDNEY DIS STAGE IV */
'5855 ' = 158 /* CHRON KIDNEY DIS STAGE V */
'5856 ' = 158 /* END STAGE RENAL DISEASE */
'5859 ' = 158 /* CHRONIC KIDNEY DIS NOS */
'5880 ' = 161 /* RENAL OSTEODYSTROPHY */
'5881 ' = 161 /* NEPHROGEN DIABETES INSIP */
'5888 ' = 161 /* IMPAIRED RENAL FUNCT NEC */
'58881' = 161 /* SEC HYPERPARATHYRD-RENAL */
'58889' = 161 /* IMPAIR REN FUNCT DIS NEC */
'5889 ' = 161 /* IMPAIRED RENAL FUNCT NOS */
'5890 ' = 161 /* UNILATERAL SMALL KIDNEY */
'5891 ' = 161 /* BILATERAL SMALL KIDNEYS */
'5899 ' = 161 /* SMALL KIDNEY NOS */
'591  ' = 161 /* HYDRONEPHROSIS */
'5930 ' = 161 /* NEPHROPTOSIS */
'5931 ' = 161 /* HYPERTROPHY OF KIDNEY */
'5932 ' = 161 /* CYST OF KIDNEY- ACQUIRED */
'5933 ' = 161 /* STRICTURE OF URETER */
'5934 ' = 161 /* URETERIC OBSTRUCTION NEC */
'5935 ' = 161 /* HYDROURETER */
'5936 ' = 161 /* POSTURAL PROTEINURIA */
'5937 ' = 161 /* VESICOURETERAL REFLUX */
'59370' = 161 /* VESICOURETERAL REFLUX W/O NEPHRO OCT94 */
'59371' = 161 /* VESICOURETER REFLUX W UNILAT NEPHROP OCT94 */
'59372' = 161 /* VESICOURETER REFLUX W BILAT NEPHROP OCT94 */
'59373' = 161 /* VESICOURETER REFLUX NOS OCT94 */
'59381' = 161 /* RENAL VASCULAR DISORDER */
'59382' = 161 /* URETERAL FISTULA */
'59389' = 161 /* RENAL & URETERAL DIS NEC */
'5939 ' = 161 /* RENAL & URETERAL DIS NOS */
'7100 ' = 210 /* SYST LUPUS ERYTHEMATOSUS */
'7101 ' = 210 /* SYSTEMIC SCLEROSIS */
'7102 ' = 210 /* SICCA SYNDROME */
'7103 ' = 210 /* DERMATOMYOSITIS */
'7104 ' = 210 /* POLYMYOSITIS */
'7105 ' = 211 /* EOSINOPHILIA MYALGIA   OCT92 */
'7108 ' = 210 /* DIFF CONNECT TIS DIS NEC */
'7109 ' = 210 /* DIFF CONNECT TIS DIS NOS */
'725  ' = 211 /* POLYMYALGIA RHEUMATICA */
'7260 ' = 211 /* ADHESIVE CAPSULIT SHLDER */
'72610' = 211 /* ROTATOR CUFF SYND NOS */
'72611' = 211 /* CALCIF TENDINITIS SHLDER */
'72612' = 211 /* BICIPITAL TENOSYNOVITIS */
'72619' = 211 /* ROTATOR CUFF DIS NEC */
'7262 ' = 211 /* SHOULDER REGION DIS NEC */
'72630' = 211 /* ELBOW ENTHESOPATHY NOS */
'72631' = 211 /* MEDIAL EPICONDYLITIS */
'72632' = 211 /* LATERAL EPICONDYLITIS */
'72633' = 211 /* OLECRANON BURSITIS */
'72639' = 211 /* ELBOW ENTHESOPATHY NEC */
'7264 ' = 211 /* ENTHESOPATHY OF WRIST */
'7265 ' = 211 /* ENTHESOPATHY OF HIP */
'72660' = 211 /* ENTHESOPATHY OF KNEE NOS */
'72661' = 211 /* PES ANSERINUS TENDINITIS */
'72662' = 211 /* TIBIAL COLL LIG BURSITIS */
'72663' = 211 /* FIBULA COLL LIG BURSITIS */
'72664' = 211 /* PATELLAR TENDINITIS */
'72665' = 211 /* PREPATELLAR BURSITIS */
'72669' = 211 /* ENTHESOPATHY OF KNEE NEC */
'72670' = 211 /* ANKLE ENTHESOPATHY NOS */
'72671' = 211 /* ACHILLES TENDINITIS */
'72672' = 211 /* TIBIALIS TENDINITIS */
'72673' = 211 /* CALCANEAL SPUR */
'72679' = 211 /* ANKLE ENTHESOPATHY NEC */
'7268 ' = 211 /* PERIPH ENTHESOPATHY NEC */
'72690' = 211 /* ENTHESOPATHY- SITE NOS */
'72691' = 211 /* EXOSTOSIS- SITE NOS */
'72700' = 211 /* SYNOVITIS NOS */
'72701' = 211 /* SYNOVITIS IN OTH DIS */
'72702' = 211 /* GIANT CELL TUMOR TENDON */
'72703' = 211 /* TRIGGER FINGER */
'72704' = 211 /* RADIAL STYLOID TENOSYNOV */
'72705' = 211 /* TENOSYNOV HAND/WRIST NEC */
'72706' = 211 /* TENOSYNOVITIS FOOT/ANKLE */
'72709' = 211 /* SYNOVITIS NEC */
'7272 ' = 211 /* OCCUPATIONAL BURSITIS */
'7273 ' = 211 /* BURSITIS NEC */
'72740' = 211 /* SYNOVIAL CYST NOS */
'72741' = 211 /* GANGLION OF JOINT */
'72742' = 211 /* GANGLION OF TENDON */
'72743' = 211 /* GANGLION NOS */
'72749' = 211 /* BURSAL CYST NEC */
'72750' = 211 /* RUPTURE OF SYNOVIUM NOS */
'72751' = 211 /* POPLITEAL SYNOVIAL CYST */
'72759' = 211 /* RUPTURE OF SYNOVIUM NEC */
'72760' = 211 /* NONTRAUM TENDON RUPT NOS */
'72761' = 211 /* ROTATOR CUFF RUPTURE */
'72762' = 211 /* BICEPS TENDON RUPTURE */
'72763' = 211 /* RUPT EXTEN TENDON HAND */
'72764' = 211 /* RUPT FLEXOR TENDON HAND */
'72765' = 211 /* RUPTURE QUADRICEP TENDON */
'72766' = 211 /* RUPTURE PATELLAR TENDON */
'72767' = 211 /* RUPTURE ACHILLES TENDON */
'72768' = 211 /* RUPTURE TENDON FOOT NEC */
'72769' = 211 /* NONTRAUM TENDON RUPT NEC */
'72781' = 211 /* CONTRACTURE OF TENDON */
'72782' = 211 /* CALCIUM DEPOSIT TENDON */
'72783' = 211 /* PLICA SYNDROME     OCT00 */
'72789' = 211 /* SYNOV/TEND/BURSA DIS NEC */
'7279 ' = 211 /* SYNOV/TEND/BURSA DIS NOS */
'7280 ' = 211 /* INFECTIVE MYOSITIS */
'72810' = 211 /* MUSCULAR CALCIFICAT NOS */
'72811' = 211 /* PROG MYOSITIS OSSIFICANS */
'72812' = 211 /* TRAUM MYOSITIS OSSIFICAN */
'72813' = 211 /* POSTOP HETEROTOPIC CALC */
'72819' = 211 /* MUSCULAR CALCIFICAT NEC */
'7282 ' = 211 /* MUSC DISUSE ATROPHY NEC */
'7283 ' = 211 /* MUSCLE DISORDERS NEC */
'7284 ' = 211 /* LAXITY OF LIGAMENT */
'7285 ' = 211 /* HYPERMOBILITY SYNDROME */
'7286 ' = 211 /* CONTRACTED PALMAR FASCIA */
'72871' = 211 /* PLANTAR FIBROMATOSIS */
'72879' = 211 /* FIBROMATOSES NEC */
'72881' = 211 /* INTERSTITIAL MYOSITIS */
'72882' = 211 /* FB GRANULOMA OF MUSCLE */
'72883' = 211 /* NONTRAUM MUSCLE RUPTURE */
'72884' = 211 /* DIASTASIS OF MUSCLE */
'72885' = 211 /* SPASM OF MUSCLE */
'72886' = 211 /* NECROTIZING FASCIITIS OCT95 */
'72887' = 211 /* Muscle weakness */
'72888' = 211 /* Rhabdomyolysis */
'72889' = 211 /* MUSCLE/LIGAMENT DIS NEC */
'7289 ' = 211 /* MUSCLE/LIGAMENT DIS NOS */
'7290 ' = 211 /* RHEUMATISM NOS */
'7291 ' = 211 /* MYALGIA AND MYOSITIS NOS */
'7292 ' = 211 /* NEURALGIA/NEURITIS NOS */
'72930' = 211 /* PANNICULITIS- UNSP SITE */
'72931' = 211 /* HYPERTROPHY OF FAT PAD */
'72939' = 211 /* PANNICULITIS- SITE NEC */
'7294 ' = 211 /* FASCIITIS NOS */
'7295 ' = 211 /* PAIN IN LIMB */
'7296 ' = 211 /* OLD FB IN SOFT TISSUE */
'72971' = 211 /* NONTRAUM COMP SYN-UP EXT */
'72972' = 211 /* NONTRAUM COMP SYN-LOW EX */
'72973' = 211 /* NONTRAUMA COMP SYN-ABD */
'72979' = 211 /* NONTRAUMA COMP SYN NEC */
'72981' = 211 /* SWELLING OF LIMB */
'72982' = 211 /* CRAMP IN LIMB */
'72989' = 211 /* MUSCSKEL SYMPT LIMB NEC */
'7299 ' = 211 /* SOFT TISSUE DIS NEC/NOS */
'7400 ' = 216 /* ANENCEPHALUS */
'7401 ' = 216 /* CRANIORACHISCHISIS */
'7402 ' = 216 /* INIENCEPHALY */
'74100' = 216 /* SPIN BIF W HYDROCEPH NOS */
'74101' = 216 /* SPIN BIF W HYDRCEPH-CERV */
'74102' = 216 /* SPIN BIF W HYDRCEPH-DORS */
'74103' = 216 /* SPIN BIF W HYDRCEPH-LUMB */
'74190' = 216 /* SPINA BIFIDA */
'74191' = 216 /* SPINA BIFIDA-CERV */
'74192' = 216 /* SPINA BIFIDA-DORSAL */
'74193' = 216 /* SPINA BIFIDA-LUMBAR */
'7420 ' = 216 /* ENCEPHALOCELE */
'7421 ' = 216 /* MICROCEPHALUS */
'7422 ' = 216 /* REDUCTION DEFORM- BRAIN */
'7423 ' = 216 /* CONGENITAL HYDROCEPHALUS */
'7424 ' = 216 /* BRAIN ANOMALY NEC */
'74251' = 216 /* DIASTEMATOMYELIA */
'74253' = 216 /* HYDROMYELIA */
'74259' = 216 /* SPINAL CORD ANOMALY NEC */
'7428 ' = 216 /* NERVOUS SYSTEM ANOM NEC */
'7429 ' = 216 /* NERVOUS SYSTEM ANOM NOS */
'74300' = 217 /* CLINIC ANOPHTHALMOS NOS */
'74303' = 217 /* CONGEN CYSTIC EYEBALL */
'74306' = 217 /* CRYPTOPHTHALMOS */
'74310' = 217 /* MICROPHTHALMOS NOS */
'74311' = 217 /* SIMPLE MICROPHTHALMOS */
'74312' = 217 /* MICROPHTH W OTH EYE ANOM */
'74320' = 217 /* BUPHTHALMOS NOS */
'74321' = 217 /* SIMPLE BUPHTHALMOS */
'74322' = 217 /* BUPHTHAL W OTH EYE ANOM */
'74330' = 217 /* CONGENITAL CATARACT NOS */
'74331' = 217 /* CAPSULAR CATARACT */
'74332' = 217 /* CORTICAL/ZONULAR CATARAC */
'74333' = 217 /* NUCLEAR CATARACT */
'74334' = 217 /* CONG TOT/SUBTOT CATARACT */
'74335' = 217 /* CONGENITAL APHAKIA */
'74336' = 217 /* ANOMALIES OF LENS SHAPE */
'74337' = 217 /* CONGENITAL ECTOPIC LENS */
'74339' = 217 /* CONG CATAR/LENS ANOM NEC */
'74341' = 217 /* ANOM CORNEAL SIZE/SHAPE */
'74342' = 217 /* CONG CORNEA OPAC AFF VIS */
'74343' = 217 /* CONG CORNEAL OPACIT NEC */
'74344' = 217 /* ANOM ANTER CHAMBER-EYE */
'74345' = 217 /* ANIRIDIA */
'74346' = 217 /* ANOM IRIS & CIL BODY NEC */
'74347' = 217 /* ANOMALIES OF SCLERA */
'74348' = 217 /* MULT ANOM ANTER SEG-EYE */
'74349' = 217 /* ANOM ANTER SEG NEC-EYE */
'74351' = 217 /* VITREOUS ANOMALIES */
'74352' = 217 /* FUNDUS COLOBOMA */
'74353' = 217 /* CONG CHORIORETINAL DEGEN */
'74354' = 217 /* CONG FOLD/CYST POST EYE */
'74355' = 217 /* CONG MACULAR CHANGE-EYE */
'74356' = 217 /* CONG RETINAL CHANGES NEC */
'74357' = 217 /* OPTIC DISC ANOMALIES */
'74358' = 217 /* VASCULAR ANOM POST EYE */
'74359' = 217 /* POST SEGMNT ANOM NEC-EYE */
'74361' = 217 /* CONGENITAL PTOSIS */
'74362' = 217 /* CONGENITAL EYELID DEFORM */
'74363' = 217 /* SPEC ANOM OF EYELID NEC */
'74364' = 217 /* SPEC LACRIMAL GLAND ANOM */
'74365' = 217 /* SPEC LACRIMAL PASS ANOM */
'74366' = 217 /* SPEC ANOMALY OF ORBIT */
'74369' = 217 /* ANOM EYELID/LACR/ORB NEC */
'7438 ' = 217 /* EYE ANOMALIES NEC */
'7439 ' = 217 /* EYE ANOMALY NOS */
'74400' = 217 /* EAR ANOM NOS/IMPAIR HEAR */
'74401' = 217 /* CONG ABSENCE EXT EAR */
'74402' = 217 /* EX EAR ANM NEC-IMPR HEAR */
'74403' = 217 /* MIDDLE EAR ANOMALY NEC */
'74404' = 217 /* ANOMALIES EAR OSSICLES */
'74405' = 217 /* ANOMALIES OF INNER EAR */
'74409' = 217 /* EAR ANOM NEC/IMPAIR HEAR */
'7441 ' = 217 /* ACCESSORY AURICLE */
'74421' = 217 /* CONG ABSENCE OF EAR LOBE */
'74422' = 217 /* MACROTIA */
'74423' = 217 /* MICROTIA */
'74424' = 217 /* EUSTACHIAN TUBE ANOM NEC */
'74429' = 217 /* EAR ANOMALIES NEC */
'7443 ' = 217 /* EAR ANOMALY NOS */
'74441' = 217 /* BRANCH CLEFT SINUS/FISTU */
'74442' = 217 /* BRANCHIAL CLEFT CYST */
'74443' = 217 /* CERVICAL AURICLE */
'74446' = 217 /* PREAURICULAR SINUS/FISTU */
'74447' = 217 /* PREAURICULAR CYST */
'74449' = 217 /* BRANCHIAL CLEFT ANOM NEC */
'7445 ' = 217 /* WEBBING OF NECK */
'74481' = 217 /* MACROCHEILIA */
'74482' = 217 /* MICROCHEILIA */
'74483' = 217 /* MACROSTOMIA */
'74484' = 217 /* MICROSTOMIA */
'74489' = 217 /* CONG FACE/NECK ANOM NEC */
'7449 ' = 217 /* CONG FACE/NECK ANOM NOS */
'7450 ' = 213 /* COMMON TRUNCUS */
'74510' = 213 /* COMPL TRANSPOS GREAT VES */
'74511' = 213 /* DOUBLE OUTLET RT VENTRIC */
'74512' = 213 /* CORRECT TRANSPOS GRT VES */
'74519' = 213 /* TRANSPOS GREAT VESS NEC */
'7452 ' = 213 /* TETRALOGY OF FALLOT */
'7453 ' = 213 /* COMMON VENTRICLE */
'7454 ' = 213 /* VENTRICULAR SEPT DEFECT */
'7455 ' = 213 /* SECUNDUM ATRIAL SEPT DEF */
'74560' = 213 /* ENDOCARD CUSHION DEF NOS */
'74561' = 213 /* OSTIUM PRIMUM DEFECT */
'74569' = 213 /* ENDOCARD CUSHION DEF NEC */
'7457 ' = 213 /* COR BILOCULARE */
'7458 ' = 213 /* SEPTAL CLOSURE ANOM NEC */
'7459 ' = 213 /* SEPTAL CLOSURE ANOM NOS */
'74600' = 213 /* PULMONARY VALVE ANOM NOS */
'74601' = 213 /* CONG PULMON VALV ATRESIA */
'74602' = 213 /* CONG PULMON VALVE STENOS */
'74609' = 213 /* PULMONARY VALVE ANOM NEC */
'7461 ' = 213 /* CONG TRICUSP ATRES/STEN */
'7462 ' = 213 /* EBSTEIN-s ANOMALY */
'7463 ' = 213 /* CONG AORTA VALV STENOSIS */
'7464 ' = 213 /* CONG AORTA VALV INSUFFIC */
'7465 ' = 213 /* CONGEN MITRAL STENOSIS */
'7466 ' = 213 /* CONG MITRAL INSUFFICIENC */
'7467 ' = 213 /* HYPOPLAS LEFT HEART SYND */
'74681' = 213 /* CONG SUBAORTIC STENOSIS */
'74682' = 213 /* COR TRIATRIATUM */
'74683' = 213 /* INFUNDIB PULMON STENOSIS */
'74684' = 213 /* OBSTRUCT HEART ANOM NEC */
'74685' = 213 /* CORONARY ARTERY ANOMALY */
'74686' = 213 /* CONGENITAL HEART BLOCK */
'74687' = 213 /* MALPOSITION OF HEART */
'74689' = 213 /* CONG HEART ANOMALY NEC */
'7469 ' = 213 /* CONG HEART ANOMALY NOS */
'7470 ' = 213 /* PATENT DUCTUS ARTERIOSUS */
'74710' = 213 /* COARCTATION OF AORTA */
'74711' = 213 /* INTERRUPT OF AORTIC ARCH */
'74720' = 213 /* CONG ANOM OF AORTA NOS */
'74721' = 213 /* ANOMALIES OF AORTIC ARCH */
'74722' = 213 /* AORTIC ATRESIA/STENOSIS */
'74729' = 213 /* CONG ANOM OF AORTA NEC */
'7473 ' = 213 /* PULMONARY ARTERY ANOM */
'74740' = 213 /* GREAT VEIN ANOMALY NOS */
'74741' = 213 /* TOT ANOM PULM VEN CONNEC */
'74742' = 213 /* PART ANOM PULM VEN CONN */
'74749' = 213 /* GREAT VEIN ANOMALY NEC */
'7475 ' = 213 /* UMBILICAL ARTERY ABSENCE */
'7476 ' = 213 /* PERIPH VASCULAR ANOM NEC */
'74760' = 213 /* UNSPEC PERIPH VASCULAR ANOM OCT93 */
'74761' = 213 /* GI VESSEL ANOMALY  OCT93 */
'74762' = 213 /* RENAL VESSEL ANOMALY OCT93 */
'74763' = 213 /* UP LIMB VESSEL ANOMALY OCT93 */
'74764' = 213 /* LOWER LIMB VESSEL ANOMALY OCT93 */
'74769' = 213 /* OTH SPEC PERIPH VASCULAR ANOM OCT93 */
'74781' = 213 /* CEREBROVASCULAR ANOMALY */
'74782' = 213 /* SPINAL VESSEL ANOMALY OCT93 */
'74783' = 213 /* PERSISTENT FETAL CIRCULATION  OCT02 */
'74789' = 213 /* CIRCULATORY ANOMALY NEC */
'7479 ' = 213 /* CIRCULATORY ANOMALY NOS */
'7480 ' = 217 /* CHOANAL ATRESIA */
'7481 ' = 217 /* NOSE ANOMALY NEC */
'7482 ' = 217 /* LARYNGEAL WEB */
'7483 ' = 217 /* LARYNGOTRACH ANOMALY NEC */
'7484 ' = 217 /* CONGENITAL CYSTIC LUNG */
'7485 ' = 217 /* AGENESIS OF LUNG */
'74860' = 217 /* LUNG ANOMALY NOS */
'74861' = 217 /* CONGEN BRONCHIECTASIS */
'74869' = 217 /* LUNG ANOMALY NEC */
'7488 ' = 217 /* RESPIRATORY ANOMALY NEC */
'7489 ' = 217 /* RESPIRATORY ANOMALY NOS */
'74900' = 217 /* CLEFT PALATE NOS */
'74901' = 217 /* UNILAT CLEFT PALATE-COMP */
'74902' = 217 /* UNILAT CLEFT PALATE-INC */
'74903' = 217 /* BILAT CLEFT PALATE-COMPL */
'74904' = 217 /* BILAT CLEFT PALATE-INC */
'74910' = 217 /* CLEFT LIP NOS */
'74911' = 217 /* UNILAT CLEFT LIP-COMPL */
'74912' = 217 /* UNILAT CLEFT LIP-IMCOMPL */
'74913' = 217 /* BILAT CLEFT LIP-COMPLETE */
'74914' = 217 /* BILAT CLEFT LIP-INCOMPL */
'74920' = 217 /* CLEFT PALATE & LIP NOS */
'74921' = 217 /* UNIL CLEFT PALAT/LIP-COM */
'74922' = 217 /* UNIL CLEFT PALAT/LIP-INC */
'74923' = 217 /* BILAT CLFT PALAT/LIP-COM */
'74924' = 217 /* BILAT CLFT PALAT/LIP-INC */
'74925' = 217 /* CLEFT PALATE & LIP NEC */
'7500 ' = 214 /* TONGUE TIE */
'75010' = 214 /* TONGUE ANOMALY NOS */
'75011' = 214 /* AGLOSSIA */
'75012' = 214 /* CONG ADHESIONS OF TONGUE */
'75013' = 214 /* CONG FISSURE OF TONGUE */
'75015' = 214 /* CONG MACROGLOSSIA */
'75016' = 214 /* MICROGLOSSIA */
'75019' = 214 /* TONGUE ANOMALY NEC */
'75021' = 214 /* SALIVARY GLAND ABSENCE */
'75022' = 214 /* ACCESSORY SALIVARY GLAND */
'75023' = 214 /* CONG ATRESIA- SALIV DUCT */
'75024' = 214 /* CONG SALIVARY FISTULA */
'75025' = 214 /* CONGENITAL LIP FISTULA */
'75026' = 214 /* MOUTH ANOMALY NEC */
'75027' = 214 /* DIVERTICULUM OF PHARYNX */
'75029' = 214 /* PHARYNGEAL ANOMALY NEC */
'7503 ' = 214 /* CONG ESOPH FISTULA/ATRES */
'7504 ' = 214 /* ESOPHAGEAL ANOMALY NEC */
'7505 ' = 214 /* CONG PYLORIC STENOSIS */
'7506 ' = 214 /* CONGENITAL HIATUS HERNIA */
'7507 ' = 214 /* GASTRIC ANOMALY NEC */
'7508 ' = 214 /* UPPER GI ANOMALY NEC */
'7509 ' = 214 /* UPPER GI ANOMALY NOS */
'7510 ' = 214 /* MECKEL-s DIVERTICULUM */
'7511 ' = 214 /* ATRESIA SMALL INTESTINE */
'7512 ' = 214 /* ATRESIA LARGE INTESTINE */
'7513 ' = 214 /* HIRSCHSPRUNG-s DISEASE */
'7514 ' = 214 /* INTESTINAL FIXATION ANOM */
'7515 ' = 214 /* INTESTINAL ANOMALY NEC */
'75160' = 214 /* BILIARY & LIVER ANOM NOS */
'75161' = 214 /* BILIARY ATRESIA */
'75162' = 214 /* CONG CYSTIC LIVER DIS */
'75169' = 214 /* BILIARY & LIVER ANOM NEC */
'7517 ' = 214 /* PANCREAS ANOMALIES */
'7518 ' = 214 /* ANOM DIGESTIVE SYST NEC */
'7519 ' = 214 /* ANOM DIGESTIVE SYST NOS */
'7520 ' = 215 /* ANOMALIES OF OVARIES */
'75210' = 215 /* TUBAL/BROAD LIG ANOM NOS */
'75211' = 215 /* EMBRYONIC CYST OF ADNEXA */
'75219' = 215 /* TUBAL/BROAD LIG ANOM NEC */
'7522 ' = 215 /* DOUBLING OF UTERUS */
'7523 ' = 215 /* UTERINE ANOMALY NEC */
'75240' = 215 /* CERVIX/FEM GEN ANOM NOS */
'75241' = 215 /* EMBRYON CYST FEM GEN NEC */
'75242' = 215 /* IMPERFORATE HYMEN */
'75249' = 215 /* CERVIX/FEM GEN ANOM NEC */
'7525 ' = 215 /* UNDESCENDED TESTICLE */
'75251' = 215 /* UNDESCEND TESTIS  OCT96 */
'75252' = 215 /* RETRACTILE TESTIS  OCT96 */
'7526 ' = 215 /* MALE HYPOSPADIAS/EPISPAD */
'75261' = 215 /* HYPOSPADIAS  OCT96 */
'75262' = 215 /* EPISPADIAS  OCT96 */
'75263' = 215 /* CONG CHORDEE  OCT96 */
'75264' = 215 /* MICROPENIS  OCT96 */
'75265' = 215 /* HIDDEN PENIS  OCT96 */
'75269' = 215 /* OTH PENILE ANOM  OCT96 */
'7527 ' = 215 /* INDETERMINATE SEX */
'7528 ' = 215 /* GENITAL ORGAN ANOM NEC */
'75281' = 215 /* Scrotal transposition */
'75289' = 215 /* Other specified anomalies of genital organs */
'7529 ' = 215 /* GENITAL ORGAN ANOM NOS */
'7530 ' = 215 /* RENAL AGENESIS */
'7531 ' = 215 /* CYSTIC KIDNEY DISEASE   J80  S90 */
'75310' = 215 /* CYSTIC KIDNEY DISEAS NOS O90 */
'75311' = 215 /* CONGENITAL RENAL CYST  O90 */
'75312' = 215 /* POLYCYSTIC KIDNEY NOS  O90 */
'75313' = 215 /* POLYCYST KID-AUTOSOM DOM O90 */
'75314' = 215 /* POLYCYST KID-AUTOSOM REC O90 */
'75315' = 215 /* RENAL DYSPLASIA    O90 */
'75316' = 215 /* MEDULLARY CYSTIC KIDNEY  O90 */
'75317' = 215 /* MEDULLARY SPONGE KIDNEY  O90 */
'75319' = 215 /* CYSTIC KIDNEY DISEAS NEC O90 */
'7532 ' = 215 /* CONGEN URETERAL OBSTRUCT */
'75320' = 215 /* OBSTR URETER NOS  OCT96 */
'75321' = 215 /* OBSTR URETERPELV JCT  OCT96 */
'75322' = 215 /* OBSTR URETERVESC JCT  OCT96 */
'75323' = 215 /* CONG URETEROCELE  OCT96 */
'75329' = 215 /* OTH OBSTR DEF URETER  OCT96 */
'7533 ' = 215 /* KIDNEY ANOMALY NEC */
'7534 ' = 215 /* URETERAL ANOMALY NEC */
'7535 ' = 215 /* BLADDER EXSTROPHY */
'7536 ' = 215 /* CONGEN URETHRAL STENOSIS */
'7537 ' = 215 /* ANOMALIES OF URACHUS */
'7538 ' = 215 /* CYSTOURETHRAL ANOM NEC */
'7539 ' = 215 /* URINARY ANOMALY NOS */
'7540 ' = 217 /* CONG SKULL/FACE/JAW DEF */
'7541 ' = 217 /* CONGENITAL TORTICOLLIS */
'7542 ' = 217 /* CONG POSTURAL DEFORMITY */
'75430' = 217 /* CONG HIP DISLOC- UNILAT */
'75431' = 217 /* CONGEN HIP DISLOC- BILAT */
'75432' = 217 /* CONG HIP SUBLUX- UNILAT */
'75433' = 217 /* CONG HIP SUBLUX- BILAT */
'75435' = 217 /* CONG HIP DISLOC W SUBLUX */
'75440' = 217 /* CONG GENU RECURVATUM */
'75441' = 217 /* CONG KNEE DISLOCATION */
'75442' = 217 /* CONGEN BOWING OF FEMUR */
'75443' = 217 /* CONG BOWING TIBIA/FIBULA */
'75444' = 217 /* CONG BOWING LEG NOS */
'75450' = 217 /* TALIPES VARUS */
'75451' = 217 /* TALIPES EQUINOVARUS */
'75452' = 217 /* METATARSUS PRIMUS VARUS */
'75453' = 217 /* METATARSUS VARUS */
'75459' = 217 /* CONG VARUS FOOT DEF NEC */
'75460' = 217 /* TALIPES VALGUS */
'75461' = 217 /* CONGENITAL PES PLANUS */
'75462' = 217 /* TALIPES CALCANEOVALGUS */
'75469' = 217 /* CONG VALGUS FOOT DEF NEC */
'75470' = 217 /* TALIPES NOS */
'75471' = 217 /* TALIPES CAVUS */
'75479' = 217 /* CONG FOOT DEFORM NEC */
'75481' = 217 /* PECTUS EXCAVATUM */
'75482' = 217 /* PECTUS CARINATUM */
'75489' = 217 /* NONTERATOGENIC ANOM NEC */
'75500' = 217 /* POLYDACTYLY NOS */
'75501' = 217 /* POLYDACTYLY- FINGERS */
'75502' = 217 /* POLYDACTYLY- TOES */
'75510' = 217 /* SYNDACTYLY- MULTIPLE/NOS */
'75511' = 217 /* SYNDACTYL FING-NO FUSION */
'75512' = 217 /* SYNDACTYL FING W FUSION */
'75513' = 217 /* SYNDACTYL TOE-NO FUSION */
'75514' = 217 /* SYNDACTYL TOE W FUSION */
'75520' = 217 /* REDUC DEFORM UP LIMB NOS */
'75521' = 217 /* TRANSVERSE DEFIC ARM */
'75522' = 217 /* LONGITUD DEFIC ARM NEC */
'75523' = 217 /* COMBIN LONGIT DEFIC ARM */
'75524' = 217 /* LONGITUDIN DEFIC HUMERUS */
'75525' = 217 /* LONGITUD DEFIC RADIOULNA */
'75526' = 217 /* LONGITUD DEFIC RADIUS */
'75527' = 217 /* LONGITUDINAL DEFIC ULNA */
'75528' = 217 /* LONGITUDINAL DEFIC HAND */
'75529' = 217 /* LONGITUD DEFIC PHALANGES */
'75530' = 217 /* REDUCTION DEFORM LEG NOS */
'75531' = 217 /* TRANSVERSE DEFIC LEG */
'75532' = 217 /* LONGITUDIN DEFIC LEG NEC */
'75533' = 217 /* COMB LONGITUDIN DEF LEG */
'75534' = 217 /* LONGITUDINAL DEFIC FEMUR */
'75535' = 217 /* TIBIOFIBULA LONGIT DEFIC */
'75536' = 217 /* LONGITUDINAL DEFIC TIBIA */
'75537' = 217 /* LONGITUDIN DEFIC FIBULA */
'75538' = 217 /* LONGITUDINAL DEFIC FOOT */
'75539' = 217 /* LONGITUD DEFIC PHALANGES */
'7554 ' = 217 /* REDUCT DEFORM LIMB NOS */
'75550' = 217 /* UPPER LIMB ANOMALY NOS */
'75551' = 217 /* CONG DEFORMITY-CLAVICLE */
'75552' = 217 /* CONG ELEVATION-SCAPULA */
'75553' = 217 /* RADIOULNAR SYNOSTOSIS */
'75554' = 217 /* MADELUNG-s DEFORMITY */
'75555' = 217 /* ACROCEPHALOSYNDACTYLY */
'75556' = 217 /* ACCESSORY CARPAL BONES */
'75557' = 217 /* MACRODACTYLIA (FINGERS) */
'75558' = 217 /* CONGENITAL CLEFT HAND */
'75559' = 217 /* UPPER LIMB ANOMALY NEC */
'75560' = 217 /* LOWER LIMB ANOMALY NOS */
'75561' = 217 /* CONGENITAL COXA VALGA */
'75562' = 217 /* CONGENITAL COXA VARA */
'75563' = 217 /* CONG HIP DEFORMITY NEC */
'75564' = 217 /* CONG KNEE DEFORMITY */
'75565' = 217 /* MACRODACTYLIA OF TOES */
'75566' = 217 /* ANOMALIES OF TOES NEC */
'75567' = 217 /* ANOMALIES OF FOOT NEC */
'75569' = 217 /* LOWER LIMB ANOMALY NEC */
'7558 ' = 217 /* CONGEN LIMB ANOMALY NEC */
'7559 ' = 217 /* CONGEN LIMB ANOMALY NOS */
'7560 ' = 217 /* ANOMAL SKULL/FACE BONES */
'75610' = 217 /* ANOMALY OF SPINE NOS */
'75611' = 217 /* LUMBOSACR SPONDYLOLYSIS */
'75612' = 217 /* SPONDYLOLISTHESIS */
'75613' = 217 /* CONG ABSENCE OF VERTEBRA */
'75614' = 217 /* HEMIVERTEBRA */
'75615' = 217 /* CONGEN FUSION OF SPINE */
'75616' = 217 /* KLIPPEL-FEIL SYNDROME */
'75617' = 217 /* SPINA BIFIDA OCCULTA */
'75619' = 217 /* ANOMALY OF SPINE NEC */
'7562 ' = 217 /* CERVICAL RIB */
'7563 ' = 217 /* RIB & STERNUM ANOMAL NEC */
'7564 ' = 217 /* CHONDRODYSTROPHY */
'75650' = 217 /* OSTEODYSTROPHY NOS */
'75651' = 217 /* OSTEOGENESIS IMPERFECTA */
'75652' = 217 /* OSTEOPETROSIS */
'75653' = 217 /* OSTEOPOIKILOSIS */
'75654' = 217 /* POLYOSTOTIC FIBROS DYSPL */
'75655' = 217 /* CHONDROECTODERM DYSPLAS */
'75656' = 217 /* MULT EPIPHYSEAL DYSPLAS */
'75659' = 217 /* OSTEODYSTROPHY NEC */
'7566 ' = 217 /* ANOMALIES OF DIAPHRAGM */
'7567 ' = 217 /* ABDOMINAL WALL ANOMALIES */
'75670' = 217 /* CONG ANOM ABD WALL NOS OCT97 */
'75671' = 217 /* CONG ANOM PRUNE BELLY SYND OCT97 */
'75679' = 217 /* OT CONG ANOM ABD WALL OCT97 */
'75681' = 217 /* ABSENCE OF MUSCLE/TENDON */
'75682' = 217 /* ACCESSORY MUSCLE */
'75683' = 217 /* EHLERS-DANLOS SYNDROME */
'75689' = 217 /* SOFT TISSUE ANOMALY NEC */
'7569 ' = 217 /* MUSCULOSKEL ANOM NEC/NOS */
'7570 ' = 217 /* HEREDITARY EDEMA OF LEGS */
'7571 ' = 217 /* ICHTHYOSIS CONGENITA */
'7572 ' = 217 /* DERMATOGLYPHIC ANOMALIES */
'75731' = 217 /* CONG ECTODERMAL DYSPLAS */
'75732' = 217 /* VASCULAR HAMARTOMAS */
'75733' = 217 /* CONG SKIN PIGMENT ANOMAL */
'75739' = 217 /* SKIN ANOMALY NEC */
'7574 ' = 217 /* HAIR ANOMALIES NEC */
'7575 ' = 217 /* NAIL ANOMALIES NEC */
'7576 ' = 217 /* BREAST ANOMALIES NEC */
'7578 ' = 217 /* OTH INTEGUMENT ANOMALIES */
'7579 ' = 217 /* INTEGUMENT ANOMALY NOS */
'7580 ' = 217 /* DOWN-s SYNDROME */
'7581 ' = 217 /* PATAU-s SYNDROME */
'7582 ' = 217 /* EDWARD-s SYNDROME */
'7583 ' = 217 /* AUTOSOMAL DELETION SYND */
'75831' = 217 /* CRI-DU-CHAT SYNDROME */
'75832' = 217 /* VELO-CARDIO-FACIAL SYND */
'75833' = 217 /* MICRODELETIONS NEC */
'75839' = 217 /* AUTOSOMAL DELETIONS NEC */
'7584 ' = 217 /* BALANCE AUTOSOM TRANSLOC */
'7585 ' = 217 /* AUTOSOMAL ANOMALIES NEC */
'7586 ' = 217 /* GONADAL DYSGENESIS */
'7587 ' = 217 /* KLINEFELTER-s SYNDROME */
'7588 ' = 217 /* SEX CHROMOSOME ANOM NEC */
'75881' = 217 /* OTH SEX CHROM ANOM  OCT96 */
'75889' = 217 /* OTH CHROMOSOM ANOM  OCT96 */
'7589 ' = 217 /* CHROMOSOME ANOMALY NOS */
'7590 ' = 217 /* ANOMALIES OF SPLEEN */
'7591 ' = 217 /* ADRENAL GLAND ANOMALY */
'7592 ' = 217 /* ENDOCRINE ANOMALY NEC */
'7593 ' = 217 /* SITUS INVERSUS */
'7594 ' = 217 /* CONJOINED TWINS */
'7595 ' = 217 /* TUBEROUS SCLEROSIS */
'7596 ' = 217 /* HAMARTOSES NEC */
'7597 ' = 217 /* MULT CONGEN ANOMAL NEC */
'7598 ' = 217 /* CONGENITAL ANOMALIES NEC  J80  S89 */
'75981' = 217 /* PRADER-WILLI SYNDROME  OCT89 */
'75982' = 217 /* MARFAN SYNDROME    OCT89 */
'75983' = 217 /* FRAGILE X SYNDROME OCT94 */
'75989' = 217 /* SPECFIED CONG ANOMAL NEC OCT89 */
'7599 ' = 217 /* CONGENITAL ANOMALY NOS */
'7600 ' = 224 /* MATERN HYPERTEN AFF NB */
'7601 ' = 224 /* MATERN URINE DIS AFF NB */
'7602 ' = 224 /* MATERNAL INFEC AFF NB */
'7603 ' = 224 /* MATERN CARDIORESP AFF NB */
'7604 ' = 224 /* MATERN NUTRIT DIS AFF NB */
'7605 ' = 224 /* MATERNAL INJURY AFF NB */
'7606 ' = 224 /* SURG OP ON MOTHER AFF NB */
'76070' = 224 /* NOXIOUS SUBST NOS AFF NB */
'76071' = 224 /* MATERNAL ALCOHOL AFF NB */
'76072' = 224 /* MATERNAL NARCOTIC AFF NB */
'76073' = 224 /* MATERNAL HALLUCIN AFF NB */
'76074' = 224 /* MATERNAL ANTI-INF AFF NB */
'76075' = 224 /* COCAINE - NXS INFL FETUS OCT91 */
'76076' = 224 /* DES AFFECTING FETUS VIA PLAC OR MILK OCT94 */
'76077' = 224 /* MAT ANTICONV AFF NB/FET */
'76078' = 224 /* MAT ANTIMETABOL AFF NB */
'76079' = 224 /* NOXIOUS SUBST NEC AFF NB */
'7608 ' = 224 /* MATERNAL COND NEC AFF NB */
'7609 ' = 224 /* MATERNAL COND NOS AFF NB */
'7610 ' = 224 /* INCOMPETNT CERVIX AFF NB */
'7611 ' = 224 /* PREMAT RUPT MEMB AFF NB */
'7612 ' = 224 /* OLIGOHYDRAMNIOS AFF NB */
'7613 ' = 224 /* POLYHYDRAMNIOS AFF NB */
'7614 ' = 224 /* ECTOPIC PREGNANCY AFF NB */
'7615 ' = 224 /* MULT PREGNANCY AFF NB */
'7616 ' = 224 /* MATERNAL DEATH AFF NB */
'7617 ' = 224 /* ANTEPART MALPRES AFF NB */
'7618 ' = 224 /* MATERN COMPL NEC AFF NB */
'7619 ' = 224 /* MATERN COMPL NOS AFF NB */
'7620 ' = 224 /* PLACENTA PREVIA AFF NB */
'7621 ' = 224 /* PLACENTA HEM NEC AFF NB */
'7622 ' = 224 /* ABN PLAC NEC/NOS AFF NB */
'7623 ' = 224 /* PLACENT TRANSFUSION SYN */
'7624 ' = 224 /* PROLAPSED CORD AFF NB */
'7625 ' = 224 /* OTH UMBIL CORD COMPRESS */
'7626 ' = 224 /* UMBIL COND NEC AFF NB */
'7627 ' = 224 /* CHORIOAMNIONITIS AFF NB */
'7628 ' = 224 /* ABN AMNION NEC AFF NB */
'7629 ' = 224 /* ABN AMNION NOS AFF NB */
'7630 ' = 224 /* BREECH DEL/EXTRAC AFF NB */
'7631 ' = 224 /* MALPOS/DISPRO NEC AFF NB */
'7632 ' = 224 /* FORCEPS DELIVERY AFF NB */
'7633 ' = 224 /* VACUUM EXTRAC DEL AFF NB */
'7634 ' = 224 /* CESAREAN DELIVERY AFF NB */
'7635 ' = 224 /* MAT ANESTH/ANALG AFF NB */
'7636 ' = 224 /* PRECIPITATE DEL AFF NB */
'7637 ' = 224 /* ABN UTERINE CONTR AFF NB */
'7638 ' = 224 /* COMPL DELIV NEC AFF NB */
'76381' = 224 /* ABN FTL HRT BEFORE LABOR  OCT98 */
'76382' = 224 /* ABN FTL HRT DURING LABOR  OCT98 */
'76383' = 224 /* ABN FTL HRT UNSP ONSET  OCT98 */
'76384' = 224 /* MECONIUM DUR DEL AFF NB */
'76389' = 224 /* OTH SPEC COMPL LABOR/DELIV  OCT98 */
'7639 ' = 224 /* COMPL DELIV NOS AFF NB */
'7640 ' = 219 /* LT-FOR-DATES W/O FET MAL  J80  S88 */
'76400' = 219 /* LIGHT-FOR-DATES WTNOS  OCT88 */
'76401' = 219 /* LIGHT-FOR-DATES <500G  OCT88 */
'76402' = 219 /* LT-FOR-DATES 500-749G  OCT88 */
'76403' = 219 /* LT-FOR-DATES 750-999G  OCT88 */
'76404' = 219 /* LT-FOR-DATES 1000-1249G  OCT88 */
'76405' = 219 /* LT-FOR-DATES 1250-1499G  OCT88 */
'76406' = 219 /* LT-FOR-DATES 1500-1749G  OCT88 */
'76407' = 219 /* LT-FOR-DATES 1750-1999G  OCT88 */
'76408' = 219 /* LT-FOR-DATES 2000-2499G  OCT88 */
'76409' = 219 /* LT-FOR-DATES 2500+G  OCT88 */
'7641 ' = 219 /* LT-FOR-DATES W FETAL MAL  J80  S88 */
'76410' = 219 /* LT-FOR-DATE W/MAL WTNOS  OCT88 */
'76411' = 219 /* LT-FOR-DATE W/MAL <500G  OCT88 */
'76412' = 219 /* LT-DATE W/MAL 500-749G OCT88 */
'76413' = 219 /* LT-DATE W/MAL 750-999G OCT88 */
'76414' = 219 /* LT-DATE W/MAL 1000-1249G OCT88 */
'76415' = 219 /* LT-DATE W/MAL 1250-1499G OCT88 */
'76416' = 219 /* LT-DATE W/MAL 1500-1749G OCT88 */
'76417' = 219 /* LT-DATE W/MAL 1750-1999G OCT88 */
'76418' = 219 /* LT-DATE W/MAL 2000-2499G OCT88 */
'76419' = 219 /* LT-FOR-DATE W/MAL 2500+G OCT88 */
'7642 ' = 219 /* FET MAL W/O LT-FOR-DATES  J80  S88 */
'76420' = 219 /* FETAL MALNUTRITION WTNOS OCT88 */
'76421' = 219 /* FETAL MALNUTRITION <500G OCT88 */
'76422' = 219 /* FETAL MALNUTR 500-749G OCT88 */
'76423' = 219 /* FETAL MAL 750-999G   OCT88 */
'76424' = 219 /* FETAL MAL 1000-1249G   OCT88 */
'76425' = 219 /* FETAL MAL 1250-1499G   OCT88 */
'76426' = 219 /* FETAL MAL 1500-1749G   OCT88 */
'76427' = 219 /* FETAL MALNUTR 1750-1999G OCT88 */
'76428' = 219 /* FETAL MALNUTR 2000-2499G OCT88 */
'76429' = 219 /* FETAL MALNUTR 2500+G   OCT88 */
'7649 ' = 219 /* FETAL GROWTH RETARD NOS J80  S88 */
'76490' = 219 /* FET GROWTH RETARD WTNOS  OCT88 */
'76491' = 219 /* FET GROWTH RETARD <500G  OCT88 */
'76492' = 219 /* FET GROWTH RET 500-749G  OCT88 */
'76493' = 219 /* FET GROWTH RET 750-999G  OCT88 */
'76494' = 219 /* FET GRWTH RET 1000-1249G OCT88 */
'76495' = 219 /* FET GRWTH RET 1250-1499G OCT88 */
'76496' = 219 /* FET GRWTH RET 1500-1749G OCT88 */
'76497' = 219 /* FET GRWTH RET 1750-1999G OCT88 */
'76498' = 219 /* FET GRWTH RET 2000-2499G OCT88 */
'76499' = 219 /* FET GROWTH RET 2500+G  OCT88 */
'7650 ' = 219 /* EXTREME IMMATURITY    J80  S88 */
'76500' = 219 /* EXTREME IMMATUR WTNOS  OCT88 */
'76501' = 219 /* EXTREME IMMATUR <500G  OCT88 */
'76502' = 219 /* EXTREME IMMATUR 500-749G OCT88 */
'76503' = 219 /* EXTREME IMMATUR 750-999G OCT88 */
'76504' = 219 /* EXTREME IMMAT 1000-1249G OCT88 */
'76505' = 219 /* EXTREME IMMAT 1250-1499G OCT88 */
'76506' = 219 /* EXTREME IMMAT 1500-1749G OCT88 */
'76507' = 219 /* EXTREME IMMAT 1750-1999G OCT88 */
'76508' = 219 /* EXTREME IMMAT 2000-2499G OCT88 */
'76509' = 219 /* EXTREME IMMAT 2500+G   OCT88 */
'7651 ' = 219 /* OTHER PRETERM INFANTS   J80  S88 */
'76510' = 219 /* PRETERM INFANT NEC WTNOS OCT88 */
'76511' = 219 /* PRETERM NEC <500G    OCT88 */
'76512' = 219 /* PRETERM NEC 500-749G   OCT88 */
'76513' = 219 /* PRETERM NEC 750-999G   OCT88 */
'76514' = 219 /* PRETERM NEC 1000-1249G OCT88 */
'76515' = 219 /* PRETERM NEC 1250-1499G OCT88 */
'76516' = 219 /* PRETERM NEC 1500-1749G OCT88 */
'76517' = 219 /* PRETERM NEC 1750-1999G OCT88 */
'76518' = 219 /* PRETERM NEC 2000-2499G OCT88 */
'76519' = 219 /* PRETERM NEC 2500+G   OCT88 */
'76520' = 219 /* UNSPECIFIED WEEKS OF GESTATION    OCT02 */
'76521' = 219 /* LESS THAN 24 COMPLETED WEEKS OF GEST  OCT02 */
'76522' = 219 /* 24 COMPLETED WEEKS OF GESTATION   OCT02 */
'76523' = 219 /* 25-26 COMPLETED WEEKS OF GESTATION  OCT02 */
'76524' = 219 /* 27-28 COMPLETED WEEKS OF GESTATION  OCT02 */
'76525' = 219 /* 29-30 COMPLETED WEEKS OF GESTATION  OCT02 */
'76526' = 219 /* 31-32 COMPLETED WEEKS OF GESTATION  OCT02 */
'76527' = 219 /* 33-34 COMPLETED WEEKS OF GESTATION  OCT02 */
'76528' = 219 /* 35-36 COMPLETED WEEKS OF GESTATION  OCT02 */
'76529' = 219 /* 37 OR MORE COMPLETED WEEKS OF GEST  OCT02 */
'7660 ' = 224 /* EXCEPTIONALLY LARGE BABY */
'7661 ' = 224 /* HEAVY-FOR-DATE INFAN NEC */
'7662 ' = 224 /* POST-TERM INFANT NOS */
'76621' = 224 /* Post-term infant */
'76622' = 224 /* Prolonged gestation of infant */
'769  ' = 221 /* RESPIRATORY DISTRESS SYN */
'7700 ' = 224 /* CONGENITAL PNEUMONIA */
'7701 ' = 224 /* NB MASSIVE ASPIRAT SYN */
'77010' = 224 /* MECONIUM ASP NOS */
'77011' = 224 /* MECONIUM ASP WO RESP SYM */
'77012' = 224 /* MECONIUM ASP W RESP SYMP */
'77013' = 224 /* AMNIOTC ASP W/O RESP SYM */
'77014' = 224 /* AMNIOTIC ASP W RESP SYM */
'77015' = 224 /* BLOOD ASP W/O RESP SYMPT */
'77016' = 224 /* BLOOD ASP W RESP SYMPT */
'77017' = 224 /* NB ASP W/O RESP SYMP NEC */
'77018' = 224 /* NB ASP W RESP SYMP NEC */
'7702 ' = 224 /* NB INTERSTIT EMPHYSEMA */
'7703 ' = 224 /* NB PULMONARY HEMORRHAGE */
'7704 ' = 224 /* PRIMARY ATELECTASIS */
'7705 ' = 224 /* NB ATELECTASIS NEC/NOS */
'7706 ' = 224 /* NB TRANSITORY TACHYPNEA */
'7707 ' = 224 /* PERINATAL CHR RESP DIS */
'7708 ' = 224 /* POST-BIRTH RESP PROB NEC */
'77081' = 224 /* PRIMARY APNEA OF NEWBORN   OCT02 */
'77082' = 224 /* OTHER APNEA OF NEWBORN     OCT02 */
'77083' = 224 /* CYANOTIC ATTACKS OF NEWBORN  OCT02 */
'77084' = 224 /* RESPIRATORY FAILURE OF NEWBORN OCT02 */
'77085' = 224 /* STOMCH CONT ASP W/O RESP */
'77086' = 224 /* STOMACH CONT ASP W RESP */
'77087' = 224 /* NB RESPIRATORY ARREST */
'77089' = 224 /* OTHER RESPIRATORY PROBLEMS AFT BIRTH OCT02 */
'7709 ' = 224 /* NB RESPIRATORY COND NOS */
'7710 ' = 224 /* CONGENITAL RUBELLA */
'7711 ' = 224 /* CONG CYTOMEGALOVIRUS INF */
'7712 ' = 224 /* CONGENITAL INFEC NEC */
'7713 ' = 224 /* TETANUS NEONATORUM */
'7714 ' = 224 /* OMPHALITIS OF NEWBORN */
'7715 ' = 224 /* NEONATAL INFEC MASTITIS */
'7716 ' = 224 /* NEONATAL CONJUNCTIVITIS */
'7717 ' = 224 /* NEONATAL CANDIDA INFECT */
'7718 ' = 224 /* PERINATAL INFECTION NEC */
'77181' = 224 /* SEPTICEMIA [SEPSIS] OF NEWBORN  OCT02 */
'77182' = 224 /* URINARY TRACT INFECTION OF NEWBORN  OCT02 */
'77183' = 224 /* BACTEREMIA OF NEWBORN */
'77189' = 224 /* OT INFECTIONS SPEC TO PERINATAL PERIOD OCT02 */
'7720 ' = 224 /* FETAL BLOOD LOSS NEC */
'7721 ' = 224 /* NB INTRAVENTRICULAR HEM */
'77210' = 224 /* INTRAVENT HEMORRHAGE NOS OCT01 */
'77211' = 224 /* INTRAVENT HEMORRHAGE GRADE I OCT01 */
'77212' = 224 /* INTRAVENT HEMORRHAGEGRADE II OCT01 */
'77213' = 224 /* INTRAVENT HEMORRHAGE GRADE III OCT01 */
'77214' = 224 /* INTRAVENT HEMORRHAGE GRADE IV  OCT01 */
'7722 ' = 224 /* NB SUBARACHNOID HEMORR */
'7723 ' = 224 /* POST-BIRTH UMBIL HEMORR */
'7724 ' = 224 /* NB GI HEMORRHAGE */
'7725 ' = 224 /* NB ADRENAL HEMORRHAGE */
'7726 ' = 224 /* NB CUTANEOUS HEMORRHAGE */
'7728 ' = 224 /* NEONATAL HEMORRHAGE NEC */
'7729 ' = 224 /* NEONATAL HEMORRHAGE NOS */
'7750 ' = 224 /* INFANT DIABET MOTHER SYN */
'7751 ' = 224 /* NEONAT DIABETES MELLITUS */
'7752 ' = 224 /* NEONAT MYASTHENIA GRAVIS */
'7753 ' = 224 /* NEONATAL THYROTOXICOSIS */
'7754 ' = 224 /* HYPOCALCEM/HYPOMAGNES NB */
'7755 ' = 224 /* NEONATAL DEHYDRATION */
'7756 ' = 224 /* NEONATAL HYPOGLYCEMIA */
'7757 ' = 224 /* LATE METAB ACIDOSIS NB */
'7758 ' = 224 /* TRANSIENT MET DIS NB NEC */
'77581' = 224 /* NB ACIDOSIS NEC */
'77589' = 224 /* NEONAT ENDO/MET DIS NEC */
'7759 ' = 224 /* TRANSIENT MET DIS NB NOS */
'7760 ' = 224 /* NB HEMORRHAGIC DISEASE */
'7761 ' = 224 /* NEONATAL THROMBOCYTOPEN */
'7762 ' = 224 /* DISSEM INTRAVASC COAG NB */
'7763 ' = 224 /* OTH NEONATAL COAG DIS */
'7764 ' = 224 /* POLYCYTHEMIA NEONATORUM */
'7765 ' = 224 /* CONGENITAL ANEMIA */
'7766 ' = 224 /* ANEMIA OF PREMATURITY */
'7767 ' = 224 /* NEONATAL NEUTROPENIA */
'7768 ' = 224 /* TRANSIENT HEMAT DIS NEC */
'7769 ' = 224 /* NB HEMATOLOGICAL DIS NOS */
'7771 ' = 224 /* MECONIUM OBSTRUCTION */
'7772 ' = 224 /* INTEST OBST-INSPISS MILK */
'7773 ' = 224 /* SWALLOWED BLOOD SYNDROME */
'7774 ' = 224 /* TRANSITORY ILEUS OF NB */
'7775 ' = 224 /* NECROT ENTEROCOLITIS NB */
'7776 ' = 224 /* PERINATAL INTEST PERFOR */
'7778 ' = 224 /* PERINAT GI SYS DIS NEC */
'7779 ' = 224 /* PERINAT GI SYS DIS NOS */
'7780 ' = 224 /* HYDROPS FETALIS NO ISOIM */
'7781 ' = 224 /* SCLEREMA NEONATORUM */
'7782 ' = 224 /* NB COLD INJURY SYNDROME */
'7783 ' = 224 /* NB HYPOTHERMIA NEC */
'7784 ' = 224 /* NB TEMP REGULAT DIS NEC */
'7785 ' = 224 /* EDEMA OF NEWBORN NEC/NOS */
'7786 ' = 224 /* CONGENITAL HYDROCELE */
'7787 ' = 224 /* NB BREAST ENGORGEMENT */
'7788 ' = 224 /* NB INTEGUMENT COND NEC */
'7789 ' = 224 /* NB INTEGUMENT COND NOS */
'7790 ' = 224 /* CONVULSIONS IN NEWBORN */
'7791 ' = 224 /* NB CEREB IRRIT NEC/NOS */
'7792 ' = 224 /* CNS DYSFUNCTION SYN NB */
'7793 ' = 224 /* NB FEEDING PROBLEMS */
'7794 ' = 224 /* NB DRUG REACTION/INTOXIC */
'7795 ' = 224 /* NB DRUG WITHDRAWAL SYNDR */
'7796 ' = 224 /* TERMINATION OF PREGNANCY */
'7797 ' = 224 /* PREVENTRICULAR LEUKOMALACIA OCT01 */
'7798 ' = 224 /* PERINATAL CONDITION NEC */
'77981' = 224 /* NEONATAL BRADYCARDIA   OCT02 */
'77982' = 224 /* NEONATAL TACHYCARDIA   OCT02 */
'77983' = 224 /* Delayed separation of umbilical cord */
'77985' = 224 /* NB CARDIAC ARREST */
'77989' = 224 /* OT SPEC COND ORIG IN PERINATAL PERIOD  OCT02 */
'7799 ' = 224 /* PERINATAL CONDITION NOS */
'7800 ' = 85 /* COMA AND STUPOR     J80  S92 */
'78001' = 85 /* COMA         OCT92 */
'78003' = 85 /* PERSISTENT VEGATATIVE STATE OCT93 */
'78009' = 85 /* STUPOR       OCT92 */
'7803 ' = 83 /* CONVULSIONS */
'78031' = 83 /* FEBRILE CONVULSIONS OCT97 */
'78032' = 83 /* COMPLX FEBRILE CONVULSNS */
'78039' = 83 /* OT CONVULSIONS OCT97 */
'78091' = 224 /* FUSSY INFANT (BABY)     OCT02 */
'78092' = 224 /* EXCESSIVE CRYING OF INFANT (BABY)  OCT02 */
'7810 ' = 95 /* ABN INVOLUN MOVEMENT NEC */
'7811 ' = 95 /* SMELL & TASTE DISTURB */
'7812 ' = 95 /* ABNORMALITY OF GAIT */
'7813 ' = 95 /* LACK OF COORDINATION */
'7814 ' = 82 /* TRANSIENT LIMB PARALYSIS */
'7817 ' = 95 /* TETANY */
'7818 ' = 95 /* NEUROLOGIC NEGLECT SYNDROME OCT94 */
'7819 ' = 211 /* NERV/MUSCULSKEL SYM NEC */
'78191' = 211 /* LOSS OF HEIGHT      OCT00 */
'78192' = 211 /* ABNORMAL POSTURE    OCT00 */
'78194' = 211 /* Facial weakness */
'78199' = 211 /* OTHER SYMPTOMS-MUSCULOSKEL  OCT00 */
'7820 ' = 95 /* SKIN SENSATION DISTURB */
'7824 ' = 151 /* JAUNDICE NOS */
'7825 ' = 133 /* CYANOSIS */
'7831 ' = 58 /* ABNORMAL WEIGHT GAIN */
'7832 ' = 58 /* ABNORMAL LOSS OF WEIGHT */
'78321' = 58 /* LOSS OF WEIGHT     OCT00 */
'78322' = 58 /* UNDERWEIGHT      OCT00 */
'7833 ' = 58 /* FEEDING PROBLEM */
'7834 ' = 58 /* LACK NORM PHYSIOL DEVEL */
'78340' = 58 /* LACK NORM PHYSIOL DEVELOP UNSPEC  OCT00 */
'78341' = 58 /* FAILURE TO THRIVE       OCT00 */
'78342' = 58 /* DELAYED MILESTONE       OCT00 */
'78343' = 58 /* SHORT STATURE       OCT00 */
'7835 ' = 58 /* POLYDIPSIA */
'7837 ' = 58 /* ADULT FAILURE TO THRIVE     OCT00 */
'7839 ' = 58 /* NUTR/METAB/DEVEL SYM NEC */
'7843 ' = 95 /* APHASIA */
'7845 ' = 95 /* SPEECH DISTURBANCE NEC */
'78460' = 95 /* SYMBOLIC DYSFUNCTION NOS */
'78461' = 95 /* ALEXIA AND DYSLEXIA */
'78469' = 95 /* SYMBOLIC DYSFUNCTION NEC */
'7850 ' = 106 /* TACHYCARDIA NOS */
'7851 ' = 106 /* PALPITATIONS */
'7852 ' = 96 /* CARDIAC MURMURS NEC */
'7853 ' = 96 /* ABNORM HEART SOUNDS NEC */
'78600' = 133 /* RESPIRATORY ABNORM NOS */
'78601' = 133 /* HYPERVENTILATION */
'78602' = 133 /* ORTHOPNEA */
'78603' = 133 /* APNEA      OCT98 */
'78604' = 133 /* CHEYNE-STOKES RESP OCT98 */
'78605' = 133 /* SHORTNESS OF BREATH  OCT98 */
'78606' = 133 /* TACHYPNEA    OCT98 */
'78607' = 133 /* WHEEZING     OCT98 */
'78609' = 133 /* RESPIRATORY ABNORM NEC */
'7862 ' = 133 /* COUGH */
'7863 ' = 133 /* HEMOPTYSIS */
'7864 ' = 133 /* ABNORMAL SPUTUM */
'78652' = 133 /* PAINFUL RESPIRATION */
'7866 ' = 133 /* CHEST SWELLING/MASS/LUMP */
'7867 ' = 133 /* ABNORMAL CHEST SOUNDS */
'7868 ' = 133 /* HICCOUGH */
'7869 ' = 133 /* RESP SYS/CHEST SYMP NEC */
'7891 ' = 151 /* HEPATOMEGALY */
'7895 ' = 151 /* ASCITES */
'7904 ' = 151 /* ELEV TRANSAMINASE/LDH */
'7905 ' = 151 /* ABN SERUM ENZY LEVEL NEC */
'7920 ' = 95 /* ABN FND-CEREBROSPINAL FL */
'7925 ' = 158 /* CLOUDY DIALYSIS EFFLUENT     OCT00 */
'7930 ' = 95 /* ABN FINDING-SKULL & HEAD */
'7931 ' = 133 /* ABN FINDINGS-LUNG FIELD */
'7937 ' = 211 /* ABN FIND-MUSCULOSKEL SYS */
'79391' = 58 /* IMAGE TEST INCON D/T FAT */
'79400' = 95 /* ABN CNS FUNCT STUDY NOS */
'79401' = 95 /* ABNORM ECHOENCEPHALOGRAM */
'79402' = 95 /* ABN ELECTROENCEPHALOGRAM */
'79409' = 95 /* ABN CNS FUNCT STUDY NEC */
'79410' = 95 /* ABN STIMUL RESPONSE NOS */
'79411' = 95 /* ABN RETINAL FUNCT STUDY */
'79412' = 95 /* ABNORM ELECTRO-OCULOGRAM */
'79413' = 95 /* ABNORMAL VEP */
'79414' = 95 /* ABN OCULOMOTOR STUDIES */
'79415' = 95 /* ABN AUDITORY FUNCT STUDY */
'79416' = 95 /* ABN VESTIBULAR FUNC STUD */
'79417' = 95 /* ABNORM ELECTROMYOGRAM */
'79419' = 95 /* ABN PERIPH NERV STUD NEC */
'7942 ' = 133 /* ABN PULMONARY FUNC STUDY */
'7945 ' = 48 /* ABN THYROID FUNCT STUDY */
'7946 ' = 51 /* ABN ENDOCRINE STUDY NEC */
'7947 ' = 58 /* ABN BASAL METABOL STUDY */
'7948 ' = 151 /* ABN LIVER FUNCTION STUDY */
'7951 ' = 41 /* ABN PAP SMEAR-OTH SITE */
'7952 ' = 217 /* ABN CHROMOSOMAL ANALYSIS */
'7957 ' = 58 /* IMMUNOLOGICAL FIND NEC */
'79579' = 58 /* NONSPECIFIC IMMUN FINDING NOS OCT94 */
'7961 ' = 95 /* ABNORMAL REFLEX */
'7994 ' = 52 /* CACHEXIA */
'80600' = 227 /* C1-C4 FX-CL/CORD INJ NOS */
'80601' = 227 /* C1-C4 FX-CL/COM CORD LES */
'80602' = 227 /* C1-C4 FX-CL/ANT CORD SYN */
'80603' = 227 /* C1-C4 FX-CL/CEN CORD SYN */
'80604' = 227 /* C1-C4 FX-CL/CORD INJ NEC */
'80605' = 227 /* C5-C7 FX-CL/CORD INJ NOS */
'80606' = 227 /* C5-C7 FX-CL/COM CORD LES */
'80607' = 227 /* C5-C7 FX-CL/ANT CORD SYN */
'80608' = 227 /* C5-C7 FX-CL/CEN CORD SYN */
'80609' = 227 /* C5-C7 FX-CL/CORD INJ NEC */
'80610' = 227 /* C1-C4 FX-OP/CORD INJ NOS */
'80611' = 227 /* C1-C4 FX-OP/COM CORD LES */
'80612' = 227 /* C1-C4 FX-OP/ANT CORD SYN */
'80613' = 227 /* C1-C4 FX-OP/CEN CORD SYN */
'80614' = 227 /* C1-C4 FX-OP/CORD INJ NEC */
'80615' = 227 /* C5-C7 FX-OP/CORD INJ NOS */
'80616' = 227 /* C5-C7 FX-OP/COM CORD LES */
'80617' = 227 /* C5-C7 FX-OP/ANT CORD SYN */
'80618' = 227 /* C5-C7 FX-OP/CEN CORD SYN */
'80619' = 227 /* C5-C7 FX-OP/CORD INJ NEC */
'80620' = 227 /* T1-T6 FX-CL/CORD INJ NOS */
'80621' = 227 /* T1-T6 FX-CL/COM CORD LES */
'80622' = 227 /* T1-T6 FX-CL/ANT CORD SYN */
'80623' = 227 /* T1-T6 FX-CL/CEN CORD SYN */
'80624' = 227 /* T1-T6 FX-CL/CORD INJ NEC */
'80625' = 227 /* T7-T12 FX-CL/CRD INJ NOS */
'80626' = 227 /* T7-T12 FX-CL/COM CRD LES */
'80627' = 227 /* T7-T12 FX-CL/ANT CRD SYN */
'80628' = 227 /* T7-T12 FX-CL/CEN CRD SYN */
'80629' = 227 /* T7-T12 FX-CL/CRD INJ NEC */
'80630' = 227 /* T1-T6 FX-OP/CORD INJ NOS */
'80631' = 227 /* T1-T6 FX-OP/COM CORD LES */
'80632' = 227 /* T1-T6 FX-OP/ANT CORD SYN */
'80633' = 227 /* T1-T6 FX-OP/CEN CORD SYN */
'80634' = 227 /* T1-T6 FX-OP/CORD INJ NEC */
'80635' = 227 /* T7-T12 FX-OP/CRD INJ NOS */
'80636' = 227 /* T7-T12 FX-OP/COM CRD LES */
'80637' = 227 /* T7-T12 FX-OP/ANT CRD SYN */
'80638' = 227 /* T7-T12 FX-OP/CEN CRD SYN */
'80639' = 227 /* T7-T12 FX-OP/CRD INJ NEC */
'8064 ' = 227 /* CL LUMBAR FX W CORD INJ */
'8065 ' = 227 /* OPN LUMBAR FX W CORD INJ */
'80660' = 227 /* FX SACRUM-CL/CRD INJ NOS */
'80661' = 227 /* FX SACR-CL/CAUDA EQU LES */
'80662' = 227 /* FX SACR-CL/CAUDA INJ NEC */
'80669' = 227 /* FX SACRUM-CL/CRD INJ NEC */
'80670' = 227 /* FX SACRUM-OP/CRD INJ NOS */
'80671' = 227 /* FX SACR-OP/CAUDA EQU LES */
'80672' = 227 /* FX SACR-OP/CAUDA INJ NEC */
'80679' = 227 /* FX SACRUM-OP/CRD INJ NEC */
'8068 ' = 227 /* VERT FX NOS-CL W CRD INJ */
'8069 ' = 227 /* VERT FX NOS-OP W CRD INJ */
'9072 ' = 227 /* LATE EFF SPINAL CORD INJ */
'95200' = 227 /* C1-C4 SPIN CORD INJ NOS */
'95201' = 227 /* COMPLETE LES CORD/C1-C4 */
'95202' = 227 /* ANTERIOR CORD SYND/C1-C4 */
'95203' = 227 /* CENTRAL CORD SYND/C1-C4 */
'95204' = 227 /* C1-C4 SPIN CORD INJ NEC */
'95205' = 227 /* C5-C7 SPIN CORD INJ NOS */
'95206' = 227 /* COMPLETE LES CORD/C5-C7 */
'95207' = 227 /* ANTERIOR CORD SYND/C5-C7 */
'95208' = 227 /* CENTRAL CORD SYND/C5-C7 */
'95209' = 227 /* C5-C7 SPIN CORD INJ NEC */
'95210' = 227 /* T1-T6 SPIN CORD INJ NOS */
'95211' = 227 /* COMPLETE LES CORD/T1-T6 */
'95212' = 227 /* ANTERIOR CORD SYND/T1-T6 */
'95213' = 227 /* CENTRAL CORD SYND/T1-T6 */
'95214' = 227 /* T1-T6 SPIN CORD INJ NEC */
'95215' = 227 /* T7-T12 SPIN CORD INJ NOS */
'95216' = 227 /* COMPLETE LES CORD/T7-T12 */
'95217' = 227 /* ANTERIOR CORD SYN/T7-T12 */
'95218' = 227 /* CENTRAL CORD SYN/T7-T12 */
'95219' = 227 /* T7-T12 SPIN CORD INJ NEC */
'9522 ' = 227 /* LUMBAR SPINAL CORD INJUR */
'9523 ' = 227 /* SACRAL SPINAL CORD INJUR */
'9524 ' = 227 /* CAUDA EQUINA INJURY */
'9528 ' = 227 /* SPIN CORD INJ-MULT SITE */
'9529 ' = 227 /* SPINAL CORD INJURY NOS */
'9941 ' = 85 /* DROWNING-NONFATAL SUBMER */
'V1029' = 41 /* HX-INTRATHORACIC MAL NEC */
'V1052' = 33 /* HX OF KIDNEY MALIGNANCY */
'V1060' = 39 /* HX OF LEUKEMIA NOS */
'V1061' = 39 /* HX OF LYMPHOID LEUKEMIA */
'V1062' = 39 /* HX OF MYELOID LEUKEMIA */
'V1063' = 39 /* HX OF MONOCYTIC LEUKEMIA */
'V1069' = 39 /* HX OF LEUKEMIA NEC */
'V1071' = 38 /* HX-LYMPHOSARCOMA */
'V1079' = 38 /* HX-LYMPHATIC MALIGN NEC */
'V1081' = 41 /* HX OF BONE MALIGNANCY */
'V1084' = 41 /* HX OF EYE MALIGNANCY */
'V1085' = 35 /* HX OF BRAIN MALIGNANCY */
'V1086' = 35 /* HX-MALIGN NERVE SYST NEC */
'V1088' = 41 /* HX-ENDOCRINE MALIGN NEC */
'V1089' = 41 /* HX OF MALIGNANCY NEC */
'V109 ' = 41 /* HX OF MALIGNANCY NOS */
'V121 ' = 52 /* HX-NUTRITION DEFICIENCY */
'V122 ' = 58 /* HX-ENDOCR/META/IMMUN DIS */
'V124 ' = 95 /* HX-NERV SYS/SENS ORG DIS */
'V1240' = 95 /* PERS HX UNSPEC NERV SYS DX OCT97 */
'V1241' = 95 /* PERS HX BENIGN NEOP BRAIN OCT97 */
'V1242' = 95 /* PERSONL HX INFECTION CNS */
'V1249' = 95 /* PERS HX OT DIS NERV SYS OCT97 */
'V126 ' = 133 /* HX-RESPIRATORY SYS DIS */
'V1260' = 133 /* HX RESP SYSTEM DIS NOS */
'V1261' = 133 /* PRSNL HX RECUR PNEUMONIA */
'V1269' = 133 /* HX RESP SYSTEM DIS NEC */
'V135 ' = 211 /* HX-MUSCULOSKELET DIS NEC */
'V136 ' = 217 /* HX-CONGENITAL MALFORM */
'V1361' = 215 /* HX HYPOSPADIAS   OCT98 */
'V1369' = 217 /* HX OTH CONG ANOM  OCT98 */
'V137 ' = 224 /* HX-PERINATAL PROBLEMS */
'V1582' = 67 /* HX TOBACCO USE OCT94 */
'V2130' = 219 /* LOW BIRTH WEIGHT UNSPEC     OCT00 */
'V2131' = 219 /* LOW BIRTH WEIGHT- < 500 GRAMS   OCT00 */
'V2132' = 219 /* LOW BIRTH WEIGHT- 500-999 GRAMS OCT00 */
'V2133' = 219 /* LOW BIRTH WEIGHT- 1000-1499 GRAMS OCT00 */
'V2134' = 219 /* LOW BIRTH WEIGHT- 1500-1999 GRAMS OCT00 */
'V2135' = 219 /* LOW BIRTH WEIGHT- 2000-2500 GRAMS OCT00 */
'V415 ' = 95 /* SMELL AND TASTE PROBLEM */
'V420 ' = 158 /* KIDNEY TRANSPLANT STATUS */
'V422 ' = 96 /* HEART VALVE TRANSPLANT */
'V426 ' = 133 /* LUNG TRANSPLANT STATUS */
'V427 ' = 151 /* LIVER TRANSPLANT STATUS */
'V433 ' = 96 /* HEART VALVE REPLAC NEC */
'V436 ' = 211 /* JOINT REPLACEMENT NEC */
'V4360' = 211 /* JOINT REPLACE NOS OCT94 */
'V4361' = 211 /* JOINT REPLACE SHOULDER OCT94 */
'V4362' = 211 /* JOINT REPLACE ELBOW OCT94 */
'V4363' = 211 /* JOINT REPLACE WRIST OCT94 */
'V4364' = 211 /* JOINT REPLACE HIP OCT94 */
'V4365' = 211 /* JOINT REPLACE KNEE OCT94 */
'V4366' = 211 /* JOINT REPLACE ANKLE OCT94 */
'V4369' = 211 /* JOINT REPLACE NEC OCT94 */
'V437 ' = 211 /* LIMB REPLACEMENT NEC */
'V441 ' = 52 /* GASTROSTOMY STATUS */
'V450 ' = 105 /* CARDIAC PACEMAKER STATUS */
'V4500' = 105 /* CARDIAC DEVICE NOS IN SITU  OCT94 */
'V4501' = 105 /* CARDIAC PACEM IN SITU OCT94 */
'V4502' = 105 /* AUTO IMPLANT DEBRIL IN SITU OCT94 */
'V4509' = 105 /* OTH CARDIAC DEVICE NEC IN SITU OCT94 */
'V451 ' = 158 /* RENAL DIALYSIS STATUS */
'V452 ' = 95 /* VENTRICULAR SHUNT STATUS */
'V454 ' = 211 /* ARTHRODESIS STATUS */
'V481 ' = 211 /* DEFICIENCIES NECK/TRUNK */
'V482 ' = 211 /* MECHANICAL PROB W HEAD */
'V483 ' = 211 /* MECH PROB W NECK & TRUNK */
'V484 ' = 95 /* SENSORY PROBLEM W HEAD */
'V485 ' = 95 /* SENSOR PROB W NECK/TRUNK */
'V490 ' = 211 /* DEFICIENCIES OF LIMBS */
'V491 ' = 211 /* MECHANICAL PROB W LIMBS */
'V492 ' = 211 /* MOTOR PROBLEMS W LIMBS */
'V493 ' = 95 /* SENSORY PROBLEMS W LIMBS */
'V495 ' = 211 /* LIMB PROBLEMS NEC */
'V4960' = 211 /* AMPUTATION STATUS - UPP EXT NOS OCT94 */
'V4961' = 211 /* AMPUTATION STATUS - THUMB OCT94 */
'V4962' = 211 /* AMPUTATION STATUS - OTH FINGER OCT94 */
'V4963' = 211 /* AMPUTATION STATUS - HAND OCT94 */
'V4964' = 211 /* AMPUTATION STATUS - WRIST OCT94 */
'V4965' = 211 /* AMPUTATION STATUS - BELOW ELBOW OCT94 */
'V4966' = 211 /* AMPUTATION STATUS - ABOVE ELBOW OCT94 */
'V4967' = 211 /* AMPUTATION STATUS - SHOULDER OCT94 */
'V4970' = 211 /* AMPUTATION STATUS - LOW EXT NOS OCT94 */
'V4971' = 211 /* AMPUTATION STATUS - GREAT TOE OCT94 */
'V4972' = 211 /* AMPUTATION STATUS - OTHER TOE OCT94 */
'V4973' = 211 /* AMPUTATION STATUS - FOOT OCT94 */
'V4974' = 211 /* AMPUTATION STATUS - ANKLE OCT94 */
'V4975' = 211 /* AMPUTATION STATUS - BELOW KNEE OCT94 */
'V4976' = 211 /* AMPUTATION STATUS - ABOVE KNEE OCT94 */
'V4977' = 211 /* AMPUTATION STATUS - HIP OCT94 */
'V502 ' = 224 /* ROUTINE CIRCUMCISION */
'V530 ' = 95 /* ADJUST NERV SYST DEVICE */
'V5301' = 95 /* FIT ADJUST CEREBR VENTR SHUNT OCT97 */
'V5302' = 95 /* FIT ADJUST NEUROPACEMAKER OCT97 */
'V5309' = 95 /* FIT ADJUST OT NERV SYS DEV OCT97 */
'V533 ' = 105 /* ADJUST CARDIAC PACEMAKER */
'V5331' = 105 /* ADJUST CARDIAC PACEMAKER OCT94 */
'V5332' = 105 /* ADJUST AUTO IMPLANT DEBRIL  OCT94 */
'V5339' = 105 /* ADJUST OTH CARDIAC DEVICE OCT94 */
'V537 ' = 211 /* FIT ORTHOPEDIC DEVICES */
'V560 ' = 158 /* RENAL DIALYSIS ENCOUNTER */
'V561 ' = 158 /* FIT ADJUST DIALYSIS CATHET OCT95 */
'V562 ' = 158 /* FIT ADJUST PERITON DIAL CATH OCT98 */
'V5631' = 158 /* ADEQUACY TESTING-HEMODIALYSIS    OCT00 */
'V5632' = 158 /* ADEQUACY TESTING-PERITONEAL DIALYSIS OCT00 */
'V568 ' = 158 /* DIALYSIS ENCOUNTER- NEC */
'V711 ' = 41 /* OBSV-SUSPCT MAL NEOPLASM */
'V850 ' = 58 /* BMI LESS THAN 19 */
'V8521' = 58 /* BMI 25.0-25.9 */
'V8522' = 58 /* BMI 26.0-26.9 */
'V8523' = 58 /* BMI 27.0-27.9 */
'V8524' = 58 /* BMI 28.0-28.9 */
'V8525' = 58 /* BMI 29.0-29.9 */
'V8530' = 58 /* BMI 30.0-30.9 */
'V8531' = 58 /* BMI 31.0-31.9 */
'V8532' = 58 /* BMI 32.0-32.9 */
'V8533' = 58 /* BMI 33.0-33.9 */
'V8534' = 58 /* BMI 34.0-34.9 */
'V8535' = 58 /* BMI 35.0-35.9 */
'V8536' = 58 /* BMI 36.0-36.9 */
'V8537' = 58 /* BMI 37.0-37.9 */
'V8538' = 58 /* BMI 38.0-38.9 */
'V8539' = 58 /* BMI 39.0-39.9 */
'V854 ' = 58 /* BMI 40 AND OVER */
'V8551' = 58 /* BMI, PEDIATRIC <5% */
'V8553' = 58 /* BMI, PEDIATRIC 85% - <95% */
'V8554' = 58 /* BMI, PEDIATRIC >= 95%     */
OTHER   = 0
;

VALUE $DRGFMT
"001" = 101 /* CRANIOTOMY AGE >17 W CC  */
"002" = 101 /* CRANIOTOMY AGE >17 WO CC  */
"003" = 102 /* CRANIOTOMY AGE 0-17  */
"004" = 103 /* SPINAL PROCEDURES (NO LONGER VALID)  */
"005" = 104 /* EXTRACRANIAL VASCULAR PROCEDURES (NO LONGER VALID)  */
"006" = 105 /* CARPAL TUNNEL RELEASE  */
"007" = 106 /* PERIPH & CRANIAL NERVE & OTHER NERV SYST PROC W CC  */
"008" = 106 /* PERIPH & CRANIAL NERVE & OTHER NERV SYST PROC WO CC  */
"009" = 107 /* SPINAL DISORDERS & INJURIES  */
"010" = 108 /* NERVOUS SYSTEM NEOPLASMS W CC  */
"011" = 108 /* NERVOUS SYSTEM NEOPLASMS WO CC  */
"012" = 109 /* DEGENERATIVE NERVOUS SYSTEM DISORDERS  */
"013" = 110 /* MULTIPLE SCLEROSIS & CEREBELLAR ATAXIA  */
"014" = 111 /* INTRACRANIAL HEMORRHAGE & STROKE W INFARCT  */
"015" = 112 /* NONSPECIFIC CVA & PRECEREBRAL OCCLUSION WO INFARCT  */
"016" = 113 /* NONSPECIFIC CEREBROVASCULAR DISORDERS W CC  */
"017" = 113 /* NONSPECIFIC CEREBROVASCULAR DISORDERS WO CC  */
"018" = 114 /* CRANIAL & PERIPHERAL NERVE DISORDERS W CC  */
"019" = 114 /* CRANIAL & PERIPHERAL NERVE DISORDERS WO CC  */
"020" = 115 /* NERVOUS SYSTEM INFECTION EXCEPT VIRAL MENINGITIS (NO LONGER VALID)  */
"021" = 116 /* VIRAL MENINGITIS  */
"022" = 117 /* HYPERTENSIVE ENCEPHALOPATHY  */
"023" = 118 /* NONTRAUMATIC STUPOR & COMA  */
"024" = 119 /* SEIZURE & HEADACHE AGE >17 W CC (NO LONGER VALID)  */
"025" = 119 /* SEIZURE & HEADACHE AGE >17 WO CC (NO LONGER VALID)  */
"026" = 120 /* SEIZURE & HEADACHE AGE 0-17  */
"027" = 121 /* TRAUMATIC STUPOR & COMA, COMA >1 HR  */
"028" = 122 /* TRAUMATIC STUPOR & COMA, COMA <1 HR AGE >17 W CC  */
"029" = 122 /* TRAUMATIC STUPOR & COMA, COMA <1 HR AGE >17 WO CC  */
"030" = 123 /* TRAUMATIC STUPOR & COMA, COMA <1 HR AGE 0-17  */
"031" = 124 /* CONCUSSION AGE >17 W CC  */
"032" = 124 /* CONCUSSION AGE >17 WO CC  */
"033" = 125 /* CONCUSSION AGE 0-17  */
"034" = 126 /* OTHER DISORDERS OF NERVOUS SYSTEM W CC  */
"035" = 126 /* OTHER DISORDERS OF NERVOUS SYSTEM WO CC  */
"036" = 201 /* RETINAL PROCEDURES  */
"037" = 202 /* ORBITAL PROCEDURES  */
"038" = 203 /* PRIMARY IRIS PROCEDURES  */
"039" = 204 /* LENS PROCEDURES WITH OR WITHOUT VITRECTOMY  */
"040" = 205 /* EXTRAOCULAR PROCEDURES EXCEPT ORBIT AGE >17  */
"041" = 206 /* EXTRAOCULAR PROCEDURES EXCEPT ORBIT AGE 0-17  */
"042" = 207 /* INTRAOCULAR PROCEDURES EXCEPT RETINA, IRIS & LENS  */
"043" = 208 /* HYPHEMA  */
"044" = 209 /* ACUTE MAJOR EYE INFECTIONS  */
"045" = 210 /* NEUROLOGICAL EYE DISORDERS  */
"046" = 211 /* OTHER DISORDERS OF THE EYE AGE >17 W CC  */
"047" = 211 /* OTHER DISORDERS OF THE EYE AGE >17 WO CC  */
"048" = 212 /* OTHER DISORDERS OF THE EYE AGE 0-17  */
"049" = 301 /* MAJOR HEAD & NECK PROCEDURES  */
"050" = 302 /* SIALOADENECTOMY  */
"051" = 303 /* SALIVARY GLAND PROCEDURES EXCEPT SIALOADENECTOMY  */
"052" = 304 /* CLEFT LIP & PALATE REPAIR  */
"053" = 305 /* SINUS & MASTOID PROCEDURES AGE >17  */
"054" = 306 /* SINUS & MASTOID PROCEDURES AGE 0-17  */
"055" = 307 /* MISCELLANEOUS EAR, NOSE, MOUTH & THROAT PROCEDURES  */
"056" = 308 /* RHINOPLASTY  */
"057" = 309 /* T&A PROC, EXCEPT TONSILLECTOMY &/OR ADENOIDECTOMY ONLY, */
"058" = 310 /* T&A PROC, EXCEPT TONSILLECTOMY &/OR ADENOIDECTOMY ONLY, */
"059" = 311 /* TONSILLECTOMY &/OR ADENOIDECTOMY ONLY, AGE >17  */
"060" = 312 /* TONSILLECTOMY &/OR ADENOIDECTOMY ONLY, AGE 0-17  */
"061" = 313 /* MYRINGOTOMY W TUBE INSERTION AGE >17  */
"062" = 314 /* MYRINGOTOMY W TUBE INSERTION AGE 0-17  */
"063" = 315 /* OTHER EAR, NOSE, MOUTH & THROAT O.R. PROCEDURES  */
"064" = 316 /* EAR, NOSE, MOUTH & THROAT MALIGNANCY  */
"065" = 317 /* DYSEQUILIBRIUM  */
"066" = 318 /* EPISTAXIS  */
"067" = 319 /* EPIGLOTTITIS  */
"068" = 320 /* OTITIS MEDIA & URI AGE >17 W CC  */
"069" = 320 /* OTITIS MEDIA & URI AGE >17 WO CC  */
"070" = 321 /* OTITIS MEDIA & URI AGE 0-17  */
"071" = 322 /* LARYNGOTRACHEITIS  */
"072" = 323 /* NASAL TRAUMA & DEFORMITY  */
"073" = 324 /* OTHER EAR, NOSE, MOUTH & THROAT DIAGNOSES AGE >17  */
"074" = 325 /* OTHER EAR, NOSE, MOUTH & THROAT DIAGNOSES AGE 0-17  */
"075" = 401 /* MAJOR CHEST PROCEDURES  */
"076" = 402 /* OTHER RESP SYSTEM O.R. PROCEDURES W CC  */
"077" = 402 /* OTHER RESP SYSTEM O.R. PROCEDURES WO CC  */
"078" = 403 /* PULMONARY EMBOLISM  */
"079" = 404 /* RESPIRATORY INFECTIONS & INFLAMMATIONS AGE >17 W CC  */
"080" = 404 /* RESPIRATORY INFECTIONS & INFLAMMATIONS AGE >17 WO CC  */
"081" = 405 /* RESPIRATORY INFECTIONS & INFLAMMATIONS AGE 0-17  */
"082" = 406 /* RESPIRATORY NEOPLASMS  */
"083" = 407 /* MAJOR CHEST TRAUMA W CC  */
"084" = 407 /* MAJOR CHEST TRAUMA WO CC  */
"085" = 408 /* PLEURAL EFFUSION W CC  */
"086" = 408 /* PLEURAL EFFUSION WO CC  */
"087" = 409 /* PULMONARY EDEMA & RESPIRATORY FAILURE  */
"088" = 410 /* CHRONIC OBSTRUCTIVE PULMONARY DISEASE  */
"089" = 411 /* SIMPLE PNEUMONIA & PLEURISY AGE >17 W CC  */
"090" = 411 /* SIMPLE PNEUMONIA & PLEURISY AGE >17 WO CC  */
"091" = 412 /* SIMPLE PNEUMONIA & PLEURISY AGE 0-17  */
"092" = 413 /* INTERSTITIAL LUNG DISEASE W CC  */
"093" = 413 /* INTERSTITIAL LUNG DISEASE WO CC  */
"094" = 414 /* PNEUMOTHORAX W CC  */
"095" = 414 /* PNEUMOTHORAX WO CC  */
"096" = 415 /* BRONCHITIS & ASTHMA AGE >17 W CC  */
"097" = 415 /* BRONCHITIS & ASTHMA AGE >17 WO CC  */
"098" = 416 /* BRONCHITIS & ASTHMA AGE 0-17  */
"099" = 417 /* RESPIRATORY SIGNS & SYMPTOMS W CC  */
"100" = 417 /* RESPIRATORY SIGNS & SYMPTOMS WO CC  */
"101" = 418 /* OTHER RESPIRATORY SYSTEM DIAGNOSES W CC  */
"102" = 418 /* OTHER RESPIRATORY SYSTEM DIAGNOSES WO CC  */
"103" = 7701 /* HEART TRANSPLANT  */
"104" = 501 /* CARDIAC VALVE & OTH MAJOR CARDIOTHORACIC PROC W CARD CAT */
"105" = 502 /* CARDIAC VALVE & OTH MAJOR CARDIOTHORACIC PROC WO CARD CA */
"106" = 503 /* CORONARY BYPASS W PTCA  */
"107" = 504 /* CORONARY BYPASS W CARDIAC CATH (NO LONGER VALID)  */
"108" = 505 /* OTHER CARDIOTHORACIC PROCEDURES  */
"109" = 506 /* CORONARY BYPASS WO PTCA OR CARDIAC CATH (NO LONGER VALID */
"110" = 507 /* MAJOR CARDIOVASCULAR PROCEDURES W CC  */
"111" = 507 /* MAJOR CARDIOVASCULAR PROCEDURES WO CC  */
"112" = 508 /* PERCUTANEOUS CARDIOVASCULAR PROCEDURES (NO LONGER VALID) */
"113" = 509 /* AMPUTATION FOR CIRC SYSTEM DISORDERS EXCEPT UPPER LIMB & */
"114" = 510 /* UPPER LIMB & TOE AMPUTATION FOR CIRC SYSTEM DISORDERS  */
"115" = 511 /* PRM CARD PACEM IMPL W AMI/HR/SHOCK OR AICD LEAD OR GNRTR */
"116" = 512 /* OTHER PERMANENT CARDIAC PACEMAKER IMPLANT (NO LONGER VAL */
"117" = 513 /* CARDIAC PACEMAKER REVISION EXCEPT DEVICE REPLACEMENT  */
"118" = 514 /* CARDIAC PACEMAKER DEVICE REPLACEMENT  */
"119" = 515 /* VEIN LIGATION & STRIPPING  */
"120" = 516 /* OTHER CIRCULATORY SYSTEM O.R. PROCEDURES  */
"121" = 517 /* CIRCULATORY DISORDERS W AMI & MAJOR COMP, DISCHARGED ALI */
"122" = 517 /* CIRCULATORY DISORDERS W AMI WO MAJOR COMP, DISCHARGED AL */
"123" = 517 /* CIRCULATORY DISORDERS W AMI, EXPIRED  */
"124" = 518 /* CIRCULATORY DISORDERS EXCEPT AMI, W CARD CATH & COMPLEX */
"125" = 519 /* CIRCULATORY DISORDERS EXCEPT AMI, W CARD CATH W/O COMPLEX DIAG */
"126" = 520 /* ACUTE & SUBACUTE ENDOCARDITIS  */
"127" = 521 /* HEART FAILURE & SHOCK  */
"128" = 522 /* DEEP VEIN THROMBOPHLEBITIS  */
"129" = 523 /* CARDIAC ARREST, UNEXPLAINED  */
"130" = 524 /* PERIPHERAL VASCULAR DISORDERS W CC  */
"131" = 524 /* PERIPHERAL VASCULAR DISORDERS WO CC  */
"132" = 525 /* ATHEROSCLEROSIS W CC  */
"133" = 525 /* ATHEROSCLEROSIS WO CC  */
"134" = 526 /* HYPERTENSION  */
"135" = 527 /* CARDIAC CONGENITAL & VALVULAR DISORDERS AGE >17 W CC  */
"136" = 527 /* CARDIAC CONGENITAL & VALVULAR DISORDERS AGE >17 WO CC  */
"137" = 528 /* CARDIAC CONGENITAL & VALVULAR DISORDERS AGE 0-17  */
"138" = 529 /* CARDIAC ARRHYTHMIA & CONDUCTION DISORDERS W CC  */
"139" = 529 /* CARDIAC ARRHYTHMIA & CONDUCTION DISORDERS WO CC  */
"140" = 530 /* ANGINA PECTORIS  */
"141" = 531 /* SYNCOPE & COLLAPSE W CC  */
"142" = 531 /* SYNCOPE & COLLAPSE WO CC  */
"143" = 532 /* CHEST PAIN  */
"144" = 533 /* OTHER CIRCULATORY SYSTEM DIAGNOSES W CC  */
"145" = 533 /* OTHER CIRCULATORY SYSTEM DIAGNOSES WO CC  */
"146" = 601 /* RECTAL RESECTION W CC  */
"147" = 601 /* RECTAL RESECTION WO CC  */
"148" = 602 /* MAJOR SMALL & LARGE BOWEL PROCEDURES W CC (NO LONGER VALID)  */
"149" = 602 /* MAJOR SMALL & LARGE BOWEL PROCEDURES WO CC  */
"150" = 603 /* PERITONEAL ADHESIOLYSIS W CC  */
"151" = 603 /* PERITONEAL ADHESIOLYSIS WO CC  */
"152" = 604 /* MINOR SMALL & LARGE BOWEL PROCEDURES W CC  */
"153" = 604 /* MINOR SMALL & LARGE BOWEL PROCEDURES WO CC  */
"154" = 605 /* STOMACH, ESOPHAGEAL & DUODENAL PROCEDURES AGE >17 W CC (NO LONGER VALID)  */
"155" = 605 /* STOMACH, ESOPHAGEAL & DUODENAL PROCEDURES AGE >17 WO CC */
"156" = 606 /* STOMACH, ESOPHAGEAL & DUODENAL PROCEDURES AGE 0-17  */
"157" = 607 /* ANAL & STOMAL PROCEDURES W CC  */
"158" = 607 /* ANAL & STOMAL PROCEDURES WO CC  */
"159" = 608 /* HERNIA PROCEDURES EXCEPT INGUINAL & FEMORAL AGE >17 W CC */
"160" = 608 /* HERNIA PROCEDURES EXCEPT INGUINAL & FEMORAL AGE >17 WO C */
"161" = 609 /* INGUINAL & FEMORAL HERNIA PROCEDURES AGE >17 W CC  */
"162" = 609 /* INGUINAL & FEMORAL HERNIA PROCEDURES AGE >17 WO CC  */
"163" = 610 /* HERNIA PROCEDURES AGE 0-17  */
"164" = 611 /* APPENDECTOMY W COMPLICATED PRINCIPAL DIAG W CC  */
"165" = 611 /* APPENDECTOMY W COMPLICATED PRINCIPAL DIAG WO CC  */
"166" = 612 /* APPENDECTOMY WO COMPLICATED PRINCIPAL DIAG W CC  */
"167" = 612 /* APPENDECTOMY WO COMPLICATED PRINCIPAL DIAG WO CC  */
"168" = 326 /* MOUTH PROCEDURES W CC  */
"169" = 326 /* MOUTH PROCEDURES WO CC  */
"170" = 613 /* OTHER DIGESTIVE SYSTEM O.R. PROCEDURES W CC  */
"171" = 613 /* OTHER DIGESTIVE SYSTEM O.R. PROCEDURES WO CC  */
"172" = 614 /* DIGESTIVE MALIGNANCY W CC  */
"173" = 614 /* DIGESTIVE MALIGNANCY WO CC  */
"174" = 615 /* G.I. HEMORRHAGE W CC  */
"175" = 615 /* G.I. HEMORRHAGE WO CC  */
"176" = 616 /* COMPLICATED PEPTIC ULCER  */
"177" = 617 /* UNCOMPLICATED PEPTIC ULCER W CC  */
"178" = 617 /* UNCOMPLICATED PEPTIC ULCER WO CC  */
"179" = 618 /* INFLAMMATORY BOWEL DISEASE  */
"180" = 619 /* G.I. OBSTRUCTION W CC  */
"181" = 619 /* G.I. OBSTRUCTION WO CC  */
"182" = 620 /* ESOPHAGITIS, GASTROENT & MISC DIGEST DISORDERS AGE >17 W */
"183" = 620 /* ESOPHAGITIS, GASTROENT & MISC DIGEST DISORDERS AGE >17 W */
"184" = 621 /* ESOPHAGITIS, GASTROENT & MISC DIGEST DISORDERS AGE 0-17 */
"185" = 327 /* DENTAL & ORAL DIS EXCEPT EXTRACTIONS & RESTORATIONS, AGE */
"186" = 328 /* DENTAL & ORAL DIS EXCEPT EXTRACTIONS & RESTORATIONS, AGE */
"187" = 329 /* DENTAL EXTRACTIONS & RESTORATIONS  */
"188" = 622 /* OTHER DIGESTIVE SYSTEM DIAGNOSES AGE >17 W CC  */
"189" = 622 /* OTHER DIGESTIVE SYSTEM DIAGNOSES AGE >17 WO CC  */
"190" = 623 /* OTHER DIGESTIVE SYSTEM DIAGNOSES AGE 0-17  */
"191" = 701 /* PANCREAS, LIVER & SHUNT PROCEDURES W CC  */
"192" = 701 /* PANCREAS, LIVER & SHUNT PROCEDURES WO CC  */
"193" = 702 /* BILIARY TRACT PROC EXCEPT ONLY CHOLECYST W OR WO C.D.E. */
"194" = 702 /* BILIARY TRACT PROC EXCEPT ONLY CHOLECYST W OR WO C.D.E. */
"195" = 703 /* CHOLECYSTECTOMY W C.D.E. W CC  */
"196" = 703 /* CHOLECYSTECTOMY W C.D.E. WO CC  */
"197" = 704 /* CHOLECYSTECTOMY EXCEPT BY LAPAROSCOPE WO C.D.E. W CC  */
"198" = 704 /* CHOLECYSTECTOMY EXCEPT BY LAPAROSCOPE WO C.D.E. WO CC  */
"199" = 705 /* HEPATOBILIARY DIAGNOSTIC PROCEDURE FOR MALIGNANCY  */
"200" = 706 /* HEPATOBILIARY DIAGNOSTIC PROCEDURE FOR NON-MALIGNANCY  */
"201" = 707 /* OTHER HEPATOBILIARY OR PANCREAS O.R. PROCEDURES  */
"202" = 708 /* CIRRHOSIS & ALCOHOLIC HEPATITIS  */
"203" = 709 /* MALIGNANCY OF HEPATOBILIARY SYSTEM OR PANCREAS  */
"204" = 710 /* DISORDERS OF PANCREAS EXCEPT MALIGNANCY  */
"205" = 711 /* DISORDERS OF LIVER EXCEPT MALIG,CIRR,ALC HEPA W CC  */
"206" = 711 /* DISORDERS OF LIVER EXCEPT MALIG,CIRR,ALC HEPA WO CC  */
"207" = 712 /* DISORDERS OF THE BILIARY TRACT W CC  */
"208" = 712 /* DISORDERS OF THE BILIARY TRACT WO CC  */
"209" = 801 /* MAJOR JOINT & LIMB REATTACHMENT PROCEDURES OF LOWER EXTR */
"210" = 802 /* HIP & FEMUR PROCEDURES EXCEPT MAJOR JOINT AGE >17 W CC  */
"211" = 802 /* HIP & FEMUR PROCEDURES EXCEPT MAJOR JOINT AGE >17 WO CC */
"212" = 803 /* HIP & FEMUR PROCEDURES EXCEPT MAJOR JOINT AGE 0-17  */
"213" = 804 /* AMPUTATION FOR MUSCULOSKELETAL SYSTEM & CONN TISSUE DISO */
"214" = 805 /* BACK & NECK PROC W CC (NO LONGER VALID)  */
"215" = 805 /* BACK & NECK PROC WO CC (NO LONGER VALID)  */
"216" = 806 /* BIOPSIES OF MUSCULOSKELETAL SYSTEM & CONNECTIVE TISSUE  */
"217" = 807 /* WND DEBRID & SKN GRFT EXCEPT HAND,FOR MUSCSKELET & CONN */
"218" = 808 /* LOWER EXTREM & HUMER PROC EXCEPT HIP,FOOT,FEMUR AGE >17 */
"219" = 808 /* LOWER EXTREM & HUMER PROC EXCEPT HIP,FOOT,FEMUR AGE >17 */
"220" = 809 /* LOWER EXTREM & HUMER PROC EXCEPT HIP,FOOT,FEMUR AGE 0-17 */
"221" = 810 /* KNEE PROC W CC (NO LONGER VALID)  */
"222" = 810 /* KNEE PROC WO CC (NO LONGER VALID)  */
"223" = 811 /* MAJOR SHOULDER/ELBOW PROC, OR OTHER UPPER EXTREMITY PROC */
"224" = 811 /* SHOULDER,ELBOW OR FOREARM PROC,EXC MAJOR JOINT PROC, WO */
"225" = 812 /* FOOT PROCEDURES  */
"226" = 813 /* SOFT TISSUE PROCEDURES W CC  */
"227" = 813 /* SOFT TISSUE PROCEDURES WO CC  */
"228" = 814 /* MAJOR THUMB OR JOINT PROC,OR OTH HAND OR WRIST PROC W CC */
"229" = 814 /* HAND OR WRIST PROC, EXCEPT MAJOR JOINT PROC, WO CC  */
"230" = 815 /* LOCAL EXCISION & REMOVAL OF INT FIX DEVICES OF HIP & FEM */
"231" = 816 /* LOCAL EXCISION & REMOVAL OF INT FIX DEVICES EXCEPT HIP & */
"232" = 817 /* ARTHROSCOPY  */
"233" = 818 /* OTHER MUSCULOSKELET SYS & CONN TISS O.R. PROC W CC  */
"234" = 818 /* OTHER MUSCULOSKELET SYS & CONN TISS O.R. PROC WO CC  */
"235" = 819 /* FRACTURES OF FEMUR  */
"236" = 820 /* FRACTURES OF HIP & PELVIS  */
"237" = 821 /* SPRAINS, STRAINS, & DISLOCATIONS OF HIP, PELVIS & THIGH */
"238" = 822 /* OSTEOMYELITIS  */
"239" = 823 /* PATHOLOGICAL FRACTURES & MUSCULOSKELETAL & CONN TISS MAL */
"240" = 824 /* CONNECTIVE TISSUE DISORDERS W CC  */
"241" = 824 /* CONNECTIVE TISSUE DISORDERS WO CC  */
"242" = 825 /* SEPTIC ARTHRITIS  */
"243" = 826 /* MEDICAL BACK PROBLEMS  */
"244" = 827 /* BONE DISEASES & SPECIFIC ARTHROPATHIES W CC  */
"245" = 827 /* BONE DISEASES & SPECIFIC ARTHROPATHIES WO CC  */
"246" = 828 /* NON-SPECIFIC ARTHROPATHIES  */
"247" = 829 /* SIGNS & SYMPTOMS OF MUSCULOSKELETAL SYSTEM & CONN TISSUE */
"248" = 830 /* TENDONITIS, MYOSITIS & BURSITIS  */
"249" = 831 /* AFTERCARE, MUSCULOSKELETAL SYSTEM & CONNECTIVE TISSUE  */
"250" = 832 /* FX, SPRN, STRN & DISL OF FOREARM, HAND, FOOT AGE >17 W C */
"251" = 832 /* FX, SPRN, STRN & DISL OF FOREARM, HAND, FOOT AGE >17 WO */
"252" = 833 /* FX, SPRN, STRN & DISL OF FOREARM, HAND, FOOT AGE 0-17  */
"253" = 834 /* FX, SPRN, STRN & DISL OF UPARM,LOWLEG EX FOOT AGE >17 W */
"254" = 834 /* FX, SPRN, STRN & DISL OF UPARM,LOWLEG EX FOOT AGE >17 WO */
"255" = 835 /* FX, SPRN, STRN & DISL OF UPARM,LOWLEG EX FOOT AGE 0-17  */
"256" = 836 /* OTHER MUSCULOSKELETAL SYSTEM & CONNECTIVE TISSUE DIAGNOS */
"257" = 901 /* TOTAL MASTECTOMY FOR MALIGNANCY W CC  */
"258" = 901 /* TOTAL MASTECTOMY FOR MALIGNANCY WO CC  */
"259" = 902 /* SUBTOTAL MASTECTOMY FOR MALIGNANCY W CC  */
"260" = 902 /* SUBTOTAL MASTECTOMY FOR MALIGNANCY WO CC  */
"261" = 903 /* BREAST PROC FOR NON-MALIGNANCY EXCEPT BIOPSY & LOCAL EXC */
"262" = 904 /* BREAST BIOPSY & LOCAL EXCISION FOR NON-MALIGNANCY  */
"263" = 905 /* SKIN GRAFT &/OR DEBRID FOR SKN ULCER OR CELLULITIS W CC */
"264" = 905 /* SKIN GRAFT &/OR DEBRID FOR SKN ULCER OR CELLULITIS WO CC */
"265" = 906 /* SKIN GRAFT &/OR DEBRID EXCEPT FOR SKIN ULCER OR CELLULIT */
"266" = 906 /* SKIN GRAFT &/OR DEBRID EXCEPT FOR SKIN ULCER OR CELLULIT */
"267" = 907 /* PERIANAL & PILONIDAL PROCEDURES  */
"268" = 908 /* SKIN, SUBCUTANEOUS TISSUE & BREAST PLASTIC PROCEDURES  */
"269" = 909 /* OTHER SKIN, SUBCUT TISS & BREAST PROC W CC  */
"270" = 909 /* OTHER SKIN, SUBCUT TISS & BREAST PROC WO CC  */
"271" = 910 /* SKIN ULCERS  */
"272" = 911 /* MAJOR SKIN DISORDERS W CC  */
"273" = 911 /* MAJOR SKIN DISORDERS WO CC  */
"274" = 912 /* MALIGNANT BREAST DISORDERS W CC  */
"275" = 912 /* MALIGNANT BREAST DISORDERS WO CC  */
"276" = 913 /* NON-MALIGANT BREAST DISORDERS  */
"277" = 914 /* CELLULITIS AGE >17 W CC  */
"278" = 914 /* CELLULITIS AGE >17 WO CC  */
"279" = 915 /* CELLULITIS AGE 0-17  */
"280" = 916 /* TRAUMA TO THE SKIN, SUBCUT TISS & BREAST AGE >17 W CC  */
"281" = 916 /* TRAUMA TO THE SKIN, SUBCUT TISS & BREAST AGE >17 WO CC  */
"282" = 917 /* TRAUMA TO THE SKIN, SUBCUT TISS & BREAST AGE 0-17  */
"283" = 918 /* MINOR SKIN DISORDERS W CC  */
"284" = 918 /* MINOR SKIN DISORDERS WO CC  */
"285" = 1001 /* AMPUTAT OF LOWER LIMB FOR ENDOCRINE,NUTRIT,& METABOL DIS */
"286" = 1002 /* ADRENAL & PITUITARY PROCEDURES  */
"287" = 1003 /* SKIN GRAFTS & WOUND DEBRID FOR ENDOC, NUTRIT & METAB DIS */
"288" = 1004 /* O.R. PROCEDURES FOR OBESITY  */
"289" = 1005 /* PARATHYROID PROCEDURES  */
"290" = 1006 /* THYROID PROCEDURES  */
"291" = 1007 /* THYROGLOSSAL PROCEDURES  */
"292" = 1008 /* OTHER ENDOCRINE, NUTRIT & METAB O.R. PROC W CC  */
"293" = 1008 /* OTHER ENDOCRINE, NUTRIT & METAB O.R. PROC WO CC  */
"294" = 1009 /* DIABETES AGE >35  */
"295" = 1010 /* DIABETES AGE 0-35  */
"296" = 1011 /* NUTRITIONAL & MISC METABOLIC DISORDERS AGE >17 W CC  */
"297" = 1011 /* NUTRITIONAL & MISC METABOLIC DISORDERS AGE >17 WO CC  */
"298" = 1012 /* NUTRITIONAL & MISC METABOLIC DISORDERS AGE 0-17  */
"299" = 1013 /* INBORN ERRORS OF METABOLISM  */
"300" = 1014 /* ENDOCRINE DISORDERS W CC  */
"301" = 1014 /* ENDOCRINE DISORDERS WO CC  */
"302" = 1101 /* KIDNEY TRANSPLANT  */
"303" = 1102 /* KIDNEY,URETER & MAJOR BLADDER PROCEDURES FOR NEOPLASM  */
"304" = 1103 /* KIDNEY,URETER & MAJOR BLADDER PROC FOR NON-NEOPL W CC  */
"305" = 1103 /* KIDNEY,URETER & MAJOR BLADDER PROC FOR NON-NEOPL WO CC  */
"306" = 1104 /* PROSTATECTOMY W CC  */
"307" = 1104 /* PROSTATECTOMY WO CC  */
"308" = 1105 /* MINOR BLADDER PROCEDURES W CC  */
"309" = 1105 /* MINOR BLADDER PROCEDURES WO CC  */
"310" = 1106 /* TRANSURETHRAL PROCEDURES W CC  */
"311" = 1106 /* TRANSURETHRAL PROCEDURES WO CC  */
"312" = 1107 /* URETHRAL PROCEDURES, AGE >17 W CC  */
"313" = 1107 /* URETHRAL PROCEDURES, AGE >17 WO CC  */
"314" = 1108 /* URETHRAL PROCEDURES, AGE 0-17  */
"315" = 1109 /* OTHER KIDNEY & URINARY TRACT O.R. PROCEDURES  */
"316" = 1110 /* RENAL FAILURE  */
"317" = 1111 /* ADMIT FOR RENAL DIALYSIS  */
"318" = 1112 /* KIDNEY & URINARY TRACT NEOPLASMS W CC  */
"319" = 1112 /* KIDNEY & URINARY TRACT NEOPLASMS WO CC  */
"320" = 1113 /* KIDNEY & URINARY TRACT INFECTIONS AGE >17 W CC  */
"321" = 1113 /* KIDNEY & URINARY TRACT INFECTIONS AGE >17 WO CC  */
"322" = 1114 /* KIDNEY & URINARY TRACT INFECTIONS AGE 0-17  */
"323" = 1115 /* URINARY STONES W CC, &/OR ESW LITHOTRIPSY  */
"324" = 1115 /* URINARY STONES WO CC  */
"325" = 1116 /* KIDNEY & URINARY TRACT SIGNS & SYMPTOMS AGE >17 W CC  */
"326" = 1116 /* KIDNEY & URINARY TRACT SIGNS & SYMPTOMS AGE >17 WO CC  */
"327" = 1117 /* KIDNEY & URINARY TRACT SIGNS & SYMPTOMS AGE 0-17  */
"328" = 1118 /* URETHRAL STRICTURE AGE >17 W CC  */
"329" = 1118 /* URETHRAL STRICTURE AGE >17 WO CC  */
"330" = 1119 /* URETHRAL STRICTURE AGE 0-17  */
"331" = 1120 /* OTHER KIDNEY & URINARY TRACT DIAGNOSES AGE >17 W CC  */
"332" = 1120 /* OTHER KIDNEY & URINARY TRACT DIAGNOSES AGE >17 WO CC  */
"333" = 1121 /* OTHER KIDNEY & URINARY TRACT DIAGNOSES AGE 0-17  */
"334" = 1201 /* MAJOR MALE PELVIC PROCEDURES W CC  */
"335" = 1201 /* MAJOR MALE PELVIC PROCEDURES WO CC  */
"336" = 1202 /* TRANSURETHRAL PROSTATECTOMY W CC  */
"337" = 1202 /* TRANSURETHRAL PROSTATECTOMY WO CC  */
"338" = 1203 /* TESTES PROCEDURES, FOR MALIGNANCY  */
"339" = 1204 /* TESTES PROCEDURES, NON-MALIGNANCY AGE >17  */
"340" = 1205 /* TESTES PROCEDURES, NON-MALIGNANCY AGE 0-17  */
"341" = 1206 /* PENIS PROCEDURES  */
"342" = 1207 /* CIRCUMCISION AGE >17  */
"343" = 1208 /* CIRCUMCISION AGE 0-17  */
"344" = 1209 /* OTHER MALE REPRODUCTIVE SYSTEM O.R. PROCEDURES FOR MALIG */
"345" = 1210 /* OTHER MALE REPRODUCTIVE SYSTEM O.R. PROC EXCEPT FOR MALI */
"346" = 1211 /* MALIGNANCY, MALE REPRODUCTIVE SYSTEM, W CC  */
"347" = 1211 /* MALIGNANCY, MALE REPRODUCTIVE SYSTEM, WO CC  */
"348" = 1212 /* BENIGN PROSTATIC HYPERTROPHY W CC  */
"349" = 1212 /* BENIGN PROSTATIC HYPERTROPHY WO CC  */
"350" = 1213 /* INFLAMMATION OF THE MALE REPRODUCTIVE SYSTEM  */
"351" = 1214 /* STERILIZATION, MALE  */
"352" = 1215 /* OTHER MALE REPRODUCTIVE SYSTEM DIAGNOSES  */
"353" = 1301 /* PELVIC EVISCERATION, RADICAL HYSTERECTOMY & RADICAL VULV */
"354" = 1302 /* UTERINE,ADNEXA PROC FOR NON-OVARIAN/ADNEXAL MALIG W CC  */
"355" = 1302 /* UTERINE,ADNEXA PROC FOR NON-OVARIAN/ADNEXAL MALIG WO CC */
"356" = 1303 /* FEMALE REPRODUCTIVE SYSTEM RECONSTRUCTIVE PROCEDURES  */
"357" = 1304 /* UTERINE & ADNEXA PROC FOR OVARIAN OR ADNEXAL MALIGNANCY */
"358" = 1305 /* UTERINE & ADNEXA PROC FOR NON-MALIGNANCY W CC  */
"359" = 1305 /* UTERINE & ADNEXA PROC FOR NON-MALIGNANCY WO CC  */
"360" = 1306 /* VAGINA, CERVIX & VULVA PROCEDURES  */
"361" = 1307 /* LAPAROSCOPY & INCISIONAL TUBAL INTERRUPTION  */
"362" = 1308 /* ENDOSCOPIC TUBAL INTERRUPTION  */
"363" = 1309 /* D&C, CONIZATION & RADIO-IMPLANT, FOR MALIGNANCY  */
"364" = 1310 /* D&C, CONIZATION EXCEPT FOR MALIGNANCY  */
"365" = 1311 /* OTHER FEMALE REPRODUCTIVE SYSTEM O.R. PROCEDURES  */
"366" = 1312 /* MALIGNANCY, FEMALE REPRODUCTIVE SYSTEM W CC  */
"367" = 1312 /* MALIGNANCY, FEMALE REPRODUCTIVE SYSTEM WO CC  */
"368" = 1313 /* INFECTIONS, FEMALE REPRODUCTIVE SYSTEM  */
"369" = 1314 /* MENSTRUAL & OTHER FEMALE REPRODUCTIVE SYSTEM DISORDERS  */
"370" = 1401 /* CESAREAN SECTION W CC  */
"371" = 1401 /* CESAREAN SECTION WO CC  */
"372" = 1402 /* VAGINAL DELIVERY W COMPLICATING DIAGNOSES  */
"373" = 1403 /* VAGINAL DELIVERY W/O COMPLICATING DIAGNOSES */
"374" = 1404 /* VAGINAL DELIVERY W STERILIZATION &/OR D&C  */
"375" = 1405 /* VAGINAL DELIVERY W O.R. PROC EXCEPT STERIL &/OR D&C  */
"376" = 1406 /* POSTPARTUM & POST ABORTION DIAGNOSES WO O.R. PROCEDURE  */
"377" = 1407 /* POSTPARTUM & POST ABORTION DIAGNOSES W O.R. PROCEDURE  */
"378" = 1408 /* ECTOPIC PREGNANCY  */
"379" = 1409 /* THREATENED ABORTION  */
"380" = 1410 /* ABORTION WO D&C  */
"381" = 1411 /* ABORTION W D&C, ASPIRATION CURETTAGE OR HYSTEROTOMY  */
"382" = 1412 /* FALSE LABOR  */
"383" = 1413 /* OTHER ANTEPARTUM DIAGNOSES W MEDICAL COMPLICATIONS  */
"384" = 1414 /* OTHER ANTEPARTUM DIAGNOSES WO MEDICAL COMPLICATIONS  */
"385" = 1502 /* NEONATES, DIED OR TRANSFERRED TO ANOTHER ACUTE CARE FACI */
"386" = 1502 /* EXTREME IMMATURITY OR RESPIRATORY DISTRESS SYNDROME, NEO */
"387" = 1503 /* PREMATURITY W MAJOR PROBLEMS  */
"388" = 1504 /* PREMATURITY WO MAJOR PROBLEMS  */
"389" = 1505 /* FULL TERM NEONATE W MAJOR PROBLEMS  */
"390" = 1506 /* NEONATE W OTHER SIGNIFICANT PROBLEMS  */
"391" = 1507 /* NORMAL NEWBORN  */
"392" = 1601 /* SPLENECTOMY AGE >17  */
"393" = 1602 /* SPLENECTOMY AGE 0-17  */
"394" = 1603 /* OTHER O.R. PROCEDURES OF THE BLOOD AND BLOOD FORMING ORG */
"395" = 1604 /* RED BLOOD CELL DISORDERS AGE >17  */
"396" = 1605 /* RED BLOOD CELL DISORDERS AGE 0-17  */
"397" = 1606 /* COAGULATION DISORDERS  */
"398" = 1607 /* RETICULOENDOTHELIAL & IMMUNITY DISORDERS W CC  */
"399" = 1607 /* RETICULOENDOTHELIAL & IMMUNITY DISORDERS WO CC  */
"400" = 1701 /* LYMPHOMA & LEUKEMIA W MAJOR O.R. PROCEDURE (NO LONGER VA */
"401" = 1702 /* LYMPHOMA & NON-ACUTE LEUKEMIA W OTHER O.R. PROC W CC  */
"402" = 1702 /* LYMPHOMA & NON-ACUTE LEUKEMIA W OTHER O.R. PROC WO CC  */
"403" = 1703 /* LYMPHOMA & NON-ACUTE LEUKEMIA W CC  */
"404" = 1703 /* LYMPHOMA & NON-ACUTE LEUKEMIA WO CC  */
"405" = 1704 /* ACUTE LEUKEMIA WO MAJOR O.R. PROCEDURE AGE 0-17  */
"406" = 1705 /* MYELOPROLIF DISORD OR POORLY DIFF NEOPL W MAJ O.R.PROC W */
"407" = 1705 /* MYELOPROLIF DISORD OR POORLY DIFF NEOPL W MAJ O.R.PROC W */
"408" = 1706 /* MYELOPROLIF DISORD OR POORLY DIFF NEOPL W OTHER O.R.PROC */
"409" = 1707 /* RADIOTHERAPY  */
"410" = 1708 /* CHEMOTHERAPY WO ACUTE LEUKEMIA AS SECONDARY DIAGNOSIS  */
"411" = 1709 /* HISTORY OF MALIGNANCY WO ENDOSCOPY  */
"412" = 1710 /* HISTORY OF MALIGNANCY W ENDOSCOPY  */
"413" = 1711 /* OTHER MYELOPROLIF DIS OR POORLY DIFF NEOPL DIAG W CC  */
"414" = 1711 /* OTHER MYELOPROLIF DIS OR POORLY DIFF NEOPL DIAG WO CC  */
"415" = 1801 /* O.R. PROCEDURE FOR INFECTIOUS & PARASITIC DISEASES (NO LONGER VALID)  */
"416" = 1802 /* SEPTICEMIA AGE >17 (NO LONGER VALID)  */
"417" = 1803 /* SEPTICEMIA AGE 0-17  */
"418" = 1804 /* POSTOPERATIVE & POST-TRAUMATIC INFECTIONS  */
"419" = 1805 /* FEVER OF UNKNOWN ORIGIN AGE >17 W CC  */
"420" = 1805 /* FEVER OF UNKNOWN ORIGIN AGE >17 WO CC  */
"421" = 1806 /* VIRAL ILLNESS AGE >17  */
"422" = 1807 /* VIRAL ILLNESS & FEVER OF UNKNOWN ORIGIN AGE 0-17  */
"423" = 1808 /* OTHER INFECTIOUS & PARASITIC DISEASES DIAGNOSES  */
"424" = 1901 /* O.R. PROCEDURE W PRINCIPAL DIAGNOSES OF MENTAL ILLNESS  */
"425" = 1902 /* ACUTE ADJUSTMENT REACTION & PSYCHOSOCIAL DYSFUNCTION  */
"426" = 1903 /* DEPRESSIVE NEUROSES  */
"427" = 1904 /* NEUROSES EXCEPT DEPRESSIVE  */
"428" = 1905 /* DISORDERS OF PERSONALITY & IMPULSE CONTROL  */
"429" = 1906 /* ORGANIC DISTURBANCES & MENTAL RETARDATION  */
"430" = 1907 /* PSYCHOSES  */
"431" = 1908 /* CHILDHOOD MENTAL DISORDERS  */
"432" = 1909 /* OTHER MENTAL DISORDER DIAGNOSES  */
"433" = 2001 /* ALCOHOL/DRUG ABUSE OR DEPENDENCE, LEFT AMA  */
"434" = 2001 /* ALC/DRUG ABUSE OR DEPEND, DETOX OR OTH SYMPT TREAT W CC */
"435" = 2001 /* ALC/DRUG ABUSE OR DEPEND, DETOX OR OTH SYMPT TREAT WO CC */
"436" = 2001 /* ALC/DRUG DEPENDENCE W REHABILITATION THERAPY (NO LONGER */
"437" = 2001 /* ALC/DRUG DEPENDENCE, COMBINED REHAB & DETOX THERAPY (NO */
"438" = 2001 /* NO LONGER VALID  */
"439" = 2101 /* SKIN GRAFTS FOR INJURIES  */
"440" = 2102 /* WOUND DEBRIDEMENTS FOR INJURIES  */
"441" = 2103 /* HAND PROCEDURES FOR INJURIES  */
"442" = 2104 /* OTHER O.R. PROCEDURES FOR INJURIES W CC  */
"443" = 2104 /* OTHER O.R. PROCEDURES FOR INJURIES WO CC  */
"444" = 2105 /* TRAUMATIC INJURY AGE >17 W CC  */
"445" = 2105 /* TRAUMATIC INJURY AGE >17 WO CC  */
"446" = 2106 /* TRAUMATIC INJURY AGE 0-17  */
"447" = 2107 /* ALLERGIC REACTIONS AGE >17  */
"448" = 2108 /* ALLERGIC REACTIONS AGE 0-17  */
"449" = 2109 /* POISONING & TOXIC EFFECTS OF DRUGS AGE >17 W CC  */
"450" = 2109 /* POISONING & TOXIC EFFECTS OF DRUGS AGE >17 WO CC  */
"451" = 2110 /* POISONING & TOXIC EFFECTS OF DRUGS AGE 0-17  */
"452" = 2111 /* COMPLICATIONS OF TREATMENT W CC  */
"453" = 2111 /* COMPLICATIONS OF TREATMENT WO CC  */
"454" = 2112 /* OTHER INJURY, POISONING & TOXIC EFFECT DIAG W CC  */
"455" = 2112 /* OTHER INJURY, POISONING & TOXIC EFFECT DIAG WO CC  */
"456" = 2201 /* BURNS, TRANSFERRED TO ANOTHER ACUTE CARE FACILITY (NO LO */
"457" = 2201 /* EXTENSIVE BURNS WO O.R. PROCEDURE (NO LONGER VALID)  */
"458" = 2202 /* NON-EXTENSIVE BURNS W SKIN GRAFT (NO LONGER VALID)  */
"459" = 2203 /* NON-EXTENSIVE BURNS W WOUND DEBRIDEMENT OR OTHER O.R. PR */
"460" = 2204 /* NON-EXTENSIVE BURNS WO O.R. PROCEDURE (NO LONGER VALID) */
"461" = 2301 /* O.R. PROC W DIAGNOSES OF OTHER CONTACT W HEALTH SERVICES */
"462" = 2302 /* REHABILITATION  */
"463" = 2303 /* SIGNS & SYMPTOMS W CC  */
"464" = 2303 /* SIGNS & SYMPTOMS WO CC  */
"465" = 2304 /* AFTERCARE W HISTORY OF MALIGNANCY AS SECONDARY DIAGNOSIS */
"466" = 2305 /* AFTERCARE WO HISTORY OF MALIGNANCY AS SECONDARY DIAGNOSI */
"467" = 2306 /* OTHER FACTORS INFLUENCING HEALTH STATUS  */
"468" = 8801 /* EXTENSIVE O.R. PROCEDURE UNRELATED TO PRINCIPAL DIAGNOSI */
"469" = 8802 /* PRINCIPAL DIAGNOSIS INVALID AS DISCHARGE DIAGNOSIS  */
"470" = 8803 /* UNGROUPABLE  */
"471" = 837 /* BILATERAL OR MULTIPLE MAJOR JOINT PROCS OF LOWER EXTREMI */
"472" = 2205 /* BILATERAL OR MULTIPLE MAJOR JOINT PROCS OF LOWER EXTREMI */
"473" = 1712 /* ACUTE LEUKEMIA WO MAJOR O.R. PROCEDURE AGE >17  */
"474" = 419 /* NO LONGER VALID  */
"475" = 420 /* RESPIRATORY SYSTEM DIAGNOSIS WITH VENTILATOR SUPPORT (NO LONGER VALID)  */
"476" = 8804 /* PROSTATIC O.R. PROCEDURE UNRELATED TO PRINCIPAL DIAGNOSI */
"477" = 8805 /* NON-EXTENSIVE O.R. PROCEDURE UNRELATED TO PRINCIPAL DIAG */
"478" = 536 /* OTHER VASCULAR PROCEDURES W CC  */
"479" = 536 /* OTHER VASCULAR PROCEDURES WO CC  */
"480" = 7702 /* LIVER TRANSPLANT  */
"481" = 7703 /* BONE MARROW TRANSPLANT  */
"482" = 7704 /* TRACHEOSTOMY FOR FACE,MOUTH & NECK DIAGNOSES  */
"483" = 7705 /* TRAC W MECH VENT 96+HRS OR PDX EXCEPT FACE,MOUTH & NECK */
"484" = 2401 /* CRANIOTOMY FOR MULTIPLE SIGNIFICANT TRAUMA  */
"485" = 2402 /* LIMB REATTACHMENT, HIP AND FEMUR PROC FOR MULTIPLE SIGNI */
"486" = 2403 /* OTHER O.R. PROCEDURES FOR MULTIPLE SIGNIFICANT TRAUMA  */
"487" = 2404 /* OTHER MULTIPLE SIGNIFICANT TRAUMA  */
"488" = 2501 /* HIV W EXTENSIVE O.R. PROCEDURE  */
"489" = 2502 /* HIV W MAJOR RELATED CONDITION  */
"490" = 2503 /* HIV W OR WO OTHER RELATED CONDITION  */
"491" = 838 /* MAJOR JOINT & LIMB REATTACHMENT PROCEDURES OF UPPER EXTR */
"492" = 1713 /* CHEMOTHERAPY W ACUTE LEUKEMIA OR W USE OF HI DOSE CHEMOA */
"493" = 713 /* LAPAROSCOPIC CHOLECYSTECTOMY WO C.D.E. W CC  */
"494" = 713 /* LAPAROSCOPIC CHOLECYSTECTOMY WO C.D.E. WO CC  */
"495" = 7706 /* LUNG TRANSPLANT  */
"496" = 839 /* COMBINED ANTERIOR/POSTERIOR SPINAL FUSION  */
"497" = 840 /* SPINAL FUSION EXCEPT CERVICAL W CC  */
"498" = 840 /* SPINAL FUSION EXCEPT CERVICAL WO CC  */
"499" = 841 /* BACK & NECK PROCEDURES EXCEPT SPINAL FUSION W CC  */
"500" = 841 /* BACK & NECK PROCEDURES EXCEPT SPINAL FUSION WO CC  */
"501" = 842 /* KNEE PROCEDURES W PDX OF INFECTION W CC  */
"502" = 842 /* KNEE PROCEDURES W PDX OF INFECTION WO CC  */
"503" = 843 /* KNEE PROCEDURES WO PDX OF INFECTION  */
"504" = 2206 /* EXTENSIVE 3RD DEGREE BURNS W SKIN GRAFT  */
"505" = 2207 /* EXTENSIVE 3RD DEGREE BURNS WO SKIN GRAFT  */
"506" = 2208 /* FULL THICKNESS BURN W SKIN GRAFT OR INHAL INJ W CC OR SI */
"507" = 2208 /* FULL THICKNESS BURN W SKIN GRFT OR INHAL INJ WO CC OR SI */
"508" = 2209 /* FULL THICKNESS BURN WO SKIN GRFT OR INHAL INJ W CC OR SI */
"509" = 2209 /* FULL THICKNESS BURN WO SKIN GRFT OR INH INJ WO CC OR SIG */
"510" = 2210 /* NON-EXTENSIVE BURNS W CC OR SIGNIFICANT TRAUMA  */
"511" = 2210 /* NON-EXTENSIVE BURNS WO CC OR SIGNIFICANT TRAUMA  */
"512" = 7707 /* SIMULTANEOUS PANCREAS/KIDNEY TRANSPLANT  */
"513" = 7708 /* PANCREAS TRANSPLANT  */
"514" = 537 /* CARDIAC DEFIB IMPLANT W CARDIAC CATH (NO LONGER VALID)  */
"515" = 538 /* CARDIAC DEFIBRILLATOR IMPLANT WO CARDIAC CATH  */
"516" = 539 /* PERCUTANEOUS CARDIOVASC PROC W AMI  */
"517" = 540 /* PERC CARDIO PROC W NON-DRUG ELUTING STENT WO AMI  */
"518" = 541 /* PERC CARDIO PROC WO CORONARY ARTERY STENT OR AMI  */
"519" = 844 /* CERVICAL SPINAL FUSION W CC  */
"520" = 844 /* CERVICAL SPINAL FUSION WO CC  */
"521" = 2001 /* ALCOHOL/DRUG ABUSE OR DEPENDENCE W CC  */
"522" = 2001 /* ALC/DRUG ABUSE OR DEPEND W REHABILITATION THERAPY WO CC */
"523" = 2001 /* ALC/DRUG ABUSE OR DEPEND WO REHABILITATION THERAPY WO CC */
"524" = 127 /* TRANSIENT ISCHEMIA  */
"525" = 542 /* HEART ASSIST SYSTEM IMPLANT  */
"526" = 543 /* PERCUTNEOUS CARDIOVASULAR PROC W DRUG ELUTING STENT W AM */
"527" = 544 /* PERCUTNEOUS CARDIOVASULAR PROC W DRUG ELUTING STENT WO A */
"528" = 128 /* INTRACRANIAL VASCULAR PROC W PDX HEMORRHAGE  */
"529" = 129 /* VENTRICULAR SHUNT PROCEDURES W CC  */
"530" = 129 /* VENTRICULAR SHUNT PROCEDURES WO CC  */
"531" = 103 /* SPINAL PROCEDURES W CC  */
"532" = 103 /* SPINAL PROCEDURES WO CC  */
"533" = 104 /* EXTRACRANIAL PROCEDURES W CC  */
"534" = 104 /* EXTRACRANIAL PROCEDURES WO CC  */
"535" = 545 /* CARDIAC DEFIB IMPLANT W CARDIAC CATH W AMI/HF/SHOCK  */
"536" = 546 /* CARDIAC DEFIB IMPLANT W CARDIAC CATH W/O AMI/HF/SHOCK */
"537" = 845 /* LOCAL EXCIS & REMOV OF INT FIX DEV EXCEPT HIP & FEMUR W */
"538" = 845 /* LOCAL EXCIS & REMOV OF INT FIX DEV EXCEPT HIP & FEMUR WO */
"539" = 1714 /* LYMPHOMA & LEUKEMIA W MAJOR OR PROCEDURE W CC  */
"540" = 1714 /* LYMPHOMA & LEUKEMIA W MAJOR OR PROCEDURE WO CC  */
"541" = 7705 /* TRACH W MV 96+HRS OR PDX EXC FACE, MTH, FACE & NECK DX W */
"542" = 7705 /* TRACH W MV 96+HRS OR PDX EXC FACE, MTH, FACE & NECK DX W */
"543" = 101 /* CRANIOTOMY WITH IMPLANTATION OF CHEMOTHERAPEUTIC AGENT O */
"544" = 801 /* MAJOR JOINT REPLACEMENT OR REATTACHMENT OF LOWER EXTREMI */
"545" = 801 /* REVISION OF HIP OR KNEE REPLACEMENT  */
"546" = 846 /* SPINAL FUSION EXC CERV WITH CURVATURE OF THE SPINE OR MA */
"547" = 504 /* CORONARY BYPASS W CARDIAC CATH W MAJOR CV DX  */
"548" = 504 /* CORONARY BYPASS W CARDIAC CATH W/O MAJOR CV DX  */
"549" = 506 /* CORONARY BYPASS W/O CARDIAC CATH W MAJOR CV DX  */
"550" = 506 /* CORONARY BYPASS W/O CARDIAC CATH W/O MAJOR CV DX  */
"551" = 511 /* PERMANENT CARDIAC PACEMAKER IMPL W MAJ CV DX OR AICD LEA */
"552" = 512 /* OTHER PERMANENT CARDIAC PACEMAKER IMPLANT W/O MAJOR CV D */
"553" = 536 /* OTHER VASCULAR PROCEDURES W CC W MAJOR CV DX  */
"554" = 536 /* OTHER VASCULAR PROCEDURES W CC W/O MAJOR CV DX  */
"555" = 539 /* PERCUTANEOUS CARDIOVASCULAR PROC W MAJOR CV DX  */
"556" = 540 /* PERCUTANEOUS CARDIOVASC PROC W NON-DRUG-ELUTING STENT W/ */
"557" = 543 /* PERCUTANEOUS CARDIOVASCULAR PROC W DRUG-ELUTING STENT W */
"558" = 544 /* PERCUTANEOUS CARDIOVASCULAR PROC W DRUG-ELUTING STENT W/ */
"559" = 130 /* ACUTE ISCHEMIC STROKE WITH USE OF THROMBOLYTIC AGENT  */
"560" = 115 /* BACTERIAL & TUBERCULOUS INFECTIONS OF NERVOUS SYSTEM */
"561" = 115 /* NON-BACTERIAL INFECTIONS OF NERVOUS SYSTEM EXCEPT VIRAL MENINGIT */
"562" = 119 /* SEIZURE AGE > 17 W CC */
"563" = 119 /* SEIZURE AGE > 17 W/O CC */
"564" = 119 /* HEADACHES AGE >17 */
"565" = 420 /* RESPIRATORY SYSTEM DIAGNOSIS WITH VENTILATOR SUPPORT 96+ HOURS */
"566" = 420 /* RESPIRATORY SYSTEM DIAGNOSIS WITH VENTILATOR SUPPORT < 96 HOURS */
"567" = 605 /* STOMACH, ESOPHAGEAL & DUODENAL PROC AGE > 17 W CC W MAJOR GI DX */
"568" = 605 /* STOMACH, ESOPHAGEAL & DUODENAL PROCEDURES PROC AGE > 17 W CC W/O */
"569" = 602 /* MAJOR SMALL & LARGE BOWEL PROCEDURES W CC W MAJOR GI DX */
"570" = 602 /* MAJOR SMALL & LARGE BOWEL PROCEDURES W CC W/O MAJOR GI DX */
"571" = 624 /* MAJOR ESOPHAGEAL DISORDERS */
"572" = 625 /* MAJOR GASTROINTESTINAL DISORDERS AND PERITONEAL INFECTIONS */
"573" = 1122 /* MAJOR BLADDER PROCEDURES */
"574" = 1608 /* MAJOR HEMATOLOGIC/IMMUNOLOGIC DIAG EXC SICKLE CELL CRISIS & COAGUL */
"575" = 1802 /* SEPTICEMIA W MV96+ HOURS  AGE  >17 */
"576" = 1802 /* SEPTICEMIA W/O MV96+ HOURS AGE  >17 */
"577" = 131 /* CAROTID ARTERY STENT PROCEDURE */
"578" = 1801 /* INFECTIOUS & PARASITIC DISEASES W OR PROCEDURE */
"579" = 1801 /* POSTOPERATIVE OR POST-TRAUMATIC INFECTIONS W OR PROCEDURE */
OTHER = 8806 /* UNKNOWN DRG */
;

VALUE $MSDRG
"001" = "103"
"002" = "103"
"003" = "541"
"004" = "542"
"005" = "480"
"006" = "480"
"007" = "495"
"008" = "512"
"009" = "481"
"010" = "513"
"011" = "482"
"012" = "482"
"013" = "482"
"020" = "528"
"021" = "528"
"022" = "528"
"023" = "543"
"024" = "543"
"025" = "001"
"026" = "002"
"028" = "531"
"029" = "532"
"030" = "532"
"031" = "529"
"032" = "530"
"033" = "530"
"034" = "577"
"035" = "577"
"036" = "577"
"037" = "533"
"038" = "534"
"039" = "534"
"040" = "006"
"041" = "007"
"042" = "008"
"052" = "009"
"053" = "009"
"054" = "010"
"055" = "011"
"056" = "012"
"057" = "012"
"058" = "013"
"059" = "013"
"060" = "013"
"061" = "559"
"062" = "559"
"063" = "559"
"064" = "014"
"065" = "014"
"066" = "014"
"067" = "015"
"068" = "015"
"069" = "524"
"070" = "016"
"071" = "017"
"072" = "017"
"073" = "018"
"074" = "019"
"075" = "021"
"076" = "021"
"077" = "022"
"078" = "022"
"079" = "022"
"080" = "023"
"081" = "023"
"082" = "027"
"083" = "027"
"084" = "027"
"085" = "028"
"086" = "029"
"087" = "030"
"088" = "031"
"089" = "032"
"090" = "033"
"091" = "034"
"092" = "035"
"093" = "035"
"094" = "560"
"095" = "560"
"096" = "560"
"097" = "561"
"098" = "561"
"099" = "561"
"101" = "562"
"102" = "564"
"103" = "564"
"113" = "037"
"114" = "037"
"115" = "040"
"116" = "036"
"117" = "038"
"121" = "044"
"122" = "044"
"123" = "045"
"124" = "043"
"125" = "046"
"129" = "049"
"130" = "049"
"133" = "052"
"134" = "055"
"135" = "053"
"136" = "054"
"137" = "168"
"138" = "169"
"139" = "050"
"146" = "064"
"147" = "064"
"148" = "064"
"149" = "065"
"150" = "066"
"151" = "066"
"152" = "067"
"153" = "068"
"154" = "072"
"155" = "073"
"156" = "074"
"157" = "185"
"158" = "186"
"159" = "187"
"163" = "075"
"164" = "075"
"165" = "075"
"166" = "076"
"167" = "077"
"168" = "077"
"175" = "078"
"177" = "079"
"178" = "080"
"179" = "081"
"180" = "082"
"181" = "082"
"182" = "082"
"183" = "083"
"184" = "084"
"185" = "084"
"186" = "085"
"187" = "086"
"188" = "086"
"189" = "087"
"190" = "088"
"191" = "088"
"192" = "088"
"193" = "089"
"194" = "090"
"195" = "091"
"196" = "092"
"197" = "093"
"198" = "093"
"199" = "094"
"200" = "095"
"201" = "095"
"202" = "096"
"203" = "097"
"204" = "099"
"205" = "101"
"206" = "102"
"207" = "565"
"208" = "566"
"215" = "525"
"216" = "104"
"217" = "104"
"218" = "104"
"219" = "105"
"220" = "105"
"221" = "105"
"222" = "535"
"223" = "535"
"224" = "536"
"225" = "536"
"226" = "515"
"227" = "515"
"228" = "108"
"229" = "108"
"230" = "108"
"231" = "106"
"232" = "106"
"233" = "547"
"234" = "548"
"235" = "549"
"236" = "550"
"237" = "110"
"238" = "111"
"239" = "113"
"240" = "113"
"241" = "113"
"242" = "551"
"243" = "552"
"244" = "552"
"246" = "557"
"247" = "558"
"248" = "555"
"249" = "556"
"250" = "518"
"251" = "518"
"252" = "479"
"253" = "553"
"254" = "554"
"255" = "114"
"256" = "114"
"257" = "114"
"258" = "118"
"259" = "118"
"260" = "117"
"261" = "117"
"262" = "117"
"263" = "119"
"264" = "120"
"280" = "121"
"281" = "122"
"282" = "122"
"283" = "123"
"284" = "123"
"285" = "123"
"286" = "124"
"287" = "125"
"288" = "126"
"289" = "126"
"290" = "126"
"291" = "127"
"292" = "127"
"293" = "127"
"294" = "128"
"295" = "128"
"296" = "129"
"297" = "129"
"298" = "129"
"299" = "130"
"300" = "131"
"301" = "131"
"302" = "132"
"303" = "133"
"304" = "134"
"305" = "134"
"306" = "135"
"307" = "136"
"308" = "138"
"309" = "139"
"310" = "139"
"311" = "140"
"312" = "141"
"313" = "143"
"314" = "144"
"315" = "145"
"316" = "145"
"326" = "155"
"327" = "156"
"328" = "567"
"329" = "149"
"330" = "569"
"331" = "570"
"332" = "146"
"333" = "147"
"334" = "147"
"335" = "150"
"336" = "151"
"337" = "151"
"338" = "164"
"339" = "165"
"340" = "165"
"341" = "166"
"342" = "167"
"343" = "167"
"344" = "152"
"345" = "153"
"346" = "153"
"347" = "157"
"348" = "158"
"349" = "158"
"350" = "161"
"351" = "162"
"353" = "159"
"354" = "160"
"355" = "160"
"356" = "170"
"357" = "171"
"358" = "171"
"368" = "571"
"369" = "571"
"370" = "571"
"371" = "572"
"372" = "572"
"373" = "572"
"374" = "172"
"375" = "173"
"376" = "173"
"377" = "174"
"378" = "175"
"379" = "175"
"380" = "176"
"381" = "176"
"382" = "176"
"383" = "177"
"384" = "178"
"385" = "179"
"386" = "179"
"387" = "179"
"388" = "180"
"389" = "181"
"390" = "181"
"391" = "182"
"392" = "183"
"393" = "188"
"394" = "189"
"395" = "190"
"405" = "191"
"406" = "192"
"407" = "192"
"408" = "193"
"409" = "194"
"410" = "194"
"411" = "195"
"412" = "196"
"413" = "196"
"414" = "197"
"415" = "198"
"416" = "198"
"417" = "493"
"418" = "494"
"419" = "494"
"420" = "199"
"421" = "200"
"422" = "200"
"423" = "201"
"424" = "201"
"425" = "201"
"432" = "202"
"433" = "202"
"434" = "202"
"435" = "203"
"436" = "203"
"437" = "203"
"438" = "204"
"439" = "204"
"440" = "204"
"441" = "205"
"442" = "206"
"443" = "206"
"444" = "207"
"445" = "208"
"446" = "208"
"453" = "496"
"454" = "496"
"455" = "496"
"456" = "546"
"457" = "546"
"458" = "546"
"459" = "497"
"460" = "498"
"461" = "471"
"462" = "471"
"463" = "217"
"464" = "217"
"465" = "217"
"466" = "545"
"467" = "545"
"468" = "545"
"469" = "544"
"470" = "544"
"471" = "519"
"472" = "520"
"473" = "520"
"474" = "213"
"475" = "213"
"476" = "213"
"477" = "216"
"478" = "216"
"479" = "216"
"480" = "210"
"481" = "211"
"482" = "212"
"483" = "491"
"484" = "491"
"485" = "501"
"486" = "502"
"487" = "502"
"488" = "503"
"489" = "503"
"490" = "499"
"491" = "500"
"492" = "218"
"493" = "219"
"494" = "220"
"495" = "537"
"496" = "538"
"497" = "538"
"498" = "230"
"499" = "230"
"500" = "226"
"501" = "227"
"502" = "227"
"503" = "225"
"504" = "225"
"505" = "225"
"506" = "228"
"507" = "223"
"508" = "223"
"509" = "232"
"510" = "224"
"511" = "224"
"512" = "224"
"513" = "229"
"514" = "229"
"515" = "233"
"516" = "234"
"517" = "234"
"533" = "235"
"534" = "235"
"535" = "236"
"536" = "236"
"537" = "237"
"538" = "237"
"539" = "238"
"540" = "238"
"541" = "238"
"542" = "239"
"543" = "239"
"544" = "239"
"545" = "240"
"546" = "241"
"547" = "241"
"548" = "242"
"549" = "242"
"550" = "242"
"551" = "243"
"552" = "243"
"553" = "244"
"554" = "245"
"555" = "247"
"556" = "247"
"557" = "248"
"558" = "248"
"559" = "249"
"560" = "249"
"561" = "249"
"562" = "250"
"563" = "251"
"564" = "256"
"565" = "256"
"566" = "256"
"573" = "263"
"574" = "264"
"575" = "264"
"576" = "265"
"577" = "266"
"578" = "266"
"579" = "267"
"580" = "268"
"581" = "269"
"582" = "257"
"583" = "258"
"584" = "259"
"585" = "260"
"592" = "271"
"593" = "271"
"594" = "271"
"595" = "272"
"596" = "273"
"597" = "274"
"598" = "275"
"599" = "275"
"600" = "276"
"601" = "276"
"602" = "277"
"603" = "278"
"604" = "280"
"605" = "281"
"606" = "283"
"607" = "284"
"614" = "286"
"615" = "286"
"616" = "285"
"617" = "285"
"618" = "285"
"619" = "288"
"620" = "288"
"621" = "288"
"622" = "287"
"623" = "287"
"624" = "287"
"625" = "289"
"626" = "290"
"627" = "291"
"628" = "292"
"629" = "293"
"630" = "293"
"637" = "294"
"638" = "295"
"639" = "295"
"640" = "296"
"641" = "297"
"642" = "299"
"643" = "300"
"644" = "301"
"645" = "301"
"652" = "302"
"653" = "573"
"654" = "573"
"655" = "573"
"656" = "303"
"657" = "303"
"658" = "303"
"659" = "304"
"660" = "305"
"661" = "305"
"662" = "308"
"663" = "309"
"664" = "309"
"665" = "306"
"666" = "307"
"667" = "307"
"668" = "310"
"669" = "311"
"670" = "311"
"671" = "312"
"672" = "313"
"673" = "315"
"674" = "315"
"675" = "315"
"682" = "316"
"683" = "316"
"684" = "316"
"685" = "317"
"686" = "318"
"687" = "319"
"688" = "319"
"689" = "320"
"690" = "321"
"691" = "323"
"692" = "323"
"693" = "324"
"694" = "324"
"695" = "325"
"696" = "326"
"697" = "328"
"698" = "331"
"699" = "332"
"700" = "333"
"707" = "334"
"708" = "335"
"709" = "341"
"710" = "341"
"711" = "338"
"712" = "339"
"713" = "336"
"714" = "337"
"715" = "344"
"716" = "344"
"717" = "345"
"718" = "345"
"722" = "346"
"723" = "347"
"724" = "347"
"725" = "348"
"726" = "349"
"727" = "350"
"728" = "350"
"729" = "351"
"730" = "352"
"734" = "353"
"735" = "353"
"736" = "357"
"737" = "357"
"738" = "357"
"739" = "354"
"740" = "355"
"741" = "355"
"742" = "358"
"743" = "359"
"744" = "361"
"745" = "362"
"746" = "360"
"747" = "360"
"748" = "356"
"749" = "365"
"750" = "365"
"754" = "366"
"755" = "367"
"756" = "367"
"757" = "368"
"758" = "368"
"759" = "368"
"760" = "369"
"761" = "369"
"765" = "370"
"766" = "371"
"767" = "374"
"768" = "375"
"769" = "377"
"770" = "381"
"774" = "372"
"775" = "373"
"776" = "376"
"777" = "378"
"778" = "379"
"779" = "380"
"780" = "382"
"781" = "383"
"782" = "384"
"789" = "385"
"790" = "386"
"791" = "387"
"792" = "388"
"793" = "389"
"794" = "390"
"795" = "391"
"799" = "392"
"800" = "393"
"801" = "393"
"802" = "394"
"803" = "394"
"804" = "394"
"808" = "574"
"809" = "574"
"810" = "574"
"811" = "395"
"812" = "396"
"813" = "397"
"814" = "398"
"815" = "399"
"816" = "399"
"820" = "539"
"821" = "540"
"822" = "540"
"823" = "401"
"824" = "402"
"825" = "402"
"826" = "406"
"827" = "407"
"828" = "407"
"829" = "408"
"830" = "408"
"834" = "405"
"835" = "473"
"836" = "473"
"837" = "492"
"838" = "492"
"839" = "492"
"840" = "403"
"841" = "404"
"842" = "404"
"843" = "411"
"844" = "412"
"845" = "413"
"846" = "410"
"847" = "410"
"848" = "410"
"849" = "409"
"853" = "578"
"854" = "578"
"855" = "578"
"856" = "579"
"857" = "579"
"858" = "579"
"862" = "418"
"863" = "418"
"864" = "419"
"865" = "421"
"867" = "423"
"868" = "423"
"869" = "423"
"870" = "417"
"871" = "576"
"872" = "576"
"876" = "424"
"880" = "425"
"881" = "426"
"882" = "427"
"883" = "428"
"884" = "429"
"885" = "430"
"886" = "431"
"887" = "432"
"894" = "433"
"895" = "521"
"896" = "523"
"897" = "523"
"901" = "440"
"902" = "440"
"903" = "440"
"904" = "439"
"905" = "439"
"906" = "441"
"907" = "442"
"908" = "443"
"909" = "443"
"913" = "444"
"914" = "445"
"915" = "447"
"916" = "448"
"917" = "449"
"918" = "450"
"919" = "452"
"920" = "453"
"921" = "453"
"922" = "454"
"923" = "455"
"927" = "504"
"928" = "506"
"929" = "507"
"933" = "505"
"934" = "508"
"935" = "510"
"939" = "461"
"940" = "461"
"941" = "461"
"945" = "462"
"946" = "462"
"947" = "463"
"948" = "464"
"949" = "465"
"950" = "466"
"951" = "467"
"955" = "484"
"956" = "485"
"957" = "486"
"958" = "486"
"959" = "486"
"963" = "487"
"964" = "487"
"965" = "487"
"969" = "488"
"970" = "488"
"974" = "489"
"975" = "489"
"976" = "489"
"977" = "490"
"981" = "468"
"982" = "468"
"983" = "468"
"984" = "476"
"985" = "476"
"986" = "476"
"987" = "477"
"988" = "477"
"989" = "477"
"998" = "469"
"999" = "470"
OTHER = "470"
;

VALUE $POVCAT
"01001" = 5
"01003" = 5
"01005" = 10
"01007" = 9
"01009" = 6
"01011" = 10
"01013" = 10
"01015" = 9
"01017" = 9
"01019" = 9
"01021" = 8
"01023" = 9
"01025" = 10
"01027" = 7
"01029" = 8
"01031" = 8
"01033" = 8
"01035" = 10
"01037" = 8
"01039" = 9
"01041" = 10
"01043" = 7
"01045" = 9
"01047" = 10
"01049" = 8
"01051" = 6
"01053" = 9
"01055" = 9
"01057" = 9
"01059" = 9
"01061" = 10
"01063" = 10
"01065" = 10
"01067" = 9
"01069" = 9
"01071" = 8
"01073" = 7
"01075" = 9
"01077" = 8
"01079" = 7
"01081" = 6
"01083" = 6
"01085" = 10
"01087" = 10
"01089" = 5
"01091" = 10
"01093" = 9
"01095" = 9
"01097" = 10
"01099" = 9
"01101" = 10
"01103" = 7
"01105" = 10
"01107" = 10
"01109" = 10
"01111" = 9
"01113" = 10
"01115" = 7
"01117" = 2
"01119" = 10
"01121" = 9
"01123" = 9
"01125" = 8
"01127" = 8
"01129" = 9
"01131" = 10
"01133" = 10
"02013" = 2
"02016" = 1
"02020" = 2
"02050" = 10
"02060" = 2
"02068" = 1
"02070" = 8
"02090" = 2
"02100" = 4
"02110" = 2
"02122" = 3
"02130" = 2
"02150" = 3
"02164" = 7
"02170" = 4
"02180" = 8
"02185" = 3
"02188" = 7
"02201" = 7
"02220" = 2
"02232" = 5
"02240" = 9
"02261" = 2
"02270" = 10
"02280" = 3
"02282" = 4
"02290" = 7
"04001" = 10
"04003" = 9
"04005" = 8
"04007" = 10
"04009" = 9
"04011" = 4
"04012" = 10
"04013" = 6
"04015" = 9
"04017" = 10
"04019" = 8
"04021" = 8
"04023" = 10
"04025" = 7
"04027" = 10
"05001" = 9
"05003" = 10
"05005" = 9
"05007" = 4
"05009" = 9
"05011" = 10
"05013" = 7
"05015" = 9
"05017" = 10
"05019" = 8
"05021" = 9
"05023" = 9
"05025" = 8
"05027" = 10
"05029" = 9
"05031" = 9
"05033" = 8
"05035" = 10
"05037" = 10
"05039" = 10
"05041" = 10
"05043" = 10
"05045" = 5
"05047" = 9
"05049" = 10
"05051" = 10
"05053" = 5
"05055" = 8
"05057" = 10
"05059" = 9
"05061" = 9
"05063" = 9
"05065" = 10
"05067" = 10
"05069" = 10
"05071" = 9
"05073" = 10
"05075" = 10
"05077" = 10
"05079" = 10
"05081" = 9
"05083" = 9
"05085" = 5
"05087" = 9
"05089" = 10
"05091" = 10
"05093" = 10
"05095" = 10
"05097" = 10
"05099" = 10
"05101" = 10
"05103" = 10
"05105" = 8
"05107" = 10
"05109" = 8
"05111" = 10
"05113" = 10
"05115" = 8
"05117" = 9
"05119" = 8
"05121" = 10
"05123" = 10
"05125" = 4
"05127" = 10
"05129" = 10
"05131" = 8
"05133" = 10
"05135" = 10
"05137" = 10
"05139" = 9
"05141" = 10
"05143" = 6
"05145" = 8
"05147" = 10
"05149" = 9
"06001" = 4
"06003" = 8
"06005" = 3
"06007" = 8
"06009" = 4
"06011" = 7
"06013" = 2
"06015" = 9
"06017" = 2
"06019" = 10
"06021" = 8
"06023" = 8
"06025" = 10
"06027" = 5
"06029" = 9
"06031" = 9
"06033" = 8
"06035" = 5
"06037" = 9
"06039" = 10
"06041" = 1
"06043" = 5
"06045" = 8
"06047" = 10
"06049" = 9
"06051" = 2
"06053" = 7
"06055" = 2
"06057" = 3
"06059" = 4
"06061" = 1
"06063" = 4
"06065" = 6
"06067" = 7
"06069" = 3
"06071" = 8
"06073" = 5
"06075" = 6
"06077" = 7
"06079" = 4
"06081" = 1
"06083" = 6
"06085" = 3
"06087" = 5
"06089" = 7
"06091" = 4
"06093" = 9
"06095" = 3
"06097" = 2
"06099" = 7
"06101" = 7
"06103" = 8
"06105" = 8
"06107" = 10
"06109" = 6
"06111" = 4
"06113" = 4
"06115" = 9
"08001" = 4
"08003" = 9
"08005" = 2
"08007" = 5
"08009" = 9
"08011" = 9
"08013" = 2
"08014" = 1
"08015" = 5
"08017" = 5
"08019" = 2
"08021" = 9
"08023" = 10
"08025" = 10
"08027" = 6
"08029" = 7
"08031" = 8
"08033" = 5
"08035" = 1
"08037" = 1
"08039" = 1
"08041" = 3
"08043" = 6
"08045" = 2
"08047" = 1
"08049" = 2
"08051" = 3
"08053" = 8
"08055" = 10
"08057" = 7
"08059" = 1
"08061" = 4
"08063" = 6
"08065" = 4
"08067" = 3
"08069" = 2
"08071" = 8
"08073" = 6
"08075" = 5
"08077" = 5
"08079" = 4
"08081" = 3
"08083" = 8
"08085" = 6
"08087" = 5
"08089" = 9
"08091" = 2
"08093" = 2
"08095" = 4
"08097" = 1
"08099" = 9
"08101" = 7
"08103" = 3
"08105" = 10
"08107" = 1
"08109" = 10
"08111" = 8
"08113" = 2
"08115" = 5
"08117" = 1
"08119" = 3
"08121" = 4
"08123" = 3
"08125" = 5
"09001" = 2
"09003" = 3
"09005" = 1
"09007" = 1
"09009" = 4
"09011" = 2
"09013" = 1
"09015" = 3
"10001" = 5
"10003" = 3
"10005" = 5
"11001" = 10
"12001" = 7
"12003" = 6
"12005" = 7
"12007" = 8
"12009" = 4
"12011" = 5
"12013" = 9
"12015" = 5
"12017" = 8
"12019" = 2
"12021" = 4
"12023" = 9
"12027" = 10
"12029" = 10
"12031" = 6
"12033" = 8
"12035" = 4
"12037" = 8
"12039" = 9
"12041" = 7
"12043" = 6
"12045" = 8
"12047" = 10
"12049" = 10
"12051" = 9
"12053" = 7
"12055" = 8
"12057" = 7
"12059" = 10
"12061" = 5
"12063" = 8
"12065" = 8
"12067" = 9
"12069" = 6
"12071" = 5
"12073" = 5
"12075" = 9
"12077" = 8
"12079" = 9
"12081" = 5
"12083" = 9
"12085" = 4
"12086" = 10
"12087" = 4
"12089" = 3
"12091" = 4
"12093" = 8
"12095" = 6
"12097" = 7
"12099" = 5
"12101" = 6
"12103" = 6
"12105" = 7
"12107" = 10
"12109" = 2
"12111" = 7
"12113" = 4
"12115" = 3
"12117" = 3
"12119" = 9
"12121" = 9
"12123" = 9
"12125" = 7
"12127" = 7
"12129" = 5
"12131" = 8
"12133" = 9
"13001" = 9
"13003" = 10
"13005" = 9
"13007" = 10
"13009" = 8
"13011" = 6
"13013" = 4
"13015" = 5
"13017" = 10
"13019" = 9
"13021" = 10
"13023" = 9
"13025" = 9
"13027" = 10
"13029" = 4
"13031" = 9
"13033" = 10
"13035" = 6
"13037" = 10
"13039" = 4
"13043" = 10
"13045" = 7
"13047" = 5
"13049" = 9
"13051" = 9
"13053" = 5
"13055" = 7
"13057" = 2
"13059" = 8
"13061" = 10
"13063" = 7
"13065" = 10
"13067" = 3
"13069" = 10
"13071" = 10
"13073" = 2
"13075" = 9
"13077" = 3
"13079" = 7
"13081" = 10
"13083" = 5
"13085" = 4
"13087" = 10
"13089" = 6
"13091" = 9
"13093" = 10
"13095" = 10
"13097" = 4
"13099" = 10
"13101" = 9
"13103" = 4
"13105" = 8
"13107" = 10
"13109" = 10
"13111" = 8
"13113" = 1
"13115" = 7
"13117" = 1
"13119" = 8
"13121" = 8
"13123" = 7
"13125" = 6
"13127" = 9
"13129" = 6
"13131" = 10
"13133" = 10
"13135" = 2
"13137" = 5
"13139" = 5
"13141" = 10
"13143" = 8
"13145" = 3
"13147" = 7
"13149" = 8
"13151" = 2
"13153" = 5
"13155" = 10
"13157" = 6
"13159" = 8
"13161" = 9
"13163" = 10
"13165" = 10
"13167" = 10
"13169" = 4
"13171" = 8
"13173" = 10
"13175" = 9
"13177" = 3
"13179" = 7
"13181" = 8
"13183" = 10
"13185" = 9
"13187" = 6
"13189" = 9
"13191" = 10
"13193" = 10
"13195" = 6
"13197" = 10
"13199" = 9
"13201" = 10
"13205" = 10
"13207" = 6
"13209" = 9
"13211" = 6
"13213" = 6
"13215" = 9
"13217" = 6
"13219" = 2
"13221" = 6
"13223" = 2
"13225" = 10
"13227" = 6
"13229" = 9
"13231" = 5
"13233" = 7
"13235" = 8
"13237" = 8
"13239" = 10
"13241" = 7
"13243" = 10
"13245" = 10
"13247" = 5
"13249" = 8
"13251" = 9
"13253" = 10
"13255" = 9
"13257" = 8
"13259" = 10
"13261" = 10
"13263" = 10
"13265" = 10
"13267" = 10
"13269" = 10
"13271" = 10
"13273" = 10
"13275" = 9
"13277" = 9
"13279" = 10
"13281" = 7
"13283" = 10
"13285" = 8
"13287" = 10
"13289" = 9
"13291" = 7
"13293" = 9
"13295" = 7
"13297" = 5
"13299" = 10
"13301" = 10
"13303" = 10
"13305" = 9
"13307" = 9
"13309" = 10
"13311" = 6
"13313" = 5
"13315" = 10
"13317" = 9
"13319" = 8
"13321" = 9
"15001" = 6
"15003" = 4
"15005" = 1
"15007" = 4
"15009" = 4
"16001" = 3
"16003" = 8
"16005" = 6
"16007" = 5
"16009" = 7
"16011" = 6
"16013" = 1
"16015" = 5
"16017" = 7
"16019" = 5
"16021" = 7
"16023" = 6
"16025" = 1
"16027" = 7
"16029" = 4
"16031" = 7
"16033" = 8
"16035" = 7
"16037" = 5
"16039" = 4
"16041" = 4
"16043" = 7
"16045" = 6
"16047" = 5
"16049" = 7
"16051" = 5
"16053" = 6
"16055" = 5
"16057" = 4
"16059" = 7
"16061" = 7
"16063" = 5
"16065" = 4
"16067" = 6
"16069" = 5
"16071" = 4
"16073" = 9
"16075" = 7
"16077" = 7
"16079" = 9
"16081" = 3
"16083" = 6
"16085" = 4
"16087" = 7
"17001" = 5
"17003" = 10
"17005" = 4
"17007" = 2
"17009" = 3
"17011" = 3
"17013" = 2
"17015" = 4
"17017" = 4
"17019" = 4
"17021" = 4
"17023" = 5
"17025" = 5
"17027" = 2
"17029" = 5
"17031" = 8
"17033" = 5
"17035" = 4
"17037" = 2
"17039" = 4
"17041" = 3
"17043" = 1
"17045" = 6
"17047" = 4
"17049" = 3
"17051" = 6
"17053" = 3
"17055" = 8
"17057" = 5
"17059" = 9
"17061" = 6
"17063" = 1
"17065" = 6
"17067" = 4
"17069" = 8
"17071" = 5
"17073" = 3
"17075" = 4
"17077" = 9
"17079" = 4
"17081" = 7
"17083" = 3
"17085" = 2
"17087" = 6
"17089" = 2
"17091" = 5
"17093" = 1
"17095" = 6
"17097" = 2
"17099" = 4
"17101" = 6
"17103" = 3
"17105" = 3
"17107" = 4
"17109" = 6
"17111" = 1
"17113" = 2
"17115" = 7
"17117" = 4
"17119" = 4
"17121" = 8
"17123" = 3
"17125" = 5
"17127" = 7
"17129" = 3
"17131" = 3
"17133" = 1
"17135" = 5
"17137" = 5
"17139" = 3
"17141" = 2
"17143" = 7
"17145" = 5
"17147" = 1
"17149" = 6
"17151" = 7
"17153" = 10
"17155" = 2
"17157" = 5
"17159" = 5
"17161" = 6
"17163" = 8
"17165" = 9
"17167" = 4
"17169" = 3
"17171" = 4
"17173" = 4
"17175" = 4
"17177" = 4
"17179" = 2
"17181" = 7
"17183" = 7
"17185" = 5
"17187" = 4
"17189" = 2
"17191" = 5
"17193" = 6
"17195" = 4
"17197" = 1
"17199" = 7
"17201" = 6
"17203" = 1
"18001" = 5
"18003" = 4
"18005" = 2
"18007" = 2
"18009" = 4
"18011" = 1
"18013" = 2
"18015" = 2
"18017" = 4
"18019" = 4
"18021" = 4
"18023" = 3
"18025" = 6
"18027" = 6
"18029" = 2
"18031" = 3
"18033" = 2
"18035" = 5
"18037" = 1
"18039" = 4
"18041" = 4
"18043" = 3
"18045" = 3
"18047" = 2
"18049" = 4
"18051" = 2
"18053" = 6
"18055" = 4
"18057" = 1
"18059" = 1
"18061" = 2
"18063" = 1
"18065" = 4
"18067" = 4
"18069" = 2
"18071" = 3
"18073" = 2
"18075" = 5
"18077" = 4
"18079" = 4
"18081" = 1
"18083" = 6
"18085" = 2
"18087" = 3
"18089" = 6
"18091" = 4
"18093" = 3
"18095" = 5
"18097" = 6
"18099" = 2
"18101" = 3
"18103" = 4
"18105" = 3
"18107" = 3
"18109" = 2
"18111" = 2
"18113" = 2
"18115" = 2
"18117" = 6
"18119" = 4
"18121" = 5
"18123" = 3
"18125" = 3
"18127" = 1
"18129" = 2
"18131" = 4
"18133" = 2
"18135" = 4
"18137" = 2
"18139" = 3
"18141" = 5
"18143" = 5
"18145" = 2
"18147" = 2
"18149" = 5
"18151" = 2
"18153" = 5
"18155" = 4
"18157" = 3
"18159" = 1
"18161" = 3
"18163" = 5
"18165" = 3
"18167" = 6
"18169" = 3
"18171" = 2
"18173" = 1
"18175" = 4
"18177" = 5
"18179" = 2
"18181" = 3
"18183" = 1
"19001" = 3
"19003" = 5
"19005" = 3
"19007" = 7
"19009" = 3
"19011" = 1
"19013" = 5
"19015" = 2
"19017" = 1
"19019" = 3
"19021" = 3
"19023" = 2
"19025" = 4
"19027" = 2
"19029" = 4
"19031" = 1
"19033" = 3
"19035" = 3
"19037" = 3
"19039" = 4
"19041" = 3
"19043" = 3
"19045" = 4
"19047" = 4
"19049" = 1
"19051" = 6
"19053" = 7
"19055" = 2
"19057" = 6
"19059" = 2
"19061" = 2
"19063" = 3
"19065" = 4
"19067" = 4
"19069" = 3
"19071" = 3
"19073" = 4
"19075" = 1
"19077" = 3
"19079" = 2
"19081" = 2
"19083" = 3
"19085" = 3
"19087" = 2
"19089" = 3
"19091" = 3
"19093" = 3
"19095" = 1
"19097" = 4
"19099" = 2
"19101" = 5
"19103" = 2
"19105" = 2
"19107" = 4
"19109" = 3
"19111" = 5
"19113" = 2
"19115" = 3
"19117" = 5
"19119" = 2
"19121" = 2
"19123" = 3
"19125" = 2
"19127" = 4
"19129" = 2
"19131" = 3
"19133" = 4
"19135" = 4
"19137" = 4
"19139" = 4
"19141" = 2
"19143" = 2
"19145" = 4
"19147" = 3
"19149" = 1
"19151" = 4
"19153" = 3
"19155" = 4
"19157" = 2
"19159" = 7
"19161" = 4
"19163" = 4
"19165" = 2
"19167" = 1
"19169" = 1
"19171" = 2
"19173" = 5
"19175" = 5
"19177" = 5
"19179" = 6
"19181" = 1
"19183" = 2
"19185" = 7
"19187" = 4
"19189" = 2
"19191" = 1
"19193" = 5
"19195" = 2
"19197" = 3
"20001" = 6
"20003" = 5
"20005" = 4
"20007" = 5
"20009" = 5
"20011" = 7
"20013" = 6
"20015" = 2
"20017" = 4
"20019" = 7
"20021" = 7
"20023" = 4
"20025" = 4
"20027" = 4
"20029" = 4
"20031" = 3
"20033" = 3
"20035" = 6
"20037" = 7
"20039" = 5
"20041" = 3
"20043" = 4
"20045" = 3
"20047" = 5
"20049" = 8
"20051" = 2
"20053" = 2
"20055" = 5
"20057" = 4
"20059" = 4
"20061" = 6
"20063" = 4
"20065" = 5
"20067" = 3
"20069" = 3
"20071" = 3
"20073" = 7
"20075" = 5
"20077" = 5
"20079" = 3
"20081" = 4
"20083" = 2
"20085" = 3
"20087" = 2
"20089" = 6
"20091" = 1
"20093" = 3
"20095" = 4
"20097" = 5
"20099" = 7
"20101" = 3
"20103" = 2
"20105" = 5
"20107" = 6
"20109" = 3
"20111" = 4
"20113" = 2
"20115" = 3
"20117" = 3
"20119" = 4
"20121" = 2
"20123" = 4
"20125" = 7
"20127" = 3
"20129" = 4
"20131" = 2
"20133" = 5
"20135" = 3
"20137" = 3
"20139" = 3
"20141" = 5
"20143" = 2
"20145" = 4
"20147" = 4
"20149" = 3
"20151" = 4
"20153" = 4
"20155" = 5
"20157" = 5
"20159" = 5
"20161" = 3
"20163" = 4
"20165" = 5
"20167" = 5
"20169" = 4
"20171" = 2
"20173" = 5
"20175" = 6
"20177" = 4
"20179" = 4
"20181" = 6
"20183" = 4
"20185" = 6
"20187" = 4
"20189" = 5
"20191" = 4
"20193" = 3
"20195" = 4
"20197" = 2
"20199" = 7
"20201" = 4
"20203" = 5
"20205" = 6
"20207" = 6
"20209" = 8
"21001" = 10
"21003" = 7
"21005" = 3
"21007" = 7
"21009" = 8
"21011" = 10
"21013" = 10
"21015" = 2
"21017" = 7
"21019" = 9
"21021" = 7
"21023" = 5
"21025" = 10
"21027" = 9
"21029" = 4
"21031" = 9
"21033" = 8
"21035" = 7
"21037" = 4
"21039" = 7
"21041" = 7
"21043" = 10
"21045" = 10
"21047" = 8
"21049" = 7
"21051" = 10
"21053" = 10
"21055" = 9
"21057" = 10
"21059" = 6
"21061" = 9
"21063" = 10
"21065" = 10
"21067" = 6
"21069" = 9
"21071" = 10
"21073" = 5
"21075" = 10
"21077" = 7
"21079" = 8
"21081" = 6
"21083" = 8
"21085" = 9
"21087" = 9
"21089" = 8
"21091" = 4
"21093" = 5
"21095" = 10
"21097" = 6
"21099" = 10
"21101" = 7
"21103" = 6
"21105" = 8
"21107" = 9
"21109" = 10
"21111" = 7
"21113" = 6
"21115" = 10
"21117" = 4
"21119" = 10
"21121" = 10
"21123" = 8
"21125" = 10
"21127" = 10
"21129" = 10
"21131" = 10
"21133" = 10
"21135" = 10
"21137" = 9
"21139" = 7
"21141" = 8
"21143" = 6
"21145" = 8
"21147" = 10
"21149" = 7
"21151" = 7
"21153" = 10
"21155" = 8
"21157" = 6
"21159" = 10
"21161" = 9
"21163" = 4
"21165" = 10
"21167" = 6
"21169" = 10
"21171" = 10
"21173" = 8
"21175" = 10
"21177" = 9
"21179" = 5
"21181" = 8
"21183" = 9
"21185" = 1
"21187" = 8
"21189" = 10
"21191" = 5
"21193" = 10
"21195" = 10
"21197" = 10
"21199" = 9
"21201" = 9
"21203" = 10
"21205" = 9
"21207" = 10
"21209" = 4
"21211" = 4
"21213" = 7
"21215" = 3
"21217" = 9
"21219" = 9
"21221" = 6
"21223" = 6
"21225" = 7
"21227" = 7
"21229" = 6
"21231" = 10
"21233" = 7
"21235" = 10
"21237" = 10
"21239" = 3
"22001" = 10
"22003" = 10
"22005" = 5
"22007" = 9
"22009" = 10
"22011" = 8
"22013" = 10
"22015" = 7
"22017" = 10
"22019" = 9
"22021" = 10
"22023" = 5
"22025" = 10
"22027" = 10
"22029" = 10
"22031" = 10
"22033" = 9
"22035" = 10
"22037" = 9
"22039" = 10
"22041" = 10
"22043" = 10
"22045" = 10
"22047" = 10
"22049" = 9
"22051" = 9
"22053" = 9
"22055" = 8
"22057" = 8
"22059" = 9
"22061" = 10
"22063" = 6
"22065" = 10
"22067" = 10
"22069" = 10
"22071" = 10
"22073" = 10
"22075" = 8
"22077" = 9
"22079" = 10
"22081" = 10
"22083" = 10
"22085" = 10
"22087" = 8
"22089" = 6
"22091" = 10
"22093" = 9
"22095" = 9
"22097" = 10
"22099" = 10
"22101" = 10
"22103" = 5
"22105" = 10
"22107" = 10
"22109" = 9
"22111" = 9
"22113" = 9
"22115" = 7
"22117" = 10
"22119" = 10
"22121" = 8
"22123" = 10
"22125" = 6
"22127" = 10
"23001" = 5
"23003" = 7
"23005" = 2
"23007" = 6
"23009" = 4
"23011" = 5
"23013" = 5
"23015" = 4
"23017" = 6
"23019" = 5
"23021" = 7
"23023" = 3
"23025" = 8
"23027" = 7
"23029" = 9
"23031" = 2
"24001" = 6
"24003" = 1
"24005" = 2
"24009" = 1
"24011" = 4
"24013" = 1
"24015" = 3
"24017" = 2
"24019" = 7
"24021" = 1
"24023" = 6
"24025" = 1
"24027" = 1
"24029" = 4
"24031" = 1
"24033" = 3
"24035" = 1
"24037" = 2
"24039" = 9
"24041" = 3
"24043" = 4
"24045" = 5
"24047" = 5
"24510" = 9
"25001" = 2
"25003" = 4
"25005" = 4
"25007" = 2
"25009" = 3
"25011" = 3
"25013" = 8
"25015" = 2
"25017" = 1
"25019" = 1
"25021" = 1
"25023" = 2
"25025" = 9
"25027" = 3
"26001" = 8
"26003" = 4
"26005" = 2
"26007" = 6
"26009" = 4
"26011" = 8
"26013" = 4
"26015" = 2
"26017" = 4
"26019" = 3
"26021" = 6
"26023" = 5
"26025" = 5
"26027" = 5
"26029" = 3
"26031" = 6
"26033" = 5
"26035" = 8
"26037" = 1
"26039" = 7
"26041" = 4
"26043" = 3
"26045" = 2
"26047" = 2
"26049" = 7
"26051" = 7
"26053" = 6
"26055" = 2
"26057" = 4
"26059" = 5
"26061" = 5
"26063" = 5
"26065" = 5
"26067" = 3
"26069" = 8
"26071" = 5
"26073" = 4
"26075" = 4
"26077" = 4
"26079" = 6
"26081" = 3
"26083" = 4
"26085" = 10
"26087" = 2
"26089" = 2
"26091" = 2
"26093" = 1
"26095" = 7
"26097" = 5
"26099" = 2
"26101" = 5
"26103" = 3
"26105" = 5
"26107" = 7
"26109" = 4
"26111" = 2
"26113" = 6
"26115" = 2
"26117" = 5
"26119" = 8
"26121" = 6
"26123" = 5
"26125" = 1
"26127" = 7
"26129" = 8
"26131" = 5
"26133" = 6
"26135" = 8
"26137" = 4
"26139" = 1
"26141" = 5
"26143" = 9
"26145" = 7
"26147" = 3
"26149" = 5
"26151" = 6
"26153" = 6
"26155" = 3
"26157" = 4
"26159" = 6
"26161" = 2
"26163" = 9
"26165" = 5
"27001" = 5
"27003" = 1
"27005" = 5
"27007" = 8
"27009" = 2
"27011" = 4
"27013" = 2
"27015" = 1
"27017" = 2
"27019" = 1
"27021" = 6
"27023" = 3
"27025" = 1
"27027" = 3
"27029" = 6
"27031" = 2
"27033" = 4
"27035" = 3
"27037" = 1
"27039" = 1
"27041" = 2
"27043" = 3
"27045" = 3
"27047" = 3
"27049" = 1
"27051" = 3
"27053" = 3
"27055" = 1
"27057" = 5
"27059" = 1
"27061" = 4
"27063" = 2
"27065" = 3
"27067" = 3
"27069" = 2
"27071" = 4
"27073" = 2
"27075" = 2
"27077" = 2
"27079" = 1
"27081" = 2
"27083" = 2
"27085" = 1
"27087" = 9
"27089" = 3
"27091" = 4
"27093" = 2
"27095" = 3
"27097" = 3
"27099" = 3
"27101" = 2
"27103" = 1
"27105" = 3
"27107" = 3
"27109" = 1
"27111" = 3
"27113" = 3
"27115" = 4
"27117" = 3
"27119" = 4
"27121" = 2
"27123" = 4
"27125" = 2
"27127" = 3
"27129" = 3
"27131" = 1
"27133" = 2
"27135" = 1
"27137" = 4
"27139" = 1
"27141" = 1
"27143" = 2
"27145" = 2
"27147" = 1
"27149" = 1
"27151" = 3
"27153" = 5
"27155" = 4
"27157" = 1
"27159" = 5
"27161" = 2
"27163" = 1
"27165" = 3
"27167" = 2
"27169" = 2
"27171" = 1
"27173" = 2
"28001" = 10
"28003" = 9
"28005" = 10
"28007" = 10
"28009" = 10
"28011" = 10
"28013" = 10
"28015" = 10
"28017" = 9
"28019" = 10
"28021" = 10
"28023" = 10
"28025" = 10
"28027" = 10
"28029" = 10
"28031" = 10
"28033" = 3
"28035" = 10
"28037" = 10
"28039" = 9
"28041" = 9
"28043" = 10
"28045" = 9
"28047" = 9
"28049" = 10
"28051" = 10
"28053" = 10
"28055" = 10
"28057" = 7
"28059" = 9
"28061" = 10
"28063" = 10
"28065" = 10
"28067" = 10
"28069" = 10
"28071" = 6
"28073" = 7
"28075" = 10
"28077" = 10
"28079" = 10
"28081" = 7
"28083" = 10
"28085" = 9
"28087" = 10
"28089" = 7
"28091" = 10
"28093" = 9
"28095" = 9
"28097" = 10
"28099" = 10
"28101" = 9
"28103" = 10
"28105" = 10
"28107" = 10
"28109" = 10
"28111" = 10
"28113" = 10
"28115" = 6
"28117" = 8
"28119" = 10
"28121" = 5
"28123" = 10
"28125" = 10
"28127" = 10
"28129" = 9
"28131" = 10
"28133" = 10
"28135" = 10
"28137" = 8
"28139" = 9
"28141" = 7
"28143" = 10
"28145" = 7
"28147" = 10
"28149" = 10
"28151" = 10
"28153" = 10
"28155" = 10
"28157" = 10
"28159" = 10
"28161" = 10
"28163" = 10
"29001" = 6
"29003" = 3
"29005" = 5
"29007" = 7
"29009" = 8
"29011" = 6
"29013" = 7
"29015" = 9
"29017" = 7
"29019" = 4
"29021" = 6
"29023" = 10
"29025" = 5
"29027" = 4
"29029" = 7
"29031" = 5
"29033" = 7
"29035" = 10
"29037" = 2
"29039" = 9
"29041" = 4
"29043" = 4
"29045" = 6
"29047" = 2
"29049" = 2
"29051" = 3
"29053" = 4
"29055" = 8
"29057" = 7
"29059" = 8
"29061" = 9
"29063" = 4
"29065" = 9
"29067" = 10
"29069" = 10
"29071" = 3
"29073" = 4
"29075" = 5
"29077" = 6
"29079" = 8
"29081" = 7
"29083" = 7
"29085" = 10
"29087" = 5
"29089" = 5
"29091" = 9
"29093" = 10
"29095" = 6
"29097" = 8
"29099" = 2
"29101" = 4
"29103" = 8
"29105" = 8
"29107" = 4
"29109" = 7
"29111" = 6
"29113" = 3
"29115" = 7
"29117" = 6
"29119" = 9
"29121" = 6
"29123" = 9
"29125" = 6
"29127" = 6
"29129" = 6
"29131" = 7
"29133" = 10
"29135" = 4
"29137" = 5
"29139" = 5
"29141" = 9
"29143" = 10
"29145" = 6
"29147" = 3
"29149" = 10
"29151" = 2
"29153" = 10
"29155" = 10
"29157" = 3
"29159" = 7
"29161" = 7
"29163" = 7
"29165" = 1
"29167" = 8
"29169" = 4
"29171" = 7
"29173" = 4
"29175" = 6
"29177" = 3
"29179" = 10
"29181" = 10
"29183" = 1
"29185" = 9
"29186" = 3
"29187" = 7
"29189" = 3
"29195" = 7
"29197" = 7
"29199" = 7
"29201" = 8
"29203" = 10
"29205" = 7
"29207" = 8
"29209" = 8
"29211" = 7
"29213" = 8
"29215" = 10
"29217" = 8
"29219" = 3
"29221" = 9
"29223" = 10
"29225" = 8
"29227" = 7
"29229" = 10
"29510" = 10
"30001" = 8
"30003" = 10
"30005" = 10
"30007" = 7
"30009" = 5
"30011" = 6
"30013" = 7
"30015" = 7
"30017" = 7
"30019" = 6
"30021" = 6
"30023" = 7
"30025" = 3
"30027" = 8
"30029" = 6
"30031" = 3
"30033" = 7
"30035" = 10
"30037" = 9
"30039" = 8
"30041" = 9
"30043" = 3
"30045" = 8
"30047" = 10
"30049" = 5
"30051" = 4
"30053" = 10
"30055" = 7
"30057" = 6
"30059" = 9
"30061" = 10
"30063" = 7
"30065" = 10
"30067" = 6
"30069" = 6
"30071" = 8
"30073" = 8
"30075" = 4
"30077" = 8
"30079" = 7
"30081" = 8
"30083" = 6
"30085" = 10
"30087" = 9
"30089" = 10
"30091" = 6
"30093" = 8
"30095" = 3
"30097" = 4
"30099" = 6
"30101" = 5
"30103" = 7
"30105" = 8
"30107" = 10
"30109" = 6
"30111" = 5
"31001" = 3
"31003" = 5
"31005" = 4
"31007" = 3
"31009" = 9
"31011" = 3
"31013" = 5
"31015" = 5
"31017" = 6
"31019" = 3
"31021" = 4
"31023" = 3
"31025" = 2
"31027" = 2
"31029" = 4
"31031" = 6
"31033" = 3
"31035" = 4
"31037" = 3
"31039" = 3
"31041" = 6
"31043" = 4
"31045" = 7
"31047" = 4
"31049" = 5
"31051" = 3
"31053" = 3
"31055" = 4
"31057" = 5
"31059" = 4
"31061" = 5
"31063" = 4
"31065" = 5
"31067" = 3
"31069" = 7
"31071" = 4
"31073" = 3
"31075" = 5
"31077" = 6
"31079" = 5
"31081" = 2
"31083" = 5
"31085" = 4
"31087" = 7
"31089" = 5
"31091" = 4
"31093" = 4
"31095" = 4
"31097" = 3
"31099" = 2
"31101" = 4
"31103" = 7
"31105" = 7
"31107" = 7
"31109" = 3
"31111" = 5
"31113" = 4
"31115" = 6
"31117" = 7
"31119" = 4
"31121" = 4
"31123" = 7
"31125" = 5
"31127" = 3
"31129" = 5
"31131" = 2
"31133" = 5
"31135" = 4
"31137" = 3
"31139" = 3
"31141" = 2
"31143" = 2
"31145" = 4
"31147" = 5
"31149" = 8
"31151" = 2
"31153" = 1
"31155" = 2
"31157" = 8
"31159" = 1
"31161" = 8
"31163" = 5
"31165" = 4
"31167" = 2
"31169" = 4
"31171" = 5
"31173" = 10
"31175" = 5
"31177" = 1
"31179" = 3
"31181" = 3
"31183" = 7
"31185" = 3
"32001" = 4
"32003" = 5
"32005" = 2
"32007" = 3
"32009" = 4
"32011" = 3
"32013" = 4
"32015" = 3
"32017" = 7
"32019" = 4
"32021" = 8
"32023" = 7
"32027" = 5
"32029" = 1
"32031" = 3
"32033" = 5
"32510" = 4
"33001" = 2
"33003" = 2
"33005" = 2
"33007" = 4
"33009" = 2
"33011" = 1
"33013" = 1
"33015" = 1
"33017" = 2
"33019" = 2
"34001" = 4
"34003" = 1
"34005" = 1
"34007" = 4
"34009" = 4
"34011" = 7
"34013" = 7
"34015" = 1
"34017" = 8
"34019" = 1
"34021" = 2
"34023" = 2
"34025" = 1
"34027" = 1
"34029" = 3
"34031" = 6
"34033" = 3
"34035" = 1
"34037" = 1
"34039" = 3
"34041" = 1
"35001" = 7
"35003" = 10
"35005" = 10
"35006" = 10
"35007" = 9
"35009" = 10
"35011" = 10
"35013" = 10
"35015" = 9
"35017" = 10
"35019" = 10
"35021" = 6
"35023" = 10
"35025" = 9
"35027" = 10
"35028" = 1
"35029" = 10
"35031" = 10
"35033" = 10
"35035" = 9
"35037" = 10
"35039" = 9
"35041" = 10
"35043" = 5
"35045" = 10
"35047" = 10
"35049" = 6
"35051" = 10
"35053" = 10
"35055" = 10
"35057" = 10
"35059" = 9
"35061" = 9
"36001" = 4
"36003" = 7
"36005" = 10
"36007" = 6
"36009" = 7
"36011" = 5
"36013" = 8
"36015" = 7
"36017" = 7
"36019" = 5
"36021" = 4
"36023" = 6
"36025" = 7
"36027" = 2
"36029" = 6
"36031" = 5
"36033" = 7
"36035" = 7
"36037" = 3
"36039" = 6
"36041" = 4
"36043" = 6
"36045" = 7
"36047" = 10
"36049" = 6
"36051" = 4
"36053" = 4
"36055" = 6
"36057" = 7
"36059" = 1
"36061" = 10
"36063" = 5
"36065" = 6
"36067" = 5
"36069" = 3
"36071" = 4
"36073" = 6
"36075" = 6
"36077" = 5
"36079" = 1
"36081" = 8
"36083" = 4
"36085" = 4
"36087" = 4
"36089" = 7
"36091" = 1
"36093" = 5
"36095" = 5
"36097" = 6
"36099" = 5
"36101" = 7
"36103" = 2
"36105" = 7
"36107" = 4
"36109" = 4
"36111" = 4
"36113" = 4
"36115" = 5
"36117" = 4
"36119" = 3
"36121" = 4
"36123" = 7
"37001" = 5
"37003" = 5
"37005" = 9
"37007" = 9
"37009" = 8
"37011" = 7
"37013" = 9
"37015" = 10
"37017" = 10
"37019" = 8
"37021" = 7
"37023" = 7
"37025" = 4
"37027" = 7
"37029" = 3
"37031" = 6
"37033" = 7
"37035" = 6
"37037" = 4
"37039" = 9
"37041" = 9
"37043" = 8
"37045" = 8
"37047" = 10
"37049" = 7
"37051" = 8
"37053" = 4
"37055" = 3
"37057" = 6
"37059" = 3
"37061" = 9
"37063" = 7
"37065" = 10
"37067" = 6
"37069" = 6
"37071" = 7
"37073" = 6
"37075" = 9
"37077" = 5
"37079" = 9
"37081" = 7
"37083" = 10
"37085" = 8
"37087" = 8
"37089" = 6
"37091" = 10
"37093" = 8
"37095" = 10
"37097" = 4
"37099" = 7
"37101" = 6
"37103" = 8
"37105" = 7
"37107" = 9
"37109" = 5
"37111" = 6
"37113" = 7
"37115" = 8
"37117" = 10
"37119" = 5
"37121" = 8
"37123" = 8
"37125" = 6
"37127" = 7
"37129" = 7
"37131" = 10
"37133" = 7
"37135" = 3
"37137" = 9
"37139" = 9
"37141" = 8
"37143" = 9
"37145" = 5
"37147" = 8
"37149" = 5
"37151" = 5
"37153" = 9
"37155" = 10
"37157" = 6
"37159" = 5
"37161" = 8
"37163" = 9
"37165" = 10
"37167" = 5
"37169" = 4
"37171" = 7
"37173" = 8
"37175" = 7
"37177" = 10
"37179" = 3
"37181" = 10
"37183" = 2
"37185" = 10
"37187" = 10
"37189" = 5
"37191" = 8
"37193" = 7
"37195" = 8
"37197" = 5
"37199" = 9
"38001" = 4
"38003" = 4
"38005" = 10
"38007" = 6
"38009" = 5
"38011" = 3
"38013" = 4
"38015" = 2
"38017" = 2
"38019" = 4
"38021" = 6
"38023" = 4
"38025" = 5
"38027" = 3
"38029" = 6
"38031" = 2
"38033" = 6
"38035" = 4
"38037" = 9
"38039" = 4
"38041" = 4
"38043" = 6
"38045" = 4
"38047" = 6
"38049" = 7
"38051" = 6
"38053" = 7
"38055" = 6
"38057" = 2
"38059" = 3
"38061" = 7
"38063" = 4
"38065" = 3
"38067" = 3
"38069" = 5
"38071" = 6
"38073" = 2
"38075" = 4
"38077" = 2
"38079" = 10
"38081" = 2
"38083" = 9
"38085" = 10
"38087" = 5
"38089" = 4
"38091" = 2
"38093" = 4
"38095" = 4
"38097" = 2
"38099" = 4
"38101" = 4
"38103" = 4
"38105" = 5
"39001" = 8
"39003" = 5
"39005" = 3
"39007" = 6
"39009" = 8
"39011" = 1
"39013" = 7
"39015" = 4
"39017" = 2
"39019" = 5
"39021" = 3
"39023" = 6
"39025" = 2
"39027" = 3
"39029" = 6
"39031" = 4
"39033" = 5
"39035" = 7
"39037" = 2
"39039" = 2
"39041" = 1
"39043" = 4
"39045" = 2
"39047" = 5
"39049" = 5
"39051" = 2
"39053" = 9
"39055" = 1
"39057" = 2
"39059" = 7
"39061" = 5
"39063" = 2
"39065" = 4
"39067" = 6
"39069" = 2
"39071" = 5
"39073" = 5
"39075" = 4
"39077" = 3
"39079" = 8
"39081" = 7
"39083" = 4
"39085" = 2
"39087" = 9
"39089" = 3
"39091" = 3
"39093" = 4
"39095" = 6
"39097" = 3
"39099" = 7
"39101" = 5
"39103" = 1
"39105" = 9
"39107" = 2
"39109" = 2
"39111" = 7
"39113" = 5
"39115" = 8
"39117" = 4
"39119" = 7
"39121" = 5
"39123" = 2
"39125" = 3
"39127" = 6
"39129" = 4
"39131" = 9
"39133" = 2
"39135" = 2
"39137" = 1
"39139" = 5
"39141" = 6
"39143" = 2
"39145" = 9
"39147" = 3
"39149" = 2
"39151" = 4
"39153" = 5
"39155" = 5
"39157" = 4
"39159" = 1
"39161" = 2
"39163" = 8
"39165" = 1
"39167" = 5
"39169" = 3
"39171" = 2
"39173" = 1
"39175" = 1
"40001" = 10
"40003" = 6
"40005" = 10
"40007" = 5
"40009" = 8
"40011" = 9
"40013" = 9
"40015" = 10
"40017" = 3
"40019" = 8
"40021" = 10
"40023" = 10
"40025" = 7
"40027" = 4
"40029" = 10
"40031" = 8
"40033" = 7
"40035" = 8
"40037" = 7
"40039" = 8
"40041" = 10
"40043" = 7
"40045" = 6
"40047" = 7
"40049" = 9
"40051" = 7
"40053" = 6
"40055" = 10
"40057" = 10
"40059" = 5
"40061" = 10
"40063" = 10
"40065" = 7
"40067" = 9
"40069" = 9
"40071" = 9
"40073" = 4
"40075" = 10
"40077" = 10
"40079" = 10
"40081" = 7
"40083" = 6
"40085" = 7
"40087" = 5
"40089" = 10
"40091" = 10
"40093" = 5
"40095" = 8
"40097" = 9
"40099" = 8
"40101" = 9
"40103" = 6
"40105" = 8
"40107" = 10
"40109" = 8
"40111" = 10
"40113" = 7
"40115" = 9
"40117" = 7
"40119" = 7
"40121" = 9
"40123" = 9
"40125" = 9
"40127" = 10
"40129" = 6
"40131" = 4
"40133" = 10
"40135" = 10
"40137" = 8
"40139" = 5
"40141" = 10
"40143" = 6
"40145" = 5
"40147" = 6
"40149" = 8
"40151" = 7
"40153" = 6
"41001" = 7
"41003" = 3
"41005" = 3
"41007" = 6
"41009" = 3
"41011" = 9
"41013" = 6
"41015" = 7
"41017" = 4
"41019" = 7
"41021" = 3
"41023" = 6
"41025" = 7
"41027" = 6
"41029" = 7
"41031" = 8
"41033" = 9
"41035" = 8
"41037" = 8
"41039" = 7
"41041" = 8
"41043" = 6
"41045" = 9
"41047" = 7
"41049" = 6
"41051" = 6
"41053" = 4
"41055" = 6
"41057" = 6
"41059" = 7
"41061" = 5
"41063" = 5
"41065" = 7
"41067" = 2
"41069" = 7
"41071" = 4
"42001" = 2
"42003" = 4
"42005" = 5
"42007" = 4
"42009" = 5
"42011" = 4
"42013" = 6
"42015" = 5
"42017" = 1
"42019" = 2
"42021" = 5
"42023" = 5
"42025" = 4
"42027" = 3
"42029" = 1
"42031" = 5
"42033" = 7
"42035" = 6
"42037" = 4
"42039" = 7
"42041" = 1
"42043" = 3
"42045" = 3
"42047" = 3
"42049" = 6
"42051" = 9
"42053" = 7
"42055" = 3
"42057" = 4
"42059" = 8
"42061" = 5
"42063" = 7
"42065" = 6
"42067" = 3
"42069" = 4
"42071" = 3
"42073" = 6
"42075" = 3
"42077" = 4
"42079" = 5
"42081" = 5
"42083" = 6
"42085" = 7
"42087" = 7
"42089" = 3
"42091" = 1
"42093" = 3
"42095" = 2
"42097" = 4
"42099" = 3
"42101" = 10
"42103" = 2
"42105" = 6
"42107" = 4
"42109" = 3
"42111" = 6
"42113" = 5
"42115" = 5
"42117" = 6
"42119" = 3
"42121" = 7
"42123" = 5
"42125" = 3
"42127" = 5
"42129" = 3
"42131" = 4
"42133" = 2
"44001" = 1
"44003" = 2
"44005" = 2
"44007" = 8
"44009" = 1
"45001" = 6
"45003" = 7
"45005" = 10
"45007" = 5
"45009" = 10
"45011" = 9
"45013" = 6
"45015" = 5
"45017" = 7
"45019" = 7
"45021" = 8
"45023" = 8
"45025" = 9
"45027" = 10
"45029" = 10
"45031" = 10
"45033" = 10
"45035" = 5
"45037" = 7
"45039" = 8
"45041" = 9
"45043" = 9
"45045" = 5
"45047" = 7
"45049" = 10
"45051" = 8
"45053" = 10
"45055" = 6
"45057" = 7
"45059" = 8
"45061" = 10
"45063" = 5
"45065" = 8
"45067" = 10
"45069" = 10
"45071" = 8
"45073" = 6
"45075" = 10
"45077" = 5
"45079" = 6
"45081" = 7
"45083" = 6
"45085" = 9
"45087" = 8
"45089" = 10
"45091" = 5
"46003" = 6
"46005" = 5
"46007" = 10
"46009" = 5
"46011" = 2
"46013" = 3
"46015" = 5
"46017" = 10
"46019" = 7
"46021" = 3
"46023" = 10
"46025" = 6
"46027" = 6
"46029" = 4
"46031" = 10
"46033" = 5
"46035" = 4
"46037" = 7
"46039" = 3
"46041" = 10
"46043" = 5
"46045" = 4
"46047" = 8
"46049" = 4
"46051" = 3
"46053" = 9
"46055" = 5
"46057" = 4
"46059" = 3
"46061" = 3
"46063" = 5
"46065" = 4
"46067" = 4
"46069" = 4
"46071" = 10
"46073" = 4
"46075" = 6
"46077" = 3
"46079" = 3
"46081" = 4
"46083" = 1
"46085" = 9
"46087" = 3
"46089" = 5
"46091" = 4
"46093" = 4
"46095" = 10
"46097" = 4
"46099" = 3
"46101" = 3
"46103" = 6
"46105" = 6
"46107" = 4
"46109" = 9
"46111" = 5
"46113" = 10
"46115" = 5
"46117" = 3
"46119" = 2
"46121" = 10
"46123" = 9
"46125" = 2
"46127" = 1
"46129" = 9
"46135" = 4
"46137" = 10
"47001" = 7
"47003" = 6
"47005" = 9
"47007" = 9
"47009" = 5
"47011" = 6
"47013" = 10
"47015" = 6
"47017" = 8
"47019" = 9
"47021" = 3
"47023" = 7
"47025" = 10
"47027" = 10
"47029" = 10
"47031" = 7
"47033" = 7
"47035" = 9
"47037" = 7
"47039" = 8
"47041" = 7
"47043" = 5
"47045" = 8
"47047" = 5
"47049" = 10
"47051" = 6
"47053" = 7
"47055" = 7
"47057" = 8
"47059" = 7
"47061" = 10
"47063" = 7
"47065" = 7
"47067" = 10
"47069" = 9
"47071" = 10
"47073" = 8
"47075" = 9
"47077" = 7
"47079" = 8
"47081" = 8
"47083" = 7
"47085" = 6
"47087" = 9
"47089" = 7
"47091" = 10
"47093" = 6
"47095" = 10
"47097" = 8
"47099" = 7
"47101" = 9
"47103" = 6
"47105" = 5
"47107" = 7
"47109" = 9
"47111" = 8
"47113" = 7
"47115" = 7
"47117" = 5
"47119" = 5
"47121" = 9
"47123" = 8
"47125" = 5
"47127" = 4
"47129" = 9
"47131" = 7
"47133" = 9
"47135" = 7
"47137" = 9
"47139" = 8
"47141" = 7
"47143" = 8
"47145" = 7
"47147" = 4
"47149" = 3
"47151" = 10
"47153" = 8
"47155" = 7
"47157" = 8
"47159" = 5
"47161" = 7
"47163" = 7
"47165" = 4
"47167" = 6
"47169" = 7
"47171" = 7
"47173" = 9
"47175" = 8
"47177" = 8
"47179" = 6
"47181" = 9
"47183" = 7
"47185" = 8
"47187" = 1
"47189" = 2
"48001" = 9
"48003" = 7
"48005" = 9
"48007" = 10
"48009" = 2
"48011" = 4
"48013" = 10
"48015" = 4
"48017" = 10
"48019" = 7
"48021" = 6
"48023" = 9
"48025" = 10
"48027" = 7
"48029" = 9
"48031" = 4
"48033" = 3
"48035" = 8
"48037" = 9
"48039" = 4
"48041" = 7
"48043" = 9
"48045" = 9
"48047" = 10
"48049" = 10
"48051" = 8
"48053" = 7
"48055" = 7
"48057" = 8
"48059" = 8
"48061" = 10
"48063" = 10
"48065" = 3
"48067" = 9
"48069" = 10
"48071" = 4
"48073" = 9
"48075" = 10
"48077" = 5
"48079" = 10
"48081" = 8
"48083" = 10
"48085" = 1
"48087" = 10
"48089" = 8
"48091" = 4
"48093" = 10
"48095" = 9
"48097" = 7
"48099" = 6
"48101" = 10
"48103" = 5
"48105" = 7
"48107" = 10
"48109" = 10
"48111" = 7
"48113" = 8
"48115" = 10
"48117" = 9
"48119" = 9
"48121" = 2
"48123" = 9
"48125" = 9
"48127" = 10
"48129" = 9
"48131" = 10
"48133" = 10
"48135" = 10
"48137" = 10
"48139" = 4
"48141" = 10
"48143" = 7
"48145" = 10
"48147" = 7
"48149" = 6
"48151" = 8
"48153" = 10
"48155" = 8
"48157" = 2
"48159" = 8
"48161" = 8
"48163" = 10
"48165" = 10
"48167" = 6
"48169" = 9
"48171" = 5
"48173" = 6
"48175" = 8
"48177" = 10
"48179" = 7
"48181" = 7
"48183" = 9
"48185" = 8
"48187" = 6
"48189" = 10
"48191" = 10
"48193" = 9
"48195" = 6
"48197" = 9
"48199" = 5
"48201" = 8
"48203" = 8
"48205" = 2
"48207" = 10
"48209" = 4
"48211" = 3
"48213" = 9
"48215" = 10
"48217" = 9
"48219" = 9
"48221" = 6
"48223" = 8
"48225" = 10
"48227" = 10
"48229" = 10
"48231" = 8
"48233" = 6
"48235" = 5
"48237" = 6
"48239" = 7
"48241" = 9
"48243" = 9
"48245" = 9
"48247" = 10
"48249" = 10
"48251" = 5
"48253" = 10
"48255" = 10
"48257" = 5
"48259" = 3
"48261" = 7
"48263" = 3
"48265" = 8
"48267" = 10
"48269" = 7
"48271" = 10
"48273" = 10
"48275" = 10
"48277" = 10
"48279" = 10
"48281" = 7
"48283" = 10
"48285" = 7
"48287" = 5
"48289" = 8
"48291" = 8
"48293" = 9
"48295" = 7
"48297" = 8
"48299" = 8
"48301" = 2
"48303" = 9
"48305" = 10
"48307" = 10
"48309" = 9
"48311" = 4
"48313" = 9
"48315" = 10
"48317" = 9
"48319" = 8
"48321" = 9
"48323" = 10
"48325" = 8
"48327" = 10
"48329" = 8
"48331" = 9
"48333" = 9
"48335" = 9
"48337" = 8
"48339" = 4
"48341" = 6
"48343" = 9
"48345" = 8
"48347" = 9
"48349" = 9
"48351" = 10
"48353" = 10
"48355" = 10
"48357" = 5
"48359" = 6
"48361" = 8
"48363" = 9
"48365" = 7
"48367" = 5
"48369" = 7
"48371" = 10
"48373" = 10
"48375" = 10
"48377" = 10
"48379" = 8
"48381" = 2
"48383" = 6
"48385" = 10
"48387" = 10
"48389" = 10
"48391" = 8
"48393" = 2
"48395" = 10
"48397" = 2
"48399" = 9
"48401" = 7
"48403" = 10
"48405" = 10
"48407" = 9
"48409" = 9
"48411" = 10
"48413" = 8
"48415" = 9
"48417" = 6
"48419" = 9
"48421" = 5
"48423" = 7
"48425" = 4
"48427" = 10
"48429" = 10
"48431" = 5
"48433" = 8
"48435" = 6
"48437" = 10
"48439" = 6
"48441" = 8
"48443" = 9
"48445" = 10
"48447" = 6
"48449" = 8
"48451" = 9
"48453" = 6
"48455" = 10
"48457" = 9
"48459" = 9
"48461" = 8
"48463" = 10
"48465" = 10
"48467" = 7
"48469" = 8
"48471" = 8
"48473" = 8
"48475" = 9
"48477" = 6
"48479" = 10
"48481" = 7
"48483" = 8
"48485" = 7
"48487" = 9
"48489" = 10
"48491" = 2
"48493" = 5
"48495" = 8
"48497" = 4
"48499" = 9
"48501" = 7
"48503" = 9
"48505" = 10
"48507" = 10
"49001" = 3
"49003" = 2
"49005" = 2
"49007" = 5
"49009" = 1
"49011" = 2
"49013" = 6
"49015" = 4
"49017" = 4
"49019" = 7
"49021" = 6
"49023" = 3
"49025" = 3
"49027" = 4
"49029" = 1
"49031" = 6
"49033" = 2
"49035" = 3
"49037" = 9
"49039" = 5
"49041" = 5
"49043" = 1
"49045" = 2
"49047" = 5
"49049" = 3
"49051" = 2
"49053" = 5
"49055" = 5
"49057" = 3
"50001" = 2
"50003" = 4
"50005" = 6
"50007" = 1
"50009" = 7
"50011" = 3
"50013" = 2
"50015" = 3
"50017" = 3
"50019" = 7
"50021" = 4
"50023" = 2
"50025" = 4
"50027" = 3
"51001" = 9
"51003" = 2
"51005" = 5
"51007" = 4
"51009" = 5
"51011" = 6
"51013" = 2
"51015" = 2
"51017" = 2
"51019" = 2
"51021" = 5
"51023" = 1
"51025" = 9
"51027" = 10
"51029" = 8
"51031" = 5
"51033" = 5
"51035" = 8
"51036" = 5
"51037" = 9
"51041" = 2
"51043" = 1
"51045" = 4
"51047" = 3
"51049" = 8
"51051" = 9
"51053" = 4
"51057" = 7
"51059" = 1
"51061" = 1
"51063" = 5
"51065" = 2
"51067" = 6
"51069" = 2
"51071" = 5
"51073" = 3
"51075" = 2
"51077" = 9
"51079" = 2
"51081" = 6
"51083" = 9
"51085" = 1
"51087" = 2
"51089" = 7
"51091" = 5
"51093" = 4
"51095" = 2
"51097" = 5
"51099" = 2
"51101" = 2
"51103" = 8
"51105" = 10
"51107" = 1
"51109" = 4
"51111" = 8
"51113" = 4
"51115" = 4
"51117" = 8
"51119" = 7
"51121" = 4
"51125" = 5
"51127" = 2
"51131" = 10
"51133" = 8
"51135" = 8
"51137" = 3
"51139" = 5
"51141" = 7
"51143" = 6
"51145" = 1
"51147" = 8
"51149" = 2
"51153" = 1
"51155" = 7
"51157" = 2
"51159" = 7
"51161" = 2
"51163" = 4
"51165" = 3
"51167" = 9
"51169" = 7
"51171" = 3
"51173" = 8
"51175" = 7
"51177" = 1
"51179" = 1
"51181" = 5
"51183" = 8
"51185" = 9
"51187" = 3
"51191" = 6
"51193" = 8
"51195" = 10
"51197" = 7
"51199" = 1
"51510" = 4
"51515" = 8
"51520" = 10
"51530" = 5
"51540" = 8
"51550" = 3
"51570" = 2
"51580" = 7
"51590" = 10
"51595" = 9
"51600" = 1
"51610" = 1
"51620" = 10
"51630" = 7
"51640" = 10
"51650" = 6
"51660" = 7
"51670" = 9
"51678" = 4
"51680" = 9
"51683" = 2
"51685" = 2
"51690" = 9
"51700" = 7
"51710" = 10
"51720" = 10
"51730" = 10
"51735" = 1
"51740" = 9
"51750" = 5
"51760" = 10
"51770" = 10
"51775" = 3
"51790" = 7
"51800" = 5
"51810" = 2
"51820" = 7
"51830" = 7
"51840" = 6
"53001" = 8
"53003" = 8
"53005" = 4
"53007" = 6
"53009" = 6
"53011" = 4
"53013" = 7
"53015" = 6
"53017" = 5
"53019" = 9
"53021" = 8
"53023" = 5
"53025" = 8
"53027" = 8
"53029" = 2
"53031" = 6
"53033" = 3
"53035" = 3
"53037" = 4
"53039" = 7
"53041" = 7
"53043" = 5
"53045" = 6
"53047" = 10
"53049" = 8
"53051" = 9
"53053" = 4
"53055" = 4
"53057" = 5
"53059" = 5
"53061" = 3
"53063" = 6
"53065" = 8
"53067" = 3
"53069" = 4
"53071" = 7
"53073" = 5
"53075" = 4
"53077" = 9
"54001" = 10
"54003" = 6
"54005" = 10
"54007" = 10
"54009" = 5
"54011" = 9
"54013" = 10
"54015" = 10
"54017" = 10
"54019" = 10
"54021" = 10
"54023" = 8
"54025" = 9
"54027" = 8
"54029" = 5
"54031" = 7
"54033" = 9
"54035" = 8
"54037" = 3
"54039" = 9
"54041" = 10
"54043" = 10
"54045" = 10
"54047" = 10
"54049" = 9
"54051" = 8
"54053" = 9
"54055" = 10
"54057" = 8
"54059" = 10
"54061" = 6
"54063" = 8
"54065" = 5
"54067" = 10
"54069" = 7
"54071" = 7
"54073" = 5
"54075" = 9
"54077" = 9
"54079" = 4
"54081" = 10
"54083" = 9
"54085" = 9
"54087" = 10
"54089" = 10
"54091" = 9
"54093" = 8
"54095" = 9
"54097" = 10
"54099" = 10
"54101" = 10
"54103" = 9
"54105" = 10
"54107" = 8
"54109" = 10
"55001" = 6
"55003" = 6
"55005" = 3
"55007" = 4
"55009" = 2
"55011" = 2
"55013" = 5
"55015" = 1
"55017" = 3
"55019" = 5
"55021" = 1
"55023" = 4
"55025" = 2
"55027" = 1
"55029" = 2
"55031" = 5
"55033" = 3
"55035" = 2
"55037" = 2
"55039" = 1
"55041" = 4
"55043" = 3
"55045" = 2
"55047" = 3
"55049" = 2
"55051" = 4
"55053" = 3
"55055" = 1
"55057" = 4
"55059" = 3
"55061" = 1
"55063" = 2
"55065" = 3
"55067" = 4
"55069" = 2
"55071" = 2
"55073" = 2
"55075" = 3
"55077" = 3
"55078" = 10
"55079" = 9
"55081" = 4
"55083" = 2
"55085" = 2
"55087" = 1
"55089" = 1
"55091" = 3
"55093" = 1
"55095" = 2
"55097" = 2
"55099" = 3
"55101" = 3
"55103" = 4
"55105" = 3
"55107" = 5
"55109" = 1
"55111" = 2
"55113" = 6
"55115" = 3
"55117" = 1
"55119" = 3
"55121" = 2
"55123" = 5
"55125" = 3
"55127" = 2
"55129" = 4
"55131" = 1
"55133" = 1
"55135" = 2
"55137" = 4
"55139" = 1
"55141" = 2
"56001" = 5
"56003" = 7
"56005" = 2
"56007" = 5
"56009" = 4
"56011" = 2
"56013" = 7
"56015" = 7
"56017" = 5
"56019" = 4
"56021" = 4
"56023" = 3
"56025" = 6
"56027" = 7
"56029" = 5
"56031" = 5
"56033" = 5
"56035" = 2
"56037" = 3
"56039" = 1
"56041" = 4
"56043" = 5
"56045" = 3
OTHER = 0
;

RUN;





